#!/usr/bin/env python
# -*- coding: utf-8 -*- 

#
# Copyright 2013, 2014, 2016, 2017 Guenter Bartsch
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
# random tokenization / nlp pre-processing related stuff
#

import sys
import re
import unittest
import logging
from num2words import num2words

def detect_latin1 (fn):

    f = open(fn)

    l1ucnt = 0

    for line in f:

        for c in line:

            o = ord(c)
            if o == 0xc4 or o == 0xd6 or o == 0xdc or o == 0xe4 or o==0xf6 or o==0xfc or o==0xdf:
                l1ucnt += 1


    f.close()

    return l1ucnt > 1

def compress_ws (s):

        vc = True

        res = ''

        for c in s:

                if c == ' ':
                        vc = False
                else:
                        if vc:
                                res = res + c
                        else:
                                res = res + ' ' + c
                        vc = True

        return res 

def isgalnum (s):

    for c in s:
        if c.isalnum():
            continue

        if c == u'%' or c ==u'§':
            continue

        return False

    return True

#####################################################################
#
# tokenizer commons
#
#####################################################################

PERCENT_PATTERN_START = re.compile(r"^[-]?\d+[,.]?\d*\s*[%]")
PERCENT_PATTERN_SPACE = re.compile(r"\s[-]?\d+[,.]?\d*\s*[%]")

NUMBER_PATTERN_START = re.compile(r"^[-]?\d+[,.]?\d*")
NUMBER_PATTERN_SPACE = re.compile(r"\s[-]?\d+[,.]?\d*")

PUNCTUATION = [
    u',', u'.', u';',  
    u'?', u'!', 
    u'+', u'-', u'*', u'#', u'=', u'|'
    u'/', u'\\',  
    u'[', u']', u'(', u')', u'»', u'«', u'<', u'>', 
    u'\'', u'"',
]

MACRO_PUNCTUATION = [
    u'@', u':'
]

#####################################################################
#
# english tokenizer
#
#####################################################################

# word replacement table
wrt_en = { u'0'          : u'zero',
           u'1'          : u'one',
           u'colour'     : u'color',
           u'okay'       : u'ok',
         }

symb_abbrev_norm_en = [
                       (u'\ufeff'  , u' '),
                       (u'\u2019'  , u"'"),
                       (u'\xa0'    , u' '),
                       (u'\u203a'  , u' '),
                       (u'\u2039'  , u' '),
                       (u'&'       , u'and'),
                       (u'\xa020'  , u' '),
                       (u'„'       , u' '),
                       (u'“'       , u' '),
                       (u'$'       , u'dollar ')
                      ]

def spellout_number_en (m):

    numstr = m.group(0)

    if numstr[0].isspace():
        numstr = numstr[1:]
        res = ' '
    else:
        res = ''

    if numstr[0] == '-':
        res += 'minus '
        numstr = numstr[1:].strip()

    if not '.' in numstr:
        numstr = numstr.replace(',','.')

    if numstr.endswith('%'):
        numstr = numstr[:len(numstr)-1]
        percent = True
    else:
        percent = False

    parts = numstr.split ('.')

    # print repr(parts)

    res += num2words(int(parts[0]))

    if len(parts)>1 and len(parts[1])>0:

        # spell out fractional part in digits

        res += ' point ' + num2words(int(parts[1]))

    if percent:
        res += ' percent'

    return res

APOSTROPHE_S_PATTERN1 = re.compile(r"\w\w+[']s\s")
APOSTROPHE_S_PATTERN2 = re.compile(r"\w\w+[']s$")
APOSTROPHE_S_PATTERN3 = re.compile(r"\w\w+[']s[,.;:]")

def protect_apostrophe_s (m):

    s = m.group(0)

    return s.replace(u"'s", u"✓s")

APOSTROPHE_NT_PATTERN1 = re.compile(r"\wn[']t\s")
APOSTROPHE_NT_PATTERN2 = re.compile(r"\wn[']t$")
APOSTROPHE_NT_PATTERN3 = re.compile(r"\wn[']t[,.;:]")

def protect_apostrophe_nt (m):

    s = m.group(0)

    return s.replace(u"n't", u"n✓t")

APOSTROPHE_D_PATTERN1 = re.compile(r"\w[']d\s")
APOSTROPHE_D_PATTERN2 = re.compile(r"\w[']d$")
APOSTROPHE_D_PATTERN3 = re.compile(r"\w[']d[,.;:]")

def protect_apostrophe_d (m):

    s = m.group(0)

    return s.replace(u"'d", u"✓d")

APOSTROPHE_RE_PATTERN1 = re.compile(r"\w[']re\s")
APOSTROPHE_RE_PATTERN2 = re.compile(r"\w[']re$")
APOSTROPHE_RE_PATTERN3 = re.compile(r"\w[']re[,.;:]")

def protect_apostrophe_re (m):

    s = m.group(0)

    return s.replace(u"'re", u"✓re")

APOSTROPHE_LL_PATTERN1 = re.compile(r"\w[']ll\s")
APOSTROPHE_LL_PATTERN2 = re.compile(r"\w[']ll$")
APOSTROPHE_LL_PATTERN3 = re.compile(r"\w[']ll[,.;:]")

def protect_apostrophe_ll (m):

    s = m.group(0)

    return s.replace(u"'ll", u"✓ll")

def tokenize_en (s, keep_punctuation=False, keep_macros=False, keep_underscores=True):

    global wrt_en, symb_abbrev_norm_en

    for san in symb_abbrev_norm_en:
        srch = san[0]
        repl = san[1]

        s = s.replace (srch, repl)

    s = s.lower()

    # deal with numbers
    s = PERCENT_PATTERN_START.sub(spellout_number_en, s)
    s = PERCENT_PATTERN_SPACE.sub(spellout_number_en, s)

    s = NUMBER_PATTERN_START.sub(spellout_number_en, s)
    s = NUMBER_PATTERN_SPACE.sub(spellout_number_en, s)

    # deal with apostrophe-s
    s = APOSTROPHE_S_PATTERN1.sub(protect_apostrophe_s, s)
    s = APOSTROPHE_S_PATTERN2.sub(protect_apostrophe_s, s)
    s = APOSTROPHE_S_PATTERN3.sub(protect_apostrophe_s, s)

    # deal with apostrophe-nt
    s = APOSTROPHE_NT_PATTERN1.sub(protect_apostrophe_nt, s)
    s = APOSTROPHE_NT_PATTERN2.sub(protect_apostrophe_nt, s)
    s = APOSTROPHE_NT_PATTERN3.sub(protect_apostrophe_nt, s)

    # deal with apostrophe-d (I'd we'd)
    s = APOSTROPHE_D_PATTERN1.sub(protect_apostrophe_d, s)
    s = APOSTROPHE_D_PATTERN2.sub(protect_apostrophe_d, s)
    s = APOSTROPHE_D_PATTERN3.sub(protect_apostrophe_d, s)

    # deal with apostrophe-re (we're they're)
    s = APOSTROPHE_RE_PATTERN1.sub(protect_apostrophe_re, s)
    s = APOSTROPHE_RE_PATTERN2.sub(protect_apostrophe_re, s)
    s = APOSTROPHE_RE_PATTERN3.sub(protect_apostrophe_re, s)

    # deal with apostrophe-ll (we'll they'll)
    s = APOSTROPHE_LL_PATTERN1.sub(protect_apostrophe_ll, s)
    s = APOSTROPHE_LL_PATTERN2.sub(protect_apostrophe_ll, s)
    s = APOSTROPHE_LL_PATTERN3.sub(protect_apostrophe_ll, s)

    # I'm, I've
    s = s.replace (u"i'm", u'i✓m')
    s = s.replace (u"i've", u'i✓ve')

    # deal with punctuation
    if keep_punctuation:
        for p in PUNCTUATION:
            s = s.replace (p, u' ' + p + u' ')
    else:
        for p in PUNCTUATION:
            s = s.replace(p,' ')
        if not keep_macros:
            for p in MACRO_PUNCTUATION:
                s = s.replace(p,' ')
        if not keep_underscores:
            s = s.replace('_',' ')

    # re-insert apostrophes
    s = s.replace (u'✓', u"'")

    res = []

    words = re.split ('\s+', s)

    # print repr(words)

    for word in words:

        w = word.rstrip().replace(u'–',u'')
        if len(w) > 0:

            if w in wrt_en:
                w = wrt_en[w]
        
                words2 = re.split('\s+', w)
                for w2 in words2:
                    res.append(w2)

            else:
                res.append (w)

    return res

#####################################################################
#
# german tokenizer
#
#####################################################################

# word replacement table
wrt = { u'0'             : u'null',
        u'10%'           : u'zehn prozent',
        u'100%'          : u'hundert prozent',
        u'1700'          : u'siebzehnhundert',
        u'1825'          : u'achtzehnhundertfünfundzwanzig',
        u'1949'          : u'neunzehnhundertneunundvierzig',
        u'1960ER'        : u'neunzehnhundertsechziger',
        u'1970ER'        : u'neunzehnhundertsiebziger',
        u'1970ERJAHREN'  : u'neunzehnhundertsiebziger jahren',
        u'1977'          : u'neunzehnhundertsiebenundsiebzig',
        u'1979'          : u'neunzehnhundertneunundsiebzig',
        u'1980ER'        : u'neunzehnhundertachtziger',
        u'1983'          : u'neunzehnhundertdreiundachtzig',
        u'1984'          : u'neunzehnhundertvierundachtzig',
        u'1989'          : u'neunzehnhundertneunundachtzig',
        u'1990'          : u'neunzehnhundertneunzig',
        u'1990ER'        : u'neunzehnhundertneunziger',
        u'1991'          : u'neunzehnhunderteinundneunzig',
        u'1993'          : u'neunzehnhundertdreiundneunzig',
        u'1998'          : u'neunzehnhundertachtundneunzig',
        u'2%'            : u'zwei prozent', 
        u'40%'           : u'vierzig prozent', 
        u'80%'           : u'achtzig prozent',
        u'800'           : u'achthundert',
        u'80ER'          : u'achtziger',

        # old spellings extracted from wiktionary

        u'abbat'            : u'abbot',
        u'abbauprozeß'      : u'abbauprozess',
        u'abbißt'           : u'abbisst',
        u'abbiß'            : u'abbiss',
        u'abblaßten'        : u'abblassten',
        u'abblaßtest'       : u'abblasstest',
        u'abblaßtet'        : u'abblasstet',
        u'abblaßte'         : u'abblasste',
        u'abblaßt'          : u'abblasst',
        u'abdaßler'         : u'abdassler',
        u'abdaßlest'        : u'abdasslest',
        u'abdaßlet'         : u'abdasslet',
        u'abdaßle'          : u'abdassle',
        u'abdaßlung'        : u'abdasslung',
        u'abdroßlest'       : u'abdrosslest',
        u'abdroßlet'        : u'abdrosslet',
        u'abdroßle'         : u'abdrossle',
        u'abdroßlung'       : u'abdrosslung',
        u'abendimbiß'       : u'abendimbiss',
        u'abend'            : u'abend',
        u'abeßt'            : u'abesst',
        u'abfalladung'      : u'abfallladung',
        u'abfallager'       : u'abfalllager',
        u'abfallaster'      : u'abfalllaster',
        u'abfalleerung'     : u'abfallleerung',
        u'abfaßen'          : u'abfassen',
        u'abfaßten'         : u'abfassten',
        u'abfaßtest'        : u'abfasstest',
        u'abfaßtet'         : u'abfasstet',
        u'abfaßte'          : u'abfasste',
        u'abfaßt'           : u'abfasst',
        u'abfloßt'          : u'abflosst',
        u'abfloß'           : u'abfloss',
        u'abflußbecken'     : u'abflussbecken',
        u'abflußgebiet'     : u'abflussgebiet',
        u'abflußgraben'     : u'abflussgraben',
        u'abflußhahn'       : u'abflusshahn',
        u'abflußkanal'      : u'abflusskanal',
        u'abflußkoeffizient': u'abflusskoeffizient',
        u'abflußleitung'    : u'abflussleitung',
        u'abflußloch'       : u'abflussloch',
        u'abflußlosem'      : u'abflusslosem',
        u'abflußlosen'      : u'abflusslosen',
        u'abflußloser'      : u'abflussloser',
        u'abflußloses'      : u'abflussloses',
        u'abflußlose'       : u'abflusslose',
        u'abflußlos'        : u'abflusslos',
        u'abflußregime'     : u'abflussregime',
        u'abflußreiniger'   : u'abflussreiniger',
        u'abflußrinnen'     : u'abflussrinnen',
        u'abflußrinne'      : u'abflussrinne',
        u'abflußrohren'     : u'abflussrohren',
        u'abflußrohres'     : u'abflussrohres',
        u'abflußrohre'      : u'abflussrohre',
        u'abflußrohrs'      : u'abflussrohrs',
        u'abflußrohr'       : u'abflussrohr',
        u'abflußsystem'     : u'abflusssystem',
        u'abfluß'           : u'abfluss',
        u'abflußventil'     : u'abflussventil',
        u'abfreßt'          : u'abfresst',
        u'abfrißt'          : u'abfrisst',
        u'abgabeschluß'     : u'abgabeschluss',
        u'abgeblaßt'        : u'abgeblasst',
        u'abgefaßt'         : u'abgefasst',
        u'abgeküßt'         : u'abgeküsst',
        u'abgepaßtem'       : u'abgepasstem',
        u'abgepaßten'       : u'abgepassten',
        u'abgepaßter'       : u'abgepasster',
        u'abgepaßtes'       : u'abgepasstes',
        u'abgepaßte'        : u'abgepasste',
        u'abgepaßt'         : u'abgepasst',
        u'abgepreßt'        : u'abgepresst',
        u'abgeschloßnerem'  : u'abgeschlossnerem',
        u'abgeschloßneren'  : u'abgeschlossneren',
        u'abgeschloßnerer'  : u'abgeschlossnerer',
        u'abgeschloßneres'  : u'abgeschlossneres',
        u'abgeschloßnere'   : u'abgeschlossnere',
        u'abgoßt'           : u'abgosst',
        u'abgoß'            : u'abgoss',
        u'abgrundhäßlich'   : u'abgrundhässlich',
        u'abgußsammlung'    : u'abgusssammlung',
        u'abguß'            : u'abguss',
        u'abißt'            : u'abisst',
        u'abkühlungsprozeß' : u'abkühlungsprozess',
        u'abküßten'         : u'abküssten',
        u'abküßtest'        : u'abküsstest',
        u'abküßtet'         : u'abküsstet',
        u'abküßte'          : u'abküsste',
        u'abküßt'           : u'abküsst',
        u'ablaßbriefen'     : u'ablassbriefen',
        u'ablaßbriefes'     : u'ablassbriefes',
        u'ablaßbriefe'      : u'ablassbriefe',
        u'ablaßbriefs'      : u'ablassbriefs',
        u'ablaßbrief'       : u'ablassbrief',
        u'ablaßhahn'        : u'ablasshahn',
        u'ablaßhandels'     : u'ablasshandels',
        u'ablaßhandel'      : u'ablasshandel',
        u'ablaßhändler'     : u'ablasshändler',
        u'ablaßjahr'        : u'ablassjahr',
        u'ablaßkrämer'      : u'ablasskrämer',
        u'ablaßlehre'       : u'ablasslehre',
        u'ablaßpraxis'      : u'ablasspraxis',
        u'ablaßprediger'    : u'ablassprediger',
        u'ablaßrohr'        : u'ablassrohr',
        u'ablaßschraube'    : u'ablassschraube',
        u'ablaßstreit'      : u'ablassstreit',
        u'ablaßt'           : u'ablasst',
        u'abläßt'           : u'ablässt',
        u'ablaß'            : u'ablass',
        u'ablaßventil'      : u'ablassventil',
        u'ablaßvorrichtung' : u'ablassvorrichtung',
        u'ablaßwesen'       : u'ablasswesen',
        u'ablaßzettel'      : u'ablasszettel',
        u'ablehnungsbeschluß': u'ablehnungsbeschluss',
        u'ablösungsprozeß'  : u'ablösungsprozess',
        u'abmeßt'           : u'abmesst',
        u'abmißt'           : u'abmisst',
        u'abnabelungsprozeß': u'abnabelungsprozess',
        u'abpaßten'         : u'abpassten',
        u'abpaßtest'        : u'abpasstest',
        u'abpaßtet'         : u'abpasstet',
        u'abpaßte'          : u'abpasste',
        u'abpaßt'           : u'abpasst',
        u'abpreßten'        : u'abpressten',
        u'abpreßtest'       : u'abpresstest',
        u'abpreßtet'        : u'abpresstet',
        u'abpreßte'         : u'abpresste',
        u'abpreßt'          : u'abpresst',
        u'abrißanträgen'    : u'abrissanträgen',
        u'abrißantrages'    : u'abrissantrages',
        u'abrißantrage'     : u'abrissantrage',
        u'abrißanträge'     : u'abrissanträge',
        u'abrißantrags'     : u'abrissantrags',
        u'abrißantrag'      : u'abrissantrag',
        u'abrißarbeiten'    : u'abrissarbeiten',
        u'abrißbagger'      : u'abrissbagger',
        u'abrißbirnen'      : u'abrissbirnen',
        u'abrißbirne'       : u'abrissbirne',
        u'abrißfirma'       : u'abrissfirma',
        u'abrißgenehmigung' : u'abrissgenehmigung',
        u'abrißhaus'        : u'abrisshaus',
        u'abrißobjekt'      : u'abrissobjekt',
        u'abrißstopp'       : u'abrissstopp',
        u'abrißt'           : u'abrisst',
        u'abriß'            : u'abriss',
        u'abrißunternehmen' : u'abrissunternehmen',
        u'abschiedskuß'     : u'abschiedskuss',
        u'abschloßt'        : u'abschlosst',
        u'abschloß'         : u'abschloss',
        u'abschlußabend'    : u'abschlussabend',
        u'abschlußarbeiten' : u'abschlussarbeiten',
        u'abschlußarbeit'   : u'abschlussarbeit',
        u'abschlußbällen'   : u'abschlussbällen',
        u'abschlußballes'   : u'abschlussballes',
        u'abschlußballe'    : u'abschlussballe',
        u'abschlußbälle'    : u'abschlussbälle',
        u'abschlußballs'    : u'abschlussballs',
        u'abschlußball'     : u'abschlussball',
        u'abschlußberichten': u'abschlussberichten',
        u'abschlußberichtes': u'abschlussberichtes',
        u'abschlußberichte' : u'abschlussberichte',
        u'abschlußberichts' : u'abschlussberichts',
        u'abschlußbericht'  : u'abschlussbericht',
        u'abschlußbilanz'   : u'abschlussbilanz',
        u'abschlußdatum'    : u'abschlussdatum',
        u'abschlußdebatte'  : u'abschlussdebatte',
        u'abschlußerklärung': u'abschlusserklärung',
        u'abschlußexamen'   : u'abschlussexamen',
        u'abschlußfahrt'    : u'abschlussfahrt',
        u'abschlußfeiern'   : u'abschlussfeiern',
        u'abschlußfeier'    : u'abschlussfeier',
        u'abschlußfest'     : u'abschlussfest',
        u'abschlußgala'     : u'abschlussgala',
        u'abschlußjahren'   : u'abschlussjahren',
        u'abschlußjahres'   : u'abschlussjahres',
        u'abschlußjahre'    : u'abschlussjahre',
        u'abschlußjahrs'    : u'abschlussjahrs',
        u'abschlußjahr'     : u'abschlussjahr',
        u'abschlußkappen'   : u'abschlusskappen',
        u'abschlußkappe'    : u'abschlusskappe',
        u'abschlußklasse'   : u'abschlussklasse',
        u'abschlußkonzert'  : u'abschlusskonzert',
        u'abschlußkundgebung': u'abschlusskundgebung',
        u'abschlußparty'    : u'abschlussparty',
        u'abschlußphase'    : u'abschlussphase',
        u'abschlußprojekt'  : u'abschlussprojekt',
        u'abschlußprüfungen': u'abschlussprüfungen',
        u'abschlußprüfung'  : u'abschlussprüfung',
        u'abschlußrechnung' : u'abschlussrechnung',
        u'abschlußreden'    : u'abschlussreden',
        u'abschlußrede'     : u'abschlussrede',
        u'abschlußsitzung'  : u'abschlusssitzung',
        u'abschlußspiel'    : u'abschlussspiel',
        u'abschlußtrainings': u'abschlusstrainings',
        u'abschlußtraining' : u'abschlusstraining',
        u'abschlußtreffen'  : u'abschlusstreffen',
        u'abschluß'         : u'abschluss',
        u'abschluß'      : u'abschluss',
        u'abschlußveranstaltung': u'abschlussveranstaltung',
        u'abschlußvorstellung': u'abschlussvorstellung',
        u'abschlußzahlung'  : u'abschlusszahlung',
        u'abschlußzensur'   : u'abschlusszensur',
        u'abschlußzeremonie': u'abschlusszeremonie',
        u'abschlußzeugnissen': u'abschlusszeugnissen',
        u'abschlußzeugnisses': u'abschlusszeugnisses',
        u'abschlußzeugnisse': u'abschlusszeugnisse',
        u'abschlußzeugnis'  : u'abschlusszeugnis',
        u'abschmißt'        : u'abschmisst',
        u'abschmiß'         : u'abschmiss',
        u'abschoßt'         : u'abschosst',
        u'abschoß'          : u'abschoss',
        u'abschußbasen'     : u'abschussbasen',
        u'abschußbasis'     : u'abschussbasis',
        u'abschußbefehlen'  : u'abschussbefehlen',
        u'abschußbefehles'  : u'abschussbefehles',
        u'abschußbefehle'   : u'abschussbefehle',
        u'abschußbefehls'   : u'abschussbefehls',
        u'abschußbefehl'    : u'abschussbefehl',
        u'abschußbereit'    : u'abschussbereit',
        u'abschußbewilligung': u'abschussbewilligung',
        u'abschußkontingent': u'abschusskontingent',
        u'abschußlisten'    : u'abschusslisten',
        u'abschußliste'     : u'abschussliste',
        u'abschußplan'      : u'abschussplan',
        u'abschußprämien'   : u'abschussprämien',
        u'abschußprämie'    : u'abschussprämie',
        u'abschußquote'     : u'abschussquote',
        u'abschußrampen'    : u'abschussrampen',
        u'abschußrampe'     : u'abschussrampe',
        u'abschußsilo'      : u'abschusssilo',
        u'abschuß'          : u'abschuss',
        u'abschußvorrichtung': u'abschussvorrichtung',
        u'abschußziffer'    : u'abschussziffer',
        u'abszeß'           : u'abszess',
        u'abwägungsbeschluß': u'abwägungsbeschluss',
        u'acajounuß'        : u'acajounuss',
        u'accusativs'       : u'akkusativs',
        u'accusativ'        : u'akkusativ',
        u'achillessehnenriß': u'achillessehnenriss',
        u'achselsproß'      : u'achselspross',
        u'achtkläßlerin'    : u'achtklässlerin',
        u'achtkläßler'      : u'achtklässler',
        u'activs'           : u'aktivs',
        u'activ'            : u'aktiv',
        u'aderlaß'          : u'aderlass',
        u'adhäsionsprozeß'  : u'adhäsionsprozess',
        u'adhäsionsverschluß': u'adhäsionsverschluss',
        u'adreßänderung'    : u'adressänderung',
        u'adreßbeschaffung' : u'adressbeschaffung',
        u'adreßbestand'     : u'adressbestand',
        u'adreßbüchern'     : u'adressbüchern',
        u'adreßbücher'      : u'adressbücher',
        u'adreßbuches'      : u'adressbuches',
        u'adreßbuche'       : u'adressbuche',
        u'adreßbüchlein'    : u'adressbüchlein',
        u'adreßbuchs'       : u'adressbuchs',
        u'adreßbuch'        : u'adressbuch',
        u'adreßbuchverlag'  : u'adressbuchverlag',
        u'adreßbüro'        : u'adressbüro',
        u'adreßliste'       : u'adressliste',
        u'adreßsammlung'    : u'adresssammlung',
        u'adreßverzeichnis' : u'adressverzeichnis',
        u'adventivsproß'    : u'adventivspross',
        u'aegypten'         : u'ägypten',
        u'aethers'          : u'äthers',
        u'affengeschiß'     : u'affengeschiss',
        u'africanerin'      : u'afrikanerin',
        u'africaner'        : u'afrikaner',
        u'africanisch'      : u'afrikanisch',
        u'africa'           : u'afrika',
        u'afterrüßler'      : u'afterrüssler',
        u'after-shave'      : u'aftershave',
        u'agrarüberschuß'   : u'agrarüberschuss',
        u'agribusineß'      : u'agribusiness',
        u'agrobusineß'      : u'agrobusiness',
        u'ahnenpaß'         : u'ahnenpass',
        u'airhosteß'        : u'airhostess',
        u'aktionsausschuß'  : u'aktionsausschuss',
        u'aktivprozeß'      : u'aktivprozess',
        u'aktschluß'        : u'aktschluss',
        u'akzelerationsprozeß': u'akzelerationsprozess',
        u'akzeß'            : u'akzess',
        u'alfalfasproß'     : u'alfalfaspross',
        u'alkoholeinfluß'   : u'alkoholeinfluss',
        u'alkoholexzeß'     : u'alkoholexzess',
        u'alkoholgenuß'     : u'alkoholgenuss',
        u'alkoholmißbräuchen': u'alkoholmissbräuchen',
        u'alkoholmißbrauches': u'alkoholmissbrauches',
        u'alkoholmißbrauche': u'alkoholmissbrauche',
        u'alkoholmißbräuche': u'alkoholmissbräuche',
        u'alkoholmißbrauchs': u'alkoholmissbrauchs',
        u'alkoholmißbrauch' : u'alkoholmissbrauch',
        u'allelujah'        : u'alleluja',
        u'allergiepaß'      : u'allergiepass',
        u'allerseelenablaß' : u'allerseelenablass',
        u'alpenpaß'         : u'alpenpass',
        u'altarkuß'         : u'altarkuss',
        u'alterthums'       : u'altertums',
        u'alterthum'        : u'altertum',
        u'alterungsprozeß'  : u'alterungsprozess',
        u'altwienerisch'    : u'alt-wienerisch',
        u'amboßbahn'        : u'ambossbahn',
        u'ambößchen'        : u'ambösschen',
        u'amboßeinsatz'     : u'ambosseinsatz',
        u'amboßfuß'         : u'ambossfuß',
        u'amboßklotz'       : u'ambossklotz',
        u'amboßrüttler'     : u'ambossrüttler',
        u'amboßstock'       : u'ambossstock',
        u'amboß'            : u'amboss',
        u'americanerin'     : u'amerikanerin',
        u'americaner'       : u'amerikaner',
        u'americanisch'     : u'amerikanisch',
        u'america'          : u'amerika',
        u'amtsmißbrauch'    : u'amtsmissbrauch',
        u'analoganschluß'   : u'analoganschluss',
        u'analogieschluß'   : u'analogieschluss',
        u'anbißt'           : u'anbisst',
        u'anbiß'            : u'anbiss',
        u'anbraßten'        : u'anbrassten',
        u'anbraßtest'       : u'anbrasstest',
        u'anbraßtet'        : u'anbrasstet',
        u'anbraßte'         : u'anbrasste',
        u'anbraßt'          : u'anbrasst',
        u'aneinanderfeßlest': u'aneinanderfesslest',
        u'aneinanderfeßlet' : u'aneinanderfesslet',
        u'aneinanderfeßle'  : u'aneinanderfessle',
        u'aneinandergepaßt' : u'aneinandergepasst',
        u'aneinandergepreßt': u'aneinandergepresst',
        u'aneinanderpaßten' : u'aneinanderpassten',
        u'aneinanderpaßtest': u'aneinanderpasstest',
        u'aneinanderpaßtet' : u'aneinanderpasstet',
        u'aneinanderpaßte'  : u'aneinanderpasste',
        u'aneinanderpaßt'   : u'aneinanderpasst',
        u'aneinanderpreßten': u'aneinanderpressten',
        u'aneinanderpreßtest': u'aneinanderpresstest',
        u'aneinanderpreßtet': u'aneinanderpresstet',
        u'aneinanderpreßte' : u'aneinanderpresste',
        u'aneinanderpreßt'  : u'aneinanderpresst',
        u'aneinanderschloßt': u'aneinanderschlosst',
        u'aneinanderschloß' : u'aneinanderschloss',
        u'aneßt'            : u'anesst',
        u'anfaßten'         : u'anfassten',
        u'anfaßtest'        : u'anfasstest',
        u'anfaßtet'         : u'anfasstet',
        u'anfaßte'          : u'anfasste',
        u'anfaßt'           : u'anfasst',
        u'anfeßlest'        : u'anfesslest',
        u'anfeßlet'         : u'anfesslet',
        u'anfeßle'          : u'anfessle',
        u'anfloßt'          : u'anflosst',
        u'anfloß'           : u'anfloss',
        u'anfreßt'          : u'anfresst',
        u'anfrißt'          : u'anfrisst',
        u'angebraßt'        : u'angebrasst',
        u'angefaßt'         : u'angefasst',
        u'angelruthe'       : u'angelrute',
        u'angemeßnerem'     : u'angemessnerem',
        u'angemeßneren'     : u'angemessneren',
        u'angemeßnerer'     : u'angemessnerer',
        u'angemeßneres'     : u'angemessneres',
        u'angemeßnere'      : u'angemessnere',
        u'angepaßtem'       : u'angepasstem',
        u'angepaßten'       : u'angepassten',
        u'angepaßterem'     : u'angepassterem',
        u'angepaßteren'     : u'angepassteren',
        u'angepaßterer'     : u'angepassterer',
        u'angepaßteres'     : u'angepassteres',
        u'angepaßtere'      : u'angepasstere',
        u'angepaßter'       : u'angepasster',
        u'angepaßtestem'    : u'angepasstestem',
        u'angepaßtesten'    : u'angepasstesten',
        u'angepaßtester'    : u'angepasstester',
        u'angepaßtestes'    : u'angepasstestes',
        u'angepaßteste'     : u'angepassteste',
        u'angepaßtes'       : u'angepasstes',
        u'angepaßte'        : u'angepasste',
        u'angepaßtheit'     : u'angepasstheit',
        u'angepaßt'         : u'angepasst',
        u'angepißt'         : u'angepisst',
        u'angepreßtem'      : u'angepresstem',
        u'angepreßten'      : u'angepressten',
        u'angepreßter'      : u'angepresster',
        u'angepreßtes'      : u'angepresstes',
        u'angepreßte'       : u'angepresste',
        u'angepreßt'        : u'angepresst',
        u'anglisierungsprozeß': u'anglisierungsprozess',
        u'angoßt'           : u'angosst',
        u'angoß'            : u'angoss',
        u'anguß'            : u'anguss',
        u'anhängeschloß'    : u'anhängeschloss',
        u'anißt'            : u'anisst',
        u'anlaßfarbe'       : u'anlassfarbe',
        u'anläßlich'        : u'anlässlich',
        u'anläßlich'     : u'anlässlich',
        u'anlaßlosem'       : u'anlasslosem',
        u'anlaßlosen'       : u'anlasslosen',
        u'anlaßloser'       : u'anlassloser',
        u'anlaßloses'       : u'anlassloses',
        u'anlaßlose'        : u'anlasslose',
        u'anlaßlos'         : u'anlasslos',
        u'anlaßt'           : u'anlasst',
        u'anläßt'           : u'anlässt',
        u'anlaß'            : u'anlass',
        u'anlaß'         : u'anlass',
        u'anmeldeschluß'    : u'anmeldeschluss',
        u'anmeßt'           : u'anmesst',
        u'anmißt'           : u'anmisst',
        u'annahmeschluß'    : u'annahmeschluss',
        u'anpaßbar'         : u'anpassbar',
        u'anpaßten'         : u'anpassten',
        u'anpaßtest'        : u'anpasstest',
        u'anpaßtet'         : u'anpasstet',
        u'anpaßte'          : u'anpasste',
        u'anpaßt'           : u'anpasst',
        u'anpassungsprozeß' : u'anpassungsprozess',
        u'anpißten'         : u'anpissten',
        u'anpißtest'        : u'anpisstest',
        u'anpißtet'         : u'anpisstet',
        u'anpißte'          : u'anpisste',
        u'anpißt'           : u'anpisst',
        u'anpreßrolle'      : u'anpressrolle',
        u'anpreßten'        : u'anpressten',
        u'anpreßtest'       : u'anpresstest',
        u'anpreßtet'        : u'anpresstet',
        u'anpreßte'         : u'anpresste',
        u'anpreßt'          : u'anpresst',
        u'anquaßlest'       : u'anquasslest',
        u'anquaßlet'        : u'anquasslet',
        u'anquaßle'         : u'anquassle',
        u'anraßlest'        : u'anrasslest',
        u'anraßlet'         : u'anrasslet',
        u'anraßle'          : u'anrassle',
        u'anrißt'           : u'anrisst',
        u'anriß'            : u'anriss',
        u'anschißt'         : u'anschisst',
        u'anschiß'          : u'anschiss',
        u'anschloßt'        : u'anschlosst',
        u'anschloß'         : u'anschloss',
        u'anschlußbahn'     : u'anschlussbahn',
        u'anschlußbillett'  : u'anschlussbillett',
        u'anschlußbus'      : u'anschlussbus',
        u'anschlußdose'     : u'anschlussdose',
        u'anschlußfertig'   : u'anschlussfertig',
        u'anschlußflug'     : u'anschlussflug',
        u'anschlußgebühr'   : u'anschlussgebühr',
        u'anschlußgleis'    : u'anschlussgleis',
        u'anschlußgoal'     : u'anschlussgoal',
        u'anschlußkabel'    : u'anschlusskabel',
        u'anschlußkonkurs'  : u'anschlusskonkurs',
        u'anschlußlinie'    : u'anschlusslinie',
        u'anschlußprojekt'  : u'anschlussprojekt',
        u'anschlußstelle'   : u'anschlussstelle',
        u'anschlußstrecke'  : u'anschlussstrecke',
        u'anschlußstück'    : u'anschlussstück',
        u'anschlußstutzen'  : u'anschlussstutzen',
        u'anschlußtor'      : u'anschlusstor',
        u'anschlußtreffern' : u'anschlusstreffern',
        u'anschlußtreffers' : u'anschlusstreffers',
        u'anschlußtreffer'  : u'anschlusstreffer',
        u'anschluß'         : u'anschluss',
        u'anschlußverfahrens': u'anschlussverfahrens',
        u'anschlußverfahren': u'anschlussverfahren',
        u'anschlußzügen'    : u'anschlusszügen',
        u'anschlußzuges'    : u'anschlusszuges',
        u'anschlußzuge'     : u'anschlusszuge',
        u'anschlußzüge'     : u'anschlusszüge',
        u'anschlußzugs'     : u'anschlusszugs',
        u'anschlußzug'      : u'anschlusszug',
        u'anschlußzwang'    : u'anschlusszwang',
        u'anschmißt'        : u'anschmisst',
        u'anschmiß'         : u'anschmiss',
        u'anschoßt'         : u'anschosst',
        u'anschoß'          : u'anschoss',
        u'anschovis'        : u'anchovis',
        u'anschuß'          : u'anschuss',
        u'antheil'          : u'anteil',
        u'anwaltsprozeß'    : u'anwaltsprozess',
        u'arachisnuß'       : u'arachisnuss',
        u'arbeitsausschuß'  : u'arbeitsausschuss',
        u'arbeitsgeräth'    : u'arbeitsgerät',
        u'arbeitsgerichtsprozeß': u'arbeitsgerichtsprozess',
        u'arbeitsprozeß'    : u'arbeitsprozess',
        u'arbeitsschluß'    : u'arbeitsschluss',
        u'arekanuß'         : u'arekanuss',
        u'armguß'           : u'armguss',
        u'armuth'           : u'armut',
        u'artilleriebeschuß': u'artilleriebeschuss',
        u'arzneimittelmißbrauch': u'arzneimittelmissbrauch',
        u'aschantinuß'      : u'aschantinuss',
        u'asteroïden'       : u'asteroiden',
        u'as'               : u'ass',
        u'asylmißbräuchen'  : u'asylmissbräuchen',
        u'asylmißbrauches'  : u'asylmissbrauches',
        u'asylmißbrauche'   : u'asylmissbrauche',
        u'asylmißbräuche'   : u'asylmissbräuche',
        u'asylmißbrauchs'   : u'asylmissbrauchs',
        u'asylmißbrauch'    : u'asylmissbrauch',
        u'athem'            : u'atem',
        u'atommüllagern'    : u'atommülllagern',
        u'atommüllagers'    : u'atommülllagers',
        u'atommüllager'     : u'atommülllager',
        u'atommüllagerungen': u'atommülllagerungen',
        u'atommüllagerung'  : u'atommülllagerung',
        u'attractionssphäre': u'attraktionssphäre',
        u'aufbauprozeß'     : u'aufbauprozess',
        u'aufbereitungsprozeß': u'aufbereitungsprozess',
        u'aufbeßrest'       : u'aufbessrest',
        u'aufbeßret'        : u'aufbessret',
        u'aufbeßre'         : u'aufbessre',
        u'aufbißt'          : u'aufbisst',
        u'aufbiß'           : u'aufbiss',
        u'aufbraßten'       : u'aufbrassten',
        u'aufbraßtest'      : u'aufbrasstest',
        u'aufbraßtet'       : u'aufbrasstet',
        u'aufbraßte'        : u'aufbrasste',
        u'aufbraßt'         : u'aufbrasst',
        u'aufeinanderbißt'  : u'aufeinanderbisst',
        u'aufeinanderbiß'   : u'aufeinanderbiss',
        u'aufeinandergepaßtem': u'aufeinandergepasstem',
        u'aufeinandergepaßten': u'aufeinandergepassten',
        u'aufeinandergepaßter': u'aufeinandergepasster',
        u'aufeinandergepaßtes': u'aufeinandergepasstes',
        u'aufeinandergepaßte': u'aufeinandergepasste',
        u'aufeinandergepaßt': u'aufeinandergepasst',
        u'aufeinandergepreßt': u'aufeinandergepresst',
        u'aufeinanderpaßten': u'aufeinanderpassten',
        u'aufeinanderpaßtest': u'aufeinanderpasstest',
        u'aufeinanderpaßtet': u'aufeinanderpasstet',
        u'aufeinanderpaßte' : u'aufeinanderpasste',
        u'aufeinanderpaßt'  : u'aufeinanderpasst',
        u'aufeinanderpreßten': u'aufeinanderpressten',
        u'aufeinanderpreßtest': u'aufeinanderpresstest',
        u'aufeinanderpreßtet': u'aufeinanderpresstet',
        u'aufeinanderpreßte': u'aufeinanderpresste',
        u'aufeinanderpreßt' : u'aufeinanderpresst',
        u'aufeßt'           : u'aufesst',
        u'auffaßten'        : u'auffassten',
        u'auffaßtest'       : u'auffasstest',
        u'auffaßtet'        : u'auffasstet',
        u'auffaßte'         : u'auffasste',
        u'auffaßt'          : u'auffasst',
        u'auffaßt'       : u'auffasst',
        u'auffreßt'         : u'auffresst',
        u'auffrißt'         : u'auffrisst',
        u'aufgebraßt'       : u'aufgebrasst',
        u'aufgefaßt'        : u'aufgefasst',
        u'aufgehißtem'      : u'aufgehisstem',
        u'aufgehißten'      : u'aufgehissten',
        u'aufgehißter'      : u'aufgehisster',
        u'aufgehißtes'      : u'aufgehisstes',
        u'aufgehißte'       : u'aufgehisste',
        u'aufgehißt'        : u'aufgehisst',
        u'aufgepaßt'        : u'aufgepasst',
        u'aufgepreßt'       : u'aufgepresst',
        u'aufgoßt'          : u'aufgosst',
        u'aufgoß'           : u'aufgoss',
        u'aufgußbeutel'     : u'aufgussbeutel',
        u'aufgußtierchen'   : u'aufgusstierchen',
        u'aufguß'           : u'aufguss',
        u'aufhißten'        : u'aufhissten',
        u'aufhißtest'       : u'aufhisstest',
        u'aufhißtet'        : u'aufhisstet',
        u'aufhißte'         : u'aufhisste',
        u'aufhißt'          : u'aufhisst',
        u'aufißt'           : u'aufisst',
        u'aufklärungsbeschluß': u'aufklärungsbeschluss',
        u'auflaßt'          : u'auflasst',
        u'aufläßt'          : u'auflässt',
        u'auflösungsprozeß' : u'auflösungsprozess',
        u'aufmeßt'          : u'aufmesst',
        u'aufmißt'          : u'aufmisst',
        u'aufpaßten'        : u'aufpassten',
        u'aufpaßtest'       : u'aufpasstest',
        u'aufpaßtet'        : u'aufpasstet',
        u'aufpaßte'         : u'aufpasste',
        u'aufpaßt'          : u'aufpasst',
        u'aufpraßlest'      : u'aufprasslest',
        u'aufpraßlet'       : u'aufprasslet',
        u'aufpraßle'        : u'aufprassle',
        u'aufpraßlung'      : u'aufprasslung',
        u'aufpreßten'       : u'aufpressten',
        u'aufpreßtest'      : u'aufpresstest',
        u'aufpreßtet'       : u'aufpresstet',
        u'aufpreßte'        : u'aufpresste',
        u'aufpreßt'         : u'aufpresst',
        u'aufrißt'          : u'aufrisst',
        u'aufriß'           : u'aufriss',
        u'aufrißzeichnung'  : u'aufrisszeichnung',
        u'aufschloßt'       : u'aufschlosst',
        u'aufschloß'        : u'aufschloss',
        u'aufschlußarbeiten': u'aufschlussarbeiten',
        u'aufschlüßlest'    : u'aufschlüsslest',
        u'aufschlüßlet'     : u'aufschlüsslet',
        u'aufschlüßle'      : u'aufschlüssle',
        u'aufschlüßlung'    : u'aufschlüsslung',
        u'aufschlußreichem' : u'aufschlussreichem',
        u'aufschlußreichen' : u'aufschlussreichen',
        u'aufschlußreicherem': u'aufschlussreicherem',
        u'aufschlußreicheren': u'aufschlussreicheren',
        u'aufschlußreicherer': u'aufschlussreicherer',
        u'aufschlußreicheres': u'aufschlussreicheres',
        u'aufschlußreichere': u'aufschlussreichere',
        u'aufschlußreicher' : u'aufschlussreicher',
        u'aufschlußreiches' : u'aufschlussreiches',
        u'aufschlußreiche'  : u'aufschlussreiche',
        u'aufschlußreichstem': u'aufschlussreichstem',
        u'aufschlußreichsten': u'aufschlussreichsten',
        u'aufschlußreichster': u'aufschlussreichster',
        u'aufschlußreichstes': u'aufschlussreichstes',
        u'aufschlußreichste': u'aufschlussreichste',
        u'aufschlußreich'   : u'aufschlussreich',
        u'aufschluß'        : u'aufschluss',
        u'aufschluß'     : u'aufschluss',
        u'aufschmißt'       : u'aufschmisst',
        u'aufschmiß'        : u'aufschmiss',
        u'aufschoßt'        : u'aufschosst',
        u'aufschoß'         : u'aufschoss',
        u'aufsproßt'        : u'aufsprosst',
        u'aufsproß'         : u'aufspross',
        u'augsproß'         : u'augspross',
        u'ausbeßrest'       : u'ausbessrest',
        u'ausbeßret'        : u'ausbessret',
        u'ausbeßre'         : u'ausbessre',
        u'ausbißt'          : u'ausbisst',
        u'ausbiß'           : u'ausbiss',
        u'ausblaßten'       : u'ausblassten',
        u'ausblaßtest'      : u'ausblasstest',
        u'ausblaßtet'       : u'ausblasstet',
        u'ausblaßte'        : u'ausblasste',
        u'ausblaßt'         : u'ausblasst',
        u'auseinanderfloßt' : u'auseinanderflosst',
        u'auseinanderfloß'  : u'auseinanderfloss',
        u'auseinanderrißt'  : u'auseinanderrisst',
        u'auseinanderriß'   : u'auseinanderriss',
        u'auseßt'           : u'ausesst',
        u'ausfirnißten'     : u'ausfirnissten',
        u'ausfirnißtest'    : u'ausfirnisstest',
        u'ausfirnißtet'     : u'ausfirnisstet',
        u'ausfirnißte'      : u'ausfirnisste',
        u'ausfirnißt'       : u'ausfirnisst',
        u'ausfloßt'         : u'ausflosst',
        u'ausfloß'          : u'ausfloss',
        u'ausflußgeschwindigkeit': u'ausflussgeschwindigkeit',
        u'ausflußhahn'      : u'ausflusshahn',
        u'ausflußloch'      : u'ausflussloch',
        u'ausflußmenge'     : u'ausflussmenge',
        u'ausflußöffnung'   : u'ausflussöffnung',
        u'ausflußrohr'      : u'ausflussrohr',
        u'ausfluß'          : u'ausfluss',
        u'ausfreßt'         : u'ausfresst',
        u'ausfrißt'         : u'ausfrisst',
        u'ausfuhrüberschuß' : u'ausfuhrüberschuss',
        u'ausgeblaßt'       : u'ausgeblasst',
        u'ausgefirnißt'     : u'ausgefirnisst',
        u'ausgelaßnerem'    : u'ausgelassnerem',
        u'ausgelaßneren'    : u'ausgelassneren',
        u'ausgelaßnerer'    : u'ausgelassnerer',
        u'ausgelaßneres'    : u'ausgelassneres',
        u'ausgelaßnere'     : u'ausgelassnere',
        u'ausgelaßner'      : u'ausgelassner',
        u'ausgepreßt'       : u'ausgepresst',
        u'ausgethan'        : u'ausgetan',
        u'ausgoßt'          : u'ausgosst',
        u'ausgoß'           : u'ausgoss',
        u'ausgußbecken'     : u'ausgussbecken',
        u'ausgußrohr'       : u'ausgussrohr',
        u'ausguß'           : u'ausguss',
        u'ausgußwasser'     : u'ausgusswasser',
        u'ausißt'           : u'ausisst',
        u'auskopierprozeß'  : u'auskopierprozess',
        u'ausländerhaß'     : u'ausländerhass',
        u'auslaßhahn'       : u'auslasshahn',
        u'auslaßt'          : u'auslasst',
        u'ausläßt'          : u'auslässt',
        u'auslaß'           : u'auslass',
        u'auslaßventil'     : u'auslassventil',
        u'ausmeßt'          : u'ausmesst',
        u'ausmißt'          : u'ausmisst',
        u'auspreßten'       : u'auspressten',
        u'auspreßtest'      : u'auspresstest',
        u'auspreßtet'       : u'auspresstet',
        u'auspreßte'        : u'auspresste',
        u'auspreßt'         : u'auspresst',
        u'ausrißt'          : u'ausrisst',
        u'ausriß'           : u'ausriss',
        u'ausschißt'        : u'ausschisst',
        u'ausschiß'         : u'ausschiss',
        u'ausschloßt'       : u'ausschlosst',
        u'ausschloß'        : u'ausschloss',
        u'ausschlußkriterien': u'ausschlusskriterien',
        u'ausschlußkriteriums': u'ausschlusskriteriums',
        u'ausschlußkriterium': u'ausschlusskriterium',
        u'ausschluß'        : u'ausschluss',
        u'ausschlußverfahrens': u'ausschlussverfahrens',
        u'ausschlußverfahren': u'ausschlussverfahren',
        u'ausschoßt'        : u'ausschosst',
        u'ausschoß'         : u'ausschoss',
        u'ausschußberatung' : u'ausschussberatung',
        u'ausschußmitgliedern': u'ausschussmitgliedern',
        u'ausschußmitglieder': u'ausschussmitglieder',
        u'ausschußmitgliedes': u'ausschussmitgliedes',
        u'ausschußmitgliede': u'ausschussmitgliede',
        u'ausschußmitglieds': u'ausschussmitglieds',
        u'ausschußmitglied' : u'ausschussmitglied',
        u'ausschußquote'    : u'ausschussquote',
        u'ausschußsitzung'  : u'ausschusssitzung',
        u'ausschuß'         : u'ausschuss',
        u'ausschußvorsitzendem': u'ausschussvorsitzendem',
        u'ausschußvorsitzenden': u'ausschussvorsitzenden',
        u'ausschußvorsitzender': u'ausschussvorsitzender',
        u'ausschußvorsitzende': u'ausschussvorsitzende',
        u'ausschußware'     : u'ausschussware',
        u'außengrenzen'  : u'aussengrenzen',
        u'außerbewußtem'    : u'außerbewusstem',
        u'außerbewußten'    : u'außerbewussten',
        u'außerbewußter'    : u'außerbewusster',
        u'außerbewußtes'    : u'außerbewusstes',
        u'außerbewußte'     : u'außerbewusste',
        u'außerbewußt'      : u'außerbewusst',
        u'autobahnanschlußstelle': u'autobahnanschlussstelle',
        u'autobahnanschluß' : u'autobahnanschluss',
        u'autotelephonen'   : u'autotelefonen',
        u'autotelephone'    : u'autotelefone',
        u'autotelephons'    : u'autotelefons',
        u'autotelephon'     : u'autotelefon',
        u'autumnalkatarren' : u'autumnalkatarrhen',
        u'autumnalkatarre'  : u'autumnalkatarrhe',
        u'autumnalkatarrs'  : u'autumnalkatarrhs',
        u'autumnalkatarr'   : u'autumnalkatarrh',
        u'babies'           : u'babys',
        u'backsteingothik'  : u'backsteingotik',
        u'bahnanschluß'     : u'bahnanschluss',
        u'bajonettanschluß' : u'bajonettanschluss',
        u'bajonettverschluß': u'bajonettverschluss',
        u'balancirt'        : u'balanciert',
        u'balkanisierungsprozeß': u'balkanisierungsprozess',
        u'ballettänzerinnen': u'balletttänzerinnen',
        u'ballettänzerin'   : u'balletttänzerin',
        u'ballettänzern'    : u'balletttänzern',
        u'ballettänzers'    : u'balletttänzers',
        u'ballettänzer'     : u'balletttänzer',
        u'ballettanz'       : u'balletttanz',
        u'ballettheater'    : u'balletttheater',
        u'bambussproß'      : u'bambusspross',
        u'bänderriß'        : u'bänderriss',
        u'bandpaßfiltern'   : u'bandpassfiltern',
        u'bandpaßfilters'   : u'bandpassfilters',
        u'bandpaßfilter'    : u'bandpassfilter',
        u'baroneß'          : u'baroness',
        u'barriquefaß'      : u'barriquefass',
        u'basküleverschluß' : u'basküleverschluss',
        u'baßbariton'       : u'bassbariton',
        u'baßbläserin'      : u'bassbläserin',
        u'baßbläser'        : u'bassbläser',
        u'baßbuffo'         : u'bassbuffo',
        u'baßdrum'          : u'bassdrum',
        u'baßflöten'        : u'bassflöten',
        u'baßflöte'         : u'bassflöte',
        u'baßgeigen'        : u'bassgeigen',
        u'baßgeigerin'      : u'bassgeigerin',
        u'baßgeiger'        : u'bassgeiger',
        u'baßgeige'         : u'bassgeige',
        u'baßgitarren'      : u'bassgitarren',
        u'baßgitarre'       : u'bassgitarre',
        u'baßhorn'          : u'basshorn',
        u'baßinstrument'    : u'bassinstrument',
        u'baßklarinette'    : u'bassklarinette',
        u'baßlage'          : u'basslage',
        u'baßlaute'         : u'basslaute',
        u'baßlinie'         : u'basslinie',
        u'baßpartie'        : u'basspartie',
        u'baßposaunen'      : u'bassposaunen',
        u'baßposaune'       : u'bassposaune',
        u'baßsaite'         : u'basssaite',
        u'baßsängern'       : u'basssängern',
        u'baßsängers'       : u'basssängers',
        u'baßsänger'        : u'basssänger',
        u'baßschlüsseln'    : u'bassschlüsseln',
        u'baßschlüssels'    : u'bassschlüssels',
        u'baßschlüssel'     : u'bassschlüssel',
        u'baßsolo'          : u'basssolo',
        u'baßstimmen'       : u'bassstimmen',
        u'baßstimme'        : u'bassstimme',
        u'baßstimme'     : u'bassstimme',
        u'baßtölpeln'       : u'basstölpeln',
        u'baßtölpels'       : u'basstölpels',
        u'baßtölpel'        : u'basstölpel',
        u'baßtuba'          : u'basstuba',
        u'baß'              : u'bass',
        u'bauchschuß'       : u'bauchschuss',
        u'baukostenzuschuß' : u'baukostenzuschuss',
        u'baumkänguruh'     : u'baumkänguru',
        u'bauzuschuß'       : u'bauzuschuss',
        u'beauties'         : u'beautys',
        u'beckmeßre'        : u'beckmessre',
        u'becreutzigend'    : u'bekreuzigend',
        u'becreutzigen'     : u'bekreuzigen',
        u'becreutzigest'    : u'bekreuzigest',
        u'becreutziget'     : u'bekreuziget',
        u'becreutzige'      : u'bekreuzige',
        u'becreutzigst'     : u'bekreuzigst',
        u'becreutzigten'    : u'bekreuzigten',
        u'becreutzigtest'   : u'bekreuzigtest',
        u'becreutzigtet'    : u'bekreuzigtet',
        u'becreutzigte'     : u'bekreuzigte',
        u'becreutzigt'      : u'bekreuzigt',
        u'becreutzig'       : u'bekreuzig',
        u'beeinflußbarem'   : u'beeinflussbarem',
        u'beeinflußbaren'   : u'beeinflussbaren',
        u'beeinflußbarerem' : u'beeinflussbarerem',
        u'beeinflußbareren' : u'beeinflussbareren',
        u'beeinflußbarerer' : u'beeinflussbarerer',
        u'beeinflußbareres' : u'beeinflussbareres',
        u'beeinflußbarere'  : u'beeinflussbarere',
        u'beeinflußbarer'   : u'beeinflussbarer',
        u'beeinflußbares'   : u'beeinflussbares',
        u'beeinflußbare'    : u'beeinflussbare',
        u'beeinflußbarkeit' : u'beeinflussbarkeit',
        u'beeinflußbarstem' : u'beeinflussbarstem',
        u'beeinflußbarsten' : u'beeinflussbarsten',
        u'beeinflußbarster' : u'beeinflussbarster',
        u'beeinflußbarstes' : u'beeinflussbarstes',
        u'beeinflußbarste'  : u'beeinflussbarste',
        u'beeinflußbar'     : u'beeinflussbar',
        u'beeinflußtem'     : u'beeinflusstem',
        u'beeinflußten'     : u'beeinflussten',
        u'beeinflußterem'   : u'beeinflussterem',
        u'beeinflußteren'   : u'beeinflussteren',
        u'beeinflußterer'   : u'beeinflussterer',
        u'beeinflußteres'   : u'beeinflussteres',
        u'beeinflußtere'    : u'beeinflusstere',
        u'beeinflußter'     : u'beeinflusster',
        u'beeinflußtestem'  : u'beeinflusstestem',
        u'beeinflußtesten'  : u'beeinflusstesten',
        u'beeinflußtester'  : u'beeinflusstester',
        u'beeinflußtestes'  : u'beeinflusstestes',
        u'beeinflußteste'   : u'beeinflussteste',
        u'beeinflußtest'    : u'beeinflusstest',
        u'beeinflußtes'     : u'beeinflusstes',
        u'beeinflußtet'     : u'beeinflusstet',
        u'beeinflußte'      : u'beeinflusste',
        u'beeinflußt'       : u'beeinflusst',
        u'beeinfluß'        : u'beeinfluss',
        u'befaßten'         : u'befassten',
        u'befaßtest'        : u'befasstest',
        u'befaßtet'         : u'befasstet',
        u'befaßte'          : u'befasste',
        u'befaßte'       : u'befasste',
        u'befaßt'           : u'befasst',
        u'befaß'            : u'befass',
        u'beflißnerem'      : u'beflissnerem',
        u'beflißneren'      : u'beflissneren',
        u'beflißnerer'      : u'beflissnerer',
        u'beflißneres'      : u'beflissneres',
        u'beflißnere'       : u'beflissnere',
        u'beflißner'        : u'beflissner',
        u'beflißt'          : u'beflisst',
        u'befliß'           : u'befliss',
        u'begnadigungserlaß': u'begnadigungserlass',
        u'begoßt'           : u'begosst',
        u'begoß'            : u'begoss',
        u'begrüßungskuß'    : u'begrüßungskuss',
        u'behältniß'        : u'behältnis',
        u'behende'          : u'behände',
        u'behendigkeit'     : u'behändigkeit',
        u'behend'           : u'behänd',
        u'behennuß'         : u'behennuss',
        u'beimeßt'          : u'beimesst',
        u'beimißt'          : u'beimisst',
        u'beinschuß'        : u'beinschuss',
        u'beischloßt'       : u'beischlosst',
        u'beischloß'        : u'beischloss',
        u'beischluß'        : u'beischluss',
        u'beischoßt'        : u'beischosst',
        u'beischoß'         : u'beischoss',
        u'belaßt'           : u'belasst',
        u'beläßt'           : u'belässt',
        u'belaß'            : u'belass',
        u'beleidigungsprozeß': u'beleidigungsprozess',
        u'belemmernd'       : u'belämmernd',
        u'belemmern'        : u'belämmern',
        u'belemmert'        : u'belämmert',
        u'belkantos'        : u'belcantos',
        u'belkanto'         : u'belcanto',
        u'bemeßt'           : u'bemesst',
        u'bemißtrauend'     : u'bemisstrauend',
        u'bemißtrauen'      : u'bemisstrauen',
        u'bemißtraut'       : u'bemisstraut',
        u'bemißt'           : u'bemisst',
        u'bemiß'            : u'bemiss',
        u'benäßten'         : u'benässten',
        u'benäßtest'        : u'benässtest',
        u'benäßtet'         : u'benässtet',
        u'benäßte'          : u'benässte',
        u'benäßt'           : u'benässt',
        u'benäß'            : u'benäss',
        u'bennuß'           : u'bennuss',
        u'benutzer:asgar'   : u'xxxxx',
        u'benutzer:balû/aal': u'ål',
        u'bepißten'         : u'bepissten',
        u'bepißtest'        : u'bepisstest',
        u'bepißtet'         : u'bepisstet',
        u'bepißte'          : u'bepisste',
        u'bepißt'           : u'bepisst',
        u'bepiß'            : u'bepiss',
        u'bequaßlest'       : u'bequasslest',
        u'bequaßlet'        : u'bequasslet',
        u'bequaßle'         : u'bequassle',
        u'berathung'        : u'beratung',
        u'beratungsausschuß': u'beratungsausschuss',
        u'bergkänguruh'     : u'bergkänguru',
        u'beschißt'         : u'beschisst',
        u'beschiß'          : u'beschiss',
        u'beschloßt'        : u'beschlosst',
        u'beschloß'         : u'beschloss',
        u'beschloß'      : u'beschloss',
        u'beschlußcharakter': u'beschlusscharakter',
        u'beschlußfähigem'  : u'beschlussfähigem',
        u'beschlußfähigen'  : u'beschlussfähigen',
        u'beschlußfähiger'  : u'beschlussfähiger',
        u'beschlußfähiges'  : u'beschlussfähiges',
        u'beschlußfähige'   : u'beschlussfähige',
        u'beschlußfähigkeit': u'beschlussfähigkeit',
        u'beschlußfähig'    : u'beschlussfähig',
        u'beschlußfassend'  : u'beschlussfassend',
        u'beschlußfassung'  : u'beschlussfassung',
        u'beschlußlage'     : u'beschlusslage',
        u'beschlußorgan'    : u'beschlussorgan',
        u'beschlußrecht'    : u'beschlussrecht',
        u'beschlußreif'     : u'beschlussreif',
        u'beschluß'         : u'beschluss',
        u'beschluß'      : u'beschluss',
        u'beschlußunfähigkeit': u'beschlussunfähigkeit',
        u'beschlußunfähig'  : u'beschlussunfähig',
        u'beschmißt'        : u'beschmisst',
        u'beschmiß'         : u'beschmiss',
        u'beschoßt'         : u'beschosst',
        u'beschoß'          : u'beschoss',
        u'beschußstempel'   : u'beschussstempel',
        u'beschuß'          : u'beschuss',
        u'besorgniß'        : u'besorgnis',
        u'beßrest'          : u'bessrest',
        u'beßret'           : u'bessret',
        u'beßre'            : u'bessre',
        u'bestandtheile'    : u'bestandteile',
        u'bestelliste'      : u'bestellliste',
        u'bestgehaßt'       : u'bestgehasst',
        u'bestußtem'        : u'bestusstem',
        u'bestußten'        : u'bestussten',
        u'bestußterem'      : u'bestussterem',
        u'bestußteren'      : u'bestussteren',
        u'bestußterer'      : u'bestussterer',
        u'bestußteres'      : u'bestussteres',
        u'bestußtere'       : u'bestusstere',
        u'bestußter'        : u'bestusster',
        u'bestußtestem'     : u'bestusstestem',
        u'bestußtesten'     : u'bestusstesten',
        u'bestußtester'     : u'bestusstester',
        u'bestußtestes'     : u'bestusstestes',
        u'bestußteste'      : u'bestussteste',
        u'bestußtes'        : u'bestusstes',
        u'bestußte'         : u'bestusste',
        u'bestußt'          : u'bestusst',
        u'betelnußpalme'    : u'betelnusspalme',
        u'betelnuß'         : u'betelnuss',
        u'betonguß'         : u'betonguss',
        u'betreßtem'        : u'betresstem',
        u'betreßten'        : u'betressten',
        u'betreßter'        : u'betresster',
        u'betreßtes'        : u'betresstes',
        u'betreßte'         : u'betresste',
        u'betreßt'          : u'betresst',
        u'betriebsausschuß' : u'betriebsausschuss',
        u'betriebspaß'      : u'betriebspass',
        u'betriebsschluß'   : u'betriebsschluss',
        u'bettüchern'       : u'betttüchern',
        u'bettücher'        : u'betttücher',
        u'bettuches'        : u'betttuches',
        u'bettuchs'         : u'betttuchs',
        u'bettuch'          : u'betttuch',
        u'bevölkerungsüberschuß': u'bevölkerungsüberschuss',
        u'bevorschußten'    : u'bevorschussten',
        u'bevorschußtest'   : u'bevorschusstest',
        u'bevorschußtet'    : u'bevorschusstet',
        u'bevorschußte'     : u'bevorschusste',
        u'bevorschußt'      : u'bevorschusst',
        u'bevorschuß'       : u'bevorschuss',
        u'bewäßrest'        : u'bewässrest',
        u'bewäßret'         : u'bewässret',
        u'bewäßre'          : u'bewässre',
        u'bewäßrungsanlage' : u'bewässrungsanlage',
        u'bewäßrungsgraben' : u'bewässrungsgraben',
        u'bewäßrungskanal'  : u'bewässrungskanal',
        u'bewäßrungspumpe'  : u'bewässrungspumpe',
        u'bewäßrungssystem' : u'bewässrungssystem',
        u'bewäßrung'        : u'bewässrung',
        u'beweisbeschluß'   : u'beweisbeschluss',
        u'bewußtem'         : u'bewusstem',
        u'bewußten'         : u'bewussten',
        u'bewußten'      : u'bewussten',
        u'bewußterem'       : u'bewussterem',
        u'bewußteren'       : u'bewussteren',
        u'bewußterer'       : u'bewussterer',
        u'bewußteres'       : u'bewussteres',
        u'bewußtere'        : u'bewusstere',
        u'bewußter'         : u'bewusster',
        u'bewußtestem'      : u'bewusstestem',
        u'bewußtesten'      : u'bewusstesten',
        u'bewußtester'      : u'bewusstester',
        u'bewußtestes'      : u'bewusstestes',
        u'bewußteste'       : u'bewussteste',
        u'bewußtes'         : u'bewusstes',
        u'bewußte'          : u'bewusste',
        u'bewußte'       : u'bewusste',
        u'bewußtheit'       : u'bewusstheit',
        u'bewußtlosigkeit'  : u'bewusstlosigkeit',
        u'bewußtlos'        : u'bewusstlos',
        u'bewußtlos'     : u'bewusstlos',
        u'bewußtmachung'    : u'bewusstmachung',
        u'bewußtseinsbildung': u'bewusstseinsbildung',
        u'bewußtseinseinengung': u'bewusstseinseinengung',
        u'bewußtseinsentwicklungen': u'bewusstseinsentwicklungen',
        u'bewußtseinsentwicklung': u'bewusstseinsentwicklung',
        u'bewußtseinserweiternd': u'bewusstseinserweiternd',
        u'bewußtseinserweiterung': u'bewusstseinserweiterung',
        u'bewußtseinsinhalt': u'bewusstseinsinhalt',
        u'bewußtseinslage'  : u'bewusstseinslage',
        u'bewußtseinslenkung': u'bewusstseinslenkung',
        u'bewußtseinsschwelle': u'bewusstseinsschwelle',
        u'bewußtseinsspaltung': u'bewusstseinsspaltung',
        u'bewußtseinsstörung': u'bewusstseinsstörung',
        u'bewußtseinstrübung': u'bewusstseinstrübung',
        u'bewußtseins'      : u'bewusstseins',
        u'bewußtseinsveränderungen': u'bewusstseinsveränderungen',
        u'bewußtseinsveränderung': u'bewusstseinsveränderung',
        u'bewußtseinszustand': u'bewusstseinszustand',
        u'bewußtsein'       : u'bewusstsein',
        u'bewußtsein'    : u'bewusstsein',
        u'bewußt'           : u'bewusst',
        u'bewußt'        : u'bewusst',
        u'bewußtwerdung'    : u'bewusstwerdung',
        u'bey'              : u'bei',
        u'beziehungsstreß'  : u'beziehungsstress',
        u'bezirksausschuß'  : u'bezirksausschuss',
        u'bezuschußten'     : u'bezuschussten',
        u'bezuschußtest'    : u'bezuschusstest',
        u'bezuschußtet'     : u'bezuschusstet',
        u'bezuschußte'      : u'bezuschusste',
        u'bezuschußt'       : u'bezuschusst',
        u'bezuschuß'        : u'bezuschuss',
        u'bierbaß'          : u'bierbass',
        u'bierfaß'          : u'bierfass',
        u'bierschiß'        : u'bierschiss',
        u'bildtelephonen'   : u'bildtelefonen',
        u'bildtelephone'    : u'bildtelefone',
        u'bildtelephons'    : u'bildtelefons',
        u'bildtelephon'     : u'bildtelefon',
        u'bildungsprozeß'   : u'bildungsprozess',
        u'bilwiß'           : u'bilwiss',
        u'binnenschiffahrt' : u'binnenschifffahrt',
        u'bios-paßwort'     : u'bios-passwort',
        u'birkenmeth'       : u'birkenmet',
        u'birkenruthe'      : u'birkenrute',
        u'birkenschößlingen': u'birkenschösslingen',
        u'birkenschößlinge' : u'birkenschösslinge',
        u'birkenschößlings' : u'birkenschösslings',
        u'birkenschößling'  : u'birkenschössling',
        u'birkentheer'      : u'birkenteer',
        u'bißchens'         : u'bisschens',
        u'bißchen'          : u'bisschen',
        u'bißchen'       : u'bisschen',
        u'bißfestem'        : u'bissfestem',
        u'bißfesten'        : u'bissfesten',
        u'bißfesterem'      : u'bissfesterem',
        u'bißfesteren'      : u'bissfesteren',
        u'bißfesterer'      : u'bissfesterer',
        u'bißfesteres'      : u'bissfesteres',
        u'bißfestere'       : u'bissfestere',
        u'bißfester'        : u'bissfester',
        u'bißfestestem'     : u'bissfestestem',
        u'bißfestesten'     : u'bissfestesten',
        u'bißfestester'     : u'bissfestester',
        u'bißfestestes'     : u'bissfestestes',
        u'bißfesteste'      : u'bissfesteste',
        u'bißfestes'        : u'bissfestes',
        u'bißfeste'         : u'bissfeste',
        u'bißfest'          : u'bissfest',
        u'bißspuren'        : u'bissspuren',
        u'bißspur'          : u'bissspur',
        u'bißt'             : u'bisst',
        u'biß'              : u'biss',
        u'biß'           : u'biss',
        u'bißverletzungen'  : u'bissverletzungen',
        u'bißverletzung'    : u'bissverletzung',
        u'bißwunden'        : u'bisswunden',
        u'bißwunde'         : u'bisswunde',
        u'blaßblauen'    : u'blassblauen',
        u'blaßblau'         : u'blassblau',
        u'bläßbock'         : u'blässbock',
        u'blaßen'           : u'blassen',
        u'bläßgänsen'       : u'blässgänsen',
        u'bläßgänse'        : u'blässgänse',
        u'bläßgans'         : u'blässgans',
        u'blaßgesichtig'    : u'blassgesichtig',
        u'blaßgesicht'      : u'blassgesicht',
        u'blaßgrün'         : u'blassgrün',
        u'bläßhühnern'      : u'blässhühnern',
        u'bläßhühner'       : u'blässhühner',
        u'bläßhuhnes'       : u'blässhuhnes',
        u'bläßhuhne'        : u'blässhuhne',
        u'bläßhuhns'        : u'blässhuhns',
        u'bläßhuhn'         : u'blässhuhn',
        u'bläßlich'         : u'blässlich',
        u'bläßlich'      : u'blässlich',
        u'blaßrosa'         : u'blassrosa',
        u'blaß'             : u'blass',
        u'blaß'          : u'blass',
        u'blattschuß'       : u'blattschuss',
        u'bleßgänsen'       : u'blessgänsen',
        u'bleßgänse'        : u'blessgänse',
        u'bleßhühnern'      : u'blesshühnern',
        u'bleßhühner'       : u'blesshühner',
        u'bleßhuhnes'       : u'blesshuhnes',
        u'bleßhuhne'        : u'blesshuhne',
        u'bleßhuhns'        : u'blesshuhns',
        u'bleßhuhn'         : u'blesshuhn',
        u'blutdruckmeßgeräten': u'blutdruckmessgeräten',
        u'blutdruckmeßgerätes': u'blutdruckmessgerätes',
        u'blutdruckmeßgeräte': u'blutdruckmessgeräte',
        u'blutdruckmeßgeräts': u'blutdruckmessgeräts',
        u'blutdruckmeßgerät': u'blutdruckmessgerät',
        u'bluterguß'        : u'bluterguss',
        u'boarding-houses'  : u'boardinghouses',
        u'boarding-house'   : u'boardinghouse',
        u'bodenriß'         : u'bodenriss',
        u'bodies'           : u'bodys',
        u'bogenschuß'       : u'bogenschuss',
        u'böllerschuß'      : u'böllerschuss',
        u'bolzenschußapparat': u'bolzenschussapparat',
        u'bombenschuß'      : u'bombenschuss',
        u'bootskompaß'      : u'bootskompass',
        u'börsenschluß'     : u'börsenschluss',
        u'boßlest'          : u'bosslest',
        u'boßlet'           : u'bosslet',
        u'boßle'            : u'bossle',
        u'boß'              : u'boss',
        u'bramahschloß'     : u'bramahschloss',
        u'brandschutzabschluß': u'brandschutzabschluss',
        u'braß'             : u'brass',
        u'bravurösem'       : u'bravourösem',
        u'bravurösen'       : u'bravourösen',
        u'bravuröserem'     : u'bravouröserem',
        u'bravuröseren'     : u'bravouröseren',
        u'bravuröserer'     : u'bravouröserer',
        u'bravuröseres'     : u'bravouröseres',
        u'bravurösere'      : u'bravourösere',
        u'bravuröser'       : u'bravouröser',
        u'bravurösestem'    : u'bravourösestem',
        u'bravurösesten'    : u'bravourösesten',
        u'bravurösester'    : u'bravourösester',
        u'bravurösestes'    : u'bravourösestes',
        u'bravuröseste'     : u'bravouröseste',
        u'bravuröses'       : u'bravouröses',
        u'bravuröse'        : u'bravouröse',
        u'bravurös'         : u'bravourös',
        u'bravur'           : u'bravour',
        u'brechnuß'         : u'brechnuss',
        u'brennesseln'      : u'brennnesseln',
        u'brennesselstoffen': u'brennnesselstoffen',
        u'brennesselstoffes': u'brennnesselstoffes',
        u'brennesselstoffe' : u'brennnesselstoffe',
        u'brennesselstoffs' : u'brennnesselstoffs',
        u'brennesselstoff'  : u'brennnesselstoff',
        u'brennesseltees'   : u'brennnesseltees',
        u'brennesseltee'    : u'brennnesseltee',
        u'brennessel'       : u'brennnessel',
        u'brillenpaß'       : u'brillenpass',
        u'brod'             : u'brot',
        u'bronzeguß'        : u'bronzeguss',
        u'bruderhaß'        : u'bruderhass',
        u'bruderkuß'        : u'bruderkuss',
        u'brummbaß'         : u'brummbass',
        u'brüßlerinnen'     : u'brüsslerinnen',
        u'brüßlerin'        : u'brüsslerin',
        u'brüßlern'         : u'brüsslern',
        u'brüßlers'         : u'brüsslers',
        u'brüßler'          : u'brüssler',
        u'büchsenschuß'     : u'büchsenschuss',
        u'buchstabenschloß' : u'buchstabenschloss',
        u'bügelschloß'      : u'bügelschloss',
        u'bügelverschluß'   : u'bügelverschluss',
        u'buggies'          : u'buggys',
        u'bumbaß'           : u'bumbass',
        u'bundeswahlausschuß': u'bundeswahlausschuss',
        u'buntbartschloß'   : u'buntbartschloss',
        u'büroschluß'       : u'büroschluss',
        u'buschkänguruh'    : u'buschkänguru',
        u'busineß'          : u'business',
        u'bußlest'          : u'busslest',
        u'bußlet'           : u'busslet',
        u'bußle'            : u'bussle',
        u'butiken'          : u'boutiquen',
        u'butike'           : u'boutique',
        u'butterfaß'        : u'butterfass',
        u'cairos'           : u'kairos',
        u'cairo'            : u'kairo',
        u'calendern'        : u'kalendern',
        u'calenders'        : u'kalenders',
        u'calender'         : u'kalender',
        u'calfaterest'      : u'kalfaterest',
        u'calfateret'       : u'kalfateret',
        u'calfatere'        : u'kalfatere',
        u'calfaternd'       : u'kalfaternd',
        u'calfatern'        : u'kalfatern',
        u'calfaterst'       : u'kalfaterst',
        u'calfaterten'      : u'kalfaterten',
        u'calfatertest'     : u'kalfatertest',
        u'calfatertet'      : u'kalfatertet',
        u'calfaterte'       : u'kalfaterte',
        u'calfatert'        : u'kalfatert',
        u'calfater'         : u'kalfater',
        u'calfatrest'       : u'kalfatrest',
        u'calfatret'        : u'kalfatret',
        u'calfatre'         : u'kalfatre',
        u'califen'          : u'kalifen',
        u'californiens'     : u'kaliforniens',
        u'californien'      : u'kalifornien',
        u'californierinnen' : u'kalifornierinnen',
        u'californierin'    : u'kalifornierin',
        u'californiern'     : u'kaliforniern',
        u'californiers'     : u'kaliforniers',
        u'californier'      : u'kalifornier',
        u'californischem'   : u'kalifornischem',
        u'californischen'   : u'kalifornischen',
        u'californischer'   : u'kalifornischer',
        u'californisches'   : u'kalifornisches',
        u'californische'    : u'kalifornische',
        u'californisch'     : u'kalifornisch',
        u'calif'            : u'kalif',
        u'campagnen'        : u'kampagnen',
        u'campagne'         : u'kampagne',
        u'campaniens'       : u'kampaniens',
        u'campanien'        : u'kampanien',
        u'canadas'          : u'kanadas',
        u'canada'           : u'kanada',
        u'canadierinnen'    : u'kanadierinnen',
        u'canadierin'       : u'kanadierin',
        u'canadiern'        : u'kanadiern',
        u'canadiers'        : u'kanadiers',
        u'canadier'         : u'kanadier',
        u'canadischem'      : u'kanadischem',
        u'canadischen'      : u'kanadischen',
        u'canadischer'      : u'kanadischer',
        u'canadisches'      : u'kanadisches',
        u'canadische'       : u'kanadische',
        u'canadisch'        : u'kanadisch',
        u'canälen'          : u'kanälen',
        u'canales'          : u'kanales',
        u'canale'           : u'kanale',
        u'canäle'           : u'kanäle',
        u'canals'           : u'kanals',
        u'canal'            : u'kanal',
        u'candis'           : u'kandis',
        u'cannibalen'       : u'kannibalen',
        u'cannibale'        : u'kannibale',
        u'cannibalinnen'    : u'kannibalinnen',
        u'cannibalin'       : u'kannibalin',
        u'cannibalismus'    : u'kannibalismus',
        u'capitalen'        : u'kapitalen',
        u'capitale'         : u'kapitale',
        u'capitalien'       : u'kapitalien',
        u'capitalismus'     : u'kapitalismus',
        u'capitals'         : u'kapitals',
        u'capital'          : u'kapital',
        u'caricaturen'      : u'karikaturen',
        u'caricatur'        : u'karikatur',
        u'carlsruhes'       : u'karlsruhes',
        u'carlsruhe'        : u'karlsruhe',
        u'carracas'         : u'caracas',
        u'carricaturen'     : u'karikaturen',
        u'carricatur'       : u'karikatur',
        u'cashewnuß'        : u'cashewnuss',
        u'cassels'          : u'kassels',
        u'cassel'           : u'kassel',
        u'cassen'           : u'kassen',
        u'casse'            : u'kasse',
        u'castilien'        : u'kastilien',
        u'catholicismus'    : u'katholizismus',
        u'catholischem'     : u'katholischem',
        u'catholischen'     : u'katholischen',
        u'catholischer'     : u'katholischer',
        u'catholisches'     : u'katholisches',
        u'catholische'      : u'katholische',
        u'catholisch'       : u'katholisch',
        u'catholizismus'    : u'katholizismus',
        u'centralkörper'    : u'zentralkörper',
        u'centren'          : u'zentren',
        u'centrums'         : u'zentrums',
        u'centrum'          : u'zentrum',
        u'chaiberpaß'       : u'chaiberpass',
        u'christenthums'    : u'christentums',
        u'christenthum'     : u'christentum',
        u'churmark'         : u'kurmark',
        u'cigaretten'       : u'zigaretten',
        u'cigarette'        : u'zigarette',
        u'cigarren'         : u'zigarren',
        u'cigarre'          : u'zigarre',
        u'citaten'          : u'zitaten',
        u'citates'          : u'zitates',
        u'citate'           : u'zitate',
        u'citats'           : u'zitats',
        u'citat'            : u'zitat',
        u'cities'           : u'citys',
        u'citronen'         : u'zitronen',
        u'citrone'          : u'zitrone',
        u'civils'           : u'zivils',
        u'civil'            : u'zivil',
        u'clarinetten'      : u'klarinetten',
        u'clarinette'       : u'klarinette',
        u'clarinettisten'   : u'klarinettisten',
        u'clarinettistinnen': u'klarinettistinnen',
        u'clarinettistin'   : u'klarinettistin',
        u'clarinettist'     : u'klarinettist',
        u'classicismus'     : u'klassizismus',
        u'clauseln'         : u'klauseln',
        u'clausel'          : u'klausel',
        u'clavieren'        : u'klavieren',
        u'clavieres'        : u'klavieres',
        u'claviere'         : u'klaviere',
        u'claviers'         : u'klaviers',
        u'clavier'          : u'klavier',
        u'cleverneß'        : u'cleverness',
        u'cliché'           : u'klischee',
        u'coblenz'          : u'koblenz',
        u'cobolentz'        : u'koblenz',
        u'cocosnüssen'      : u'kokosnüssen',
        u'cocosnüsse'       : u'kokosnüsse',
        u'cocosnuß'         : u'kokosnuss',
        u'collisionen'      : u'kollisionen',
        u'collision'        : u'kollision',
        u'cölns'            : u'kölns',
        u'cöln'             : u'köln',
        u'colonialwaren'    : u'kolonialwaren',
        u'colonialware'     : u'kolonialware',
        u'colonien'         : u'kolonien',
        u'colonie'          : u'kolonie',
        u'colorieren'       : u'kolorieren',
        u'colour'        : u'color',
        u'columbianischem'  : u'kolumbianischem',
        u'columbianischen'  : u'kolumbianischen',
        u'columbianischer'  : u'kolumbianischer',
        u'columbianisches'  : u'kolumbianisches',
        u'columbianische'   : u'kolumbianische',
        u'columbianisch'    : u'kolumbianisch',
        u'columbiens'       : u'kolumbiens',
        u'columbien'        : u'kolumbien',
        u'combinationen'    : u'kombinationen',
        u'combination'      : u'kombination',
        u'combinatorik'     : u'kombinatorik',
        u'commas'           : u'kommas',
        u'commata'          : u'kommata',
        u'comma'            : u'komma',
        u'communismus'      : u'kommunismus',
        u'communisten'      : u'kommunisten',
        u'communistinnen'   : u'kommunistinnen',
        u'communistin'      : u'kommunistin',
        u'communistischem'  : u'kommunistischem',
        u'communistischen'  : u'kommunistischen',
        u'communistischer'  : u'kommunistischer',
        u'communistisches'  : u'kommunistisches',
        u'communistische'   : u'kommunistische',
        u'communistisch'    : u'kommunistisch',
        u'communist'        : u'kommunist',
        u'comödien'         : u'komödien',
        u'comödie'          : u'komödie',
        u'comparativen'     : u'komparativen',
        u'comparative'      : u'komparative',
        u'comparativs'      : u'komparativs',
        u'comparativ'       : u'komparativ',
        u'competentem'      : u'kompetentem',
        u'competenten'      : u'kompetenten',
        u'competenterem'    : u'kompetenterem',
        u'competenteren'    : u'kompetenteren',
        u'competenterer'    : u'kompetenterer',
        u'competenteres'    : u'kompetenteres',
        u'competentere'     : u'kompetentere',
        u'competenter'      : u'kompetenter',
        u'competentestem'   : u'kompetentestem',
        u'competentesten'   : u'kompetentesten',
        u'competentester'   : u'kompetentester',
        u'competentestes'   : u'kompetentestes',
        u'competenteste'    : u'kompetenteste',
        u'competentes'      : u'kompetentes',
        u'competente'       : u'kompetente',
        u'competent'        : u'kompetent',
        u'competenzen'      : u'kompetenzen',
        u'competenz'        : u'kompetenz',
        u'complexität'      : u'komplexität',
        u'componisten'      : u'komponisten',
        u'componistinnen'   : u'komponistinnen',
        u'componistin'      : u'komponistin',
        u'componist'        : u'komponist',
        u'compositionen'    : u'kompositionen',
        u'composition'      : u'komposition',
        u'compromissen'     : u'kompromissen',
        u'compromisses'     : u'kompromisses',
        u'compromisse'      : u'kompromisse',
        u'compromißlosem'   : u'kompromisslosem',
        u'compromißlosen'   : u'kompromisslosen',
        u'compromißloser'   : u'kompromissloser',
        u'compromißloses'   : u'kompromissloses',
        u'compromißlose'    : u'kompromisslose',
        u'compromißlos'     : u'kompromisslos',
        u'compromiß'        : u'kompromiss',
        u'concentrirte'     : u'konzentrierte',
        u'concerten'        : u'konzerten',
        u'concertes'        : u'konzertes',
        u'concerte'         : u'konzerte',
        u'concerts'         : u'konzerts',
        u'concert'          : u'konzert',
        u'conclusionen'     : u'konklusionen',
        u'conclusion'       : u'konklusion',
        u'concurrenz'       : u'konkurrenz',
        u'congressen'       : u'kongressen',
        u'congresses'       : u'kongresses',
        u'congresse'        : u'kongresse',
        u'congreßsaales'    : u'kongresssaales',
        u'congreßsaale'     : u'kongresssaale',
        u'congreßsaals'     : u'kongresssaals',
        u'congreßsaal'      : u'kongresssaal',
        u'congreßsälen'     : u'kongresssälen',
        u'congreßsäle'      : u'kongresssäle',
        u'congreß'          : u'kongress',
        u'congruenzen'      : u'kongruenzen',
        u'congruenz'        : u'kongruenz',
        u'conjunctiven'     : u'konjunktiven',
        u'conjunctive'      : u'konjunktive',
        u'conjunctivs'      : u'konjunktivs',
        u'conjunctiv'       : u'konjunktiv',
        u'consequentem'     : u'konsequentem',
        u'consequenten'     : u'konsequenten',
        u'consequenterem'   : u'konsequenterem',
        u'consequenteren'   : u'konsequenteren',
        u'consequenterer'   : u'konsequenterer',
        u'consequenteres'   : u'konsequenteres',
        u'consequentere'    : u'konsequentere',
        u'consequenter'     : u'konsequenter',
        u'consequentestem'  : u'konsequentestem',
        u'consequentesten'  : u'konsequentesten',
        u'consequentester'  : u'konsequentester',
        u'consequentestes'  : u'konsequentestes',
        u'consequenteste'   : u'konsequenteste',
        u'consequentes'     : u'konsequentes',
        u'consequente'      : u'konsequente',
        u'consequent'       : u'konsequent',
        u'consequenzen'     : u'konsequenzen',
        u'consequenz'       : u'konsequenz',
        u'consonantenhäufung': u'konsonantenhäufung',
        u'consonanten'      : u'konsonanten',
        u'consonant'        : u'konsonant',
        u'consonanzen'      : u'konsonanzen',
        u'consonanz'        : u'konsonanz',
        u'constanten'       : u'konstanten',
        u'constante'        : u'konstante',
        u'constanz'         : u'konstanz',
        u'constructionen'   : u'konstruktionen',
        u'construction'     : u'konstruktion',
        u'contrabässen'     : u'kontrabässen',
        u'contrabasses'     : u'kontrabasses',
        u'contrabässe'      : u'kontrabässe',
        u'contrabaß'        : u'kontrabass',
        u'contrapuncten'    : u'kontrapunkten',
        u'contrapunctes'    : u'kontrapunktes',
        u'contrapuncte'     : u'kontrapunkte',
        u'contrapuncts'     : u'kontrapunkts',
        u'contrapunct'      : u'kontrapunkt',
        u'conventionen'     : u'konventionen',
        u'convention'       : u'konvention',
        u'conversationen'   : u'konversationen',
        u'conversation'     : u'konversation',
        u'coolneß'          : u'coolness',
        u'cooperationen'    : u'kooperationen',
        u'cooperation'      : u'kooperation',
        u'copien'           : u'kopien',
        u'copie'            : u'kopie',
        u'cordilleren'      : u'kordilleren',
        u'cormoranen'       : u'kormoranen',
        u'cormorane'        : u'kormorane',
        u'cormorans'        : u'kormorans',
        u'cormoran'         : u'kormoran',
        u'corollaren'       : u'korollaren',
        u'corollare'        : u'korollare',
        u'corollars'        : u'korollars',
        u'corollar'         : u'korollar',
        u'correcturen'      : u'korrekturen',
        u'correctur'        : u'korrektur',
        u'costaricanerinnen': u'costa-ricanerinnen',
        u'costaricanerin'   : u'costa-ricanerin',
        u'costaricanern'    : u'costa-ricanern',
        u'costaricaners'    : u'costa-ricaners',
        u'costaricaner'     : u'costa-ricaner',
        u'costaricanischem' : u'costa-ricanischem',
        u'costaricanischen' : u'costa-ricanischen',
        u'costaricanischer' : u'costa-ricanischer',
        u'costaricanisches' : u'costa-ricanisches',
        u'costaricanische'  : u'costa-ricanische',
        u'costaricanisch'   : u'costa-ricanisch',
        u'cöthens'          : u'köthens',
        u'cöthen'           : u'köthen',
        u'counteß'          : u'countess',
        u'cretins'          : u'kretins',
        u'cretin'           : u'kretin',
        u'creutzen'         : u'kreuzen',
        u'creutzes'         : u'kreuzes',
        u'creutze'          : u'kreuze',
        u'creutzigend'      : u'kreuzigend',
        u'creutzigen'       : u'kreuzigen',
        u'creutzigest'      : u'kreuzigest',
        u'creutziget'       : u'kreuziget',
        u'creutzige'        : u'kreuzige',
        u'creutzigst'       : u'kreuzigst',
        u'creutzigten'      : u'kreuzigten',
        u'creutzigtest'     : u'kreuzigtest',
        u'creutzigtet'      : u'kreuzigtet',
        u'creutzigte'       : u'kreuzigte',
        u'creutzigt'        : u'kreuzigt',
        u'creutzig'         : u'kreuzig',
        u'creutzigungen'    : u'kreuzigungen',
        u'creutzigung'      : u'kreuzigung',
        u'creutz'           : u'kreuz',
        u'crocodilen'       : u'krokodilen',
        u'crocodile'        : u'krokodile',
        u'crocodils'        : u'krokodils',
        u'crocodil'         : u'krokodil',
        u'crystallinischer' : u'kristallinischer',
        u'cubanerinnen'     : u'kubanerinnen',
        u'cubanerin'        : u'kubanerin',
        u'cubanern'         : u'kubanern',
        u'cubaners'         : u'kubaners',
        u'cubaner'          : u'kubaner',
        u'cubanischem'      : u'kubanischem',
        u'cubanischen'      : u'kubanischen',
        u'cubanischer'      : u'kubanischer',
        u'cubanisches'      : u'kubanisches',
        u'cubanische'       : u'kubanische',
        u'cubanisch'        : u'kubanisch',
        u'cubas'            : u'kubas',
        u'cuba'             : u'kuba',
        u'culturen'         : u'kulturen',
        u'cultur'           : u'kultur',
        u'cursivem'         : u'kursivem',
        u'cursiven'         : u'kursiven',
        u'cursiver'         : u'kursiver',
        u'cursives'         : u'kursives',
        u'cursive'          : u'kursive',
        u'cursiv'           : u'kursiv',
        u'curvatur'         : u'kurvatur',
        u'cuscus'           : u'kuskus',
        u'czaren'           : u'zaren',
        u'czar'             : u'zar',
        u'dachgeschoß'      : u'dachgeschoss',
        u'dachgeschoßwohnungen': u'dachgeschosswohnungen',
        u'dachgeschoßwohnung': u'dachgeschosswohnung',
        u'daddies'          : u'daddys',
        u'dahinfloßt'       : u'dahinflosst',
        u'dahinfloß'        : u'dahinfloss',
        u'dalaßt'           : u'dalasst',
        u'daläßt'           : u'dalässt',
        u'dammriß'          : u'dammriss',
        u'dampfroß'         : u'dampfross',
        u'dampfschiffahrten': u'dampfschifffahrten',
        u'dampfschiffahrtsgesellschaften': u'dampfschifffahrtsgesellschaften',
        u'dampfschiffahrtsgesellschaft': u'dampfschifffahrtsgesellschaft',
        u'dampfschiffahrt'  : u'dampfschifffahrt',
        u'danaidenfaß'      : u'danaidenfass',
        u'danebenschoßt'    : u'danebenschosst',
        u'danebenschoß'     : u'danebenschoss',
        u'dargethan'        : u'dargetan',
        u'darmriß'          : u'darmriss',
        u'darmverschluß'    : u'darmverschluss',
        u'darthuend'        : u'dartuend',
        u'darthuen'         : u'dartuen',
        u'darthuest'        : u'dartuest',
        u'darthuet'         : u'dartuet',
        u'darthue'          : u'dartue',
        u'darthun'          : u'dartun',
        u'darthust'         : u'dartust',
        u'darthut'          : u'dartut',
        u'darzuthun'        : u'darzutun',
        u'daß-sätzen'       : u'dass-sätzen',
        u'daßsätzen'        : u'dasssätzen',
        u'daß-satzes'       : u'dass-satzes',
        u'daßsatzes'        : u'dasssatzes',
        u'daß-satze'        : u'dass-satze',
        u'daß-sätze'        : u'dass-sätze',
        u'daßsätze'         : u'dasssätze',
        u'daß-satz'         : u'dass-satz',
        u'daßsatz'          : u'dasssatz',
        u'daß'              : u'dass',
        u'daß'           : u'dass',
        u'dasz'             : u'dass',
        u'datenflußdiagrammen': u'datenflussdiagrammen',
        u'datenflußdiagramme': u'datenflussdiagramme',
        u'datenflußdiagramms': u'datenflussdiagramms',
        u'datenflußdiagramm': u'datenflussdiagramm',
        u'davonschoßt'      : u'davonschosst',
        u'davonschoß'       : u'davonschoss',
        u'davysch'          : u'davysch',
        u'decembern'        : u'dezembern',
        u'decembers'        : u'dezembers',
        u'december'         : u'dezember',
        u'deflationsprozeß' : u'deflationsprozess',
        u'delikateßgeschäft': u'delikatessgeschäft',
        u'delikateßgurke'   : u'delikatessgurke',
        u'delikateßheringen': u'delikatessheringen',
        u'delikateßheringe' : u'delikatessheringe',
        u'delikateßherings' : u'delikatessherings',
        u'delikateßhering'  : u'delikatesshering',
        u'delikateßladen'   : u'delikatessladen',
        u'delikateßmajonäse': u'delikatessmajonäse',
        u'delikateßmayonnaise': u'delikatessmayonnaise',
        u'delikateßsenf'    : u'delikatesssenf',
        u'delikateßware'    : u'delikatessware',
        u'dengelamboß'      : u'dengelamboss',
        u'denkprozeß'       : u'denkprozess',
        u'deplaciertem'     : u'deplatziertem',
        u'deplacierten'     : u'deplatzierten',
        u'deplacierterem'   : u'deplatzierterem',
        u'deplacierteren'   : u'deplatzierteren',
        u'deplacierterer'   : u'deplatzierterer',
        u'deplacierteres'   : u'deplatzierteres',
        u'deplaciertere'    : u'deplatziertere',
        u'deplacierter'     : u'deplatzierter',
        u'deplaciertestem'  : u'deplatziertestem',
        u'deplaciertesten'  : u'deplatziertesten',
        u'deplaciertester'  : u'deplatziertester',
        u'deplaciertestes'  : u'deplatziertestes',
        u'deplacierteste'   : u'deplatzierteste',
        u'deplaciertes'     : u'deplatziertes',
        u'deplacierte'      : u'deplatzierte',
        u'deplaciert'       : u'deplatziert',
        u'deplaziertem'     : u'deplatziertem',
        u'deplazierten'     : u'deplatzierten',
        u'deplazierterem'   : u'deplatzierterem',
        u'deplazierteren'   : u'deplatzierteren',
        u'deplazierterer'   : u'deplatzierterer',
        u'deplazierteres'   : u'deplatzierteres',
        u'deplaziertere'    : u'deplatziertere',
        u'deplazierter'     : u'deplatzierter',
        u'deplaziertestem'  : u'deplatziertestem',
        u'deplaziertesten'  : u'deplatziertesten',
        u'deplaziertester'  : u'deplatziertester',
        u'deplaziertestes'  : u'deplatziertestes',
        u'deplazierteste'   : u'deplatzierteste',
        u'deplaziertes'     : u'deplatziertes',
        u'deplazierte'      : u'deplatzierte',
        u'deplaziert'       : u'deplatziert',
        u'deputiertenkongreß': u'deputiertenkongress',
        u'desachalandiren'  : u'desachalandieren',
        u'deßhalb'       : u'desshalb',
        u'detailbeseßnerem' : u'detailbesessnerem',
        u'detailbeseßneren' : u'detailbesessneren',
        u'detailbeseßnerer' : u'detailbesessnerer',
        u'detailbeseßneres' : u'detailbesessneres',
        u'detailbeseßnere'  : u'detailbesessnere',
        u'detailbeseßner'   : u'detailbesessner',
        u'deutschenhaß'     : u'deutschenhass',
        u'diättips'         : u'diättipps',
        u'diättip'          : u'diättipp',
        u'dichterroß'       : u'dichterross',
        u'dienstbeflißnerem': u'dienstbeflissnerem',
        u'dienstbeflißneren': u'dienstbeflissneren',
        u'dienstbeflißnerer': u'dienstbeflissnerer',
        u'dienstbeflißneres': u'dienstbeflissneres',
        u'dienstbeflißnere' : u'dienstbeflissnere',
        u'dienstbeflißner'  : u'dienstbeflissner',
        u'dienstschluß'     : u'dienstschluss',
        u'diethyläthers'    : u'diethylethers',
        u'diethyläther'     : u'diethylether',
        u'differenzierungsprozeß': u'differenzierungsprozess',
        u'diplomatenpaß'    : u'diplomatenpass',
        u'direktschuß'      : u'direktschuss',
        u'dißten'           : u'dissten',
        u'dißtest'          : u'disstest',
        u'dißtet'           : u'disstet',
        u'dißte'            : u'disste',
        u'disstreß'         : u'disstress',
        u'dißt'             : u'disst',
        u'diß'              : u'diss',
        u'distanzschuß'     : u'distanzschuss',
        u'ditto'            : u'dito',
        u'doctor'        : u'doktor',
        u'donaudampfschiffahrtsgesellschaftskapitänen': u'donaudampfschifffahrtsgesellschaftskapitänen',
        u'donaudampfschiffahrtsgesellschaftskapitäne': u'donaudampfschifffahrtsgesellschaftskapitäne',
        u'donaudampfschiffahrtsgesellschaftskapitäns': u'donaudampfschifffahrtsgesellschaftskapitäns',
        u'donaudampfschiffahrtsgesellschaftskapitän': u'donaudampfschifffahrtsgesellschaftskapitän',
        u'donaudampfschiffahrtsgesellschaft': u'donaudampfschifffahrtsgesellschaft',
        u'doppelpaßspiel'   : u'doppelpassspiel',
        u'doppelpaß'        : u'doppelpass',
        u'drankfaß'         : u'drankfass',
        u'drauflosschoßt'   : u'drauflosschosst',
        u'drauflosschoß'    : u'drauflosschoss',
        u'drehschuß'        : u'drehschuss',
        u'dreipaß'          : u'dreipass',
        u'dreßten'          : u'dressten',
        u'dreßtest'         : u'dresstest',
        u'dreßtet'          : u'dresstet',
        u'dreßte'           : u'dresste',
        u'dreßt'            : u'dresst',
        u'dreß'             : u'dress',
        u'dreyen'           : u'dreien',
        u'dreyer'           : u'dreier',
        u'dreye'            : u'dreie',
        u'drey'             : u'drei',
        u'drittklaßlerin'   : u'drittklasslerin',
        u'drittkläßlerin'   : u'drittklässlerin',
        u'drittkläßlern'    : u'drittklässlern',
        u'drittkläßlers'    : u'drittklässlers',
        u'drittklaßler'     : u'drittklassler',
        u'drittkläßler'     : u'drittklässler',
        u'drittplaziertem'  : u'drittplatziertem',
        u'drittplazierten'  : u'drittplatzierten',
        u'drittplazierter'  : u'drittplatzierter',
        u'drittplazierte'   : u'drittplatzierte',
        u'drogeneinfluß'    : u'drogeneinfluss',
        u'drogenmißbrauch'  : u'drogenmissbrauch',
        u'droßlest'         : u'drosslest',
        u'droßlet'          : u'drosslet',
        u'droßle'           : u'drossle',
        u'droßlung'         : u'drosslung',
        u'dum-dum-geschoß'  : u'dum-dum-geschoss',
        u'dumdumgeschoß'    : u'dumdumgeschoss',
        u'dummies'          : u'dummys',
        u'dünnschiß'        : u'dünnschiss',
        u'durchbißt'        : u'durchbisst',
        u'durchbiß'         : u'durchbiss',
        u'durcheinandereßt' : u'durcheinanderesst',
        u'durcheinanderißt' : u'durcheinanderisst',
        u'durchfloßt'       : u'durchflosst',
        u'durchfloß'        : u'durchfloss',
        u'durchflußgeschwindigkeit': u'durchflussgeschwindigkeit',
        u'durchflußmengen'  : u'durchflussmengen',
        u'durchflußmenge'   : u'durchflussmenge',
        u'durchflußmesser'  : u'durchflussmesser',
        u'durchfluß'        : u'durchfluss',
        u'durchfreßnerem'   : u'durchfressnerem',
        u'durchfreßneren'   : u'durchfressneren',
        u'durchfreßnerer'   : u'durchfressnerer',
        u'durchfreßneres'   : u'durchfressneres',
        u'durchfreßnere'    : u'durchfressnere',
        u'durchfreßner'     : u'durchfressner',
        u'durchfreßt'       : u'durchfresst',
        u'durchfrißt'       : u'durchfrisst',
        u'durchgepreßt'     : u'durchgepresst',
        u'durchgeseßnerem'  : u'durchgesessnerem',
        u'durchgeseßneren'  : u'durchgesessneren',
        u'durchgeseßnerer'  : u'durchgesessnerer',
        u'durchgeseßneres'  : u'durchgesessneres',
        u'durchgeseßnere'   : u'durchgesessnere',
        u'durchgeseßner'    : u'durchgesessner',
        u'durchgoßt'        : u'durchgosst',
        u'durchgoß'         : u'durchgoss',
        u'durchißt'         : u'durchisst',
        u'durchlaßt'        : u'durchlasst',
        u'durchläßt'        : u'durchlässt',
        u'durchlaß'         : u'durchlass',
        u'durchnäßten'      : u'durchnässten',
        u'durchnäßter'   : u'durchnässter',
        u'durchnäßtest'     : u'durchnässtest',
        u'durchnäßtet'      : u'durchnässtet',
        u'durchnäßte'       : u'durchnässte',
        u'durchnäßt'        : u'durchnässt',
        u'durchnäß'         : u'durchnäss',
        u'durchnumerieren'  : u'durchnummerieren',
        u'durchschuß'       : u'durchschuss',
        u'durchtelephonieren': u'durchtelefonieren',
        u'dußligem'         : u'dussligem',
        u'dußligen'         : u'dussligen',
        u'dußligerem'       : u'dussligerem',
        u'dußligeren'       : u'dussligeren',
        u'dußligerer'       : u'dussligerer',
        u'dußligeres'       : u'dussligeres',
        u'dußligere'        : u'dussligere',
        u'dußliger'         : u'dussliger',
        u'dußliges'         : u'dussliges',
        u'dußlige'          : u'dusslige',
        u'dußligstem'       : u'dussligstem',
        u'dußligsten'       : u'dussligsten',
        u'dußligster'       : u'dussligster',
        u'dußligstes'       : u'dussligstes',
        u'dußligste'        : u'dussligste',
        u'dußlig'           : u'dusslig',
        u'e-baß'            : u'e-bass',
        u'egyptens'         : u'ägyptens',
        u'egypten'          : u'ägypten',
        u'eheprozeß'        : u'eheprozess',
        u'ehescheidungsprozeß': u'ehescheidungsprozess',
        u'ehprozeß'         : u'ehprozess',
        u'ehrprozeß'        : u'ehrprozess',
        u'eigenthumen'      : u'eigentumen',
        u'eigenthümern'     : u'eigentümern',
        u'eigenthümers'     : u'eigentümers',
        u'eigenthümer'      : u'eigentümer',
        u'eigenthumes'      : u'eigentumes',
        u'eigenthume'       : u'eigentume',
        u'eigenthums'       : u'eigentums',
        u'eigenthum'        : u'eigentum',
        u'einbleuen'        : u'einbläuen',
        u'einfangprozeß'    : u'einfangprozess',
        u'einflußbereichen' : u'einflussbereichen',
        u'einflußbereiches' : u'einflussbereiches',
        u'einflußbereiche'  : u'einflussbereiche',
        u'einflußbereichs'  : u'einflussbereichs',
        u'einflußbereich'   : u'einflussbereich',
        u'einflußreichem'   : u'einflussreichem',
        u'einflußreichen'   : u'einflussreichen',
        u'einflußreicherem' : u'einflussreicherem',
        u'einflußreicheren' : u'einflussreicheren',
        u'einflußreicherer' : u'einflussreicherer',
        u'einflußreicheres' : u'einflussreicheres',
        u'einflußreichere'  : u'einflussreichere',
        u'einflußreicher'   : u'einflussreicher',
        u'einflußreiches'   : u'einflussreiches',
        u'einflußreiche'    : u'einflussreiche',
        u'einflußreichstem' : u'einflussreichstem',
        u'einflußreichsten' : u'einflussreichsten',
        u'einflußreichster' : u'einflussreichster',
        u'einflußreichstes' : u'einflussreichstes',
        u'einflußreichste'  : u'einflussreichste',
        u'einflußreich'     : u'einflussreich',
        u'einfluß'          : u'einfluss',
        u'eingefaßte'    : u'eingefasste',
        u'eingekremt'       : u'eingecremt',
        u'einkremend'       : u'eincremend',
        u'einkremen'        : u'eincremen',
        u'einkremest'       : u'eincremest',
        u'einkremet'        : u'eincremet',
        u'einkreme'         : u'eincreme',
        u'einkremst'        : u'eincremst',
        u'einkremten'       : u'eincremten',
        u'einkremtest'      : u'eincremtest',
        u'einkremtet'       : u'eincremtet',
        u'einkremte'        : u'eincremte',
        u'einkremt'         : u'eincremt',
        u'einkrem'          : u'eincrem',
        u'einlaßt'          : u'einlasst',
        u'einläßt'          : u'einlässt',
        u'einlaß'           : u'einlass',
        u'einnäßten'        : u'einnässten',
        u'einnäßtest'       : u'einnässtest',
        u'einnäßtet'        : u'einnässtet',
        u'einnäßte'         : u'einnässte',
        u'einschißt'        : u'einschisst',
        u'einschiß'         : u'einschiss',
        u'einschloß'        : u'einschloss',
        u'einschluß'        : u'einschluss',
        u'einschmelzungsprozeß': u'einschmelzungsprozess',
        u'einschußlöchern'  : u'einschusslöchern',
        u'einschußlöcher'   : u'einschusslöcher',
        u'einschußloches'   : u'einschussloches',
        u'einschußloche'    : u'einschussloche',
        u'einschußlochs'    : u'einschusslochs',
        u'einschußloch'     : u'einschussloch',
        u'einschuß'         : u'einschuss',
        u'einsendeschluß'   : u'einsendeschluss',
        u'einzukremen'      : u'einzucremen',
        u'eisschnellaufens' : u'eisschnelllaufens',
        u'eisschnellaufen'  : u'eisschnelllaufen',
        u'eisschnelläuferinnen': u'eisschnellläuferinnen',
        u'eisschnelläuferin': u'eisschnellläuferin',
        u'eisschnelläufern' : u'eisschnellläufern',
        u'eisschnelläufers' : u'eisschnellläufers',
        u'eisschnelläufer'  : u'eisschnellläufer',
        u'eisschnellaufes'  : u'eisschnelllaufes',
        u'eisschnellaufe'   : u'eisschnelllaufe',
        u'eisschnellaufs'   : u'eisschnelllaufs',
        u'eisschnellauf'    : u'eisschnelllauf',
        u'electro'          : u'elektro',
        u'elephanten'    : u'elefanten',
        u'elephant'      : u'elefant',
        u'elsaß-lothringens': u'elsass-lothringens',
        u'elsaß-lothringen' : u'elsass-lothringen',
        u'elsaß'            : u'elsass',
        u'emanzipationsprozeß': u'emanzipationsprozess',
        u'emporrißt'        : u'emporrisst',
        u'emporriß'         : u'emporriss',
        u'energiepaß'       : u'energiepass',
        u'engpaß'           : u'engpass',
        u'entfeßlest'       : u'entfesslest',
        u'entfeßlet'        : u'entfesslet',
        u'entfeßle'         : u'entfessle',
        u'entfloßt'         : u'entflosst',
        u'entfloß'          : u'entfloss',
        u'entlaßt'          : u'entlasst',
        u'entläßt'          : u'entlässt',
        u'entlaß'           : u'entlass',
        u'entrißt'          : u'entrisst',
        u'entriß'           : u'entriss',
        u'entschloßt'       : u'entschlosst',
        u'entschloß'        : u'entschloss',
        u'entschloß'     : u'entschloss',
        u'entschlüßlest'    : u'entschlüsslest',
        u'entschlüßlet'     : u'entschlüsslet',
        u'entschlüßle'      : u'entschlüssle',
        u'entschluß'        : u'entschluss',
        u'entschluß'     : u'entschluss',
        u'entspannungsprozeß': u'entspannungsprozess',
        u'entsproßt'        : u'entsprosst',
        u'entsproß'         : u'entspross',
        u'entstehungsprozeß': u'entstehungsprozess',
        u'entwäßre'         : u'entwässre',
        u'entweder-oder'    : u'entweder-oder',
        u'entwickelungsprozeß': u'entwickelungsprozess',
        u'entwicklungsprozeß': u'entwicklungsprozess',
        u'entzweirißt'      : u'entzweirisst',
        u'entzweiriß'       : u'entzweiriss',
        u'erblaßten'        : u'erblassten',
        u'erblaßtest'       : u'erblasstest',
        u'erblaßtet'        : u'erblasstet',
        u'erblaßte'         : u'erblasste',
        u'erblaßt'          : u'erblasst',
        u'erblaß'           : u'erblass',
        u'erdgeschoßwohnungen': u'erdgeschosswohnungen',
        u'erdgeschoßwohnung': u'erdgeschosswohnung',
        u'erdnußbutter'     : u'erdnussbutter',
        u'erdnußflips'      : u'erdnussflips',
        u'erdnußflip'       : u'erdnussflip',
        u'erdnuß'           : u'erdnuss',
        u'erdroßlest'       : u'erdrosslest',
        u'erdroßlet'        : u'erdrosslet',
        u'erdroßle'         : u'erdrossle',
        u'ereigniß'         : u'ereignis',
        u'erfaßbarer'    : u'erfassbarer',
        u'erfaßten'         : u'erfassten',
        u'erfaßtest'        : u'erfasstest',
        u'erfaßtet'         : u'erfasstet',
        u'erfaßte'          : u'erfasste',
        u'erfaßte'       : u'erfasste',
        u'erfaßt'           : u'erfasst',
        u'erfaßt'        : u'erfasst',
        u'erfaß'            : u'erfass',
        u'erforderniß'      : u'erfordernis',
        u'ergoßt'           : u'ergosst',
        u'ergoß'            : u'ergoss',
        u'erkenntnisprozeß' : u'erkenntnisprozess',
        u'erkenntniß'       : u'erkenntnis',
        u'erlaßt'           : u'erlasst',
        u'erläßt'           : u'erlässt',
        u'erlaß'            : u'erlass',
        u'ermeßt'           : u'ermesst',
        u'ermißt'           : u'ermisst',
        u'ermiß'            : u'ermiss',
        u'erpreßten'        : u'erpressten',
        u'erpreßtest'       : u'erpresstest',
        u'erpreßtet'        : u'erpresstet',
        u'erpreßte'         : u'erpresste',
        u'erpreßt'          : u'erpresst',
        u'erpreß'           : u'erpress',
        u'errathen'         : u'erraten',
        u'erschloßt'        : u'erschlosst',
        u'erschloß'         : u'erschloss',
        u'erschoßt'         : u'erschosst',
        u'erschoß'          : u'erschoss',
        u'ersproßt'         : u'ersprosst',
        u'ersproß'          : u'erspross',
        u'erstklaßlerinnen' : u'erstklasslerinnen',
        u'erstkläßlerinnen' : u'erstklässlerinnen',
        u'erstklaßlerin'    : u'erstklasslerin',
        u'erstkläßlerin'    : u'erstklässlerin',
        u'erstklaßlern'     : u'erstklasslern',
        u'erstkläßlern'     : u'erstklässlern',
        u'erstklaßlers'     : u'erstklasslers',
        u'erstkläßlers'     : u'erstklässlers',
        u'erstklaßler'      : u'erstklassler',
        u'erstkläßler'      : u'erstklässler',
        u'erstplaziertem'   : u'erstplatziertem',
        u'erstplazierten'   : u'erstplatzierten',
        u'erstplazierter'   : u'erstplatzierter',
        u'erstplazierte'    : u'erstplatzierte',
        u'erziehungsprozeß' : u'erziehungsprozess',
        u'eßbarem'          : u'essbarem',
        u'eßbaren'          : u'essbaren',
        u'eßbarerem'        : u'essbarerem',
        u'eßbareren'        : u'essbareren',
        u'eßbarerer'        : u'essbarerer',
        u'eßbareres'        : u'essbareres',
        u'eßbarer'          : u'essbarer',
        u'eßbares'          : u'essbares',
        u'eßbare'           : u'essbare',
        u'eßbarstem'        : u'essbarstem',
        u'eßbarsten'        : u'essbarsten',
        u'eßbarster'        : u'essbarster',
        u'eßbarstes'        : u'essbarstes',
        u'eßbarste'         : u'essbarste',
        u'eßbar'            : u'essbar',
        u'eßbestecken'      : u'essbestecken',
        u'eßbesteckes'      : u'essbesteckes',
        u'eßbestecke'       : u'essbestecke',
        u'eßbestecks'       : u'essbestecks',
        u'eßbesteck'        : u'essbesteck',
        u'eßecken'          : u'essecken',
        u'eßecke'           : u'essecke',
        u'eßgeschirr'       : u'essgeschirr',
        u'eßgewohnheit'     : u'essgewohnheit',
        u'eßkastanie'       : u'esskastanie',
        u'eßküche'          : u'essküche',
        u'eßkulturen'       : u'esskulturen',
        u'eßkultur'         : u'esskultur',
        u'eßlöffeln'        : u'esslöffeln',
        u'eßlöffels'        : u'esslöffels',
        u'eßlöffel'         : u'esslöffel',
        u'eßlöffelweisem'   : u'esslöffelweisem',
        u'eßlöffelweisen'   : u'esslöffelweisen',
        u'eßlöffelweiser'   : u'esslöffelweiser',
        u'eßlöffelweises'   : u'esslöffelweises',
        u'eßlöffelweise'    : u'esslöffelweise',
        u'eßlust'           : u'esslust',
        u'eßpapiers'        : u'esspapiers',
        u'eßpapier'         : u'esspapier',
        u'eßstäbchen'       : u'essstäbchen',
        u'eßstörungen'      : u'essstörungen',
        u'eßstörung'        : u'essstörung',
        u'eßstube'       : u'essstube',
        u'eßsucht'          : u'esssucht',
        u'eßtischen'        : u'esstischen',
        u'eßtisches'        : u'esstisches',
        u'eßtische'         : u'esstische',
        u'eßtischs'         : u'esstischs',
        u'eßtisch'          : u'esstisch',
        u'eßtisch'       : u'esstisch',
        u'eßt'              : u'esst',
        u'eßzimmern'        : u'esszimmern',
        u'eßzimmerstuhles'  : u'esszimmerstuhles',
        u'eßzimmerstuhle'   : u'esszimmerstuhle',
        u'eßzimmerstuhls'   : u'esszimmerstuhls',
        u'eßzimmerstuhl'    : u'esszimmerstuhl',
        u'eßzimmers'        : u'esszimmers',
        u'eßzimmertür'      : u'esszimmertür',
        u'eßzimmer'         : u'esszimmer',
        u'eßzimmer'      : u'esszimmer',
        u'eur'           : u'euro',
        u'expreß'           : u'express',
        u'expreßzügen'      : u'expresszügen',
        u'expreßzuges'      : u'expresszuges',
        u'expreßzuge'       : u'expresszuge',
        u'expreßzüge'       : u'expresszüge',
        u'expreßzugs'       : u'expresszugs',
        u'expreßzug'        : u'expresszug',
        u'exzeß'            : u'exzess',
        u'fabrikationsprozeß': u'fabrikationsprozess',
        u'fahrniß'          : u'fahrnis',
        u'fahrradschloß'    : u'fahrradschloss',
        u'fairneß'          : u'fairness',
        u'fangschuß'        : u'fangschuss',
        u'farbphotos'       : u'farbfotos',
        u'farbphoto'        : u'farbfoto',
        u'faßbarem'         : u'fassbarem',
        u'faßbaren'         : u'fassbaren',
        u'faßbarerem'       : u'fassbarerem',
        u'faßbareren'       : u'fassbareren',
        u'faßbarerer'       : u'fassbarerer',
        u'faßbareres'       : u'fassbareres',
        u'faßbarere'        : u'fassbarere',
        u'faßbarer'         : u'fassbarer',
        u'faßbares'         : u'fassbares',
        u'faßbare'          : u'fassbare',
        u'faßbarstem'       : u'fassbarstem',
        u'faßbarsten'       : u'fassbarsten',
        u'faßbarster'       : u'fassbarster',
        u'faßbarstes'       : u'fassbarstes',
        u'faßbarste'        : u'fassbarste',
        u'faßbar'           : u'fassbar',
        u'faßbieren'        : u'fassbieren',
        u'faßbieres'        : u'fassbieres',
        u'faßbiere'         : u'fassbiere',
        u'faßbiers'         : u'fassbiers',
        u'faßbier'          : u'fassbier',
        u'faßbindern'       : u'fassbindern',
        u'faßbinders'       : u'fassbinders',
        u'faßbinder'        : u'fassbinder',
        u'faßbomben'        : u'fassbomben',
        u'faßbombe'         : u'fassbombe',
        u'faßdauben'        : u'fassdauben',
        u'faßdaube'         : u'fassdaube',
        u'fassettenartigem' : u'facettenartigem',
        u'fassettenartigen' : u'facettenartigen',
        u'fassettenartiger' : u'facettenartiger',
        u'fassettenartiges' : u'facettenartiges',
        u'fassettenartige'  : u'facettenartige',
        u'fassettenartig'   : u'facettenartig',
        u'fassettenaugen'   : u'facettenaugen',
        u'fassettenauges'   : u'facettenauges',
        u'fassettenauge'    : u'facettenauge',
        u'fassettenreichem' : u'facettenreichem',
        u'fassettenreichen' : u'facettenreichen',
        u'fassettenreicherem': u'facettenreicherem',
        u'fassettenreicheren': u'facettenreicheren',
        u'fassettenreicherer': u'facettenreicherer',
        u'fassettenreicheres': u'facettenreicheres',
        u'fassettenreichere': u'facettenreichere',
        u'fassettenreicher' : u'facettenreicher',
        u'fassettenreiches' : u'facettenreiches',
        u'fassettenreiche'  : u'facettenreiche',
        u'fassettenreichstem': u'facettenreichstem',
        u'fassettenreichsten': u'facettenreichsten',
        u'fassettenreichster': u'facettenreichster',
        u'fassettenreichstes': u'facettenreichstes',
        u'fassettenreichste': u'facettenreichste',
        u'fassettenreichtums': u'facettenreichtums',
        u'fassettenreichtum': u'facettenreichtum',
        u'fassettenreich'   : u'facettenreich',
        u'fassetten'        : u'facetten',
        u'fassette'         : u'facette',
        u'faßgeschmackes'   : u'fassgeschmackes',
        u'faßgeschmacks'    : u'fassgeschmacks',
        u'faßgeschmack'     : u'fassgeschmack',
        u'faßküfern'        : u'fassküfern',
        u'faßküfers'        : u'fassküfers',
        u'faßküfer'         : u'fassküfer',
        u'faßlichem'        : u'fasslichem',
        u'faßlichen'        : u'fasslichen',
        u'faßlicherem'      : u'fasslicherem',
        u'faßlicheren'      : u'fasslicheren',
        u'faßlicherer'      : u'fasslicherer',
        u'faßlicheres'      : u'fasslicheres',
        u'faßlichere'       : u'fasslichere',
        u'faßlicher'        : u'fasslicher',
        u'faßliches'        : u'fassliches',
        u'faßliche'         : u'fassliche',
        u'faßlichstem'      : u'fasslichstem',
        u'faßlichsten'      : u'fasslichsten',
        u'faßlichster'      : u'fasslichster',
        u'faßlichstes'      : u'fasslichstes',
        u'faßlichste'       : u'fasslichste',
        u'faßlich'          : u'fasslich',
        u'faßmalern'        : u'fassmalern',
        u'faßmalers'        : u'fassmalers',
        u'faßmaler'         : u'fassmaler',
        u'faßten'           : u'fassten',
        u'faßten'        : u'fassten',
        u'faßtest'          : u'fasstest',
        u'faßtet'           : u'fasstet',
        u'faßte'            : u'fasste',
        u'faßte'         : u'fasste',
        u'faßtrichtern'     : u'fasstrichtern',
        u'faßtrichters'     : u'fasstrichters',
        u'faßtrichter'      : u'fasstrichter',
        u'faßt'             : u'fasst',
        u'faßt'          : u'fasst',
        u'faß'              : u'fass',
        u'faßweinen'        : u'fassweinen',
        u'faßweines'        : u'fassweines',
        u'faßweine'         : u'fassweine',
        u'faßweins'         : u'fassweins',
        u'faßwein'          : u'fasswein',
        u'fäulnisprozeß'    : u'fäulnisprozess',
        u'faustschluß'      : u'faustschluss',
        u'fehlpaß'          : u'fehlpass',
        u'fehlschluß'       : u'fehlschluss',
        u'fehlschuß'        : u'fehlschuss',
        u'fellos'           : u'felllos',
        u'fernschuß'        : u'fernschuss',
        u'fertigungsprozeß' : u'fertigungsprozess',
        u'feßlest'          : u'fesslest',
        u'feßlet'           : u'fesslet',
        u'feßle'            : u'fessle',
        u'fettusche'        : u'fetttusche',
        u'feuerschutzabschluß': u'feuerschutzabschluss',
        u'figurbewußtem'    : u'figurbewusstem',
        u'figurbewußten'    : u'figurbewussten',
        u'figurbewußterem'  : u'figurbewussterem',
        u'figurbewußteren'  : u'figurbewussteren',
        u'figurbewußterer'  : u'figurbewussterer',
        u'figurbewußteres'  : u'figurbewussteres',
        u'figurbewußtere'   : u'figurbewusstere',
        u'figurbewußter'    : u'figurbewusster',
        u'figurbewußtestem' : u'figurbewusstestem',
        u'figurbewußtesten' : u'figurbewusstesten',
        u'figurbewußtester' : u'figurbewusstester',
        u'figurbewußtestes' : u'figurbewusstestes',
        u'figurbewußteste'  : u'figurbewussteste',
        u'figurbewußtes'    : u'figurbewusstes',
        u'figurbewußte'     : u'figurbewusste',
        u'figurbewußt'      : u'figurbewusst',
        u'filmriß'          : u'filmriss',
        u'firnißten'        : u'firnissten',
        u'firnißtest'       : u'firnisstest',
        u'firnißtet'        : u'firnisstet',
        u'firnißte'         : u'firnisste',
        u'firnißt'          : u'firnisst',
        u'firniß'           : u'firniss',
        u'fitneßcentern'    : u'fitnesscentern',
        u'fitneßcenters'    : u'fitnesscenters',
        u'fitneßcenter'     : u'fitnesscenter',
        u'fitneßgeräten'    : u'fitnessgeräten',
        u'fitneßgerätes'    : u'fitnessgerätes',
        u'fitneßgeräte'     : u'fitnessgeräte',
        u'fitneßgeräts'     : u'fitnessgeräts',
        u'fitneßgerät'      : u'fitnessgerät',
        u'fitneßräumen'     : u'fitnessräumen',
        u'fitneßraumes'     : u'fitnessraumes',
        u'fitneßraume'      : u'fitnessraume',
        u'fitneßräume'      : u'fitnessräume',
        u'fitneßraums'      : u'fitnessraums',
        u'fitneßraum'       : u'fitnessraum',
        u'fitneß-studios'   : u'fitness-studios',
        u'fitneßstudios'    : u'fitnessstudios',
        u'fitneß-studio'    : u'fitness-studio',
        u'fitneßstudio'     : u'fitnessstudio',
        u'fitneßtrainings'  : u'fitnesstrainings',
        u'fitneßtraining'   : u'fitnesstraining',
        u'fitneß'           : u'fitness',
        u'flachschuß'       : u'flachschuss',
        u'flohbiß'          : u'flohbiss',
        u'floßt'            : u'flosst',
        u'floß'             : u'floss',
        u'flußaalen'        : u'flussaalen',
        u'flußaales'        : u'flussaales',
        u'flußaale'         : u'flussaale',
        u'flußaals'         : u'flussaals',
        u'flußaal'          : u'flussaal',
        u'flußabwärts'      : u'flussabwärts',
        u'flußarmen'        : u'flussarmen',
        u'flußarmes'        : u'flussarmes',
        u'flußarme'         : u'flussarme',
        u'flußarms'         : u'flussarms',
        u'flußarm'          : u'flussarm',
        u'flußaufwärts'     : u'flussaufwärts',
        u'flußbetten'       : u'flussbetten',
        u'flußbette'        : u'flussbette',
        u'flußbett'         : u'flussbett',
        u'flüßchens'        : u'flüsschens',
        u'flüßchen'         : u'flüsschen',
        u'flußdenkens'      : u'flussdenkens',
        u'flußdenken'       : u'flussdenken',
        u'flußfischen'      : u'flussfischen',
        u'flußfisches'      : u'flussfisches',
        u'flußfische'       : u'flussfische',
        u'flußfischs'       : u'flussfischs',
        u'flußfisch'        : u'flussfisch',
        u'flußgebietseinheiten': u'flussgebietseinheiten',
        u'flußgebietseinheit': u'flussgebietseinheit',
        u'flußgeistern'     : u'flussgeistern',
        u'flußgeister'      : u'flussgeister',
        u'flußgeistes'      : u'flussgeistes',
        u'flußgeiste'       : u'flussgeiste',
        u'flußgeists'       : u'flussgeists',
        u'flußgeist'        : u'flussgeist',
        u'flußgründen'      : u'flussgründen',
        u'flußgrundes'      : u'flussgrundes',
        u'flußgrunde'       : u'flussgrunde',
        u'flußgründe'       : u'flussgründe',
        u'flußgrunds'       : u'flussgrunds',
        u'flußgrund'        : u'flussgrund',
        u'flußhafens'       : u'flusshafens',
        u'flußhafen'        : u'flusshafen',
        u'flußhäfen'        : u'flusshäfen',
        u'flußhändlern'     : u'flusshändlern',
        u'flußhändlers'     : u'flusshändlers',
        u'flußhändler'      : u'flusshändler',
        u'flußkrebsen'      : u'flusskrebsen',
        u'flußkrebses'      : u'flusskrebses',
        u'flußkrebse'       : u'flusskrebse',
        u'flußkrebs'        : u'flusskrebs',
        u'flußläufen'       : u'flussläufen',
        u'flußlaufes'       : u'flusslaufes',
        u'flußlaufe'        : u'flusslaufe',
        u'flußläufe'        : u'flussläufe',
        u'flußlaufs'        : u'flusslaufs',
        u'flußlauf'         : u'flusslauf',
        u'flußmarschbodens' : u'flussmarschbodens',
        u'flußmarschboden'  : u'flussmarschboden',
        u'flußmarschböden'  : u'flussmarschböden',
        u'flußmitten'       : u'flussmitten',
        u'flußmitte'        : u'flussmitte',
        u'flußmündungen'    : u'flussmündungen',
        u'flußmündung'      : u'flussmündung',
        u'flußnamens'       : u'flussnamens',
        u'flußnamen'        : u'flussnamen',
        u'flußname'         : u'flussname',
        u'flußniederungen'  : u'flussniederungen',
        u'flußniederung'    : u'flussniederung',
        u'flußpferden'      : u'flusspferden',
        u'flußpferdes'      : u'flusspferdes',
        u'flußpferde'       : u'flusspferde',
        u'flußpferds'       : u'flusspferds',
        u'flußpferd'        : u'flusspferd',
        u'flußregenpfeifern': u'flussregenpfeifern',
        u'flußregenpfeifers': u'flussregenpfeifers',
        u'flußregenpfeifer' : u'flussregenpfeifer',
        u'flußsäure'        : u'flusssäure',
        u'flussschiffahrt'  : u'flussschifffahrt',
        u'flußschiffahrt'   : u'flussschifffahrt',
        u'flußschiffen'     : u'flussschiffen',
        u'flußschiffes'     : u'flussschiffes',
        u'flußschiffe'      : u'flussschiffe',
        u'flußschifffahrt'  : u'flussschifffahrt',
        u'flußschiffs'      : u'flussschiffs',
        u'flußschiff'       : u'flussschiff',
        u'flußseeschwalben' : u'flussseeschwalben',
        u'flußseeschwalbe'  : u'flussseeschwalbe',
        u'flußspaten'       : u'flussspaten',
        u'flußspäten'       : u'flussspäten',
        u'flußspates'       : u'flussspates',
        u'flußspate'        : u'flussspate',
        u'flußspäte'        : u'flussspäte',
        u'flußspats'        : u'flussspats',
        u'flußspat'         : u'flussspat',
        u'flußufern'        : u'flussufern',
        u'flußufers'        : u'flussufers',
        u'flußufer'         : u'flussufer',
        u'fluß'             : u'fluss',
        u'flußwassern'      : u'flusswassern',
        u'flußwässern'      : u'flusswässern',
        u'flußwassers'      : u'flusswassers',
        u'flußwasser'       : u'flusswasser',
        u'flußwässer'       : u'flusswässer',
        u'fönend'           : u'föhnend',
        u'fönen'            : u'föhnen',
        u'fönest'           : u'föhnest',
        u'fönes'            : u'föhnes',
        u'fönet'            : u'föhnet',
        u'föne'             : u'föhne',
        u'fönst'            : u'föhnst',
        u'föns'             : u'föhns',
        u'fönten'           : u'föhnten',
        u'föntest'          : u'föhntest',
        u'föntet'           : u'föhntet',
        u'fönte'            : u'föhnte',
        u'fönt'             : u'föhnt',
        u'fön'              : u'föhn',
        u'formiren'         : u'formieren',
        u'fotographen'      : u'fotografen',
        u'fotographieren'   : u'fotografieren',
        u'fotograph'        : u'fotograf',
        u'frachtschiffahrt' : u'frachtschifffahrt',
        u'fraktionsbeschluß': u'fraktionsbeschluss',
        u'frauenhaß'        : u'frauenhass',
        u'frauenüberschuß'  : u'frauenüberschuss',
        u'freilaßt'         : u'freilasst',
        u'freiläßt'         : u'freilässt',
        u'fremdenhaß'       : u'fremdenhass',
        u'freßaalen'        : u'fressaalen',
        u'freßaales'        : u'fressaales',
        u'freßaale'         : u'fressaale',
        u'freßaals'         : u'fressaals',
        u'freßaal'          : u'fressaal',
        u'freßfeinden'      : u'fressfeinden',
        u'freßfeindes'      : u'fressfeindes',
        u'freßfeinde'       : u'fressfeinde',
        u'freßfeinds'       : u'fressfeinds',
        u'freßfeind'        : u'fressfeind',
        u'freßluken'        : u'fressluken',
        u'freßluke'         : u'fressluke',
        u'freßsäcken'       : u'fresssäcken',
        u'freßsackes'       : u'fresssackes',
        u'freßsacke'        : u'fresssacke',
        u'freßsäcke'        : u'fresssäcke',
        u'freßsacks'        : u'fresssacks',
        u'freßsack'         : u'fresssack',
        u'freßsüchtigem'    : u'fresssüchtigem',
        u'freßsüchtigen'    : u'fresssüchtigen',
        u'freßsüchtigerem'  : u'fresssüchtigerem',
        u'freßsüchtigeren'  : u'fresssüchtigeren',
        u'freßsüchtigerer'  : u'fresssüchtigerer',
        u'freßsüchtigeres'  : u'fresssüchtigeres',
        u'freßsüchtigere'   : u'fresssüchtigere',
        u'freßsüchtiger'    : u'fresssüchtiger',
        u'freßsüchtiges'    : u'fresssüchtiges',
        u'freßsüchtige'     : u'fresssüchtige',
        u'freßsüchtigstem'  : u'fresssüchtigstem',
        u'freßsüchtigsten'  : u'fresssüchtigsten',
        u'freßsüchtigster'  : u'fresssüchtigster',
        u'freßsüchtigstes'  : u'fresssüchtigstes',
        u'freßsüchtigste'   : u'fresssüchtigste',
        u'freßsüchtig'      : u'fresssüchtig',
        u'freytagen'        : u'freitagen',
        u'freytages'        : u'freitages',
        u'freytage'         : u'freitage',
        u'freytags'         : u'freitags',
        u'freytag'          : u'freitag',
        u'friedensprozeß'   : u'friedensprozess',
        u'friedensschluß'   : u'friedensschluss',
        u'frißt'            : u'frisst',
        u'friß'             : u'friss',
        u'friteuse'         : u'fritteuse',
        u'fritieren'        : u'frittieren',
        u'froschbiß'        : u'froschbiss',
        u'frottéstoffen'    : u'frotteestoffen',
        u'frottéstoffes'    : u'frotteestoffes',
        u'frottéstoffe'     : u'frotteestoffe',
        u'frottéstoffs'     : u'frotteestoffs',
        u'frottéstoff'      : u'frotteestoff',
        u'frottés'          : u'frottees',
        u'frotté'           : u'frottee',
        u'füllaut'          : u'fülllaut',
        u'fürbaß'           : u'fürbass',
        u'fürstenthum'      : u'fürstentum',
        u'fussballänderspielen': u'fußballländerspielen',
        u'fussballänderspieles': u'fußballländerspieles',
        u'fussballänderspiele': u'fußballländerspiele',
        u'fussballänderspiels': u'fußballländerspiels',
        u'fussballänderspiel': u'fußballländerspiel',
        u'fußballänderspiel': u'fußballländerspiel',
        u'fussballandesmeisterinnen': u'fußballlandesmeisterinnen',
        u'fussballandesmeisterin': u'fußballlandesmeisterin',
        u'fussballandesmeistern': u'fußballlandesmeistern',
        u'fussballandesmeisters': u'fußballlandesmeisters',
        u'fussballandesmeister': u'fußballlandesmeister',
        u'fußballandesmeister': u'fußballlandesmeister',
        u'fussballegenden'  : u'fußballlegenden',
        u'fußballegenden'   : u'fußballlegenden',
        u'fussballegende'   : u'fußballlegende',
        u'fußballegende'    : u'fußballlegende',
        u'fussballehrbüchern': u'fußballlehrbüchern',
        u'fussballehrbücher': u'fußballlehrbücher',
        u'fussballehrbuches': u'fußballlehrbuches',
        u'fussballehrbuche' : u'fußballlehrbuche',
        u'fussballehrbuchs' : u'fußballlehrbuchs',
        u'fussballehrbuch'  : u'fußballlehrbuch',
        u'fußballehrbuch'   : u'fußballlehrbuch',
        u'fussballehrerinnen': u'fußballlehrerinnen',
        u'fussballehrerin'  : u'fußballlehrerin',
        u'fussballehrern'   : u'fußballlehrern',
        u'fussballehrers'   : u'fußballlehrers',
        u'fussballehrer'    : u'fußballlehrer',
        u'fußballehrer'     : u'fußballlehrer',
        u'fussballiga'      : u'fußballliga',
        u'fußballiga'       : u'fußballliga',
        u'fußkuß'           : u'fußkuss',
        u'fußlest'          : u'fusslest',
        u'fußlet'           : u'fusslet',
        u'fußle'            : u'fussle',
        u'fußmeßstationen'  : u'fussmessstationen',
        u'fußmeßstation'    : u'fussmessstation',
        u'gangsterboß'      : u'gangsterboss',
        u'gärprozeß'        : u'gärprozess',
        u'gärungsprozeß'    : u'gärungsprozess',
        u'gasanschluß'      : u'gasanschluss',
        u'gäßchens'         : u'gässchens',
        u'gäßchen'          : u'gässchen',
        u'gäßchen'       : u'gässchen',
        u'gastwirthen'      : u'gastwirten',
        u'gastwirthes'      : u'gastwirtes',
        u'gastwirthe'       : u'gastwirte',
        u'gastwirths'       : u'gastwirts',
        u'gastwirth'        : u'gastwirt',
        u'gebirgspaß'       : u'gebirgspass',
        u'gebiß'            : u'gebiss',
        u'gecreutzigt'      : u'gekreuzigt',
        u'gedißt'           : u'gedisst',
        u'gedreßt'          : u'gedresst',
        u'gefängniß'        : u'gefängnis',
        u'gefaßtem'         : u'gefasstem',
        u'gefaßten'         : u'gefassten',
        u'gefaßterem'       : u'gefassterem',
        u'gefaßteren'       : u'gefassteren',
        u'gefaßterer'       : u'gefassterer',
        u'gefaßteres'       : u'gefassteres',
        u'gefaßtere'        : u'gefasstere',
        u'gefaßter'         : u'gefasster',
        u'gefaßtestem'      : u'gefasstestem',
        u'gefaßtesten'      : u'gefasstesten',
        u'gefaßtester'      : u'gefasstester',
        u'gefaßtestes'      : u'gefasstestes',
        u'gefaßteste'       : u'gefassteste',
        u'gefaßtes'         : u'gefasstes',
        u'gefaßte'          : u'gefasste',
        u'gefaßt'           : u'gefasst',
        u'gefaßt'        : u'gefasst',
        u'gefönt'           : u'geföhnt',
        u'gehaßt'           : u'gehasst',
        u'geheimniß'        : u'geheimnis',
        u'geheimtips'       : u'geheimtipps',
        u'geheimtip'        : u'geheimtipp',
        u'gehißt'           : u'gehisst',
        u'gehußt'           : u'gehusst',
        u'gekremt'          : u'gecremt',
        u'geküßt'           : u'geküsst',
        u'gelaßnerem'       : u'gelassnerem',
        u'gelaßneren'       : u'gelassneren',
        u'gelaßnerer'       : u'gelassnerer',
        u'gelaßneres'       : u'gelassneres',
        u'gelaßnere'        : u'gelassnere',
        u'gelaßner'         : u'gelassner',
        u'gelaß'            : u'gelass',
        u'geldabfluß'       : u'geldabfluss',
        u'geldzufluß'       : u'geldzufluss',
        u'gelöthet'         : u'gelötet',
        u'gemeinderäthen'   : u'gemeinderäten',
        u'gemeinderathes'   : u'gemeinderates',
        u'gemeinderathe'    : u'gemeinderate',
        u'gemeinderäthe'    : u'gemeinderäte',
        u'gemeinderaths'    : u'gemeinderats',
        u'gemeinderath'     : u'gemeinderat',
        u'gemeinfaßlichem'  : u'gemeinfasslichem',
        u'gemeinfaßlichen'  : u'gemeinfasslichen',
        u'gemeinfaßlicherem': u'gemeinfasslicherem',
        u'gemeinfaßlicheren': u'gemeinfasslicheren',
        u'gemeinfaßlicherer': u'gemeinfasslicherer',
        u'gemeinfaßlicheres': u'gemeinfasslicheres',
        u'gemeinfaßlichere' : u'gemeinfasslichere',
        u'gemeinfaßlicher'  : u'gemeinfasslicher',
        u'gemeinfaßliches'  : u'gemeinfassliches',
        u'gemeinfaßliche'   : u'gemeinfassliche',
        u'gemeinfaßlichstem': u'gemeinfasslichstem',
        u'gemeinfaßlichsten': u'gemeinfasslichsten',
        u'gemeinfaßlichster': u'gemeinfasslichster',
        u'gemeinfaßlichstes': u'gemeinfasslichstes',
        u'gemeinfaßlichste' : u'gemeinfasslichste',
        u'gemeinfaßlich'    : u'gemeinfasslich',
        u'gemeynt'          : u'gemeint',
        u'gemißt'           : u'gemisst',
        u'gemsen'           : u'gämsen',
        u'gemse'            : u'gämse',
        u'gemshörnern'      : u'gämshörnern',
        u'gemshörner'       : u'gämshörner',
        u'gemshornes'       : u'gämshornes',
        u'gemshorne'        : u'gämshorne',
        u'gemshorns'        : u'gämshorns',
        u'gemshorn'         : u'gämshorn',
        u'gemußt'           : u'gemusst',
        u'gemüthern'        : u'gemütern',
        u'gemüther'         : u'gemüter',
        u'gemüthes'         : u'gemütes',
        u'gemüthe'          : u'gemüte',
        u'gemüths'          : u'gemüts',
        u'gemüth'           : u'gemüt',
        u'genäßt'           : u'genässt',
        u'generalstabsausschuß': u'generalstabsausschuss',
        u'genesungsprozeß'  : u'genesungsprozess',
        u'genickschuß'      : u'genickschuss',
        u'genoß'            : u'genoss',
        u'genoß'         : u'genoss',
        u'genüßlichem'      : u'genüsslichem',
        u'genüßlichen'      : u'genüsslichen',
        u'genüßlicherem'    : u'genüsslicherem',
        u'genüßlicheren'    : u'genüsslicheren',
        u'genüßlicherer'    : u'genüsslicherer',
        u'genüßlicheres'    : u'genüsslicheres',
        u'genüßlichere'     : u'genüsslichere',
        u'genüßlicher'      : u'genüsslicher',
        u'genüßliches'      : u'genüssliches',
        u'genüßliche'       : u'genüssliche',
        u'genüßlichstem'    : u'genüsslichstem',
        u'genüßlichsten'    : u'genüsslichsten',
        u'genüßlichster'    : u'genüsslichster',
        u'genüßlichstes'    : u'genüsslichstes',
        u'genüßlichste'     : u'genüsslichste',
        u'genüßlich'        : u'genüsslich',
        u'genußmenschen'    : u'genussmenschen',
        u'genußmensch'      : u'genussmensch',
        u'genußmitteln'     : u'genussmitteln',
        u'genußmittels'     : u'genussmittels',
        u'genußmittel'      : u'genussmittel',
        u'genußspechten'    : u'genussspechten',
        u'genußspechtes'    : u'genussspechtes',
        u'genußspechte'     : u'genussspechte',
        u'genußspechts'     : u'genussspechts',
        u'genußspecht'      : u'genussspecht',
        u'genußsüchtigem'   : u'genusssüchtigem',
        u'genußsüchtigen'   : u'genusssüchtigen',
        u'genußsüchtigerem' : u'genusssüchtigerem',
        u'genußsüchtigeren' : u'genusssüchtigeren',
        u'genußsüchtigerer' : u'genusssüchtigerer',
        u'genußsüchtigeres' : u'genusssüchtigeres',
        u'genußsüchtigere'  : u'genusssüchtigere',
        u'genußsüchtiger'   : u'genusssüchtiger',
        u'genußsüchtiges'   : u'genusssüchtiges',
        u'genußsüchtige'    : u'genusssüchtige',
        u'genußsüchtigstem' : u'genusssüchtigstem',
        u'genußsüchtigsten' : u'genusssüchtigsten',
        u'genußsüchtigster' : u'genusssüchtigster',
        u'genußsüchtigstes' : u'genusssüchtigstes',
        u'genußsüchtigste'  : u'genusssüchtigste',
        u'genußsüchtig'     : u'genusssüchtig',
        u'genußsucht'       : u'genusssucht',
        u'genuß'            : u'genuss',
        u'genuß'         : u'genuss',
        u'gepaßt'           : u'gepasst',
        u'gepißt'           : u'gepisst',
        u'gepreßtem'        : u'gepresstem',
        u'gepreßten'        : u'gepressten',
        u'gepreßter'        : u'gepresster',
        u'gepreßtes'        : u'gepresstes',
        u'gepreßte'         : u'gepresste',
        u'gepreßt'          : u'gepresst',
        u'gepreßt'       : u'gepresst',
        u'gerauht'          : u'geraut',
        u'gerichtsbeschluß' : u'gerichtsbeschluss',
        u'gerichtsprozeß'   : u'gerichtsprozess',
        u'geröllawinen'     : u'gerölllawinen',
        u'geröllawine'      : u'gerölllawine',
        u'gesamtabschluß'   : u'gesamtabschluss',
        u'geschäftsprozeß'  : u'geschäftsprozess',
        u'geschaßt'         : u'geschasst',
        u'geschirreinigern' : u'geschirrreinigern',
        u'geschirreinigers' : u'geschirrreinigers',
        u'geschirreiniger'  : u'geschirrreiniger',
        u'geschiß'          : u'geschiss',
        u'geschlußfolgert'  : u'geschlussfolgert',
        u'geschneuzt'       : u'geschnäuzt',
        u'geschoßflächenzahlen': u'geschossflächenzahlen',
        u'geschoßflächenzahl': u'geschossflächenzahl',
        u'geschoßhöhen'     : u'geschosshöhen',
        u'geschoßhöhe'      : u'geschosshöhe',
        u'geschoßpost'      : u'geschosspost',
        u'geschoß'          : u'geschoss',
        u'geschoßwohnungen' : u'geschosswohnungen',
        u'geschoßwohnung'   : u'geschosswohnung',
        u'gesetzesbeschluß' : u'gesetzesbeschluss',
        u'gespieen'         : u'gespien',
        u'gestreßt'         : u'gestresst',
        u'gethan'           : u'getan',
        u'gethieres'        : u'getieres',
        u'gethiere'         : u'getiere',
        u'gethiers'         : u'getiers',
        u'gethier'          : u'getier',
        u'gethürmt'         : u'getürmt',
        u'gewehrschuß'      : u'gewehrschuss',
        u'gewinnummern'     : u'gewinnnummern',
        u'gewinnummer'      : u'gewinnnummer',
        u'gewissensbiß'     : u'gewissensbiss',
        u'gewißheiten'      : u'gewissheiten',
        u'gewißheit'        : u'gewissheit',
        u'gewißheit'     : u'gewissheit',
        u'gewiß'            : u'gewiss',
        u'gewiß'         : u'gewiss',
        u'gewußtem'         : u'gewusstem',
        u'gewußten'         : u'gewussten',
        u'gewußter'         : u'gewusster',
        u'gewußtes'         : u'gewusstes',
        u'gewußte'          : u'gewusste',
        u'gewußt'           : u'gewusst',
        u'gewußt'        : u'gewusst',
        u'giebt'            : u'gibt',
        u'glasfluß'         : u'glasfluss',
        u'gletscherfluß'    : u'gletscherfluss',
        u'glimmstengeln'    : u'glimmstängeln',
        u'glimmstengels'    : u'glimmstängels',
        u'glimmstengel'     : u'glimmstängel',
        u'gnadenschuß'      : u'gnadenschuss',
        u'goettingen'       : u'göttingen',
        u'goß'              : u'goss',
        u'goß'           : u'goss',
        u'gothen'           : u'goten',
        u'gothe'            : u'gote',
        u'gothik'           : u'gotik',
        u'gothischem'       : u'gotischem',
        u'gothischen'       : u'gotischen',
        u'gothischer'       : u'gotischer',
        u'gothisches'       : u'gotisches',
        u'gothische'        : u'gotische',
        u'gothisch'         : u'gotisch',
        u'gothlands'        : u'gotlands',
        u'gothland'         : u'gotland',
        u'gränzen'          : u'grenzen',
        u'gränze'           : u'grenze',
        u'gräßlichem'       : u'grässlichem',
        u'gräßlichen'       : u'grässlichen',
        u'gräßlichen'    : u'grässlichen',
        u'gräßlicherem'     : u'grässlicherem',
        u'gräßlicheren'     : u'grässlicheren',
        u'gräßlicherer'     : u'grässlicherer',
        u'gräßlicheres'     : u'grässlicheres',
        u'gräßlichere'      : u'grässlichere',
        u'gräßlicher'       : u'grässlicher',
        u'gräßliches'       : u'grässliches',
        u'gräßliche'        : u'grässliche',
        u'gräßliche'     : u'grässliche',
        u'gräßlichstem'     : u'grässlichstem',
        u'gräßlichsten'     : u'grässlichsten',
        u'gräßlichster'     : u'grässlichster',
        u'gräßlichstes'     : u'grässlichstes',
        u'gräßlichste'      : u'grässlichste',
        u'gräßlich'         : u'grässlich',
        u'gräßlich'      : u'grässlich',
        u'grellila'         : u'grelllila',
        u'grenzfluß'        : u'grenzfluss',
        u'greueln'          : u'gräueln',
        u'greuels'          : u'gräuels',
        u'greueltaten'      : u'gräueltaten',
        u'greueltat'        : u'gräueltat',
        u'greuel'           : u'gräuel',
        u'greuelwörtern'    : u'gräuelwörtern',
        u'greuelwortes'     : u'gräuelwortes',
        u'greuel-wort'      : u'gräuelwort',
        u'greuelwort'       : u'gräuelwort',
        u'greulichem'       : u'gräulichem',
        u'greulichen'       : u'gräulichen',
        u'greulicherem'     : u'gräulicherem',
        u'greulicheren'     : u'gräulicheren',
        u'greulicherer'     : u'gräulicherer',
        u'greulicheres'     : u'gräulicheres',
        u'greulichere'      : u'gräulichere',
        u'greulicher'       : u'gräulicher',
        u'greuliches'       : u'gräuliches',
        u'greuliche'        : u'gräuliche',
        u'greulichstem'     : u'gräulichstem',
        u'greulichsten'     : u'gräulichsten',
        u'greulichster'     : u'gräulichster',
        u'greulichstes'     : u'gräulichstes',
        u'greulichste'      : u'gräulichste',
        u'greulich'         : u'gräulich',
        u'grislibären'      : u'grizzlybären',
        u'grislibärin'      : u'grizzlybärin',
        u'grislibär'        : u'grizzlybär',
        u'grislis'          : u'grizzlys',
        u'grisli'           : u'grizzly',
        u'grossen'       : u'großen',
        u'grosses'       : u'großes',
        u'grosse'        : u'große',
        u'großfürstenthum'  : u'großfürstentum',
        u'großschiffahrtsstraßen': u'großschifffahrtsstraßen',
        u'großschiffahrtsstraße': u'großschifffahrtsstraße',
        u'grossschiffahrtswegen': u'großschifffahrtswegen',
        u'großschiffahrtswegen': u'großschifffahrtswegen',
        u'grossschiffahrtsweges': u'großschifffahrtsweges',
        u'großschiffahrtsweges': u'großschifffahrtsweges',
        u'grossschiffahrtswege': u'großschifffahrtswege',
        u'großschiffahrtswege': u'großschifffahrtswege',
        u'grossschiffahrtswegs': u'großschifffahrtswegs',
        u'großschiffahrtswegs': u'großschifffahrtswegs',
        u'grossschiffahrtsweg': u'großschifffahrtsweg',
        u'großschiffahrtsweg': u'großschifffahrtsweg',
        u'grossschiffahrt'  : u'großschifffahrt',
        u'gross'         : u'groß',
        u'groszherzogthum'  : u'großherzogtum',
        u'grottenhäßlichem' : u'grottenhässlichem',
        u'grottenhäßlichen' : u'grottenhässlichen',
        u'grottenhäßlicher' : u'grottenhässlicher',
        u'grottenhäßliches' : u'grottenhässliches',
        u'grottenhäßliche'  : u'grottenhässliche',
        u'grottenhäßlich'   : u'grottenhässlich',
        u'grundbaß'         : u'grundbass',
        u'grundriß'         : u'grundriss',
        u'gummimantelgeschoß': u'gummimantelgeschoss',
        u'gurkenpaß'        : u'gurkenpass',
        u'gürtelthieren'    : u'gürteltieren',
        u'gürtelthieres'    : u'gürteltieres',
        u'gürtelthiere'     : u'gürteltiere',
        u'gürtelthiers'     : u'gürteltiers',
        u'gürtelthier'      : u'gürteltier',
        u'gürthelthieren'   : u'gürteltieren',
        u'gürthelthiere'    : u'gürteltiere',
        u'gürthelthier'     : u'gürteltier',
        u'gußbeton'         : u'gussbeton',
        u'gußeisens'        : u'gusseisens',
        u'gußeisen'         : u'gusseisen',
        u'gußeisernem'      : u'gusseisernem',
        u'gußeisernen'      : u'gusseisernen',
        u'gußeiserner'      : u'gusseiserner',
        u'gußeisernes'      : u'gusseisernes',
        u'gußeiserne'       : u'gusseiserne',
        u'gußeisern'        : u'gusseisern',
        u'gußform'          : u'gussform',
        u'gußteilen'        : u'gussteilen',
        u'gußteiles'        : u'gussteiles',
        u'gußteile'         : u'gussteile',
        u'gußteils'         : u'gussteils',
        u'gußteil'          : u'gussteil',
        u'guß'              : u'guss',
        u'gutenachtkuß'     : u'gutenachtkuss',
        u'güterschiffahrt'  : u'güterschifffahrt',
        u'haarriß'          : u'haarriss',
        u'halbgeschoß'      : u'halbgeschoss',
        u'hallelujah'       : u'halleluja',
        u'handelsbilanzüberschuß': u'handelsbilanzüberschuss',
        u'handelung'        : u'handlung',
        u'handies'          : u'handys',
        u'handkuß'          : u'handkuss',
        u'haraß'            : u'harass',
        u'häresieprozeß'    : u'häresieprozess',
        u'haselnußsträuchern': u'haselnusssträuchern',
        u'haselnußsträucher': u'haselnusssträucher',
        u'haselnußstrauches': u'haselnussstrauches',
        u'haselnußstrauche' : u'haselnussstrauche',
        u'haselnußstrauchs' : u'haselnussstrauchs',
        u'haselnußstrauch'  : u'haselnussstrauch',
        u'haselnuß'         : u'haselnuss',
        u'haselruthen'      : u'haselruten',
        u'haselruthe'       : u'haselrute',
        u'hasenkänguruh'    : u'hasenkänguru',
        u'haßfiguren'       : u'hassfiguren',
        u'haßfigur'         : u'hassfigur',
        u'haßkommentaren'   : u'hasskommentaren',
        u'haßkommentare'    : u'hasskommentare',
        u'haßkommentars'    : u'hasskommentars',
        u'haßkommentar'     : u'hasskommentar',
        u'häßlichem'        : u'hässlichem',
        u'häßlichen'        : u'hässlichen',
        u'häßlichen'     : u'hässlichen',
        u'häßlicherem'      : u'hässlicherem',
        u'häßlicheren'      : u'hässlicheren',
        u'häßlicherer'      : u'hässlicherer',
        u'häßlicheres'      : u'hässlicheres',
        u'häßlichere'       : u'hässlichere',
        u'häßlicher'        : u'hässlicher',
        u'häßlicher'     : u'hässlicher',
        u'häßliches'        : u'hässliches',
        u'häßliches'     : u'hässliches',
        u'häßliche'         : u'hässliche',
        u'häßliche'      : u'hässliche',
        u'häßlichkeiten'    : u'hässlichkeiten',
        u'häßlichkeit'      : u'hässlichkeit',
        u'häßlichkeit'   : u'hässlichkeit',
        u'häßlichstem'      : u'hässlichstem',
        u'häßlichsten'      : u'hässlichsten',
        u'häßlichster'      : u'hässlichster',
        u'häßlichstes'      : u'hässlichstes',
        u'häßlichste'       : u'hässlichste',
        u'häßlich'          : u'hässlich',
        u'häßlich'       : u'hässlich',
        u'haßliebe'         : u'hassliebe',
        u'haßmasken'        : u'hassmasken',
        u'haßmaske'         : u'hassmaske',
        u'haßobjekten'      : u'hassobjekten',
        u'haßobjektes'      : u'hassobjektes',
        u'haßobjekte'       : u'hassobjekte',
        u'haßobjekts'       : u'hassobjekts',
        u'haßobjekt'        : u'hassobjekt',
        u'haßpredigern'     : u'hasspredigern',
        u'haßpredigers'     : u'hasspredigers',
        u'haßprediger'      : u'hassprediger',
        u'haßpredigten'     : u'hasspredigten',
        u'haßpredigt'       : u'hasspredigt',
        u'haßten'           : u'hassten',
        u'haßtest'          : u'hasstest',
        u'haßtet'           : u'hasstet',
        u'haßte'            : u'hasste',
        u'haßte'         : u'hasste',
        u'haßtiraden'       : u'hasstiraden',
        u'haßtirade'        : u'hasstirade',
        u'haßt'             : u'hasst',
        u'haß'              : u'hass',
        u'haß'           : u'hass',
        u'hauptschiffahrtsstrassen': u'hauptschifffahrtsstraßen',
        u'hauptschiffahrtsstrasse': u'hauptschifffahrtsstraße',
        u'hauptschulabschluß': u'hauptschulabschluss',
        u'hausanschluß'     : u'hausanschluss',
        u'haushaltsausschuß': u'haushaltsausschuss',
        u'hefepreßweinen'   : u'hefepressweinen',
        u'hefepreßweines'   : u'hefepressweines',
        u'hefepreßweine'    : u'hefepressweine',
        u'hefepreßweins'    : u'hefepressweins',
        u'hefepreßwein'     : u'hefepresswein',
        u'heidenthum'       : u'heidentum',
        u'heilprozeß'       : u'heilprozess',
        u'heilungsprozeß'   : u'heilungsprozess',
        u'heimathen'        : u'heimaten',
        u'heimath'          : u'heimat',
        u'heimatschuß'      : u'heimatschuss',
        u'heissen'       : u'heißen',
        u'heisst'        : u'heißt',
        u'hellichtem'       : u'helllichtem',
        u'hellichten'       : u'helllichten',
        u'hellichter'       : u'helllichter',
        u'hellichtes'       : u'helllichtes',
        u'hellichte'        : u'helllichte',
        u'hellicht'         : u'helllicht',
        u'hellila'          : u'helllila',
        u'herausrißt'       : u'herausrisst',
        u'herausriß'        : u'herausriss',
        u'hercules'         : u'herkules',
        u'herscht'          : u'herrscht',
        u'herstellungsprozeß': u'herstellungsprozess',
        u'herumtelephonierendem': u'herumtelefonierendem',
        u'herumtelephonierenden': u'herumtelefonierenden',
        u'herumtelephonierender': u'herumtelefonierender',
        u'herumtelephonierendes': u'herumtelefonierendes',
        u'herumtelephonierende': u'herumtelefonierende',
        u'herumtelephonierend': u'herumtelefonierend',
        u'herumtelephonieren': u'herumtelefonieren',
        u'herumtelephonierest': u'herumtelefonierest',
        u'herumtelephonieret': u'herumtelefonieret',
        u'herumtelephoniere': u'herumtelefoniere',
        u'herumtelephonierst': u'herumtelefonierst',
        u'herumtelephonierten': u'herumtelefonierten',
        u'herumtelephoniertest': u'herumtelefoniertest',
        u'herumtelephoniertet': u'herumtelefoniertet',
        u'herumtelephonierte': u'herumtelefonierte',
        u'herumtelephoniert': u'herumtelefoniert',
        u'herumzutelephonieren': u'herumzutelefonieren',
        u'herunterfloß'     : u'herunterfloss',
        u'herunterlaßt'     : u'herunterlasst',
        u'herunterläßt'     : u'herunterlässt',
        u'herzas'           : u'herzass',
        u'hexenprozeß'      : u'hexenprozess',
        u'hexenschuß'       : u'hexenschuss',
        u'hindurchfloß'     : u'hindurchfloss',
        u'hineinbißt'       : u'hineinbisst',
        u'hineinbiß'        : u'hineinbiss',
        u'hinriß'           : u'hinriss',
        u'hinterlaßt'       : u'hinterlasst',
        u'hinterläßt'       : u'hinterlässt',
        u'hinterlaß'        : u'hinterlass',
        u'hißten'           : u'hissten',
        u'hißtest'          : u'hisstest',
        u'hißtet'           : u'hisstet',
        u'hißte'            : u'hisste',
        u'hißt'             : u'hisst',
        u'hiß'              : u'hiss',
        u'hobbies'          : u'hobbys',
        u'hochgenuß'        : u'hochgenuss',
        u'hochschulabschluß': u'hochschulabschluss',
        u'hochzeitsphoto'   : u'hochzeitsfoto',
        u'holzfaß'          : u'holzfass',
        u'hosteß'           : u'hostess',
        u'hoteltelephonen'  : u'hoteltelefonen',
        u'hoteltelephone'   : u'hoteltelefone',
        u'hoteltelephons'   : u'hoteltelefons',
        u'hoteltelephon'    : u'hoteltelefon',
        u'hülfelehrer'      : u'hilfslehrer',
        u'hülfslehrer'      : u'hilfslehrer',
        u'hundebiß'         : u'hundebiss',
        u'hußten'           : u'hussten',
        u'hußtest'          : u'husstest',
        u'hußtet'           : u'husstet',
        u'hußte'            : u'husste',
        u'hußt'             : u'husst',
        u'huß'              : u'huss',
        u'imbißbuden'       : u'imbissbuden',
        u'imbißbude'        : u'imbissbude',
        u'imbißständen'     : u'imbissständen',
        u'imbißstandes'     : u'imbissstandes',
        u'imbißstande'      : u'imbissstande',
        u'imbißstände'      : u'imbissstände',
        u'imbißstands'      : u'imbissstands',
        u'imbißstand'       : u'imbissstand',
        u'imbiß'            : u'imbiss',
        u'imbiß'         : u'imbiss',
        u'imperfecten'      : u'imperfekten',
        u'imperfecte'       : u'imperfekte',
        u'imperfects'       : u'imperfekts',
        u'imperfect'        : u'imperfekt',
        u'impfpaß'          : u'impfpass',
        u'incompetentem'    : u'inkompetentem',
        u'incompetenten'    : u'inkompetenten',
        u'incompetenterem'  : u'inkompetenterem',
        u'incompetenteren'  : u'inkompetenteren',
        u'incompetenterer'  : u'inkompetenterer',
        u'incompetenteres'  : u'inkompetenteres',
        u'incompetentere'   : u'inkompetentere',
        u'incompetenter'    : u'inkompetenter',
        u'incompetentestem' : u'inkompetentestem',
        u'incompetentesten' : u'inkompetentesten',
        u'incompetentester' : u'inkompetentester',
        u'incompetentestes' : u'inkompetentestes',
        u'incompetenteste'  : u'inkompetenteste',
        u'incompetentes'    : u'inkompetentes',
        u'incompetente'     : u'inkompetente',
        u'incompetent'      : u'inkompetent',
        u'incompetenzen'    : u'inkompetenzen',
        u'incompetenz'      : u'inkompetenz',
        u'inconsequentem'   : u'inkonsequentem',
        u'inconsequenten'   : u'inkonsequenten',
        u'inconsequenterem' : u'inkonsequenterem',
        u'inconsequenteren' : u'inkonsequenteren',
        u'inconsequenterer' : u'inkonsequenterer',
        u'inconsequenteres' : u'inkonsequenteres',
        u'inconsequentere'  : u'inkonsequentere',
        u'inconsequenter'   : u'inkonsequenter',
        u'inconsequentestem': u'inkonsequentestem',
        u'inconsequentesten': u'inkonsequentesten',
        u'inconsequentester': u'inkonsequentester',
        u'inconsequentestes': u'inkonsequentestes',
        u'inconsequenteste' : u'inkonsequenteste',
        u'inconsequentes'   : u'inkonsequentes',
        u'inconsequente'    : u'inkonsequente',
        u'inconsequent'     : u'inkonsequent',
        u'inconsequenzen'   : u'inkonsequenzen',
        u'inconsequenz'     : u'inkonsequenz',
        u'indicativen'      : u'indikativen',
        u'indicative'       : u'indikative',
        u'indicativs'       : u'indikativs',
        u'indicativ'        : u'indikativ',
        u'indizienprozeß'   : u'indizienprozess',
        u'inquisitionsprozeß': u'inquisitionsprozess',
        u'integrationsprozeß': u'integrationsprozess',
        u'intercity-expreß' : u'intercity-express',
        u'intercityexpreß'  : u'intercityexpress',
        u'interressanter'   : u'interessanter',
        u'ionisationsmeßröhren': u'ionisationsmessröhren',
        u'ionisationsmeßröhre': u'ionisationsmessröhre',
        u'ionisierungsprozeß': u'ionisierungsprozess',
        u'i-punkten'        : u'i-punkten',
        u'i-punktes'        : u'i-punktes',
        u'i-punkte'         : u'i-punkte',
        u'i-punkts'         : u'i-punkts',
        u'i-punkt'          : u'i-punkt',
        u'ißt'              : u'isst',
        u'ißt'           : u'isst',
        u'iß'               : u'iss',
        u'i-tüpfelchen'     : u'i-tüpfelchen',
        u'jagdschloß'       : u'jagdschloss',
        u'jäheit'           : u'jähheit',
        u'jahresabschluß'   : u'jahresabschluss',
        u'jahresüberschuß'  : u'jahresüberschuss',
        u'jahrn'            : u'jahren',
        u'jauchefaß'        : u'jauchefass',
        u'jauchenfaß'       : u'jauchenfass',
        u'job-sharing'      : u'jobsharing',
        u'jockeis'          : u'jockeys',
        u'jockei'           : u'jockey',
        u'jogakursen'       : u'yogakursen',
        u'jogakurses'       : u'yogakurses',
        u'jogakurse'        : u'yogakurse',
        u'jogakurs'         : u'yogakurs',
        u'jogalehrerinnen'  : u'yogalehrerinnen',
        u'jogalehrerin'     : u'yogalehrerin',
        u'jogalehrern'      : u'yogalehrern',
        u'jogalehrers'      : u'yogalehrers',
        u'jogalehrer'       : u'yogalehrer',
        u'jogaschulen'      : u'yogaschulen',
        u'jogaschule'       : u'yogaschule',
        u'jogas'            : u'yogas',
        u'jogaübungen'      : u'yogaübungen',
        u'jogaübung'        : u'yogaübung',
        u'joga'             : u'yoga',
        u'judenhaß'         : u'judenhass',
        u'judenthum'        : u'judentum',
        u'jüdisch-deutsch'  : u'jüdischdeutsch',
        u'julierpaß'        : u'julierpass',
        u'kabelanschluß'    : u'kabelanschluss',
        u'kabinettsbeschluß': u'kabinettsbeschluss',
        u'kabrio'           : u'cabrio',
        u'kalbsnuß'         : u'kalbsnuss',
        u'kalorienbewußtem' : u'kalorienbewusstem',
        u'kalorienbewußten' : u'kalorienbewussten',
        u'kalorienbewußterem': u'kalorienbewussterem',
        u'kalorienbewußteren': u'kalorienbewussteren',
        u'kalorienbewußterer': u'kalorienbewussterer',
        u'kalorienbewußteres': u'kalorienbewussteres',
        u'kalorienbewußtere': u'kalorienbewusstere',
        u'kalorienbewußter' : u'kalorienbewusster',
        u'kalorienbewußtestem': u'kalorienbewusstestem',
        u'kalorienbewußtesten': u'kalorienbewusstesten',
        u'kalorienbewußtester': u'kalorienbewusstester',
        u'kalorienbewußtestes': u'kalorienbewusstestes',
        u'kalorienbewußteste': u'kalorienbewussteste',
        u'kalorienbewußtes' : u'kalorienbewusstes',
        u'kalorienbewußte'  : u'kalorienbewusste',
        u'kalorienbewußt'   : u'kalorienbewusst',
        u'kaltgepreßt'      : u'kaltgepresst',
        u'kalvinismus'      : u'calvinismus',
        u'kalvinisten'      : u'calvinisten',
        u'kalvinistinnen'   : u'calvinistinnen',
        u'kalvinistin'      : u'calvinistin',
        u'kalvinistischem'  : u'calvinistischem',
        u'kalvinistischen'  : u'calvinistischen',
        u'kalvinistischerem': u'calvinistischerem',
        u'kalvinistischeren': u'calvinistischeren',
        u'kalvinistischerer': u'calvinistischerer',
        u'kalvinistischeres': u'calvinistischeres',
        u'kalvinistischere' : u'calvinistischere',
        u'kalvinistischer'  : u'calvinistischer',
        u'kalvinistisches'  : u'calvinistisches',
        u'kalvinistische'   : u'calvinistische',
        u'kalvinistischstem': u'calvinistischstem',
        u'kalvinistischster': u'calvinistischster',
        u'kalvinistischstes': u'calvinistischstes',
        u'kalvinistischste' : u'calvinistischste',
        u'kalvinistisch'    : u'calvinistisch',
        u'kalvinist'        : u'calvinist',
        u'kameraverschluß'  : u'kameraverschluss',
        u'kamerunnuß'       : u'kamerunnuss',
        u'kammachern'       : u'kammmachern',
        u'kammachers'       : u'kammmachers',
        u'kammacher'        : u'kammmacher',
        u'kammaschine'      : u'kammmaschine',
        u'kämmaschine'      : u'kämmmaschine',
        u'kammolchen'       : u'kammmolchen',
        u'kammolches'       : u'kammmolches',
        u'kammolche'        : u'kammmolche',
        u'kammolchs'        : u'kammmolchs',
        u'kammolch'         : u'kammmolch',
        u'kammuscheln'      : u'kammmuscheln',
        u'kammuschel'       : u'kammmuschel',
        u'känguruhapfel'    : u'känguruapfel',
        u'känguruhdorn'     : u'kängurudorn',
        u'känguruhfleisches': u'kängurufleisches',
        u'känguruhfleische' : u'kängurufleische',
        u'känguruhfleischs' : u'kängurufleischs',
        u'känguruhfleisch'  : u'kängurufleisch',
        u'känguruhinsel'    : u'känguruinsel',
        u'känguruhledern'   : u'känguruledern',
        u'känguruhleders'   : u'känguruleders',
        u'känguruhleder'    : u'känguruleder',
        u'känguruhmaus'     : u'kängurumaus',
        u'känguruhratte'    : u'kängururatte',
        u'känguruhs'        : u'kängurus',
        u'känguruh'         : u'känguru',
        u'kaninchenkänguruhs': u'kaninchenkängurus',
        u'kaninchenkänguruh': u'kaninchenkänguru',
        u'kanonenschuß'     : u'kanonenschuss',
        u'kanzelmißbrauches': u'kanzelmissbrauches',
        u'kanzelmißbrauche' : u'kanzelmissbrauche',
        u'kanzelmißbrauchsparagraphen': u'kanzelmissbrauchsparagraphen',
        u'kanzelmißbrauchsparagraph': u'kanzelmissbrauchsparagraph',
        u'kanzelmißbrauchs' : u'kanzelmissbrauchs',
        u'kanzelmißbrauch'  : u'kanzelmissbrauch',
        u'kapitalzufluß'    : u'kapitalzufluss',
        u'kapselriß'        : u'kapselriss',
        u'karakteren'       : u'charakteren',
        u'karaktere'        : u'charaktere',
        u'karakters'        : u'charakters',
        u'karakter'         : u'charakter',
        u'karamelfarbenem'  : u'karamellfarbenem',
        u'karamelfarbenen'  : u'karamellfarbenen',
        u'karamelfarbener'  : u'karamellfarbener',
        u'karamelfarbenes'  : u'karamellfarbenes',
        u'karamelfarbene'   : u'karamellfarbene',
        u'karamelfarben'    : u'karamellfarben',
        u'karamels'         : u'karamells',
        u'karamel'          : u'karamell',
        u'karfreytagen'     : u'karfreitagen',
        u'karfreytages'     : u'karfreitages',
        u'karfreytage'      : u'karfreitage',
        u'karfreytags'      : u'karfreitags',
        u'karfreytag'       : u'karfreitag',
        u'kargos'           : u'cargos',
        u'kargo'            : u'cargo',
        u'karoas'           : u'karoass',
        u'kartentelephonen' : u'kartentelefonen',
        u'kartentelephone'  : u'kartentelefone',
        u'kartentelephons'  : u'kartentelefons',
        u'kartentelephon'   : u'kartentelefon',
        u'kaßlern'          : u'kasslern',
        u'kaßlers'          : u'kasslers',
        u'kaßler'           : u'kassler',
        u'katarren'         : u'katarrhen',
        u'katarre'          : u'katarrhe',
        u'katarrs'          : u'katarrhs',
        u'katarr'           : u'katarrh',
        u'katholicismus'    : u'katholizismus',
        u'kehlkopfverschlußlauten': u'kehlkopfverschlusslauten',
        u'kehlkopfverschlußlautes': u'kehlkopfverschlusslautes',
        u'kehlkopfverschlußlaute': u'kehlkopfverschlusslaute',
        u'kehlkopfverschlußlauts': u'kehlkopfverschlusslauts',
        u'kehlkopfverschlußlaut': u'kehlkopfverschlusslaut',
        u'kennummern'       : u'kennnummern',
        u'kennummer'        : u'kennnummer',
        u'keßheit'          : u'kessheit',
        u'keß'              : u'kess',
        u'ketschupflaschen' : u'ketchupflaschen',
        u'ketschupflasche'  : u'ketchupflasche',
        u'ketschups'        : u'ketchups',
        u'ketschup'         : u'ketchup',
        u'ketzerprozeß'     : u'ketzerprozess',
        u'khaiberpaß'       : u'khaiberpass',
        u'khyberpaß'        : u'khyberpass',
        u'kindesmißbräuchen': u'kindesmissbräuchen',
        u'kindesmißbrauches': u'kindesmissbrauches',
        u'kindesmißbrauche' : u'kindesmissbrauche',
        u'kindesmißbräuche' : u'kindesmissbräuche',
        u'kindesmißbrauchs' : u'kindesmissbrauchs',
        u'kindesmißbrauch'  : u'kindesmissbrauch',
        u'kindesmißhandlungen': u'kindesmisshandlungen',
        u'kindesmißhandlung': u'kindesmisshandlung',
        u'kirchthurm'       : u'kirchturm',
        u'kißchens'         : u'kisschens',
        u'kißchen'          : u'kisschen',
        u'klappulten'       : u'klapppulten',
        u'klappultes'       : u'klapppultes',
        u'klappulte'        : u'klapppulte',
        u'klappults'        : u'klapppults',
        u'klappult'         : u'klapppult',
        u'klassenbewußtsein': u'klassenbewusstsein',
        u'klassenhaß'       : u'klassenhass',
        u'klaßleitern'      : u'klassleitern',
        u'klaßleiters'      : u'klassleiters',
        u'klaßleiter'       : u'klassleiter',
        u'klaß'             : u'klass',
        u'klatschenaß'      : u'klatschenass',
        u'klatschnaß'       : u'klatschnass',
        u'klausenpaß'       : u'klausenpass',
        u'klemmappen'       : u'klemmmappen',
        u'klemmappe'        : u'klemmmappe',
        u'klemmassen'       : u'klemmmaßen',
        u'klemmaßen'        : u'klemmmaßen',
        u'klemmasses'       : u'klemmmaßes',
        u'klemmaßes'        : u'klemmmaßes',
        u'klemmasse'        : u'klemmmaße',
        u'klemmaße'         : u'klemmmaße',
        u'klemmass'         : u'klemmmaß',
        u'klemmaß'          : u'klemmmaß',
        u'klettenhaftverschluß': u'klettenhaftverschluss',
        u'klettenverschluß' : u'klettenverschluss',
        u'klettverschluß'   : u'klettverschluss',
        u'klitschenaß'      : u'klitschenass',
        u'klitschnaß'       : u'klitschnass',
        u'knacknuß'         : u'knacknuss',
        u'knallaut'         : u'knalllaut',
        u'knallila'         : u'knalllila',
        u'kofferschloß'     : u'kofferschloss',
        u'kohlenstoffasern' : u'kohlenstofffasern',
        u'kohlenstoffaser'  : u'kohlenstofffaser',
        u'kokillenguß'      : u'kokillenguss',
        u'kokosnuß'         : u'kokosnuss',
        u'kolanuß'          : u'kolanuss',
        u'kollektivbewußtsein': u'kollektivbewusstsein',
        u'kollier'          : u'collier',
        u'kolofoniums'      : u'kolophoniums',
        u'kolofonium'       : u'kolophonium',
        u'koloßkopf'        : u'kolosskopf',
        u'koloß'            : u'koloss',
        u'kombinationschloß': u'kombinationschloss',
        u'kommißbroten'     : u'kommissbroten',
        u'kommißbrotes'     : u'kommissbrotes',
        u'kommißbrote'      : u'kommissbrote',
        u'kommißbrots'      : u'kommissbrots',
        u'kommißbrot'       : u'kommissbrot',
        u'kommißstiefel'    : u'kommissstiefel',
        u'kommißstimmen'    : u'kommissstimmen',
        u'kommißstimme'     : u'kommissstimme',
        u'kommiß'           : u'kommiss',
        u'kommißzeit'       : u'kommisszeit',
        u'kommunikee'       : u'kommuniqué',
        u'kompaßnadeln'     : u'kompassnadeln',
        u'kompaßnadel'      : u'kompassnadel',
        u'kompaßrosen'      : u'kompassrosen',
        u'kompaßrose'       : u'kompassrose',
        u'kompaß'           : u'kompass',
        u'komplicen'        : u'komplizen',
        u'komplice'         : u'komplize',
        u'kompotteller'     : u'kompottteller',
        u'kompromißbereitem': u'kompromissbereitem',
        u'kompromißbereiten': u'kompromissbereiten',
        u'kompromißbereiterem': u'kompromissbereiterem',
        u'kompromißbereiteren': u'kompromissbereiteren',
        u'kompromißbereiterer': u'kompromissbereiterer',
        u'kompromißbereiteres': u'kompromissbereiteres',
        u'kompromißbereitere': u'kompromissbereitere',
        u'kompromißbereiter': u'kompromissbereiter',
        u'kompromißbereitestem': u'kompromissbereitestem',
        u'kompromißbereitesten': u'kompromissbereitesten',
        u'kompromißbereitester': u'kompromissbereitester',
        u'kompromißbereitestes': u'kompromissbereitestes',
        u'kompromißbereiteste': u'kompromissbereiteste',
        u'kompromißbereites': u'kompromissbereites',
        u'kompromißbereite' : u'kompromissbereite',
        u'kompromißbereitschaft': u'kompromissbereitschaft',
        u'kompromißbereit'  : u'kompromissbereit',
        u'kompromißfähigkeit': u'kompromissfähigkeit',
        u'kompromißfähig'   : u'kompromissfähig',
        u'kompromißkandidatin': u'kompromisskandidatin',
        u'kompromißkandidat': u'kompromisskandidat',
        u'kompromißlerinnen': u'kompromisslerinnen',
        u'kompromißlerin'   : u'kompromisslerin',
        u'kompromißlerisch' : u'kompromisslerisch',
        u'kompromißlern'    : u'kompromisslern',
        u'kompromißlers'    : u'kompromisslers',
        u'kompromißler'     : u'kompromissler',
        u'kompromißlosem'   : u'kompromisslosem',
        u'kompromißlosen'   : u'kompromisslosen',
        u'kompromißloserem' : u'kompromissloserem',
        u'kompromißloseren' : u'kompromissloseren',
        u'kompromißloserer' : u'kompromissloserer',
        u'kompromißloseres' : u'kompromissloseres',
        u'kompromißlosere'  : u'kompromisslosere',
        u'kompromißloser'   : u'kompromissloser',
        u'kompromißlosestem': u'kompromisslosestem',
        u'kompromißlosesten': u'kompromisslosesten',
        u'kompromißlosester': u'kompromisslosester',
        u'kompromißlosestes': u'kompromisslosestes',
        u'kompromißloseste' : u'kompromissloseste',
        u'kompromißloses'   : u'kompromissloses',
        u'kompromißlose'    : u'kompromisslose',
        u'kompromißlosigkeit': u'kompromisslosigkeit',
        u'kompromißlos'     : u'kompromisslos',
        u'kompromißlösung'  : u'kompromisslösung',
        u'kompromiß'        : u'kompromiss',
        u'kompromißversuch' : u'kompromissversuch',
        u'kompromißvorschlägen': u'kompromissvorschlägen',
        u'kompromißvorschlages': u'kompromissvorschlages',
        u'kompromißvorschlage': u'kompromissvorschlage',
        u'kompromißvorschläge': u'kompromissvorschläge',
        u'kompromißvorschlags': u'kompromissvorschlags',
        u'kompromißvorschlag': u'kompromissvorschlag',
        u'komputern'        : u'computern',
        u'komputers'        : u'computers',
        u'komputer'         : u'computer',
        u'komteß'           : u'komtess',
        u'konferenzbeschluß': u'konferenzbeschluss',
        u'kongreßabgeordnetem': u'kongressabgeordnetem',
        u'kongreßabgeordneten': u'kongressabgeordneten',
        u'kongreßabgeordneter': u'kongressabgeordneter',
        u'kongreßabgeordnete': u'kongressabgeordnete',
        u'kongreßhalle'     : u'kongresshalle',
        u'kongreßpolens'    : u'kongresspolens',
        u'kongreßpolen'     : u'kongresspolen',
        u'kongreßsaales'    : u'kongresssaales',
        u'kongreßsaale'     : u'kongresssaale',
        u'kongreßsaals'     : u'kongresssaals',
        u'kongreßsaal'      : u'kongresssaal',
        u'kongreßsälen'     : u'kongresssälen',
        u'kongreßsäle'      : u'kongresssäle',
        u'kongreßstädten'   : u'kongressstädten',
        u'kongreßstädte'    : u'kongressstädte',
        u'kongreßstadt'     : u'kongressstadt',
        u'kongreßteilnehmerinnen': u'kongressteilnehmerinnen',
        u'kongreßteilnehmerin': u'kongressteilnehmerin',
        u'kongreßteilnehmern': u'kongressteilnehmern',
        u'kongreßteilnehmers': u'kongressteilnehmers',
        u'kongreßteilnehmer': u'kongressteilnehmer',
        u'kongreß'          : u'kongress',
        u'kongreßwahlen'    : u'kongresswahlen',
        u'kongreßwahl'      : u'kongresswahl',
        u'kongreßzentrum'   : u'kongresszentrum',
        u'königsschloß'     : u'königsschloss',
        u'königthümern'     : u'königtümern',
        u'königthümer'      : u'königtümer',
        u'königthums'       : u'königtums',
        u'königthum'        : u'königtum',
        u'konkursprozeß'    : u'konkursprozess',
        u'kontainern'       : u'containern',
        u'kontainers'       : u'containers',
        u'kontainer'        : u'container',
        u'kontrabaß'        : u'kontrabass',
        u'kontraktabschluß' : u'kontraktabschluss',
        u'kontrollampen'    : u'kontrolllampen',
        u'kontrollampe'     : u'kontrolllampe',
        u'kontrolleuchten'  : u'kontrollleuchten',
        u'kontrolleuchte'   : u'kontrollleuchte',
        u'kontrolliste'     : u'kontrollliste',
        u'konzernjahresabschluß': u'konzernjahresabschluss',
        u'kopfnuß'          : u'kopfnuss',
        u'kopfschuß'        : u'kopfschuss',
        u'koppelschloß'     : u'koppelschloss',
        u'körperbewußtsein' : u'körperbewusstsein',
        u'kostenbewußtsein' : u'kostenbewusstsein',
        u'kostenbewußt'     : u'kostenbewusst',
        u'kothen'           : u'koten',
        u'kothes'           : u'kotes',
        u'kothe'            : u'kote',
        u'koths'            : u'kots',
        u'koth'             : u'kot',
        u'kottbus'          : u'cottbus',
        u'kraßheit'         : u'krassheit',
        u'kraß'             : u'krass',
        u'kreisprozeß'      : u'kreisprozess',
        u'kremartigem'      : u'cremeartigem',
        u'kremartigen'      : u'cremeartigen',
        u'kremartiger'      : u'cremeartiger',
        u'kremartiges'      : u'cremeartiges',
        u'kremartige'       : u'cremeartige',
        u'kremartig'        : u'cremeartig',
        u'kremeartigem'     : u'cremeartigem',
        u'kremeartigen'     : u'cremeartigen',
        u'kremeartiger'     : u'cremeartiger',
        u'kremeartiges'     : u'cremeartiges',
        u'kremeartige'      : u'cremeartige',
        u'kremeartig'       : u'cremeartig',
        u'kremefarbenem'    : u'cremefarbenem',
        u'kremefarbenen'    : u'cremefarbenen',
        u'kremefarbener'    : u'cremefarbener',
        u'kremefarbenes'    : u'cremefarbenes',
        u'kremefarbene'     : u'cremefarbene',
        u'kremefarben'      : u'cremefarben',
        u'kremefarbigem'    : u'cremefarbigem',
        u'kremefarbigen'    : u'cremefarbigen',
        u'kremefarbiger'    : u'cremefarbiger',
        u'kremefarbiges'    : u'cremefarbiges',
        u'kremefarbige'     : u'cremefarbige',
        u'kremefarbig'      : u'cremefarbig',
        u'kremend'          : u'cremend',
        u'kremen'           : u'cremen',
        u'kremest'          : u'cremest',
        u'kremet'           : u'cremet',
        u'kreme'            : u'creme',
        u'kremfarbenem'     : u'cremefarbenem',
        u'kremfarbenen'     : u'cremefarbenen',
        u'kremfarbener'     : u'cremefarbener',
        u'kremfarbenes'     : u'cremefarbenes',
        u'kremfarbene'      : u'cremefarbene',
        u'kremfarben'       : u'cremefarben',
        u'kremfarbigem'     : u'cremefarbigem',
        u'kremfarbigen'     : u'cremefarbigen',
        u'kremfarbiger'     : u'cremefarbiger',
        u'kremfarbiges'     : u'cremefarbiges',
        u'kremfarbige'      : u'cremefarbige',
        u'kremfarbig'       : u'cremefarbig',
        u'kremigem'         : u'cremigem',
        u'kremigen'         : u'cremigen',
        u'kremigerem'       : u'cremigerem',
        u'kremigeren'       : u'cremigeren',
        u'kremigerer'       : u'cremigerer',
        u'kremigeres'       : u'cremigeres',
        u'kremigere'        : u'cremigere',
        u'kremiger'         : u'cremiger',
        u'kremiges'         : u'cremiges',
        u'kremige'          : u'cremige',
        u'kremigstem'       : u'cremigstem',
        u'kremigsten'       : u'cremigsten',
        u'kremigster'       : u'cremigster',
        u'kremigstes'       : u'cremigstes',
        u'kremigste'        : u'cremigste',
        u'kremig'           : u'cremig',
        u'kremst'           : u'cremst',
        u'kremten'          : u'cremten',
        u'kremtest'         : u'cremtest',
        u'kremtet'          : u'cremtet',
        u'kremte'           : u'cremte',
        u'kremt'            : u'cremt',
        u'krem'             : u'crem',
        u'krem'             : u'creme',
        u'kreppapieren'     : u'krepppapieren',
        u'kreppapieres'     : u'krepppapieres',
        u'kreppapiere'      : u'krepppapiere',
        u'kreppapiers'      : u'krepppapiers',
        u'kreppapier'       : u'krepppapier',
        u'kreutzen'         : u'kreuzen',
        u'kreutzes'         : u'kreuzes',
        u'kreutze'          : u'kreuze',
        u'kreutz'           : u'kreuz',
        u'kreuzas'          : u'kreuzass',
        u'kreuzbandriß'     : u'kreuzbandriss',
        u'kriegsverbrecherprozeß': u'kriegsverbrecherprozess',
        u'krimgothisch'     : u'krimgotisch',
        u'kriminalprozeß'   : u'kriminalprozess',
        u'krißligem'        : u'krissligem',
        u'krißligen'        : u'krissligen',
        u'krißligerem'      : u'krissligerem',
        u'krißligeren'      : u'krissligeren',
        u'krißligerer'      : u'krissligerer',
        u'krißligeres'      : u'krissligeres',
        u'krißligere'       : u'krissligere',
        u'krißliger'        : u'krissliger',
        u'krißliges'        : u'krissliges',
        u'krißlige'         : u'krisslige',
        u'krißligstem'      : u'krissligstem',
        u'krißligsten'      : u'krissligsten',
        u'krißligster'      : u'krissligster',
        u'krißligstes'      : u'krissligstes',
        u'krißligste'       : u'krissligste',
        u'krißlig'          : u'krisslig',
        u'kristalleuchter'  : u'kristallleuchter',
        u'kristallinse'     : u'kristalllinse',
        u'kristallisationsprozeß': u'kristallisationsprozess',
        u'kristallustern'   : u'kristalllustern',
        u'kristallüstern'   : u'kristalllüstern',
        u'kristallusters'   : u'kristalllusters',
        u'kristallüsters'   : u'kristalllüsters',
        u'kristalluster'    : u'kristallluster',
        u'kristallüster'    : u'kristalllüster',
        u'kronprinzeßlich'  : u'kronprinzesslich',
        u'kroß'             : u'kross',
        u'krummachen'       : u'krummmachen',
        u'kulturausschuß'   : u'kulturausschuss',
        u'kunststoffadens'  : u'kunststofffadens',
        u'kunststoffaden'   : u'kunststofffaden',
        u'kunststoffäden'   : u'kunststofffäden',
        u'kunststoffaser'   : u'kunststofffaser',
        u'kunststoffenstern': u'kunststofffenstern',
        u'kunststoffensters': u'kunststofffensters',
        u'kunststoffenster' : u'kunststofffenster',
        u'kunststoffolien'  : u'kunststofffolien',
        u'kunststoffolie'   : u'kunststofffolie',
        u'kunststoffspritzgußteilen': u'kunststoffspritzgussteilen',
        u'kunststoffspritzgußteiles': u'kunststoffspritzgussteiles',
        u'kunststoffspritzgußteile': u'kunststoffspritzgussteile',
        u'kunststoffspritzgußteils': u'kunststoffspritzgussteils',
        u'kunststoffspritzgußteil': u'kunststoffspritzgussteil',
        u'kupee'            : u'coupé',
        u'kurzfaßten'       : u'kurzfassten',
        u'kurzfaßtest'      : u'kurzfasstest',
        u'kurzfaßtet'       : u'kurzfasstet',
        u'kurzfaßte'        : u'kurzfasste',
        u'kurzpaßspieles'   : u'kurzpassspieles',
        u'kurzpaßspiels'    : u'kurzpassspiels',
        u'kurzpaßspiel'     : u'kurzpassspiel',
        u'kurzpaß'          : u'kurzpass',
        u'kurzschloßt'      : u'kurzschlosst',
        u'kurzschloß'       : u'kurzschloss',
        u'kurzschlußhandlungen': u'kurzschlusshandlungen',
        u'kurzschlußhandlung': u'kurzschlusshandlung',
        u'kurzschlußlüftungen': u'kurzschlusslüftungen',
        u'kurzschlußlüftung': u'kurzschlusslüftung',
        u'kurzschlußreaktionen': u'kurzschlussreaktionen',
        u'kurzschlußreaktion': u'kurzschlussreaktion',
        u'kurzschlußtaten'  : u'kurzschlusstaten',
        u'kurzschlußtat'    : u'kurzschlusstat',
        u'kurzschluß'       : u'kurzschluss',
        u'küßchens'         : u'küsschens',
        u'küßchen'          : u'küsschen',
        u'kußechtem'        : u'kussechtem',
        u'kußechten'        : u'kussechten',
        u'kußechterem'      : u'kussechterem',
        u'kußechteren'      : u'kussechteren',
        u'kußechterer'      : u'kussechterer',
        u'kußechteres'      : u'kussechteres',
        u'kußechtere'       : u'kussechtere',
        u'kußechter'        : u'kussechter',
        u'kußechtestem'     : u'kussechtestem',
        u'kußechtesten'     : u'kussechtesten',
        u'kußechtester'     : u'kussechtester',
        u'kußechtestes'     : u'kussechtestes',
        u'kußechteste'      : u'kussechteste',
        u'kußechtes'        : u'kussechtes',
        u'kußechte'         : u'kussechte',
        u'kußecht'          : u'kussecht',
        u'kußhänden'        : u'kusshänden',
        u'kußhände'         : u'kusshände',
        u'kußhand'          : u'kusshand',
        u'kußkrankheiten'   : u'kusskrankheiten',
        u'kußkrankheit'     : u'kusskrankheit',
        u'küßten'           : u'küssten',
        u'küßten'        : u'küssten',
        u'küßtest'          : u'küsstest',
        u'küßtet'           : u'küsstet',
        u'küßte'            : u'küsste',
        u'küßte'         : u'küsste',
        u'küßt'             : u'küsst',
        u'kuß'              : u'kuss',
        u'kuß'           : u'kuss',
        u'kußzahlen'        : u'kusszahlen',
        u'kußzahl'          : u'kusszahl',
        u'kwaß'             : u'kwass',
        u'ladenschlußgesetz': u'ladenschlussgesetz',
        u'ladenschluß'      : u'ladenschluss',
        u'ladenschlußzeit'  : u'ladenschlusszeit',
        u'ladies'           : u'ladys',
        u'lambertsnuß'      : u'lambertsnuss',
        u'lamellenverschluß': u'lamellenverschluss',
        u'landcadetten'     : u'landkadetten',
        u'landcadett'       : u'landkadett',
        u'landesverrathes'  : u'landesverrates',
        u'landesverrathe'   : u'landesverrate',
        u'landesverraths'   : u'landesverrats',
        u'landesverrath'    : u'landesverrat',
        u'landschloß'       : u'landschloss',
        u'langstengeligem'  : u'langstängeligem',
        u'langstengeligen'  : u'langstängeligen',
        u'langstengeliger'  : u'langstängeliger',
        u'langstengeliges'  : u'langstängeliges',
        u'langstengelige'   : u'langstängelige',
        u'langstengelig'    : u'langstängelig',
        u'langstengligem'   : u'langstängligem',
        u'langstengligen'   : u'langstängligen',
        u'langstengliger'   : u'langstängliger',
        u'langstengliges'   : u'langstängliges',
        u'langstenglige'    : u'langstänglige',
        u'langstenglig'     : u'langstänglig',
        u'läßlichem'        : u'lässlichem',
        u'läßlichen'        : u'lässlichen',
        u'läßlicherem'      : u'lässlicherem',
        u'läßlicheren'      : u'lässlicheren',
        u'läßlicherer'      : u'lässlicherer',
        u'läßlicheres'      : u'lässlicheres',
        u'läßlichere'       : u'lässlichere',
        u'läßlicher'        : u'lässlicher',
        u'läßliches'        : u'lässliches',
        u'läßliche'         : u'lässliche',
        u'läßlichstem'      : u'lässlichstem',
        u'läßlichsten'      : u'lässlichsten',
        u'läßlichster'      : u'lässlichster',
        u'läßlichstes'      : u'lässlichstes',
        u'läßlichste'       : u'lässlichste',
        u'läßlich'          : u'lässlich',
        u'laßt'             : u'lasst',
        u'laßt'          : u'lasst',
        u'läßt'             : u'lässt',
        u'läßt'          : u'lässt',
        u'laß'              : u'lass',
        u'laß'           : u'lass',
        u'lattenschuß'      : u'lattenschuss',
        u'laufpaß'          : u'laufpass',
        u'laugenfaß'        : u'laugenfass',
        u'lebensgenuß'      : u'lebensgenuss',
        u'lebensprozeß'     : u'lebensprozess',
        u'leberabszeß'      : u'leberabszess',
        u'legirend'         : u'legierend',
        u'legiren'          : u'legieren',
        u'legirest'         : u'legierest',
        u'legiret'          : u'legieret',
        u'legire'           : u'legiere',
        u'legirst'          : u'legierst',
        u'legirten'         : u'legierten',
        u'legirtest'        : u'legiertest',
        u'legirtet'         : u'legiertet',
        u'legirte'          : u'legierte',
        u'legirt'           : u'legiert',
        u'legir'            : u'legier',
        u'lehrabschluß'     : u'lehrabschluss',
        u'lehrabschlußzeugnis': u'lehrabschlusszeugnis',
        u'lehrprozeß'       : u'lehrprozess',
        u'leichenblaß'      : u'leichenblass',
        u'leichenpaß'       : u'leichenpass',
        u'lenkradschloß'    : u'lenkradschloss',
        u'lenkungsausschuß' : u'lenkungsausschuss',
        u'lernprozeß'       : u'lernprozess',
        u'liebesschloß'     : u'liebesschloss',
        u'lieferengpaß'     : u'lieferengpass',
        u'linksschuß'       : u'linksschuss',
        u'litteratur'       : u'literatur',
        u'lobbies'          : u'lobbys',
        u'locativen'        : u'lokativen',
        u'locative'         : u'lokative',
        u'locativs'         : u'lokativs',
        u'locativ'          : u'lokativ',
        u'lorbaß'           : u'lorbass',
        u'loslaßt'          : u'loslasst',
        u'losläßt'          : u'loslässt',
        u'losschoßt'        : u'losschosst',
        u'losschoß'         : u'losschoss',
        u'löthend'          : u'lötend',
        u'lothen'           : u'loten',
        u'löthen'           : u'löten',
        u'löthest'          : u'lötest',
        u'lothes'           : u'lotes',
        u'lötheten'         : u'löteten',
        u'löthetest'        : u'lötetest',
        u'löthetet'         : u'lötetet',
        u'löthete'          : u'lötete',
        u'löthet'           : u'lötet',
        u'lothe'            : u'lote',
        u'löthe'            : u'löte',
        u'loths'            : u'lots',
        u'loth'             : u'lot',
        u'lötschenpaß'      : u'lötschenpass',
        u'luftschiffahrt'   : u'luftschifffahrt',
        u'luftschloß'       : u'luftschloss',
        u'lukmanierpaß'     : u'lukmanierpass',
        u'lustschloß'       : u'lustschloss',
        u'macedoniens'      : u'mazedoniens',
        u'macedonien'       : u'mazedonien',
        u'macedonischem'    : u'mazedonischem',
        u'macedonischen'    : u'mazedonischen',
        u'macedonischer'    : u'mazedonischer',
        u'macedonisches'    : u'mazedonisches',
        u'macedonische'     : u'mazedonische',
        u'macedonisch'      : u'mazedonisch',
        u'machtmißbräuchen' : u'machtmissbräuchen',
        u'machtmißbrauches' : u'machtmissbrauches',
        u'machtmißbrauche'  : u'machtmissbrauche',
        u'machtmißbräuche'  : u'machtmissbräuche',
        u'machtmißbrauchs'  : u'machtmissbrauchs',
        u'machtmißbrauch'   : u'machtmissbrauch',
        u'maerz'            : u'märz',
        u'maffiabossen'     : u'mafiabossen',
        u'maffiabosses'     : u'mafiabosses',
        u'maffiabosse'      : u'mafiabosse',
        u'maffiaboss'       : u'mafiaboss',
        u'maffiaboß'        : u'mafiaboss',
        u'maffias'          : u'mafias',
        u'maffia'           : u'mafia',
        u'mafiaboß'         : u'mafiaboss',
        u'magen-darm-katarren': u'magen-darm-katarrhen',
        u'magen-darm-katarres': u'magen-darm-katarrhes',
        u'magen-darm-katarre': u'magen-darm-katarrhe',
        u'magen-darm-katarrs': u'magen-darm-katarrhs',
        u'magen-darm-katarr': u'magen-darm-katarrh',
        u'magistratsbeschluß': u'magistratsbeschluss',
        u'majonäse'         : u'mayonnaise',
        u'majoritätsbeschluß': u'majoritätsbeschluss',
        u'maläsen'          : u'malaisen',
        u'maläse'           : u'malaise',
        u'malojapaß'        : u'malojapass',
        u'mammutprozeß'     : u'mammutprozess',
        u'männerüberschuß'  : u'männerüberschuss',
        u'markenbewußtsein' : u'markenbewusstsein',
        u'markenbewußt'     : u'markenbewusst',
        u'marschkompaß'     : u'marschkompass',
        u'masculina'        : u'maskulina',
        u'masculinums'      : u'maskulinums',
        u'masculinum'       : u'maskulinum',
        u'masurkas'         : u'mazurkas',
        u'masurka'          : u'mazurka',
        u'masurken'         : u'mazurken',
        u'maulkorberlaß'    : u'maulkorberlass',
        u'maulthieren'      : u'maultieren',
        u'maulthieres'      : u'maultieres',
        u'maulthiere'       : u'maultiere',
        u'maulthiers'       : u'maultiers',
        u'maulthier'        : u'maultier',
        u'medicinen'        : u'medizinen',
        u'medicin'          : u'medizin',
        u'meeranschluß'     : u'meeranschluss',
        u'mehrentheils'     : u'mehrenteils',
        u'meinungsbildungsprozeß': u'meinungsbildungsprozess',
        u'meldeschluß'      : u'meldeschluss',
        u'meniskusriß'      : u'meniskusriss',
        u'menschenhaß'      : u'menschenhass',
        u'mercurs'          : u'merkurs',
        u'mercur'           : u'merkur',
        u'meßbarem'         : u'messbarem',
        u'meßbaren'         : u'messbaren',
        u'meßbarerem'       : u'messbarerem',
        u'meßbareren'       : u'messbareren',
        u'meßbarerer'       : u'messbarerer',
        u'meßbareres'       : u'messbareres',
        u'meßbarere'        : u'messbarere',
        u'meßbarer'         : u'messbarer',
        u'meßbares'         : u'messbares',
        u'meßbare'          : u'messbare',
        u'meßbarkeit'       : u'messbarkeit',
        u'meßbarstem'       : u'messbarstem',
        u'meßbarsten'       : u'messbarsten',
        u'meßbarster'       : u'messbarster',
        u'meßbarstes'       : u'messbarstes',
        u'meßbarste'        : u'messbarste',
        u'meßbar'           : u'messbar',
        u'meßbechern'       : u'messbechern',
        u'meßbechers'       : u'messbechers',
        u'meßbecher'        : u'messbecher',
        u'meßbeträgen'      : u'messbeträgen',
        u'meßbetrages'      : u'messbetrages',
        u'meßbetrage'       : u'messbetrage',
        u'meßbeträge'       : u'messbeträge',
        u'meßbetrags'       : u'messbetrags',
        u'meßbetrag'        : u'messbetrag',
        u'meßbüchern'       : u'messbüchern',
        u'meßbücher'        : u'messbücher',
        u'meßbuches'        : u'messbuches',
        u'meßbuche'         : u'messbuche',
        u'meßbuchs'         : u'messbuchs',
        u'meßbuch'          : u'messbuch',
        u'meßdienerinnen'   : u'messdienerinnen',
        u'meßdienerin'      : u'messdienerin',
        u'meßdienern'       : u'messdienern',
        u'meßdieners'       : u'messdieners',
        u'meßdiener'        : u'messdiener',
        u'meßergebnissen'   : u'messergebnissen',
        u'meßergebnisses'   : u'messergebnisses',
        u'meßergebnisse'    : u'messergebnisse',
        u'meßergebnis'      : u'messergebnis',
        u'meßfehlern'       : u'messfehlern',
        u'meßfehlers'       : u'messfehlers',
        u'meßfehler'        : u'messfehler',
        u'meßfeiern'        : u'messfeiern',
        u'meßfeier'         : u'messfeier',
        u'meßgenauheit'     : u'messgenauheit',
        u'meßgenauigkeit'   : u'messgenauigkeit',
        u'meßgeräten'       : u'messgeräten',
        u'meßgerätes'       : u'messgerätes',
        u'meßgeräte'        : u'messgeräte',
        u'meßgeräts'        : u'messgeräts',
        u'meßgerät'         : u'messgerät',
        u'meßgewandes'      : u'messgewandes',
        u'meßgewands'       : u'messgewands',
        u'meßgewand'        : u'messgewand',
        u'meßlatten'        : u'messlatten',
        u'meßlatte'         : u'messlatte',
        u'meßmitteln'       : u'messmitteln',
        u'meßmittels'       : u'messmittels',
        u'meßmittel'        : u'messmittel',
        u'meßnern'          : u'messnern',
        u'meßners'          : u'messners',
        u'meßner'           : u'messner',
        u'meßschiebern'     : u'messschiebern',
        u'meßschiebers'     : u'messschiebers',
        u'meßschieber'      : u'messschieber',
        u'meßstationen'     : u'messstationen',
        u'meßstation'       : u'messstation',
        u'meßstellen'       : u'messstellen',
        u'meßstelle'        : u'messstelle',
        u'meßstipendien'    : u'messstipendien',
        u'meßstipendiums'   : u'messstipendiums',
        u'meßstipendium'    : u'messstipendium',
        u'meßtechnik'       : u'messtechnik',
        u'meßt'             : u'messt',
        u'meßverfahrens'    : u'messverfahrens',
        u'meßverfahren'     : u'messverfahren',
        u'meßwagens'        : u'messwagens',
        u'meßwagen'         : u'messwagen',
        u'meßweinen'        : u'messweinen',
        u'meßweines'        : u'messweines',
        u'meßweine'         : u'messweine',
        u'meßweins'         : u'messweins',
        u'meßwein'          : u'messwein',
        u'meßwerken'        : u'messwerken',
        u'meßwerkes'        : u'messwerkes',
        u'meßwerke'         : u'messwerke',
        u'meßwerks'         : u'messwerks',
        u'meßwerk'          : u'messwerk',
        u'meßwerten'        : u'messwerten',
        u'meßwertes'        : u'messwertes',
        u'meßwerte'         : u'messwerte',
        u'meßwerts'         : u'messwerts',
        u'meßwert'          : u'messwert',
        u'metallampe'       : u'metalllampe',
        u'metallegierungen' : u'metalllegierungen',
        u'metallegierung'   : u'metalllegierung',
        u'metalleuchter'    : u'metallleuchter',
        u'metalleuchte'     : u'metallleuchte',
        u'metallfaß'        : u'metallfass',
        u'metalloïde'       : u'metalloide',
        u'meynend'          : u'meinend',
        u'meynen'           : u'meinen',
        u'meynest'          : u'meinest',
        u'meynet'           : u'meinet',
        u'meyne'            : u'meine',
        u'meynst'           : u'meinst',
        u'meynten'          : u'meinten',
        u'meyntest'         : u'meintest',
        u'meyntet'          : u'meintet',
        u'meynte'           : u'meinte',
        u'meynt'            : u'meint',
        u'meyn'             : u'mein',
        u'midlife-crisis'   : u'midlife-crisis',
        u'mikrophone'    : u'mikrofone',
        u'mikrophon'     : u'mikrofon',
        u'milchgebiß'       : u'milchgebiss',
        u'millenium'     : u'millennium',
        u'milzriß'          : u'milzriss',
        u'mißachtend'       : u'missachtend',
        u'mißachten'        : u'missachten',
        u'mißachtest'       : u'missachtest',
        u'mißachteten'      : u'missachteten',
        u'mißachtetest'     : u'missachtetest',
        u'mißachtetet'      : u'missachtetet',
        u'mißachtete'       : u'missachtete',
        u'mißachtet'        : u'missachtet',
        u'mißachte'         : u'missachte',
        u'mißachtungen'     : u'missachtungen',
        u'mißachtung'       : u'missachtung',
        u'mißbefinden'      : u'missbefinden',
        u'mißbefindlichkeit': u'missbefindlichkeit',
        u'mißbehagen'       : u'missbehagen',
        u'mißbehaglich'     : u'missbehaglich',
        u'mißbeschaffenheit': u'missbeschaffenheit',
        u'mißbeschaffen'    : u'missbeschaffen',
        u'mißbildungen'     : u'missbildungen',
        u'mißbildung'       : u'missbildung',
        u'mißbilligend'     : u'missbilligend',
        u'mißbilligen'      : u'missbilligen',
        u'mißbilligest'     : u'missbilligest',
        u'mißbilliget'      : u'missbilliget',
        u'mißbillige'       : u'missbillige',
        u'mißbilligst'      : u'missbilligst',
        u'mißbilligten'     : u'missbilligten',
        u'mißbilligtest'    : u'missbilligtest',
        u'mißbilligtet'     : u'missbilligtet',
        u'mißbilligte'      : u'missbilligte',
        u'mißbilligt'       : u'missbilligt',
        u'mißbillig'        : u'missbillig',
        u'mißbilligungen'   : u'missbilligungen',
        u'mißbilligungsanträgen': u'missbilligungsanträgen',
        u'mißbilligungsantrages': u'missbilligungsantrages',
        u'mißbilligungsantrage': u'missbilligungsantrage',
        u'mißbilligungsanträge': u'missbilligungsanträge',
        u'mißbilligungsantrags': u'missbilligungsantrags',
        u'mißbilligungsantrag': u'missbilligungsantrag',
        u'mißbilligung'     : u'missbilligung',
        u'mißbrauchend'     : u'missbrauchend',
        u'mißbrauchen'      : u'missbrauchen',
        u'mißbräuchen'      : u'missbräuchen',
        u'mißbrauchest'     : u'missbrauchest',
        u'mißbrauches'      : u'missbrauches',
        u'mißbrauchet'      : u'missbrauchet',
        u'mißbrauche'       : u'missbrauche',
        u'mißbräuche'       : u'missbräuche',
        u'mißbräuchlichem'  : u'missbräuchlichem',
        u'mißbräuchlichen'  : u'missbräuchlichen',
        u'mißbräuchlicher'  : u'missbräuchlicher',
        u'mißbräuchlicherweise': u'missbräuchlicherweise',
        u'mißbräuchliches'  : u'missbräuchliches',
        u'mißbräuchliche'   : u'missbräuchliche',
        u'mißbräuchlich'    : u'missbräuchlich',
        u'mißbrauchskonzept': u'missbrauchskonzept',
        u'mißbrauchst'      : u'missbrauchst',
        u'mißbrauchs'       : u'missbrauchs',
        u'mißbrauchten'     : u'missbrauchten',
        u'mißbrauchtest'    : u'missbrauchtest',
        u'mißbrauchtet'     : u'missbrauchtet',
        u'mißbrauchte'      : u'missbrauchte',
        u'mißbraucht'       : u'missbraucht',
        u'mißbrauch'        : u'missbrauch',
        u'mißdeutbar'       : u'missdeutbar',
        u'mißdeuten'        : u'missdeuten',
        u'mißdeutung'       : u'missdeutung',
        u'mißempfindung'    : u'missempfindung',
        u'mißerfolgen'      : u'misserfolgen',
        u'mißerfolges'      : u'misserfolges',
        u'mißerfolge'       : u'misserfolge',
        u'mißerfolgs'       : u'misserfolgs',
        u'mißerfolg'        : u'misserfolg',
        u'mißernten'        : u'missernten',
        u'mißernten'     : u'missernten',
        u'mißernte'         : u'missernte',
        u'mißfallend'       : u'missfallend',
        u'mißfallensäußerung': u'missfallensäußerung',
        u'mißfallenskundgebung': u'missfallenskundgebung',
        u'mißfallen'        : u'missfallen',
        u'mißfallest'       : u'missfallest',
        u'mißfallet'        : u'missfallet',
        u'mißfalle'         : u'missfalle',
        u'mißfällig'        : u'missfällig',
        u'mißfällst'        : u'missfällst',
        u'mißfallt'         : u'missfallt',
        u'mißfällt'         : u'missfällt',
        u'mißfall'          : u'missfall',
        u'mißfarben'        : u'missfarben',
        u'mißfarbe'         : u'missfarbe',
        u'mißfarbig'        : u'missfarbig',
        u'mißfielen'        : u'missfielen',
        u'mißfielest'       : u'missfielest',
        u'mißfielet'        : u'missfielet',
        u'mißfiele'         : u'missfiele',
        u'mißfielst'        : u'missfielst',
        u'mißfielt'         : u'missfielt',
        u'mißfiel'          : u'missfiel',
        u'mißgebildet'      : u'missgebildet',
        u'mißgeburten'      : u'missgeburten',
        u'mißgeburt'        : u'missgeburt',
        u'mißgelauntem'     : u'missgelauntem',
        u'mißgelaunten'     : u'missgelaunten',
        u'mißgelaunterem'   : u'missgelaunterem',
        u'mißgelaunteren'   : u'missgelaunteren',
        u'mißgelaunterer'   : u'missgelaunterer',
        u'mißgelaunteres'   : u'missgelaunteres',
        u'mißgelauntere'    : u'missgelauntere',
        u'mißgelaunter'     : u'missgelaunter',
        u'mißgelauntestem'  : u'missgelauntestem',
        u'mißgelauntesten'  : u'missgelauntesten',
        u'mißgelauntester'  : u'missgelauntester',
        u'mißgelauntestes'  : u'missgelauntestes',
        u'mißgelaunteste'   : u'missgelaunteste',
        u'mißgelauntes'     : u'missgelauntes',
        u'mißgelaunte'      : u'missgelaunte',
        u'mißgelauntheit'   : u'missgelauntheit',
        u'mißgelaunt'       : u'missgelaunt',
        u'mißgeschicken'    : u'missgeschicken',
        u'mißgeschickes'    : u'missgeschickes',
        u'mißgeschicke'     : u'missgeschicke',
        u'mißgeschicks'     : u'missgeschicks',
        u'mißgeschick'      : u'missgeschick',
        u'mißgestaltet'     : u'missgestaltet',
        u'mißgestalt'       : u'missgestalt',
        u'mißgestimmt'      : u'missgestimmt',
        u'mißgewachsen'     : u'missgewachsen',
        u'mißglückend'      : u'missglückend',
        u'mißglücken'       : u'missglücken',
        u'mißglückest'      : u'missglückest',
        u'mißglücket'       : u'missglücket',
        u'mißglücke'        : u'missglücke',
        u'mißglückst'       : u'missglückst',
        u'mißglücktem'      : u'missglücktem',
        u'mißglückten'      : u'missglückten',
        u'mißglückterem'    : u'missglückterem',
        u'mißglückteren'    : u'missglückteren',
        u'mißglückterer'    : u'missglückterer',
        u'mißglückteres'    : u'missglückteres',
        u'mißglücktere'     : u'missglücktere',
        u'mißglückter'      : u'missglückter',
        u'mißglücktestem'   : u'missglücktestem',
        u'mißglücktesten'   : u'missglücktesten',
        u'mißglücktester'   : u'missglücktester',
        u'mißglücktestes'   : u'missglücktestes',
        u'mißglückteste'    : u'missglückteste',
        u'mißglücktest'     : u'missglücktest',
        u'mißglücktes'      : u'missglücktes',
        u'mißglücktet'      : u'missglücktet',
        u'mißglückte'       : u'missglückte',
        u'mißglückt'        : u'missglückt',
        u'mißglück'         : u'missglück',
        u'mißgönnen'        : u'missgönnen',
        u'mißgriff'         : u'missgriff',
        u'mißgünstigem'     : u'missgünstigem',
        u'mißgünstigen'     : u'missgünstigen',
        u'mißgünstigerem'   : u'missgünstigerem',
        u'mißgünstigeren'   : u'missgünstigeren',
        u'mißgünstigerer'   : u'missgünstigerer',
        u'mißgünstigeres'   : u'missgünstigeres',
        u'mißgünstigere'    : u'missgünstigere',
        u'mißgünstiger'     : u'missgünstiger',
        u'mißgünstiges'     : u'missgünstiges',
        u'mißgünstige'      : u'missgünstige',
        u'mißgünstigstem'   : u'missgünstigstem',
        u'mißgünstigsten'   : u'missgünstigsten',
        u'mißgünstigster'   : u'missgünstigster',
        u'mißgünstigstes'   : u'missgünstigstes',
        u'mißgünstigste'    : u'missgünstigste',
        u'mißgünstig'       : u'missgünstig',
        u'mißgunst'         : u'missgunst',
        u'mißhandelest'     : u'misshandelest',
        u'mißhandelet'      : u'misshandelet',
        u'mißhandele'       : u'misshandele',
        u'mißhandelnd'      : u'misshandelnd',
        u'mißhandeln'       : u'misshandeln',
        u'mißhandelst'      : u'misshandelst',
        u'mißhandelten'     : u'misshandelten',
        u'mißhandeltest'    : u'misshandeltest',
        u'mißhandeltet'     : u'misshandeltet',
        u'mißhandelte'      : u'misshandelte',
        u'mißhandelt'       : u'misshandelt',
        u'mißhandel'        : u'misshandel',
        u'mißhandlest'      : u'misshandlest',
        u'mißhandlet'       : u'misshandlet',
        u'mißhandle'        : u'misshandle',
        u'mißhandlungen'    : u'misshandlungen',
        u'mißhandlung'      : u'misshandlung',
        u'mißheirat'        : u'missheirat',
        u'mißhelligkeit'    : u'misshelligkeit',
        u'mißhellig'        : u'misshellig',
        u'mißklängen'       : u'missklängen',
        u'mißklänge'        : u'missklänge',
        u'mißklangs'        : u'missklangs',
        u'mißklang'         : u'missklang',
        u'mißkommunikationen': u'misskommunikationen',
        u'mißkommunikation' : u'misskommunikation',
        u'mißkredit'        : u'misskredit',
        u'mißlangen'        : u'misslangen',
        u'mißlängen'        : u'misslängen',
        u'mißlängest'       : u'misslängest',
        u'mißlänget'        : u'misslänget',
        u'mißlänge'         : u'misslänge',
        u'mißlangst'        : u'misslangst',
        u'mißlängst'        : u'misslängst',
        u'mißlangt'         : u'misslangt',
        u'mißlängt'         : u'misslängt',
        u'mißlang'          : u'misslang',
        u'mißlaunig'        : u'misslaunig',
        u'mißlaut'          : u'misslaut',
        u'mißleiten'        : u'missleiten',
        u'mißleitung'       : u'missleitung',
        u'mißlichem'        : u'misslichem',
        u'mißlichen'        : u'misslichen',
        u'mißlicherem'      : u'misslicherem',
        u'mißlicheren'      : u'misslicheren',
        u'mißlicherer'      : u'misslicherer',
        u'mißlicheres'      : u'misslicheres',
        u'mißlichere'       : u'misslichere',
        u'mißlicher'        : u'misslicher',
        u'mißliches'        : u'missliches',
        u'mißliche'         : u'missliche',
        u'mißlichkeit'      : u'misslichkeit',
        u'mißlichstem'      : u'misslichstem',
        u'mißlichsten'      : u'misslichsten',
        u'mißlichster'      : u'misslichster',
        u'mißlichstes'      : u'misslichstes',
        u'mißlichste'       : u'misslichste',
        u'mißlich'          : u'misslich',
        u'mißliebigem'      : u'missliebigem',
        u'mißliebigen'      : u'missliebigen',
        u'mißliebigerem'    : u'missliebigerem',
        u'mißliebigeren'    : u'missliebigeren',
        u'mißliebigerer'    : u'missliebigerer',
        u'mißliebigeres'    : u'missliebigeres',
        u'mißliebigere'     : u'missliebigere',
        u'mißliebiger'      : u'missliebiger',
        u'mißliebiges'      : u'missliebiges',
        u'mißliebige'       : u'missliebige',
        u'mißliebigkeiten'  : u'missliebigkeiten',
        u'mißliebigkeit'    : u'missliebigkeit',
        u'mißliebigstem'    : u'missliebigstem',
        u'mißliebigsten'    : u'missliebigsten',
        u'mißliebigster'    : u'missliebigster',
        u'mißliebigstes'    : u'missliebigstes',
        u'mißliebigste'     : u'missliebigste',
        u'mißliebig'        : u'missliebig',
        u'mißlingend'       : u'misslingend',
        u'mißlingen'        : u'misslingen',
        u'mißlingest'       : u'misslingest',
        u'mißlinget'        : u'misslinget',
        u'mißlinge'         : u'misslinge',
        u'mißlingst'        : u'misslingst',
        u'mißlingt'         : u'misslingt',
        u'mißling'          : u'missling',
        u'mißlungen'        : u'misslungen',
        u'mißmanagements'   : u'missmanagements',
        u'mißmanagement'    : u'missmanagement',
        u'mißmutes'         : u'missmutes',
        u'mißmute'          : u'missmute',
        u'mißmutigem'       : u'missmutigem',
        u'mißmutigen'       : u'missmutigen',
        u'mißmutigerem'     : u'missmutigerem',
        u'mißmutigeren'     : u'missmutigeren',
        u'mißmutigerer'     : u'missmutigerer',
        u'mißmutigeres'     : u'missmutigeres',
        u'mißmutigere'      : u'missmutigere',
        u'mißmutiger'       : u'missmutiger',
        u'mißmutiges'       : u'missmutiges',
        u'mißmutige'        : u'missmutige',
        u'mißmutigstem'     : u'missmutigstem',
        u'mißmutigsten'     : u'missmutigsten',
        u'mißmutigster'     : u'missmutigster',
        u'mißmutigstes'     : u'missmutigstes',
        u'mißmutigste'      : u'missmutigste',
        u'mißmutig'         : u'missmutig',
        u'mißmuts'          : u'missmuts',
        u'mißmut'           : u'missmut',
        u'mißratend'        : u'missratend',
        u'mißraten'         : u'missraten',
        u'mißratest'        : u'missratest',
        u'mißratet'         : u'missratet',
        u'mißrate'          : u'missrate',
        u'mißrätst'         : u'missrätst',
        u'mißrat'           : u'missrat',
        u'mißrät'           : u'missrät',
        u'mißrieten'        : u'missrieten',
        u'mißrietest'       : u'missrietest',
        u'mißrietet'        : u'missrietet',
        u'mißriete'         : u'missriete',
        u'mißrietst'        : u'missrietst',
        u'mißriet'          : u'missriet',
        u'mißständen'       : u'missständen',
        u'mißstandes'       : u'missstandes',
        u'mißstande'        : u'missstande',
        u'mißstände'        : u'missstände',
        u'mißstands'        : u'missstands',
        u'mißstand'         : u'missstand',
        u'mißstimmung'      : u'missstimmung',
        u'mißten'           : u'missten',
        u'mißtest'          : u'misstest',
        u'mißtet'           : u'misstet',
        u'mißte'            : u'misste',
        u'mißtönend'        : u'misstönend',
        u'mißtönig'         : u'misstönig',
        u'mißton'           : u'misston',
        u'mißtrauend'       : u'misstrauend',
        u'mißtrauensanträgen': u'misstrauensanträgen',
        u'mißtrauensantrages': u'misstrauensantrages',
        u'mißtrauensantrage': u'misstrauensantrage',
        u'mißtrauensanträge': u'misstrauensanträge',
        u'mißtrauensantrags': u'misstrauensantrags',
        u'mißtrauensantrag' : u'misstrauensantrag',
        u'mißtrauens'       : u'misstrauens',
        u'mißtrauensvota'   : u'misstrauensvota',
        u'mißtrauensvoten'  : u'misstrauensvoten',
        u'mißtrauensvotums' : u'misstrauensvotums',
        u'mißtrauensvotum'  : u'misstrauensvotum',
        u'mißtrauen'        : u'misstrauen',
        u'mißtrauen'     : u'misstrauen',
        u'mißtrauest'       : u'misstrauest',
        u'mißtrauet'        : u'misstrauet',
        u'mißtraue'         : u'misstraue',
        u'mißtrauischem'    : u'misstrauischem',
        u'mißtrauischen'    : u'misstrauischen',
        u'mißtrauischerem'  : u'misstrauischerem',
        u'mißtrauischeren'  : u'misstrauischeren',
        u'mißtrauischerer'  : u'misstrauischerer',
        u'mißtrauischeres'  : u'misstrauischeres',
        u'mißtrauischere'   : u'misstrauischere',
        u'mißtrauischer'    : u'misstrauischer',
        u'mißtrauisches'    : u'misstrauisches',
        u'mißtrauische'     : u'misstrauische',
        u'mißtrauischstem'  : u'misstrauischstem',
        u'mißtrauischsten'  : u'misstrauischsten',
        u'mißtrauischster'  : u'misstrauischster',
        u'mißtrauischstes'  : u'misstrauischstes',
        u'mißtrauischste'   : u'misstrauischste',
        u'mißtrauisch'      : u'misstrauisch',
        u'mißtrauisch'   : u'misstrauisch',
        u'mißtraust'        : u'misstraust',
        u'mißtrauten'       : u'misstrauten',
        u'mißtrautest'      : u'misstrautest',
        u'mißtrautet'       : u'misstrautet',
        u'mißtraute'        : u'misstraute',
        u'mißtraut'         : u'misstraut',
        u'mißtrau'          : u'misstrau',
        u'mißtritt'         : u'misstritt',
        u'mißt'             : u'misst',
        u'miß-'             : u'miss-',
        u'miß'              : u'miss',
        u'mißvergnügens'    : u'missvergnügens',
        u'mißvergnügen'     : u'missvergnügen',
        u'mißvergnügtem'    : u'missvergnügtem',
        u'mißvergnügten'    : u'missvergnügten',
        u'mißvergnügterem'  : u'missvergnügterem',
        u'mißvergnügteren'  : u'missvergnügteren',
        u'mißvergnügterer'  : u'missvergnügterer',
        u'mißvergnügteres'  : u'missvergnügteres',
        u'mißvergnügtere'   : u'missvergnügtere',
        u'mißvergnügter'    : u'missvergnügter',
        u'mißvergnügtestem' : u'missvergnügtestem',
        u'mißvergnügtesten' : u'missvergnügtesten',
        u'mißvergnügtester' : u'missvergnügtester',
        u'mißvergnügtestes' : u'missvergnügtestes',
        u'mißvergnügteste'  : u'missvergnügteste',
        u'mißvergnügtes'    : u'missvergnügtes',
        u'mißvergnügte'     : u'missvergnügte',
        u'mißvergnügt'      : u'missvergnügt',
        u'mißvergnügt'   : u'missvergnügt',
        u'mißverhältnis'    : u'missverhältnis',
        u'mißverständlichem': u'missverständlichem',
        u'mißverständlichen': u'missverständlichen',
        u'mißverständlicherem': u'missverständlicherem',
        u'mißverständlicheren': u'missverständlicheren',
        u'mißverständlicherer': u'missverständlicherer',
        u'mißverständlicheres': u'missverständlicheres',
        u'mißverständlichere': u'missverständlichere',
        u'mißverständlicher': u'missverständlicher',
        u'mißverständliches': u'missverständliches',
        u'mißverständliche' : u'missverständliche',
        u'mißverständlichstem': u'missverständlichstem',
        u'mißverständlichsten': u'missverständlichsten',
        u'mißverständlichster': u'missverständlichster',
        u'mißverständlichstes': u'missverständlichstes',
        u'mißverständlichste': u'missverständlichste',
        u'mißverständlich'  : u'missverständlich',
        u'mißverständnissen': u'missverständnissen',
        u'mißverständnisses': u'missverständnisses',
        u'mißverständnisse' : u'missverständnisse',
        u'mißverständniß'   : u'missverständnis',
        u'mißverständnis'   : u'missverständnis',
        u'mißverständnis': u'missverständnis',
        u'mißverstehen'     : u'missverstehen',
        u'mißverstehe'      : u'missverstehe',
        u'mißwachsen'       : u'misswachsen',
        u'mißwachs'         : u'misswachs',
        u'mißwahl'          : u'misswahl',
        u'mißweisung'       : u'missweisung',
        u'mißwirtschaft'    : u'misswirtschaft',
        u'mißwuchs'         : u'misswuchs',
        u'mißzufrieden'     : u'misszufrieden',
        u'miteßt'           : u'mitesst',
        u'mitißt'           : u'mitisst',
        u'mitrißt'          : u'mitrisst',
        u'mitriß'           : u'mitriss',
        u'mobiltelephonen'  : u'mobiltelefonen',
        u'mobiltelephone'   : u'mobiltelefone',
        u'mobiltelephons'   : u'mobiltelefons',
        u'mobiltelephon'    : u'mobiltelefon',
        u'modebewußtem'     : u'modebewusstem',
        u'modebewußten'     : u'modebewussten',
        u'modebewußterem'   : u'modebewussterem',
        u'modebewußteren'   : u'modebewussteren',
        u'modebewußterer'   : u'modebewussterer',
        u'modebewußteres'   : u'modebewussteres',
        u'modebewußtere'    : u'modebewusstere',
        u'modebewußter'     : u'modebewusster',
        u'modebewußtestem'  : u'modebewusstestem',
        u'modebewußtesten'  : u'modebewusstesten',
        u'modebewußtester'  : u'modebewusstester',
        u'modebewußtestes'  : u'modebewusstestes',
        u'modebewußteste'   : u'modebewussteste',
        u'modebewußtes'     : u'modebewusstes',
        u'modebewußte'      : u'modebewusste',
        u'modebewußt'       : u'modebewusst',
        u'mohären'          : u'mohairen',
        u'mohäre'           : u'mohaire',
        u'mohärs'           : u'mohairs',
        u'mohär'            : u'mohair',
        u'mohr'             : u'moor',
        u'monsterprozeß'    : u'monsterprozess',
        u'mops'             : u'mopps',
        u'mop'              : u'mopp',
        u'mordprozeß'       : u'mordprozess',
        u'möven'            : u'möwen',
        u'möve'             : u'möwe',
        u'mülladung'        : u'müllladung',
        u'müllager'         : u'mülllager',
        u'mulläppchen'      : u'mullläppchen',
        u'müllaster'        : u'mülllaster',
        u'mülleerung'       : u'müllleerung',
        u'mülleuten'        : u'müllleuten',
        u'mülleute'         : u'müllleute',
        u'münztelephonen'   : u'münztelefonen',
        u'münztelephone'    : u'münztelefone',
        u'münztelephons'    : u'münztelefons',
        u'münztelephon'     : u'münztelefon',
        u'muskatnuß'        : u'muskatnuss',
        u'muskelfaserriß'   : u'muskelfaserriss',
        u'muskelriß'        : u'muskelriss',
        u'mußten'           : u'mussten',
        u'müßten'           : u'müssten',
        u'mußtest'          : u'musstest',
        u'müßtest'          : u'müsstest',
        u'mußtet'           : u'musstet',
        u'müßtet'           : u'müsstet',
        u'mußte'            : u'musste',
        u'mußte'         : u'musste',
        u'müßte'            : u'müsste',
        u'müßte'         : u'müsste',
        u'mußt'             : u'musst',
        u'mußt'          : u'musst',
        u'müßt'             : u'müsst',
        u'müßt'          : u'müsst',
        u'muß'              : u'muss',
        u'muß'           : u'muss',
        u'musterprozeß'     : u'musterprozess',
        u'muthes'           : u'mutes',
        u'muthe'            : u'mute',
        u'muths'            : u'muts',
        u'muth'             : u'mut',
        u'myrre'            : u'myrrhe',
        u'nachkriegsphotos' : u'nachkriegsfotos',
        u'nachkriegsphoto'  : u'nachkriegsfoto',
        u'nachlaßgericht'   : u'nachlassgericht',
        u'nachlaßpfleger'   : u'nachlasspfleger',
        u'nachlaßt'         : u'nachlasst',
        u'nachläßt'         : u'nachlässt',
        u'nachlaß'          : u'nachlass',
        u'nachlaßverwalterinnen': u'nachlassverwalterinnen',
        u'nachlaßverwalterin': u'nachlassverwalterin',
        u'nachlaßverwaltern': u'nachlassverwaltern',
        u'nachlaßverwalters': u'nachlassverwalters',
        u'nachlaßverwalter' : u'nachlassverwalter',
        u'nachlaßverwaltung': u'nachlassverwaltung',
        u'nachschuß'        : u'nachschuss',
        u'nachtblüthen'     : u'nachtblüten',
        u'nansenpaß'        : u'nansenpass',
        u'naphta'           : u'naphtha',
        u'narzißmen'        : u'narzissmen',
        u'narzißmus'        : u'narzissmus',
        u'narzißten'        : u'narzissten',
        u'narzißtischem'    : u'narzisstischem',
        u'narzißtischen'    : u'narzisstischen',
        u'narzißtischerem'  : u'narzisstischerem',
        u'narzißtischeren'  : u'narzisstischeren',
        u'narzißtischerer'  : u'narzisstischerer',
        u'narzißtischeres'  : u'narzisstischeres',
        u'narzißtischere'   : u'narzisstischere',
        u'narzißtischer'    : u'narzisstischer',
        u'narzißtisches'    : u'narzisstisches',
        u'narzißtische'     : u'narzisstische',
        u'narzißtischstem'  : u'narzisstischstem',
        u'narzißtischsten'  : u'narzisstischsten',
        u'narzißtischster'  : u'narzisstischster',
        u'narzißtischstes'  : u'narzisstischstes',
        u'narzißtischste'   : u'narzisstischste',
        u'narzißtisch'      : u'narzisstisch',
        u'narzißt'          : u'narzisst',
        u'narziß'           : u'narziss',
        u'naßfest'          : u'nassfest',
        u'naßforschem'      : u'nassforschem',
        u'naßforschen'      : u'nassforschen',
        u'naßforscherem'    : u'nassforscherem',
        u'naßforscheren'    : u'nassforscheren',
        u'naßforscherer'    : u'nassforscherer',
        u'naßforscheres'    : u'nassforscheres',
        u'naßforschere'     : u'nassforschere',
        u'naßforscher'      : u'nassforscher',
        u'naßforschestem'   : u'nassforschestem',
        u'naßforschesten'   : u'nassforschesten',
        u'naßforschester'   : u'nassforschester',
        u'naßforschestes'   : u'nassforschestes',
        u'naßforscheste'    : u'nassforscheste',
        u'naßforsches'      : u'nassforsches',
        u'naßforsche'       : u'nassforsche',
        u'naßforschstem'    : u'nassforschstem',
        u'naßforschsten'    : u'nassforschsten',
        u'naßforschster'    : u'nassforschster',
        u'naßforschstes'    : u'nassforschstes',
        u'naßforschste'     : u'nassforschste',
        u'naßforsch'        : u'nassforsch',
        u'naßfuttern'       : u'nassfuttern',
        u'naßfutters'       : u'nassfutters',
        u'naßfutter'        : u'nassfutter',
        u'naßgeschwitztem'  : u'nassgeschwitztem',
        u'naßgeschwitzten'  : u'nassgeschwitzten',
        u'naßgeschwitzter'  : u'nassgeschwitzter',
        u'naßgeschwitztes'  : u'nassgeschwitztes',
        u'naßgeschwitzte'   : u'nassgeschwitzte',
        u'naßgeschwitzt'    : u'nassgeschwitzt',
        u'naßkaltem'        : u'nasskaltem',
        u'naßkalten'        : u'nasskalten',
        u'naßkälterem'      : u'nasskälterem',
        u'naßkälteren'      : u'nasskälteren',
        u'naßkälterer'      : u'nasskälterer',
        u'naßkälteres'      : u'nasskälteres',
        u'naßkältere'       : u'nasskältere',
        u'naßkalter'        : u'nasskalter',
        u'naßkälter'        : u'nasskälter',
        u'naßkältestem'     : u'nasskältestem',
        u'naßkältesten'     : u'nasskältesten',
        u'naßkältester'     : u'nasskältester',
        u'naßkältestes'     : u'nasskältestes',
        u'naßkälteste'      : u'nasskälteste',
        u'naßkaltes'        : u'nasskaltes',
        u'naßkalte'         : u'nasskalte',
        u'naßkalt'          : u'nasskalt',
        u'naßklebendem'     : u'nassklebendem',
        u'naßklebenden'     : u'nassklebenden',
        u'naßklebender'     : u'nassklebender',
        u'naßklebendes'     : u'nassklebendes',
        u'naßklebende'      : u'nassklebende',
        u'naßklebend'       : u'nassklebend',
        u'naßkotes'         : u'nasskotes',
        u'naßkots'          : u'nasskots',
        u'naßkot'           : u'nasskot',
        u'näßlich'          : u'nässlich',
        u'naßrasierer'      : u'nassrasierer',
        u'naßrasuren'       : u'nassrasuren',
        u'naßrasur'         : u'nassrasur',
        u'naßschnees'       : u'nassschnees',
        u'naßschnee'        : u'nassschnee',
        u'näßten'           : u'nässten',
        u'näßtest'          : u'nässtest',
        u'näßtet'           : u'nässtet',
        u'näßte'            : u'nässte',
        u'näßt'             : u'nässt',
        u'naß'              : u'nass',
        u'naß'           : u'nass',
        u'näß'              : u'näss',
        u'naßwäsche'        : u'nasswäsche',
        u'naßzelle'         : u'nasszelle',
        u'nationalbewußtem' : u'nationalbewusstem',
        u'nationalbewußten' : u'nationalbewussten',
        u'nationalbewußterem': u'nationalbewussterem',
        u'nationalbewußteren': u'nationalbewussteren',
        u'nationalbewußterer': u'nationalbewussterer',
        u'nationalbewußteres': u'nationalbewussteres',
        u'nationalbewußtere': u'nationalbewusstere',
        u'nationalbewußter' : u'nationalbewusster',
        u'nationalbewußtestem': u'nationalbewusstestem',
        u'nationalbewußtesten': u'nationalbewusstesten',
        u'nationalbewußtester': u'nationalbewusstester',
        u'nationalbewußtestes': u'nationalbewusstestes',
        u'nationalbewußteste': u'nationalbewussteste',
        u'nationalbewußtes' : u'nationalbewusstes',
        u'nationalbewußte'  : u'nationalbewusste',
        u'nationalbewußtsein': u'nationalbewusstsein',
        u'nationalbewußt'   : u'nationalbewusst',
        u'nebelschlußleuchten': u'nebelschlussleuchten',
        u'nebelschlußleuchte': u'nebelschlussleuchte',
        u'nebenfluß'        : u'nebenfluss',
        u'nebengelaß'       : u'nebengelass',
        u'negerkuß'         : u'negerkuss',
        u'negirend'         : u'negierend',
        u'negiren'          : u'negieren',
        u'negirest'         : u'negierest',
        u'negiret'          : u'negieret',
        u'negire'           : u'negiere',
        u'negirst'          : u'negierst',
        u'negirten'         : u'negierten',
        u'negirtest'        : u'negiertest',
        u'negirtet'         : u'negiertet',
        u'negirte'          : u'negierte',
        u'negirt'           : u'negiert',
        u'negir'            : u'negier',
        u'negligees'        : u'negligés',
        u'negligee'         : u'negligé',
        u'nessessär'        : u'necessaire',
        u'netzanschluß'     : u'netzanschluss',
        u'neuß'             : u'neuss',
        u'neuwienerisch'    : u'neu-wienerisch',
        u'niederlaßt'       : u'niederlasst',
        u'niederläßt'       : u'niederlässt',
        u'niederschoßt'     : u'niederschosst',
        u'niederschoß'      : u'niederschoss',
        u'nivellirend'      : u'nivellierend',
        u'nivelliren'       : u'nivellieren',
        u'nivellirest'      : u'nivellierest',
        u'nivelliret'       : u'nivellieret',
        u'nivellire'        : u'nivelliere',
        u'nivellirst'       : u'nivellierst',
        u'nivellirten'      : u'nivellierten',
        u'nivellirtest'     : u'nivelliertest',
        u'nivellirtet'      : u'nivelliertet',
        u'nivellirte'       : u'nivellierte',
        u'nivellirt'        : u'nivelliert',
        u'nivellir'         : u'nivellier',
        u'nordwestrußlands' : u'nordwestrusslands',
        u'nordwestrußland'  : u'nordwestrussland',
        u'normalgeschoß'    : u'normalgeschoss',
        u'normenausschuß'   : u'normenausschuss',
        u'nöthen'           : u'nöten',
        u'nöthe'            : u'nöte',
        u'nöthigen'         : u'nötigen',
        u'noth'             : u'not',
        u'notwaßrest'       : u'notwassrest',
        u'notwaßret'        : u'notwassret',
        u'notwaßre'         : u'notwassre',
        u'nullagen'         : u'nulllagen',
        u'nullage'          : u'nulllage',
        u'nulleitern'       : u'nullleitern',
        u'nulleiters'       : u'nullleiters',
        u'nulleiter'        : u'nullleiter',
        u'nullinie'         : u'nulllinie',
        u'nullösungen'      : u'nulllösungen',
        u'nullösung'        : u'nulllösung',
        u'numerierenden'    : u'nummerierenden',
        u'numerierend'      : u'nummerierend',
        u'numerieren'       : u'nummerieren',
        u'numerierest'      : u'nummerierest',
        u'numerieret'       : u'nummerieret',
        u'numeriere'        : u'nummeriere',
        u'numerierst'       : u'nummerierst',
        u'numerierten'      : u'nummerierten',
        u'numeriertest'     : u'nummeriertest',
        u'numeriertet'      : u'nummeriertet',
        u'numerierte'       : u'nummerierte',
        u'numeriert'        : u'nummeriert',
        u'numerierungen'    : u'nummerierungen',
        u'numerierung'      : u'nummerierung',
        u'numerier'         : u'nummerier',
        u'nußbäumen'        : u'nussbäumen',
        u'nußbaumes'        : u'nussbaumes',
        u'nußbaume'         : u'nussbaume',
        u'nußbäume'         : u'nussbäume',
        u'nußbaumhölzern'   : u'nussbaumhölzern',
        u'nußbaumhölzer'    : u'nussbaumhölzer',
        u'nußbaumholzes'    : u'nussbaumholzes',
        u'nußbaumholze'     : u'nussbaumholze',
        u'nußbaumholz'      : u'nussbaumholz',
        u'nußbaums'         : u'nussbaums',
        u'nußbaum'          : u'nussbaum',
        u'nußbraun'         : u'nussbraun',
        u'nüßchens'         : u'nüsschens',
        u'nüßchen'          : u'nüsschen',
        u'nußecke'          : u'nussecke',
        u'nußförmigem'      : u'nussförmigem',
        u'nußförmigen'      : u'nussförmigen',
        u'nußförmiger'      : u'nussförmiger',
        u'nußförmiges'      : u'nussförmiges',
        u'nußförmige'       : u'nussförmige',
        u'nußförmig'        : u'nussförmig',
        u'nußfüllungen'     : u'nussfüllungen',
        u'nußfüllung'       : u'nussfüllung',
        u'nußknackern'      : u'nussknackern',
        u'nußknackers'      : u'nussknackers',
        u'nußknacker'       : u'nussknacker',
        u'nußkohle'         : u'nusskohle',
        u'nußkuchen'        : u'nusskuchen',
        u'nußöl'            : u'nussöl',
        u'nußpfirsichen'    : u'nusspfirsichen',
        u'nußpfirsiches'    : u'nusspfirsiches',
        u'nußpfirsiche'     : u'nusspfirsiche',
        u'nußpfirsichs'     : u'nusspfirsichs',
        u'nußpfirsich'      : u'nusspfirsich',
        u'nußpilzen'        : u'nusspilzen',
        u'nußpilzes'        : u'nusspilzes',
        u'nußpilze'         : u'nusspilze',
        u'nußpilz'          : u'nusspilz',
        u'nußschalen'       : u'nussschalen',
        u'nußschale'        : u'nussschale',
        u'nußschinkens'     : u'nussschinkens',
        u'nußschinken'      : u'nussschinken',
        u'nußschokoladen'   : u'nussschokoladen',
        u'nußschokolade'    : u'nussschokolade',
        u'nußstrudeln'      : u'nussstrudeln',
        u'nußstrudels'      : u'nussstrudels',
        u'nußstrudel'       : u'nussstrudel',
        u'nußtorten'        : u'nusstorten',
        u'nußtorte'         : u'nusstorte',
        u'nuß'              : u'nuss',
        u'nuß'           : u'nuss',
        u'obergränzen'      : u'obergrenzen',
        u'obergränze'       : u'obergrenze',
        u'objektivanschluß' : u'objektivanschluss',
        u'octobern'         : u'oktobern',
        u'octobers'         : u'oktobers',
        u'october'          : u'oktober',
        u'oels'             : u'öls',
        u'oel'              : u'öl',
        u'ok'            : u'okay',
        u'öldruckkontrollampen': u'öldruckkontrolllampen',
        u'öldruckkontrollampe': u'öldruckkontrolllampe',
        u'ölfaß'            : u'ölfass',
        u'ölmeßstäben'      : u'ölmessstäben',
        u'ölmeßstabes'      : u'ölmessstabes',
        u'ölmeßstabe'       : u'ölmessstabe',
        u'ölmeßstäbe'       : u'ölmessstäbe',
        u'ölmeßstabs'       : u'ölmessstabs',
        u'ölmeßstab'        : u'ölmessstab',
        u'ordre'            : u'order',
        u'orientexpreß'     : u'orientexpress',
        u'orthophotos'      : u'orthofotos',
        u'orthophoto'       : u'orthofoto',
        u'oscillirend'      : u'oszillierend',
        u'ösfaß'            : u'ösfass',
        u'ostgothenkönigen' : u'ostgotenkönigen',
        u'ostgothenköniges' : u'ostgotenköniges',
        u'ostgothenkönige'  : u'ostgotenkönige',
        u'ostgothenkönigs'  : u'ostgotenkönigs',
        u'ostgothenkönig'   : u'ostgotenkönig',
        u'ostgothen'        : u'ostgoten',
        u'ostgothe'         : u'ostgote',
        u'oute'             : u'out',
        u'owne'             : u'own',
        u'paranußbaum'      : u'paranussbaum',
        u'paranuß'          : u'paranuss',
        u'parlamentsausschuß': u'parlamentsausschuss',
        u'parlamentsbeschluß': u'parlamentsbeschluss',
        u'parnaß'           : u'parnass',
        u'parteiausschluß'  : u'parteiausschluss',
        u'parteiausschlußverfahrens': u'parteiausschlussverfahrens',
        u'parteiausschlußverfahren': u'parteiausschlussverfahren',
        u'parteibeschluß'   : u'parteibeschluss',
        u'parteikongreß'    : u'parteikongress',
        u'parteitagsbeschluß': u'parteitagsbeschluss',
        u'parties'          : u'partys',
        u'paßamt'           : u'passamt',
        u'paßanträgen'      : u'passanträgen',
        u'paßantrages'      : u'passantrages',
        u'paßantrage'       : u'passantrage',
        u'paßanträge'       : u'passanträge',
        u'paßantrags'       : u'passantrags',
        u'paßantrag'        : u'passantrag',
        u'paßbehörden'      : u'passbehörden',
        u'paßbehörde'       : u'passbehörde',
        u'paßbildern'       : u'passbildern',
        u'paßbilder'        : u'passbilder',
        u'paßbildes'        : u'passbildes',
        u'paßbilde'         : u'passbilde',
        u'paßbilds'         : u'passbilds',
        u'paßbild'          : u'passbild',
        u'passee'           : u'passé',
        u'paßempfängern'    : u'passempfängern',
        u'paßempfängers'    : u'passempfängers',
        u'paßempfänger'     : u'passempfänger',
        u'paßform'          : u'passform',
        u'paßfotos'         : u'passfotos',
        u'paßfoto'          : u'passfoto',
        u'paßgängern'       : u'passgängern',
        u'paßgängers'       : u'passgängers',
        u'paßgänger'        : u'passgänger',
        u'paßganges'        : u'passganges',
        u'paßgangs'         : u'passgangs',
        u'paßgang'          : u'passgang',
        u'paßgebern'        : u'passgebern',
        u'paßgebers'        : u'passgebers',
        u'paßgeber'         : u'passgeber',
        u'paßgenau'         : u'passgenau',
        u'paßgerecht'       : u'passgerecht',
        u'paßhöhe'          : u'passhöhe',
        u'paßinhabern'      : u'passinhabern',
        u'paßinhabers'      : u'passinhabers',
        u'paßinhaber'       : u'passinhaber',
        u'passivprozeß'     : u'passivprozess',
        u'paßkontrollen'    : u'passkontrollen',
        u'paßkontrolle'     : u'passkontrolle',
        u'paßpflicht'       : u'passpflicht',
        u'paßphotos'        : u'passfotos',
        u'paßphoto'         : u'passfoto',
        u'paßspielen'       : u'passspielen',
        u'paßspieles'       : u'passspieles',
        u'paßspiele'        : u'passspiele',
        u'paßspiels'        : u'passspiels',
        u'paßspiel'         : u'passspiel',
        u'paßstelle'        : u'passstelle',
        u'paßstraßen'       : u'passstraßen',
        u'paßstraße'        : u'passstraße',
        u'paßten'           : u'passten',
        u'paßtest'          : u'passtest',
        u'paßtet'           : u'passtet',
        u'paßte'            : u'passte',
        u'paßte'         : u'passte',
        u'paßträgern'       : u'passträgern',
        u'paßträgers'       : u'passträgers',
        u'paßträger'        : u'passträger',
        u'paßt'             : u'passt',
        u'paßt'          : u'passt',
        u'paß'              : u'pass',
        u'paß'           : u'pass',
        u'paßwärts'         : u'passwärts',
        u'paßwesen'         : u'passwesen',
        u'paßwörtern'       : u'passwörtern',
        u'paßwörter'        : u'passwörter',
        u'paßwortes'        : u'passwortes',
        u'paßworte'         : u'passworte',
        u'paßwortgeschützt' : u'passwortgeschützt',
        u'paßwortmanagern'  : u'passwortmanagern',
        u'paßwortmanagers'  : u'passwortmanagers',
        u'paßwortmanager'   : u'passwortmanager',
        u'paßworts'         : u'passworts',
        u'paßwort'          : u'passwort',
        u'paßzwang'         : u'passzwang',
        u'patentverschluß'  : u'patentverschluss',
        u'patschenaß'       : u'patschenass',
        u'patschnaß'        : u'patschnass',
        u'pekannuß'         : u'pekannuss',
        u'perfecten'        : u'perfekten',
        u'perfecte'         : u'perfekte',
        u'perfects'         : u'perfekts',
        u'perfect'          : u'perfekt',
        u'personenschiffahrt': u'personenschifffahrt',
        u'petitionsausschuß': u'petitionsausschuss',
        u'pfandschloß'      : u'pfandschloss',
        u'pfeffernuß'       : u'pfeffernuss',
        u'pfeill'        : u'pfeil',
        u'pfeilschuß'       : u'pfeilschuss',
        u'pferdegebiß'      : u'pferdegebiss',
        u'pferdekuß'        : u'pferdekuss',
        u'pflichtbewußtem'  : u'pflichtbewusstem',
        u'pflichtbewußten'  : u'pflichtbewussten',
        u'pflichtbewußterem': u'pflichtbewussterem',
        u'pflichtbewußteren': u'pflichtbewussteren',
        u'pflichtbewußterer': u'pflichtbewussterer',
        u'pflichtbewußteres': u'pflichtbewussteres',
        u'pflichtbewußtere' : u'pflichtbewusstere',
        u'pflichtbewußter'  : u'pflichtbewusster',
        u'pflichtbewußtestem': u'pflichtbewusstestem',
        u'pflichtbewußtesten': u'pflichtbewusstesten',
        u'pflichtbewußtester': u'pflichtbewusstester',
        u'pflichtbewußtestes': u'pflichtbewusstestes',
        u'pflichtbewußteste': u'pflichtbewussteste',
        u'pflichtbewußtes'  : u'pflichtbewusstes',
        u'pflichtbewußte'   : u'pflichtbewusste',
        u'pflichtbewußtseins': u'pflichtbewusstseins',
        u'pflichtbewußtsein': u'pflichtbewusstsein',
        u'pflichtbewußt'    : u'pflichtbewusst',
        u'pflichtvergeßnerem': u'pflichtvergessnerem',
        u'pflichtvergeßneren': u'pflichtvergessneren',
        u'pflichtvergeßnerer': u'pflichtvergessnerer',
        u'pflichtvergeßneres': u'pflichtvergessneres',
        u'pflichtvergeßnere': u'pflichtvergessnere',
        u'pflichtvergeßner' : u'pflichtvergessner',
        u'pfostenschuß'     : u'pfostenschuss',
        u'phantasieren'  : u'fantasieren',
        u'phantasie'     : u'fantasie',
        u'phantastereien': u'fantastereien',
        u'phantastisch'  : u'fantastisch',
        u'philipp'       : u'philip',
        u'photografen'      : u'fotografen',
        u'photografierend'  : u'fotografierend',
        u'photografieren'   : u'fotografieren',
        u'photografierest'  : u'fotografierest',
        u'photografieret'   : u'fotografieret',
        u'photografiere'    : u'fotografiere',
        u'photografierst'   : u'fotografierst',
        u'photografierten'  : u'fotografierten',
        u'photografiertest' : u'fotografiertest',
        u'photografiertet'  : u'fotografiertet',
        u'photografierte'   : u'fotografierte',
        u'photografiert'    : u'fotografiert',
        u'photografier'     : u'fotografier',
        u'photograf'        : u'fotograf',
        u'photographierend' : u'fotografierend',
        u'photographieren'  : u'fotografieren',
        u'photographierest' : u'fotografierest',
        u'photographieret'  : u'fotografieret',
        u'photographiere'   : u'fotografiere',
        u'photographierst'  : u'fotografierst',
        u'photographierten' : u'fotografierten',
        u'photographiertest': u'fotografiertest',
        u'photographiertet' : u'fotografiertet',
        u'photographierte'  : u'fotografierte',
        u'photographiert'   : u'fotografiert',
        u'photographier'    : u'fotografier',
        u'photos'           : u'fotos',
        u'photo'            : u'foto',
        u'photo'         : u'foto',
        u'pikas'            : u'pikass',
        u'pimpernuß'        : u'pimpernuss',
        u'pinnadel'         : u'pinnnadel',
        u'pißnelken'        : u'pissnelken',
        u'pißnelke'         : u'pissnelke',
        u'pißten'           : u'pissten',
        u'pißtest'          : u'pisstest',
        u'pißtet'           : u'pisstet',
        u'pißte'            : u'pisste',
        u'pißt'             : u'pisst',
        u'piß'              : u'piss',
        u'pistaziennuß'     : u'pistaziennuss',
        u'pistolenschuß'    : u'pistolenschuss',
        u'pitschenaß'       : u'pitschenass',
        u'pitschepatschenaß': u'pitschepatschenass',
        u'pitschnaß'        : u'pitschnass',
        u'placierend'       : u'platzierend',
        u'placieren'        : u'platzieren',
        u'placierest'       : u'platzierest',
        u'placieret'        : u'platzieret',
        u'placierst'        : u'platzierst',
        u'placierten'       : u'platzierten',
        u'placiertest'      : u'platziertest',
        u'placiertet'       : u'platziertet',
        u'placierte'        : u'platzierte',
        u'placiert'         : u'platziert',
        u'placier'          : u'platzier',
        u'plagiatsprozeß'   : u'plagiatsprozess',
        u'platitüden'       : u'plattitüden',
        u'platitüde'        : u'plattitüde',
        u'platschnaß'       : u'platschnass',
        u'plattenboß'       : u'plattenboss',
        u'plazierend'       : u'platzierend',
        u'plazieren'        : u'platzieren',
        u'plazierest'       : u'platzierest',
        u'plazieret'        : u'platzieret',
        u'plaziere'         : u'platziere',
        u'plazierst'        : u'platzierst',
        u'plazierten'       : u'platzierten',
        u'plaziertest'      : u'platziertest',
        u'plaziertet'       : u'platziertet',
        u'plazierte'        : u'platzierte',
        u'plaziert'         : u'platziert',
        u'plazier'          : u'platzier',
        u'plusquamperfecten': u'plusquamperfekten',
        u'plusquamperfecte' : u'plusquamperfekte',
        u'plusquamperfects' : u'plusquamperfekts',
        u'plusquamperfect'  : u'plusquamperfekt',
        u'pökelfaß'         : u'pökelfass',
        u'ponies'           : u'ponys',
        u'portraitierend'   : u'porträtierend',
        u'portraitieren'    : u'porträtieren',
        u'portraitierest'   : u'porträtierest',
        u'portraitieret'    : u'porträtieret',
        u'portraitiere'     : u'porträtiere',
        u'portraitierst'    : u'porträtierst',
        u'portraitierten'   : u'porträtierten',
        u'portraitiertest'  : u'porträtiertest',
        u'portraitiertet'   : u'porträtiertet',
        u'portraitierte'    : u'porträtierte',
        u'portraitiert'     : u'porträtiert',
        u'portraitier'      : u'porträtier',
        u'portraits'        : u'porträts',
        u'portrait'         : u'porträt',
        u'positivprozeß'    : u'positivprozess',
        u'potthäßlichem'    : u'potthässlichem',
        u'potthäßlichen'    : u'potthässlichen',
        u'potthäßlicher'    : u'potthässlicher',
        u'potthäßliches'    : u'potthässliches',
        u'potthäßliche'     : u'potthässliche',
        u'potthäßlich'      : u'potthässlich',
        u'poussierstengeln' : u'poussierstängeln',
        u'poussierstengels' : u'poussierstängels',
        u'poussierstengel'  : u'poussierstängel',
        u'practicierend'    : u'praktizierend',
        u'practicieren'     : u'praktizieren',
        u'practicierest'    : u'praktizierest',
        u'practicieret'     : u'praktizieret',
        u'practiciere'      : u'praktiziere',
        u'practicierst'     : u'praktizierst',
        u'practicierten'    : u'praktizierten',
        u'practiciertest'   : u'praktiziertest',
        u'practiciertet'    : u'praktiziertet',
        u'practicierte'     : u'praktizierte',
        u'practiciert'      : u'praktiziert',
        u'practicier'       : u'praktizier',
        u'practicirend'     : u'praktizierend',
        u'practiciren'      : u'praktizieren',
        u'practicirest'     : u'praktizierest',
        u'practiciret'      : u'praktizieret',
        u'practicire'       : u'praktiziere',
        u'practicirst'      : u'praktizierst',
        u'practicirten'     : u'praktizierten',
        u'practicirtest'    : u'praktiziertest',
        u'practicirtet'     : u'praktiziertet',
        u'practicirte'      : u'praktizierte',
        u'practicirt'       : u'praktiziert',
        u'practicir'        : u'praktizier',
        u'praktizirend'     : u'praktizierend',
        u'praktiziren'      : u'praktizieren',
        u'praktizirest'     : u'praktizierest',
        u'praktiziret'      : u'praktizieret',
        u'praktizire'       : u'praktiziere',
        u'praktizirst'      : u'praktizierst',
        u'praktizirten'     : u'praktizierten',
        u'praktizirtest'    : u'praktiziertest',
        u'praktizirtet'     : u'praktiziertet',
        u'praktizirte'      : u'praktizierte',
        u'praktizirt'       : u'praktiziert',
        u'praktizir'        : u'praktizier',
        u'präzisionsmeßgerät': u'präzisionsmessgerät',
        u'preisbewußtem'    : u'preisbewusstem',
        u'preisbewußten'    : u'preisbewussten',
        u'preisbewußterem'  : u'preisbewussterem',
        u'preisbewußteren'  : u'preisbewussteren',
        u'preisbewußterer'  : u'preisbewussterer',
        u'preisbewußteres'  : u'preisbewussteres',
        u'preisbewußtere'   : u'preisbewusstere',
        u'preisbewußter'    : u'preisbewusster',
        u'preisbewußtestem' : u'preisbewusstestem',
        u'preisbewußtesten' : u'preisbewusstesten',
        u'preisbewußtester' : u'preisbewusstester',
        u'preisbewußtestes' : u'preisbewusstestes',
        u'preisbewußteste'  : u'preisbewussteste',
        u'preisbewußtes'    : u'preisbewusstes',
        u'preisbewußte'     : u'preisbewusste',
        u'preisbewußt'      : u'preisbewusst',
        u'preisnachlaß'     : u'preisnachlass',
        u'prellschuß'       : u'prellschuss',
        u'preßball'         : u'pressball',
        u'preßbleiglases'   : u'pressbleiglases',
        u'preßbleiglas'     : u'pressbleiglas',
        u'preßburgs'        : u'pressburgs',
        u'preßburg'         : u'pressburg',
        u'preßform'         : u'pressform',
        u'preßfrisch'       : u'pressfrisch',
        u'preßglas'         : u'pressglas',
        u'preßhefe'         : u'presshefe',
        u'preßholz'         : u'pressholz',
        u'preßkohle'        : u'presskohle',
        u'preßköpfen'       : u'pressköpfen',
        u'preßkopfes'       : u'presskopfes',
        u'preßkopfe'        : u'presskopfe',
        u'preßköpfe'        : u'pressköpfe',
        u'preßkopfs'        : u'presskopfs',
        u'preßkopf'         : u'presskopf',
        u'preßling'         : u'pressling',
        u'preßluftbohrern'  : u'pressluftbohrern',
        u'preßluftbohrers'  : u'pressluftbohrers',
        u'preßluftbohrer'   : u'pressluftbohrer',
        u'preßluftflasche'  : u'pressluftflasche',
        u'preßlufthämmern'  : u'presslufthämmern',
        u'preßlufthammers'  : u'presslufthammers',
        u'preßlufthammer'   : u'presslufthammer',
        u'preßlufthämmer'   : u'presslufthämmer',
        u'preßluft'         : u'pressluft',
        u'preßsäcken'       : u'presssäcken',
        u'preßsackes'       : u'presssackes',
        u'preßsacke'        : u'presssacke',
        u'preßsäcke'        : u'presssäcke',
        u'preßsacks'        : u'presssacks',
        u'preßsack'         : u'presssack',
        u'preßschlag'       : u'pressschlag',
        u'preßspanplatte'   : u'pressspanplatte',
        u'preßspan'         : u'pressspan',
        u'preßstempelkannen': u'pressstempelkannen',
        u'preßstempelkanne' : u'pressstempelkanne',
        u'preßstoff'        : u'pressstoff',
        u'preßstroh'        : u'pressstroh',
        u'preßten'          : u'pressten',
        u'preßtest'         : u'presstest',
        u'preßtet'          : u'presstet',
        u'preßte'           : u'presste',
        u'preßte'        : u'presste',
        u'preßt'            : u'presst',
        u'preß'             : u'press',
        u'preßwehe'         : u'presswehe',
        u'preßwerken'       : u'presswerken',
        u'preßwerkern'      : u'presswerkern',
        u'preßwerkers'      : u'presswerkers',
        u'preßwerker'       : u'presswerker',
        u'preßwerkes'       : u'presswerkes',
        u'preßwerke'        : u'presswerke',
        u'preßwerks'        : u'presswerks',
        u'preßwerk'         : u'presswerk',
        u'preßwurst'        : u'presswurst',
        u'principen'        : u'prinzipen',
        u'principe'         : u'prinzipe',
        u'principien'       : u'prinzipien',
        u'princips'         : u'prinzips',
        u'princip'          : u'prinzip',
        u'prinzeßbohnen'    : u'prinzessbohnen',
        u'prinzeßbohne'     : u'prinzessbohne',
        u'prinzeß'          : u'prinzess',
        u'problemlösungsprozeß': u'problemlösungsprozess',
        u'proceß'           : u'prozess',
        u'producte'         : u'produkte',
        u'produktionsprozeß': u'produktionsprozess',
        u'profeß'           : u'profess',
        u'programmässigem'  : u'programmmäßigem',
        u'programmässigen'  : u'programmmäßigen',
        u'programmässiger'  : u'programmmäßiger',
        u'programmässiges'  : u'programmmäßiges',
        u'programmässige'   : u'programmmäßige',
        u'programmässig'    : u'programmmäßig',
        u'programmusik'     : u'programmmusik',
        u'progreß'          : u'progress',
        u'projektabschluß'  : u'projektabschluss',
        u'promotionsausschuß': u'promotionsausschuss',
        u'prozeßabwicklung' : u'prozessabwicklung',
        u'prozeßausgängen'  : u'prozessausgängen',
        u'prozeßausganges'  : u'prozessausganges',
        u'prozeßausgange'   : u'prozessausgange',
        u'prozeßausgänge'   : u'prozessausgänge',
        u'prozeßausgangs'   : u'prozessausgangs',
        u'prozeßausgang'    : u'prozessausgang',
        u'prozeßbevollmächtigter': u'prozessbevollmächtigter',
        u'prozeßbevollmächtigt': u'prozessbevollmächtigt',
        u'prozeßfähigkeit'  : u'prozessfähigkeit',
        u'prozeßfähig'      : u'prozessfähig',
        u'prozeßgegner'     : u'prozessgegner',
        u'prozeßkostenhilfe': u'prozesskostenhilfe',
        u'prozeßkosten'     : u'prozesskosten',
        u'prozeßleitelektronikern': u'prozessleitelektronikern',
        u'prozeßleitelektronikers': u'prozessleitelektronikers',
        u'prozeßleitelektroniker': u'prozessleitelektroniker',
        u'prozeßlüftungen'  : u'prozesslüftungen',
        u'prozeßlüftung'    : u'prozesslüftung',
        u'prozeßordnung'    : u'prozessordnung',
        u'prozeßrecht'      : u'prozessrecht',
        u'prozeßunfähigkeit': u'prozessunfähigkeit',
        u'prozeßunfähig'    : u'prozessunfähig',
        u'prozeß'           : u'prozess',
        u'prozeß'        : u'prozess',
        u'prozeßverläufen'  : u'prozessverläufen',
        u'prozeßverlaufes'  : u'prozessverlaufes',
        u'prozeßverlaufe'   : u'prozessverlaufe',
        u'prozeßverläufe'   : u'prozessverläufe',
        u'prozeßverlaufs'   : u'prozessverlaufs',
        u'prozeßverlauf'    : u'prozessverlauf',
        u'prüfungsausschuß' : u'prüfungsausschuss',
        u'pudelnaß'         : u'pudelnass',
        u'pulverfaß'        : u'pulverfass',
        u'pußlest'          : u'pusslest',
        u'pußlet'           : u'pusslet',
        u'pußle'            : u'pussle',
        u'pußlig'           : u'pusslig',
        u'qualitätsbewußtem': u'qualitätsbewusstem',
        u'qualitätsbewußten': u'qualitätsbewussten',
        u'qualitätsbewußter': u'qualitätsbewusster',
        u'qualitätsbewußtes': u'qualitätsbewusstes',
        u'qualitätsbewußte' : u'qualitätsbewusste',
        u'qualitätsbewußtsein': u'qualitätsbewusstsein',
        u'qualitätsbewußt'  : u'qualitätsbewusst',
        u'quartalabschluß'  : u'quartalabschluss',
        u'quartalsabschluß' : u'quartalsabschluss',
        u'quaßlest'         : u'quasslest',
        u'quaßlet'          : u'quasslet',
        u'quaßle'           : u'quassle',
        u'quatschnaß'       : u'quatschnass',
        u'quellfluß'        : u'quellfluss',
        u'quellüftungen'    : u'quelllüftungen',
        u'quellüftung'      : u'quelllüftung',
        u'quelluft'         : u'quellluft',
        u'quentchens'       : u'quäntchens',
        u'quentchen'        : u'quäntchen',
        u'querpaß'          : u'querpass',
        u'querschuß'        : u'querschuss',
        u'quicke'           : u'quick',
        u'quicksteps'       : u'quickstepps',
        u'quickstep'        : u'quickstepp',
        u'racen'            : u'rassen',
        u'race'             : u'rasse',
        u'radicalem'        : u'radikalem',
        u'radicalen'        : u'radikalen',
        u'radicalerem'      : u'radikalerem',
        u'radicaleren'      : u'radikaleren',
        u'radicalerer'      : u'radikalerer',
        u'radicaleres'      : u'radikaleres',
        u'radicalere'       : u'radikalere',
        u'radicaler'        : u'radikaler',
        u'radicales'        : u'radikales',
        u'radicale'         : u'radikale',
        u'radicalstem'      : u'radikalstem',
        u'radicalsten'      : u'radikalsten',
        u'radicalster'      : u'radikalster',
        u'radicalstes'      : u'radikalstes',
        u'radicalste'       : u'radikalste',
        u'radical'          : u'radikal',
        u'radikalenerlaß'   : u'radikalenerlass',
        u'raketenabschußrampen': u'raketenabschussrampen',
        u'raketenabschußrampe': u'raketenabschussrampe',
        u'rammaschine'      : u'rammmaschine',
        u'ranlaßt'          : u'ranlasst',
        u'ranläßt'          : u'ranlässt',
        u'rassenhaß'        : u'rassenhass',
        u'räterußland'      : u'räterussland',
        u'räthen'           : u'räten',
        u'rathes'           : u'rates',
        u'rathe'            : u'rate',
        u'räthe'            : u'räte',
        u'räthselhaften'    : u'rätselhaften',
        u'räthselhafte'     : u'rätselhafte',
        u'raths'            : u'rats',
        u'rath'             : u'rat',
        u'ratsbeschluß'     : u'ratsbeschluss',
        u'ratschluß'        : u'ratschluss',
        u'rauchfaß'         : u'rauchfass',
        u'rauchschutzabschluß': u'rauchschutzabschluss',
        u'rauhbänken'       : u'raubänken',
        u'rauhbänke'        : u'raubänke',
        u'rauhbank'         : u'raubank',
        u'rauhbauzigem'     : u'raubauzigem',
        u'rauhbauzigen'     : u'raubauzigen',
        u'rauhbauzigerem'   : u'raubauzigerem',
        u'rauhbauzigeren'   : u'raubauzigeren',
        u'rauhbauzigerer'   : u'raubauzigerer',
        u'rauhbauzigeres'   : u'raubauzigeres',
        u'rauhbauzigere'    : u'raubauzigere',
        u'rauhbauziger'     : u'raubauziger',
        u'rauhbauziges'     : u'raubauziges',
        u'rauhbauzige'      : u'raubauzige',
        u'rauhbauzigstem'   : u'raubauzigstem',
        u'rauhbauzigsten'   : u'raubauzigsten',
        u'rauhbauzigster'   : u'raubauzigster',
        u'rauhbauzigstes'   : u'raubauzigstes',
        u'rauhbauzigste'    : u'raubauzigste',
        u'rauhbauzig'       : u'raubauzig',
        u'rauhbauz'         : u'raubauz',
        u'rauhbeinen'       : u'raubeinen',
        u'rauhbeines'       : u'raubeines',
        u'rauhbeine'        : u'raubeine',
        u'rauhbeinigem'     : u'raubeinigem',
        u'rauhbeinigen'     : u'raubeinigen',
        u'rauhbeinigerem'   : u'raubeinigerem',
        u'rauhbeinigeren'   : u'raubeinigeren',
        u'rauhbeinigerer'   : u'raubeinigerer',
        u'rauhbeinigeres'   : u'raubeinigeres',
        u'rauhbeinigere'    : u'raubeinigere',
        u'rauhbeiniger'     : u'raubeiniger',
        u'rauhbeiniges'     : u'raubeiniges',
        u'rauhbeinige'      : u'raubeinige',
        u'rauhbeinigstem'   : u'raubeinigstem',
        u'rauhbeinigsten'   : u'raubeinigsten',
        u'rauhbeinigster'   : u'raubeinigster',
        u'rauhbeinigstes'   : u'raubeinigstes',
        u'rauhbeinigste'    : u'raubeinigste',
        u'rauhbeinig'       : u'raubeinig',
        u'rauhbeins'        : u'raubeins',
        u'rauhbein'         : u'raubein',
        u'rauhbewürfen'     : u'raubewürfen',
        u'rauhbewurfes'     : u'raubewurfes',
        u'rauhbewurfe'      : u'raubewurfe',
        u'rauhbewürfe'      : u'raubewürfe',
        u'rauhbewurfs'      : u'raubewurfs',
        u'rauhbewurf'       : u'raubewurf',
        u'rauhborstig'      : u'rauborstig',
        u'rauhem'           : u'rauem',
        u'rauhend'          : u'rauend',
        u'rauhen'           : u'rauen',
        u'rauher'           : u'rauer',
        u'rauhest'          : u'rauest',
        u'rauhes'           : u'raues',
        u'rauhet'           : u'rauet',
        u'rauhe'            : u'raue',
        u'rauhfasertapeten' : u'raufasertapeten',
        u'rauhfasertapete'  : u'raufasertapete',
        u'rauhfrösten'      : u'raufrösten',
        u'rauhfrostes'      : u'raufrostes',
        u'rauhfroste'       : u'raufroste',
        u'rauhfröste'       : u'raufröste',
        u'rauhfrosts'       : u'raufrosts',
        u'rauhfrost'        : u'raufrost',
        u'rauhfusskäuzen'   : u'raufußkäuzen',
        u'rauhfußkäuzen'    : u'raufußkäuzen',
        u'rauhfusskauzes'   : u'raufußkauzes',
        u'rauhfußkauzes'    : u'raufußkauzes',
        u'rauhfusskauze'    : u'raufußkauze',
        u'rauhfußkauze'     : u'raufußkauze',
        u'rauhfusskäuze'    : u'raufußkäuze',
        u'rauhfußkäuze'     : u'raufußkäuze',
        u'rauhfusskauz'     : u'raufußkauz',
        u'rauhfußkauz'      : u'raufußkauz',
        u'rauhhaardackeln'  : u'rauhaardackeln',
        u'rauhhaardackels'  : u'rauhaardackels',
        u'rauhhaardackel'   : u'rauhaardackel',
        u'rauhheit'         : u'rauheit',
        u'rauhledern'       : u'rauledern',
        u'rauhleders'       : u'rauleders',
        u'rauhleder'        : u'rauleder',
        u'rauhputzen'       : u'rauputzen',
        u'rauhputzes'       : u'rauputzes',
        u'rauhputze'        : u'rauputze',
        u'rauhputz'         : u'rauputz',
        u'rauhreifes'       : u'raureifes',
        u'rauhreife'        : u'raureife',
        u'rauhreifs'        : u'raureifs',
        u'rauhreif'         : u'raureif',
        u'rauhst'           : u'raust',
        u'rauhten'          : u'rauten',
        u'rauhtest'         : u'rautest',
        u'rauhtet'          : u'rautet',
        u'rauhte'           : u'raute',
        u'rauht'            : u'raut',
        u'rauh'             : u'rau',
        u'rauhwaren'        : u'rauwaren',
        u'rauhware'         : u'rauware',
        u'raumschiffahrt'   : u'raumschifffahrt',
        u'rausschmiß'       : u'rausschmiss',
        u'reactionen'       : u'reaktionen',
        u'reaction'         : u'reaktion',
        u'realschulabschluß': u'realschulabschluss',
        u'rebschoß'         : u'rebschoss',
        u'recepten'         : u'rezepten',
        u'receptes'         : u'rezeptes',
        u'recepte'          : u'rezepte',
        u'recepts'          : u'rezepts',
        u'recept'           : u'rezept',
        u'rechtsausschuß'   : u'rechtsausschuss',
        u'rechtsbewußtseins': u'rechtsbewusstseins',
        u'rechtsbewußtsein' : u'rechtsbewusstsein',
        u'rechtshandelung'  : u'rechtshandlung',
        u'rechtsschuß'      : u'rechtsschuss',
        u'redaktionsschluß' : u'redaktionsschluss',
        u'redefluß'         : u'redefluss',
        u'reductionen'      : u'reduktionen',
        u'reduction'        : u'reduktion',
        u'reflectirtes'     : u'reflektiertes',
        u'regenereigniß'    : u'regenereignis',
        u'regenfaß'         : u'regenfass',
        u'regenguß'         : u'regenguss',
        u'regennaß'         : u'regennass',
        u'regierungsbeschluß': u'regierungsbeschluss',
        u'regionalexpreß'   : u'regionalexpress',
        u'regreßanspruch'   : u'regressanspruch',
        u'regreßpflichtig'  : u'regresspflichtig',
        u'regreßpflicht'    : u'regresspflicht',
        u'regreß'           : u'regress',
        u'reifeprozeß'      : u'reifeprozess',
        u'reifungsprozeß'   : u'reifungsprozess',
        u'reisekostenzuschuß': u'reisekostenzuschuss',
        u'reisepaß'         : u'reisepass',
        u'reißverschlußsystemen': u'reißverschlusssystemen',
        u'reißverschlußsysteme': u'reißverschlusssysteme',
        u'reißverschlußsystems': u'reißverschlusssystems',
        u'reißverschlußsystem': u'reißverschlusssystem',
        u'reißverschluß'    : u'reißverschluss',
        u'renaissanceschloß': u'renaissanceschloss',
        u'renkverschluß'    : u'renkverschluss',
        u'repräsentationsschluß': u'repräsentationsschluss',
        u'reproduktionsprozeß': u'reproduktionsprozess',
        u'reschenpaß'       : u'reschenpass',
        u'respizirend'      : u'respizierend',
        u'respiziren'       : u'respizieren',
        u'respizirest'      : u'respizierest',
        u'respiziret'       : u'respizieret',
        u'respizire'        : u'respiziere',
        u'respizirst'       : u'respizierst',
        u'respizirten'      : u'respizierten',
        u'respizirtest'     : u'respiziertest',
        u'respizirtet'      : u'respiziertet',
        u'respizirte'       : u'respizierte',
        u'respizirt'        : u'respiziert',
        u'respizir'         : u'respizier',
        u'rettungsschuß'    : u'rettungsschuss',
        u'rez-de-chaussée'  : u'rez-de-chaussée',
        u'rezeptionsprozeß' : u'rezeptionsprozess',
        u'rezeß'            : u'rezess',
        u'rheinschiffahrten': u'rheinschifffahrten',
        u'rheinschiffahrt'  : u'rheinschifffahrt',
        u'richterwahlausschuß': u'richterwahlausschuss',
        u'riesenkänguruh'   : u'riesenkänguru',
        u'riesenroß'        : u'riesenross',
        u'rißfestem'        : u'rissfestem',
        u'rißfesten'        : u'rissfesten',
        u'rißfesterem'      : u'rissfesterem',
        u'rißfesteren'      : u'rissfesteren',
        u'rißfesterer'      : u'rissfesterer',
        u'rißfesteres'      : u'rissfesteres',
        u'rißfestere'       : u'rissfestere',
        u'rißfester'        : u'rissfester',
        u'rißfestestem'     : u'rissfestestem',
        u'rißfestesten'     : u'rissfestesten',
        u'rißfestester'     : u'rissfestester',
        u'rißfestestes'     : u'rissfestestes',
        u'rißfesteste'      : u'rissfesteste',
        u'rißfestes'        : u'rissfestes',
        u'rißfeste'         : u'rissfeste',
        u'rißfest'          : u'rissfest',
        u'rißt'             : u'risst',
        u'riß'              : u'riss',
        u'riß'           : u'riss',
        u'rißwunden'        : u'risswunden',
        u'rißwunde'         : u'risswunde',
        u'roheiten'         : u'rohheiten',
        u'roheit'           : u'rohheit',
        u'rohstofförderungen': u'rohstoffförderungen',
        u'rohstofförderung' : u'rohstoffförderung',
        u'rolladens'        : u'rollladens',
        u'rolladen'         : u'rollladen',
        u'rolläden'         : u'rollläden',
        u'römisch-catholischem': u'römisch-katholischem',
        u'römisch-catholischen': u'römisch-katholischen',
        u'römisch-catholischer': u'römisch-katholischer',
        u'römisch-catholisches': u'römisch-katholisches',
        u'römisch-catholische': u'römisch-katholische',
        u'römisch-catholisch': u'römisch-katholisch',
        u'röntgenpaß'       : u'röntgenpass',
        u'roßäpfeln'        : u'rossäpfeln',
        u'roßapfels'        : u'rossapfels',
        u'roßapfel'         : u'rossapfel',
        u'roßäpfel'         : u'rossäpfel',
        u'roßarzt'          : u'rossarzt',
        u'roßbreiten'       : u'rossbreiten',
        u'rößchen'          : u'rösschen',
        u'roßhaaren'        : u'rosshaaren',
        u'roßhaares'        : u'rosshaares',
        u'roßhaare'         : u'rosshaare',
        u'roßhaarmatratzen' : u'rosshaarmatratzen',
        u'roßhaarmatratze'  : u'rosshaarmatratze',
        u'roßhaars'         : u'rosshaars',
        u'roßhaar'          : u'rosshaar',
        u'roßkamm'          : u'rosskamm',
        u'roßkastanien'     : u'rosskastanien',
        u'roßkastanie'      : u'rosskastanie',
        u'roßkuren'         : u'rosskuren',
        u'roßkur'           : u'rosskur',
        u'roßschlachter'    : u'rossschlachter',
        u'roßschlächter'    : u'rossschlächter',
        u'roßtäuschereien'  : u'rosstäuschereien',
        u'roßtäuscherei'    : u'rosstäuscherei',
        u'roßtäuschern'     : u'rosstäuschern',
        u'roßtäuschers'     : u'rosstäuschers',
        u'roßtäuschertrick' : u'rosstäuschertrick',
        u'roßtäuscher'      : u'rosstäuscher',
        u'roßtrappe'        : u'rosstrappe',
        u'roß'              : u'ross',
        u'roßvölkern'       : u'rossvölkern',
        u'roßvölker'        : u'rossvölker',
        u'roßvolkes'        : u'rossvolkes',
        u'roßvolke'         : u'rossvolke',
        u'roßvolks'         : u'rossvolks',
        u'roßvolk'          : u'rossvolk',
        u'roteturmpaß'      : u'roteturmpass',
        u'rotguß'           : u'rotguss',
        u'rothem'           : u'rotem',
        u'rothen'           : u'roten',
        u'rotherem'         : u'roterem',
        u'rötherem'         : u'röterem',
        u'rotheren'         : u'roteren',
        u'rötheren'         : u'röteren',
        u'rotherer'         : u'roterer',
        u'rötherer'         : u'röterer',
        u'rotheres'         : u'roteres',
        u'rötheres'         : u'röteres',
        u'rothere'          : u'rotere',
        u'röthere'          : u'rötere',
        u'rother'           : u'roter',
        u'röther'           : u'röter',
        u'rothestem'        : u'rotestem',
        u'röthestem'        : u'rötestem',
        u'rothesten'        : u'rotesten',
        u'röthesten'        : u'rötesten',
        u'rothester'        : u'rotester',
        u'röthester'        : u'rötester',
        u'rothestes'        : u'rotestes',
        u'röthestes'        : u'rötestes',
        u'rotheste'         : u'roteste',
        u'rötheste'         : u'röteste',
        u'rothes'           : u'rotes',
        u'rothe'            : u'rote',
        u'roth'             : u'rot',
        u'rotirenden'       : u'rotierenden',
        u'rotsiegelbeschluß': u'rotsiegelbeschluss',
        u'roulettischen'    : u'roulettetischen',
        u'roulettisches'    : u'roulettetisches',
        u'roulettische'     : u'roulettetische',
        u'roulettischs'     : u'roulettetischs',
        u'roulettisch'      : u'roulettetisch',
        u'roulettkugeln'    : u'roulettekugeln',
        u'roulettkugel'     : u'roulettekugel',
        u'rouletts'         : u'roulettes',
        u'roulett-tischen'  : u'roulettetischen',
        u'rouletttischen'   : u'roulettetischen',
        u'roulett-tisches'  : u'roulettetisches',
        u'rouletttisches'   : u'roulettetisches',
        u'roulett-tische'   : u'roulettetische',
        u'rouletttische'    : u'roulettetische',
        u'roulett-tischs'   : u'roulettetischs',
        u'rouletttischs'    : u'roulettetischs',
        u'roulett-tisch'    : u'roulettetisch',
        u'rouletttisch'     : u'roulettetisch',
        u'roulett'          : u'roulette',
        u'rowdies'          : u'rowdys',
        u'rückfluß'         : u'rückfluss',
        u'rückpaßregel'     : u'rückpassregel',
        u'rückpaß'          : u'rückpass',
        u'rückschluß'       : u'rückschluss',
        u'rumfaß'           : u'rumfass',
        u'runderlaß'        : u'runderlass',
        u'runterlaßt'       : u'runterlasst',
        u'runterläßt'       : u'runterlässt',
        u'russifizierungsprozeß': u'russifizierungsprozess',
        u'rußlanddeutschem' : u'russlanddeutschem',
        u'rußlanddeutschen' : u'russlanddeutschen',
        u'rußlanddeutscher' : u'russlanddeutscher',
        u'rußlanddeutsches' : u'russlanddeutsches',
        u'rußlanddeutsche'  : u'russlanddeutsche',
        u'rußlanddeutsch'   : u'russlanddeutsch',
        u'rußländern'       : u'russländern',
        u'rußländers'       : u'russländers',
        u'rußländer'        : u'russländer',
        u'rußlandgeschäft'  : u'russlandgeschäft',
        u'rußländischem'    : u'russländischem',
        u'rußländischen'    : u'russländischen',
        u'rußländischerem'  : u'russländischerem',
        u'rußländischeren'  : u'russländischeren',
        u'rußländischerer'  : u'russländischerer',
        u'rußländischeres'  : u'russländischeres',
        u'rußländischere'   : u'russländischere',
        u'rußländischer'    : u'russländischer',
        u'rußländisches'    : u'russländisches',
        u'rußländische'     : u'russländische',
        u'rußländischstem'  : u'russländischstem',
        u'rußländischsten'  : u'russländischsten',
        u'rußländischster'  : u'russländischster',
        u'rußländischstes'  : u'russländischstes',
        u'rußländischste'   : u'russländischste',
        u'rußländisch'      : u'russländisch',
        u'rußlandreisen'    : u'russlandreisen',
        u'rußlandreise'     : u'russlandreise',
        u'rußlands'         : u'russlands',
        u'rußlands'      : u'russlands',
        u'rußland'          : u'russland',
        u'rußland'       : u'russland',
        u'rußland-verstehern': u'russland-verstehern',
        u'rußlandverstehern': u'russlandverstehern',
        u'rußland-verstehers': u'russland-verstehers',
        u'rußlandverstehers': u'russlandverstehers',
        u'rußland-versteher': u'russland-versteher',
        u'rußlandversteher' : u'russlandversteher',
        u'ruthengänger'     : u'rutengänger',
        u'ruthen'           : u'ruten',
        u'ruthe'            : u'rute',
        u'säbelraßler'      : u'säbelrassler',
        u'sahneyoghurts'    : u'sahnejoghurts',
        u'sahneyoghurt'     : u'sahnejoghurt',
        u'saisonschluß'     : u'saisonschluss',
        u'salutschuß'       : u'salutschuss',
        u'salzfäßchens'     : u'salzfässchens',
        u'salzfäßchen'      : u'salzfässchen',
        u'salzfaß'          : u'salzfass',
        u'samenerguß'       : u'samenerguss',
        u'sammelanschluß'   : u'sammelanschluss',
        u'sammelnußfrüchten': u'sammelnussfrüchten',
        u'sammelnußfrüchte' : u'sammelnussfrüchte',
        u'sammelnußfrucht'  : u'sammelnussfrucht',
        u'sängerbaß'     : u'sängerbass',
        u'sarraß'           : u'sarrass',
        u'saßnitz'          : u'sassnitz',
        u'satellitenphotos' : u'satellitenfotos',
        u'satellitenphoto'  : u'satellitenfoto',
        u'satellitentelephonen': u'satellitentelefonen',
        u'satellitentelephone': u'satellitentelefone',
        u'satellitentelephons': u'satellitentelefons',
        u'satellitentelephon': u'satellitentelefon',
        u'satzschlußzeichens': u'satzschlusszeichens',
        u'satzschlußzeichen': u'satzschlusszeichen',
        u'säuberungsprozeß' : u'säuberungsprozess',
        u'säugethieren'     : u'säugetieren',
        u'säugethieres'     : u'säugetieres',
        u'säugethiere'      : u'säugetiere',
        u'säugethiers'      : u'säugetiers',
        u'säugethier'       : u'säugetier',
        u'säulenabschluß'   : u'säulenabschluss',
        u'saunaaufguß'      : u'saunaaufguss',
        u'säureüberschuß'   : u'säureüberschuss',
        u'schaffensprozeß'  : u'schaffensprozess',
        u'schalenguß'       : u'schalenguss',
        u'schallehre'       : u'schalllehre',
        u'schalleiter'      : u'schallleiter',
        u'schalloch'        : u'schallloch',
        u'schalterschluß'   : u'schalterschluss',
        u'scharmantem'      : u'charmantem',
        u'scharmanten'      : u'charmanten',
        u'scharmanterem'    : u'charmanterem',
        u'scharmanteren'    : u'charmanteren',
        u'scharmanterer'    : u'charmanterer',
        u'scharmanteres'    : u'charmanteres',
        u'scharmantere'     : u'charmantere',
        u'scharmanter'      : u'charmanter',
        u'scharmantestem'   : u'charmantestem',
        u'scharmantesten'   : u'charmantesten',
        u'scharmantester'   : u'charmantester',
        u'scharmantestes'   : u'charmantestes',
        u'scharmanteste'    : u'charmanteste',
        u'scharmantes'      : u'charmantes',
        u'scharmante'       : u'charmante',
        u'scharmant'        : u'charmant',
        u'scharms'          : u'charmes',
        u'scharm'           : u'charme',
        u'schaßten'         : u'schassten',
        u'schaßtest'        : u'schasstest',
        u'schaßtet'         : u'schasstet',
        u'schaßte'          : u'schasste',
        u'schaßt'           : u'schasst',
        u'schaß'            : u'schass',
        u'schattenriß'      : u'schattenriss',
        u'schaumkuß'        : u'schaumkuss',
        u'schauprozeß'      : u'schauprozess',
        u'scheidungsprozeß' : u'scheidungsprozess',
        u'schellenaß'    : u'schellenass',
        u'schiffahrten'     : u'schifffahrten',
        u'schiffahrtsabgaben': u'schifffahrtsabgaben',
        u'schiffahrtsabgabe': u'schifffahrtsabgabe',
        u'schiffahrtsbehörden': u'schifffahrtsbehörden',
        u'schiffahrtsbehörde': u'schifffahrtsbehörde',
        u'schiffahrtsgerichten': u'schifffahrtsgerichten',
        u'schiffahrtsgerichtes': u'schifffahrtsgerichtes',
        u'schiffahrtsgerichte': u'schifffahrtsgerichte',
        u'schiffahrtsgerichts': u'schifffahrtsgerichts',
        u'schiffahrtsgericht': u'schifffahrtsgericht',
        u'schiffahrtsgesellschaften': u'schifffahrtsgesellschaften',
        u'schiffahrtsgesellschaft': u'schifffahrtsgesellschaft',
        u'schiffahrtskunde' : u'schifffahrtskunde',
        u'schiffahrtslinien': u'schifffahrtslinien',
        u'schiffahrtslinie' : u'schifffahrtslinie',
        u'schiffahrtspolizeien': u'schifffahrtspolizeien',
        u'schiffahrtspolizei': u'schifffahrtspolizei',
        u'schiffahrtsrechten': u'schifffahrtsrechten',
        u'schiffahrtsrechtes': u'schifffahrtsrechtes',
        u'schiffahrtsrechte': u'schifffahrtsrechte',
        u'schiffahrtsrechts': u'schifffahrtsrechts',
        u'schiffahrtsrecht' : u'schifffahrtsrecht',
        u'schiffahrtsrouten': u'schifffahrtsrouten',
        u'schiffahrtsroute' : u'schifffahrtsroute',
        u'schiffahrtsstrassen': u'schifffahrtsstraßen',
        u'schiffahrtsstraßen': u'schifffahrtsstraßen',
        u'schiffahrtsstrasse': u'schifffahrtsstraße',
        u'schiffahrtsstraße': u'schifffahrtsstraße',
        u'schiffahrtswegen' : u'schifffahrtswegen',
        u'schiffahrtsweges' : u'schifffahrtsweges',
        u'schiffahrtswege'  : u'schifffahrtswege',
        u'schiffahrtsweg'   : u'schifffahrtsweg',
        u'schiffahrtszeichens': u'schifffahrtszeichens',
        u'schiffahrtszeichen': u'schifffahrtszeichen',
        u'schiffahrt'       : u'schifffahrt',
        u'schiffscanal'     : u'schiffskanal',
        u'schikoree'        : u'chicorée',
        u'schinesen'        : u'chinesen',
        u'schißlaweng'      : u'schisslaweng',
        u'schißt'           : u'schisst',
        u'schiß'            : u'schiss',
        u'schlachtroß'      : u'schlachtross',
        u'schlagfluß'       : u'schlagfluss',
        u'schlammasse'      : u'schlammmasse',
        u'schlangenbiß'     : u'schlangenbiss',
        u'schleppinseln'    : u'schlepppinseln',
        u'schleppinsels'    : u'schlepppinsels',
        u'schleppinsel'     : u'schlepppinsel',
        u'schleppschiffahrt': u'schleppschifffahrt',
        u'schlichtungsausschuß': u'schlichtungsausschuss',
        u'schliessen'       : u'schließen',
        u'schliesse'        : u'schließe',
        u'schlißt'          : u'schlisst',
        u'schliß'           : u'schliss',
        u'schlitzverschluß' : u'schlitzverschluss',
        u'schloßbaumeistern': u'schlossbaumeistern',
        u'schloßbaumeisters': u'schlossbaumeisters',
        u'schloßbaumeister' : u'schlossbaumeister',
        u'schloßbergen'     : u'schlossbergen',
        u'schloßberges'     : u'schlossberges',
        u'schloßberge'      : u'schlossberge',
        u'schloßbergs'      : u'schlossbergs',
        u'schloßberg'       : u'schlossberg',
        u'schloßbrauereien' : u'schlossbrauereien',
        u'schloßbrauerei'   : u'schlossbrauerei',
        u'schlößchens'      : u'schlösschens',
        u'schlößchen'       : u'schlösschen',
        u'schloßgartens'    : u'schlossgartens',
        u'schloßgarten'     : u'schlossgarten',
        u'schloßgärten'     : u'schlossgärten',
        u'schloßgespenstern': u'schlossgespenstern',
        u'schloßgespenster' : u'schlossgespenster',
        u'schloßgespenstes' : u'schlossgespenstes',
        u'schloßgespenste'  : u'schlossgespenste',
        u'schloßgespensts'  : u'schlossgespensts',
        u'schloßgespenst'   : u'schlossgespenst',
        u'schloßherren'     : u'schlossherren',
        u'schloßherrinnen'  : u'schlossherrinnen',
        u'schloßherrin'     : u'schlossherrin',
        u'schloßherrn'      : u'schlossherrn',
        u'schloßherr'       : u'schlossherr',
        u'schloßhof'        : u'schlosshof',
        u'schloßhunden'     : u'schlosshunden',
        u'schloßhundes'     : u'schlosshundes',
        u'schloßhunde'      : u'schlosshunde',
        u'schloßhunds'      : u'schlosshunds',
        u'schloßhund'       : u'schlosshund',
        u'schloßkapellen'   : u'schlosskapellen',
        u'schloßkapelle'    : u'schlosskapelle',
        u'schloßkirchen'    : u'schlosskirchen',
        u'schloßkirche'     : u'schlosskirche',
        u'schloßkutschern'  : u'schlosskutschern',
        u'schloßkutschers'  : u'schlosskutschers',
        u'schloßkutscher'   : u'schlosskutscher',
        u'schloßparken'     : u'schlossparken',
        u'schloßpärken'     : u'schlosspärken',
        u'schloßparke'      : u'schlossparke',
        u'schloßpärke'      : u'schlosspärke',
        u'schloßparks'      : u'schlossparks',
        u'schloßpark'       : u'schlosspark',
        u'schloßruine'      : u'schlossruine',
        u'schloßtürmen'     : u'schlosstürmen',
        u'schloßturmes'     : u'schlossturmes',
        u'schloßturme'      : u'schlossturme',
        u'schloßtürme'      : u'schlosstürme',
        u'schloßturms'      : u'schlossturms',
        u'schloßturm'       : u'schlossturm',
        u'schloßt'          : u'schlosst',
        u'schloß'           : u'schloss',
        u'schloß'        : u'schloss',
        u'schlußabrechnungen': u'schlussabrechnungen',
        u'schlußabrechnung' : u'schlussabrechnung',
        u'schlußabstimmung' : u'schlussabstimmung',
        u'schlußakkorden'   : u'schlussakkorden',
        u'schlußakkordes'   : u'schlussakkordes',
        u'schlußakkorde'    : u'schlussakkorde',
        u'schlußakkords'    : u'schlussakkords',
        u'schlußakkord'     : u'schlussakkord',
        u'schlußakten'      : u'schlussakten',
        u'schlußaktes'      : u'schlussaktes',
        u'schlußakte'       : u'schlussakte',
        u'schlußakts'       : u'schlussakts',
        u'schlußakt'        : u'schlussakt',
        u'schlußapplausen'  : u'schlussapplausen',
        u'schlußapplauses'  : u'schlussapplauses',
        u'schlußapplause'   : u'schlussapplause',
        u'schlußapplaus'    : u'schlussapplaus',
        u'schlußball'       : u'schlussball',
        u'schlußbearbeitungen': u'schlussbearbeitungen',
        u'schlußbearbeitung': u'schlussbearbeitung',
        u'schlußbemerkungen': u'schlussbemerkungen',
        u'schlußbemerkung'  : u'schlussbemerkung',
        u'schlußberichten'  : u'schlussberichten',
        u'schlußberichtes'  : u'schlussberichtes',
        u'schlußberichte'   : u'schlussberichte',
        u'schlußberichts'   : u'schlussberichts',
        u'schlußbericht'    : u'schlussbericht',
        u'schlußbesprechungen': u'schlussbesprechungen',
        u'schlußbesprechung': u'schlussbesprechung',
        u'schlußbestimmungen': u'schlussbestimmungen',
        u'schlußbilanz'     : u'schlussbilanz',
        u'schlußbildern'    : u'schlussbildern',
        u'schlußbilder'     : u'schlussbilder',
        u'schlußbildes'     : u'schlussbildes',
        u'schlußbilde'      : u'schlussbilde',
        u'schlußbilds'      : u'schlussbilds',
        u'schlußbild'       : u'schlussbild',
        u'schlußbrief'      : u'schlussbrief',
        u'schlußchören'     : u'schlusschören',
        u'schlußchores'     : u'schlusschores',
        u'schlußchore'      : u'schlusschore',
        u'schlußchöre'      : u'schlusschöre',
        u'schlußchors'      : u'schlusschors',
        u'schlußchor'       : u'schlusschor',
        u'schlußdokumenten' : u'schlussdokumenten',
        u'schlußdokumentes' : u'schlussdokumentes',
        u'schlußdokumente'  : u'schlussdokumente',
        u'schlußdokuments'  : u'schlussdokuments',
        u'schlußdokument'   : u'schlussdokument',
        u'schlußdritteln'   : u'schlussdritteln',
        u'schlußdrittels'   : u'schlussdrittels',
        u'schlußdrittel'    : u'schlussdrittel',
        u'schlußeffekten'   : u'schlusseffekten',
        u'schlußeffektes'   : u'schlusseffektes',
        u'schlußeffekte'    : u'schlusseffekte',
        u'schlußeffekts'    : u'schlusseffekts',
        u'schlußeffekt'     : u'schlusseffekt',
        u'schlußendlichem'  : u'schlussendlichem',
        u'schlußendlichen'  : u'schlussendlichen',
        u'schlußendlicher'  : u'schlussendlicher',
        u'schlußendliches'  : u'schlussendliches',
        u'schlußendliche'   : u'schlussendliche',
        u'schlußendlich'    : u'schlussendlich',
        u'schlußerklärungen': u'schlusserklärungen',
        u'schlußerklärung'  : u'schlusserklärung',
        u'schlußetappen'    : u'schlussetappen',
        u'schlußetappe'     : u'schlussetappe',
        u'schlußfeiern'     : u'schlussfeiern',
        u'schlußfeier'      : u'schlussfeier',
        u'schlußfolgere'    : u'schlussfolgere',
        u'schlußfolgernd'   : u'schlussfolgernd',
        u'schlußfolgern'    : u'schlussfolgern',
        u'schlußfolgerst'   : u'schlussfolgerst',
        u'schlußfolgerten'  : u'schlussfolgerten',
        u'schlußfolgertest' : u'schlussfolgertest',
        u'schlußfolgertet'  : u'schlussfolgertet',
        u'schlußfolgerte'   : u'schlussfolgerte',
        u'schlußfolgert'    : u'schlussfolgert',
        u'schlußfolgerung'  : u'schlussfolgerung',
        u'schlußfolger'     : u'schlussfolger',
        u'schlußfolge'      : u'schlussfolge',
        u'schlußfolgre'     : u'schlussfolgre',
        u'schlußformeln'    : u'schlussformeln',
        u'schlußformel'     : u'schlussformel',
        u'schlußkapiteln'   : u'schlusskapiteln',
        u'schlußkapitels'   : u'schlusskapitels',
        u'schlußkapitel'    : u'schlusskapitel',
        u'schlußketten'     : u'schlussketten',
        u'schlußkette'      : u'schlusskette',
        u'schlußkundgebungen': u'schlusskundgebungen',
        u'schlußkundgebung' : u'schlusskundgebung',
        u'schlußkurs'       : u'schlusskurs',
        u'schlußläuferinnen': u'schlussläuferinnen',
        u'schlußläuferin'   : u'schlussläuferin',
        u'schlußläufern'    : u'schlussläufern',
        u'schlußläufers'    : u'schlussläufers',
        u'schlußläufer'     : u'schlussläufer',
        u'schlußleuchte'    : u'schlussleuchte',
        u'schlußlichtern'   : u'schlusslichtern',
        u'schlußlichter'    : u'schlusslichter',
        u'schlußlichtes'    : u'schlusslichtes',
        u'schlußlichte'     : u'schlusslichte',
        u'schlußlichts'     : u'schlusslichts',
        u'schlußlicht'      : u'schlusslicht',
        u'schlußmann'       : u'schlussmann',
        u'schlußnote'       : u'schlussnote',
        u'schlußnotierung'  : u'schlussnotierung',
        u'schlußpfiffen'    : u'schlusspfiffen',
        u'schlußpfiffes'    : u'schlusspfiffes',
        u'schlußpfiffe'     : u'schlusspfiffe',
        u'schlußpfiffs'     : u'schlusspfiffs',
        u'schlußpfiff'      : u'schlusspfiff',
        u'schlußphasen'     : u'schlussphasen',
        u'schlußphase'      : u'schlussphase',
        u'schlußpunkten'    : u'schlusspunkten',
        u'schlußpunktes'    : u'schlusspunktes',
        u'schlußpunkte'     : u'schlusspunkte',
        u'schlußpunkts'     : u'schlusspunkts',
        u'schlußpunkt'      : u'schlusspunkt',
        u'schlußredaktion'  : u'schlussredaktion',
        u'schlußrunden'     : u'schlussrunden',
        u'schlußrunde'      : u'schlussrunde',
        u'schlußsteinen'    : u'schlusssteinen',
        u'schlußsteines'    : u'schlusssteines',
        u'schlußsteine'     : u'schlusssteine',
        u'schlußsteins'     : u'schlusssteins',
        u'schlußstein'      : u'schlussstein',
        u'schlußstrichen'   : u'schlussstrichen',
        u'schlußstriches'   : u'schlussstriches',
        u'schlußstriche'    : u'schlussstriche',
        u'schlußstrichs'    : u'schlussstrichs',
        u'schlußstrich'     : u'schlussstrich',
        u'schluß'           : u'schluss',
        u'schluß'        : u'schluss',
        u'schlußveranstaltungen': u'schlussveranstaltungen',
        u'schlußveranstaltung': u'schlussveranstaltung',
        u'schlußverhandlungen': u'schlussverhandlungen',
        u'schlußverhandlung': u'schlussverhandlung',
        u'schlußverkäufen'  : u'schlussverkäufen',
        u'schlußverkaufes'  : u'schlussverkaufes',
        u'schlußverkaufe'   : u'schlussverkaufe',
        u'schlußverkäufe'   : u'schlussverkäufe',
        u'schlußverkaufs'   : u'schlussverkaufs',
        u'schlußverkauf'    : u'schlussverkauf',
        u'schlußworten'     : u'schlussworten',
        u'schlußwortes'     : u'schlusswortes',
        u'schlußworte'      : u'schlussworte',
        u'schlußworts'      : u'schlussworts',
        u'schlußwort'       : u'schlusswort',
        u'schlußziehung'    : u'schlussziehung',
        u'schmißt'          : u'schmisst',
        u'schmiß'           : u'schmiss',
        u'schmuckblattelegrammen': u'schmuckblatttelegrammen',
        u'schmuckblattelegramme': u'schmuckblatttelegramme',
        u'schmuckblattelegramms': u'schmuckblatttelegramms',
        u'schmuckblattelegramm': u'schmuckblatttelegramm',
        u'schnappschuß'     : u'schnappschuss',
        u'schnellebigem'    : u'schnelllebigem',
        u'schnellebigen'    : u'schnelllebigen',
        u'schnellebiger'    : u'schnelllebiger',
        u'schnellebiges'    : u'schnelllebiges',
        u'schnellebige'     : u'schnelllebige',
        u'schnellebig'      : u'schnelllebig',
        u'schnellimbiß'     : u'schnellimbiss',
        u'schnellöschantrag': u'schnelllöschantrag',
        u'schneuzend'       : u'schnäuzend',
        u'schneuzen'        : u'schnäuzen',
        u'schneuzest'       : u'schnäuzest',
        u'schneuzet'        : u'schnäuzet',
        u'schneuze'         : u'schnäuze',
        u'schneuzten'       : u'schnäuzten',
        u'schneuztest'      : u'schnäuztest',
        u'schneuztet'       : u'schnäuztet',
        u'schneuzte'        : u'schnäuzte',
        u'schneuztüchern'   : u'schnäuztüchern',
        u'schneuztücher'    : u'schnäuztücher',
        u'schneuztuches'    : u'schnäuztuches',
        u'schneuztuche'     : u'schnäuztuche',
        u'schneuztuchs'     : u'schnäuztuchs',
        u'schneuztuch'      : u'schnäuztuch',
        u'schneuzt'         : u'schnäuzt',
        u'schneuz'          : u'schnäuz',
        u'schnurlostelephonen': u'schnurlostelefonen',
        u'schnurlostelephone': u'schnurlostelefone',
        u'schnurlostelephons': u'schnurlostelefons',
        u'schnurlostelephon': u'schnurlostelefon',
        u'schockphotos'     : u'schockfotos',
        u'schockphoto'      : u'schockfoto',
        u'schokokuß'        : u'schokokuss',
        u'schokoladengenuß' : u'schokoladengenuss',
        u'schooß'           : u'schoß',
        u'schosen'          : u'chosen',
        u'schose'           : u'chose',
        u'schößchen'        : u'schösschen',
        u'schoßfestem'      : u'schossfestem',
        u'schoßfesten'      : u'schossfesten',
        u'schoßfesterem'    : u'schossfesterem',
        u'schoßfesteren'    : u'schossfesteren',
        u'schoßfesterer'    : u'schossfesterer',
        u'schoßfesteres'    : u'schossfesteres',
        u'schoßfestere'     : u'schossfestere',
        u'schoßfester'      : u'schossfester',
        u'schoßfestestem'   : u'schossfestestem',
        u'schoßfestesten'   : u'schossfestesten',
        u'schoßfestester'   : u'schossfestester',
        u'schoßfestestes'   : u'schossfestestes',
        u'schoßfesteste'    : u'schossfesteste',
        u'schoßfestes'      : u'schossfestes',
        u'schoßfeste'       : u'schossfeste',
        u'schoßfest'        : u'schossfest',
        u'schößlingen'      : u'schösslingen',
        u'schößlinge'       : u'schösslinge',
        u'schößlings'       : u'schösslings',
        u'schößling'        : u'schössling',
        u'schoßt'           : u'schosst',
        u'schoß'            : u'schoss',
        u'schrankschloß'    : u'schrankschloss',
        u'schraubverschluß' : u'schraubverschluss',
        u'schreckensblaß'   : u'schreckensblass',
        u'schriee'          : u'schrie',
        u'schrittempos'     : u'schritttempos',
        u'schrittempo'      : u'schritttempo',
        u'schrotschuß'      : u'schrotschuss',
        u'schrubbesens'     : u'schrubbbesens',
        u'schrubbesen'      : u'schrubbbesen',
        u'schrumpfungsprozeß': u'schrumpfungsprozess',
        u'schuhbendeln'     : u'schuhbändeln',
        u'schuhbendels'     : u'schuhbändels',
        u'schuhbendel'      : u'schuhbändel',
        u'schulabschlußfeiern': u'schulabschlussfeiern',
        u'schulabschlußfeier': u'schulabschlussfeier',
        u'schulabschluß'    : u'schulabschluss',
        u'schuldbewußtem'   : u'schuldbewusstem',
        u'schuldbewußten'   : u'schuldbewussten',
        u'schuldbewußterem' : u'schuldbewussterem',
        u'schuldbewußteren' : u'schuldbewussteren',
        u'schuldbewußterer' : u'schuldbewussterer',
        u'schuldbewußteres' : u'schuldbewussteres',
        u'schuldbewußtere'  : u'schuldbewusstere',
        u'schuldbewußter'   : u'schuldbewusster',
        u'schuldbewußtestem': u'schuldbewusstestem',
        u'schuldbewußtesten': u'schuldbewusstesten',
        u'schuldbewußtester': u'schuldbewusstester',
        u'schuldbewußtestes': u'schuldbewusstestes',
        u'schuldbewußteste' : u'schuldbewussteste',
        u'schuldbewußtes'   : u'schuldbewusstes',
        u'schuldbewußte'    : u'schuldbewusste',
        u'schuldbewußt'     : u'schuldbewusst',
        u'schuldenerlaß'    : u'schuldenerlass',
        u'schulschluß'      : u'schulschluss',
        u'schußbereitem'    : u'schussbereitem',
        u'schußbereiten'    : u'schussbereiten',
        u'schußbereiter'    : u'schussbereiter',
        u'schußbereites'    : u'schussbereites',
        u'schußbereite'     : u'schussbereite',
        u'schußbereit'      : u'schussbereit',
        u'schüßchens'       : u'schüsschens',
        u'schüßchen'        : u'schüsschen',
        u'schußfahrten'     : u'schussfahrten',
        u'schußfahrt'       : u'schussfahrt',
        u'schußfertigem'    : u'schussfertigem',
        u'schußfertigen'    : u'schussfertigen',
        u'schußfertiger'    : u'schussfertiger',
        u'schußfertiges'    : u'schussfertiges',
        u'schußfertige'     : u'schussfertige',
        u'schußfertig'      : u'schussfertig',
        u'schußfestem'      : u'schussfestem',
        u'schußfesten'      : u'schussfesten',
        u'schußfester'      : u'schussfester',
        u'schußfestes'      : u'schussfestes',
        u'schußfeste'       : u'schussfeste',
        u'schußfest'        : u'schussfest',
        u'schußkreisen'     : u'schusskreisen',
        u'schußkreises'     : u'schusskreises',
        u'schußkreise'      : u'schusskreise',
        u'schußkreis'       : u'schusskreis',
        u'schußligem'       : u'schussligem',
        u'schußligen'       : u'schussligen',
        u'schußligerem'     : u'schussligerem',
        u'schußligeren'     : u'schussligeren',
        u'schußligerer'     : u'schussligerer',
        u'schußligeres'     : u'schussligeres',
        u'schußligere'      : u'schussligere',
        u'schußliger'       : u'schussliger',
        u'schußliges'       : u'schussliges',
        u'schußlige'        : u'schusslige',
        u'schußligstem'     : u'schussligstem',
        u'schußligsten'     : u'schussligsten',
        u'schußligster'     : u'schussligster',
        u'schußligstes'     : u'schussligstes',
        u'schußligste'      : u'schussligste',
        u'schußlig'         : u'schusslig',
        u'schußsicherem'    : u'schusssicherem',
        u'schußsicheren'    : u'schusssicheren',
        u'schußsicherer'    : u'schusssicherer',
        u'schußsicheres'    : u'schusssicheres',
        u'schußsichere'     : u'schusssichere',
        u'schußsicher'      : u'schusssicher',
        u'schuß'            : u'schuss',
        u'schuß'         : u'schuss',
        u'schußverletzungen': u'schussverletzungen',
        u'schußverletzung'  : u'schussverletzung',
        u'schußwaffen'      : u'schusswaffen',
        u'schußwaffe'       : u'schusswaffe',
        u'schußwechseln'    : u'schusswechseln',
        u'schußwechsels'    : u'schusswechsels',
        u'schußwechsel'     : u'schusswechsel',
        u'schußwunden'      : u'schusswunden',
        u'schußwunde'       : u'schusswunde',
        u'schwimmeisterinnen': u'schwimmmeisterinnen',
        u'schwimmeisterin'  : u'schwimmmeisterin',
        u'schwimmeister'    : u'schwimmmeister',
        u'schwurgerichtsprozeß': u'schwurgerichtsprozess',
        u'science-fiction'  : u'science-fiction',
        u'seeschiffahrtsstrassen': u'seeschifffahrtsstraßen',
        u'seeschiffahrtsstrasse': u'seeschifffahrtsstraße',
        u'seeschiffahrtstrassen': u'seeschifffahrtstraßen',
        u'seeschiffahrtstrasse': u'seeschifffahrtstraße',
        u'sehnenriß'        : u'sehnenriss',
        u'seigerriß'        : u'seigerriss',
        u'seitenriß'        : u'seitenriss',
        u'selbstbewußtem'   : u'selbstbewusstem',
        u'selbstbewußten'   : u'selbstbewussten',
        u'selbstbewußterem' : u'selbstbewussterem',
        u'selbstbewußteren' : u'selbstbewussteren',
        u'selbstbewußterer' : u'selbstbewussterer',
        u'selbstbewußteres' : u'selbstbewussteres',
        u'selbstbewußtere'  : u'selbstbewusstere',
        u'selbstbewußter'   : u'selbstbewusster',
        u'selbstbewußtestem': u'selbstbewusstestem',
        u'selbstbewußtesten': u'selbstbewusstesten',
        u'selbstbewußtester': u'selbstbewusstester',
        u'selbstbewußtestes': u'selbstbewusstestes',
        u'selbstbewußteste' : u'selbstbewussteste',
        u'selbstbewußtes'   : u'selbstbewusstes',
        u'selbstbewußte'    : u'selbstbewusste',
        u'selbstbewußtsein' : u'selbstbewusstsein',
        u'selbstbewußt'     : u'selbstbewusst',
        u'selbstportraits'  : u'selbstporträts',
        u'selbstportrait'   : u'selbstporträt',
        u'senatsbeschluß'   : u'senatsbeschluss',
        u'sendeschluß'      : u'sendeschluss',
        u'sendungsbewußtseins': u'sendungsbewusstseins',
        u'sendungsbewußtsein': u'sendungsbewusstsein',
        u'sensationsprozeß' : u'sensationsprozess',
        u'seßhaftem'        : u'sesshaftem',
        u'seßhaften'        : u'sesshaften',
        u'seßhafterem'      : u'sesshafterem',
        u'seßhafteren'      : u'sesshafteren',
        u'seßhafterer'      : u'sesshafterer',
        u'seßhafteres'      : u'sesshafteres',
        u'seßhaftere'       : u'sesshaftere',
        u'seßhafter'        : u'sesshafter',
        u'seßhaftestem'     : u'sesshaftestem',
        u'seßhaftesten'     : u'sesshaftesten',
        u'seßhaftester'     : u'sesshaftester',
        u'seßhaftestes'     : u'sesshaftestes',
        u'seßhafteste'      : u'sesshafteste',
        u'seßhaftes'        : u'sesshaftes',
        u'seßhafte'         : u'sesshafte',
        u'seßhaft'          : u'sesshaft',
        u'sexbeseßnerem'    : u'sexbesessnerem',
        u'sexbeseßneren'    : u'sexbesessneren',
        u'sexbeseßnerer'    : u'sexbesessnerer',
        u'sexbeseßneres'    : u'sexbesessneres',
        u'sexbeseßnere'     : u'sexbesessnere',
        u'sexbeseßner'      : u'sexbesessner',
        u'seyd'             : u'seid',
        u'seyend'           : u'seiend',
        u'seyen'            : u'seien',
        u'seyest'           : u'seiest',
        u'seyet'            : u'seiet',
        u'seyn'             : u'sein',
        u'seyst'            : u'seist',
        u'sey'              : u'sei',
        u'sicilianischem'   : u'sizilianischem',
        u'sicilianischen'   : u'sizilianischen',
        u'sicilianischer'   : u'sizilianischer',
        u'sicilianisches'   : u'sizilianisches',
        u'sicilianische'    : u'sizilianische',
        u'sicilianisch'     : u'sizilianisch',
        u'siciliens'        : u'siziliens',
        u'sicilien'         : u'sizilien',
        u'siechthums'       : u'siechtums',
        u'siechthum'        : u'siechtum',
        u'siegesbewußtem'   : u'siegesbewusstem',
        u'siegesbewußten'   : u'siegesbewussten',
        u'siegesbewußterem' : u'siegesbewussterem',
        u'siegesbewußteren' : u'siegesbewussteren',
        u'siegesbewußterer' : u'siegesbewussterer',
        u'siegesbewußteres' : u'siegesbewussteres',
        u'siegesbewußtere'  : u'siegesbewusstere',
        u'siegesbewußter'   : u'siegesbewusster',
        u'siegesbewußtestem': u'siegesbewusstestem',
        u'siegesbewußtesten': u'siegesbewusstesten',
        u'siegesbewußtester': u'siegesbewusstester',
        u'siegesbewußtestes': u'siegesbewusstestes',
        u'siegesbewußteste' : u'siegesbewussteste',
        u'siegesbewußtes'   : u'siegesbewusstes',
        u'siegesbewußte'    : u'siegesbewusste',
        u'siegesbewußt'     : u'siegesbewusst',
        u'siegesgewißheit'  : u'siegesgewissheit',
        u'siegesgewiß'      : u'siegesgewiss',
        u'siegesgewiß'   : u'siegesgewiss',
        u'siemens-martin-prozeß': u'siemens-martin-prozess',
        u'sierraleonischem' : u'sierra-leonischem',
        u'sierraleonischen' : u'sierra-leonischen',
        u'sierraleonischer' : u'sierra-leonischer',
        u'sierraleonisches' : u'sierra-leonisches',
        u'sierraleonische'  : u'sierra-leonische',
        u'sierraleonisch'   : u'sierra-leonisch',
        u'silvesterkuß'     : u'silvesterkuss',
        u'sketschen'        : u'sketchen',
        u'sketsches'        : u'sketches',
        u'sketsche'         : u'sketche',
        u'sketschs'         : u'sketchs',
        u'sketsch'          : u'sketch',
        u'socialem'         : u'sozialem',
        u'socialen'         : u'sozialen',
        u'socialerem'       : u'sozialerem',
        u'socialeren'       : u'sozialeren',
        u'socialerer'       : u'sozialerer',
        u'socialeres'       : u'sozialeres',
        u'socialere'        : u'sozialere',
        u'socialer'         : u'sozialer',
        u'sociales'         : u'soziales',
        u'sociale'          : u'soziale',
        u'socialismen'      : u'sozialismen',
        u'socialismus'      : u'sozialismus',
        u'socialstem'       : u'sozialstem',
        u'socialsten'       : u'sozialsten',
        u'socialster'       : u'sozialster',
        u'socialstes'       : u'sozialstes',
        u'socialste'        : u'sozialste',
        u'social'           : u'sozial',
        u'sockelgeschoß'    : u'sockelgeschoss',
        u'sodass'        : u'so dass',
        u'sodaß'            : u'sodass',
        u'solenitäten'      : u'solennitäten',
        u'sommerschlußverkäufen': u'sommerschlussverkäufen',
        u'sommerschlußverkaufes': u'sommerschlussverkaufes',
        u'sommerschlußverkaufe': u'sommerschlussverkaufe',
        u'sommerschlußverkäufe': u'sommerschlussverkäufe',
        u'sommerschlußverkaufs': u'sommerschlussverkaufs',
        u'sommerschlußverkauf': u'sommerschlussverkauf',
        u'sondirungen'      : u'sondierungen',
        u'sondirung'        : u'sondierung',
        u'sozialisationsprozeß': u'sozialisationsprozess',
        u'sozialmißbrauches': u'sozialmissbrauches',
        u'sozialmißbrauchs' : u'sozialmissbrauchs',
        u'sozialmißbrauch'  : u'sozialmissbrauch',
        u'spannbettüchern'  : u'spannbetttüchern',
        u'spannbettücher'   : u'spannbetttücher',
        u'spannbettuches'   : u'spannbetttuches',
        u'spannbettuche'    : u'spannbetttuche',
        u'spannbettuchs'    : u'spannbetttuchs',
        u'spannbettuch'     : u'spannbetttuch',
        u'spass'            : u'spaß',
        u'spätgothik'       : u'spätgotik',
        u'specifische'      : u'spezifische',
        u'sperrädern'       : u'sperrrädern',
        u'sperräder'        : u'sperrräder',
        u'sperrades'        : u'sperrrades',
        u'sperrade'         : u'sperrrade',
        u'sperrads'         : u'sperrrads',
        u'sperrad'          : u'sperrrad',
        u'sperriegeln'      : u'sperrriegeln',
        u'sperriegels'      : u'sperrriegels',
        u'sperriegel'       : u'sperrriegel',
        u'spieen'           : u'spien',
        u'spionageprozeß'   : u'spionageprozess',
        u'splißt'           : u'splisst',
        u'spliß'            : u'spliss',
        u'sportdreß'        : u'sportdress',
        u'sprachbewußtseins': u'sprachbewusstseins',
        u'sprachbewußtsein' : u'sprachbewusstsein',
        u'sprenggeschoß'    : u'sprenggeschoss',
        u'spritzgußteilen'  : u'spritzgussteilen',
        u'spritzgußteiles'  : u'spritzgussteiles',
        u'spritzgußteile'   : u'spritzgussteile',
        u'spritzgußteils'   : u'spritzgussteils',
        u'sprößlingen'      : u'sprösslingen',
        u'sprößlinge'       : u'sprösslinge',
        u'sprößlings'       : u'sprösslings',
        u'sprößling'        : u'sprössling',
        u'sproßt'           : u'sprosst',
        u'sproß'            : u'spross',
        u'sproßvokalen'     : u'sprossvokalen',
        u'sproßvokale'      : u'sprossvokale',
        u'sproßvokals'      : u'sprossvokals',
        u'sproßvokal'       : u'sprossvokal',
        u'srilankischem'    : u'sri-lankischem',
        u'srilankischen'    : u'sri-lankischen',
        u'srilankischer'    : u'sri-lankischer',
        u'srilankisches'    : u'sri-lankisches',
        u'srilankische'     : u'sri-lankische',
        u'srilankisch'      : u'sri-lankisch',
        u'stadträthen'      : u'stadträten',
        u'stadtrathes'      : u'stadtrates',
        u'stadtrathe'       : u'stadtrate',
        u'stadträthe'       : u'stadträte',
        u'stadtraths'       : u'stadtrats',
        u'stadtrath'        : u'stadtrat',
        u'stadtschloß'      : u'stadtschloss',
        u'stadtthoren'      : u'stadttoren',
        u'stadtthores'      : u'stadttores',
        u'stadtthore'       : u'stadttore',
        u'stadtthors'       : u'stadttors',
        u'stadtthor'        : u'stadttor',
        u'stahlroß'         : u'stahlross',
        u'stallaterne'      : u'stalllaterne',
        u'stammorphem'      : u'stammmorphem',
        u'stammutter'       : u'stammmutter',
        u'standesbewußtem'  : u'standesbewusstem',
        u'standesbewußten'  : u'standesbewussten',
        u'standesbewußter'  : u'standesbewusster',
        u'standesbewußtes'  : u'standesbewusstes',
        u'standesbewußte'   : u'standesbewusste',
        u'standesbewußt'    : u'standesbewusst',
        u'stanglpaß'        : u'stanglpass',
        u'starkregenereigniß': u'starkregenereignis',
        u'startschuß'       : u'startschuss',
        u'steckschuß'       : u'steckschuss',
        u'steilpaß'         : u'steilpass',
        u'steinschloß'      : u'steinschloss',
        u'stellfaß'         : u'stellfass',
        u'stemmeisseln'     : u'stemmmeißeln',
        u'stemmeissels'     : u'stemmmeißels',
        u'stemmeissel'      : u'stemmmeißel',
        u'stemmeißel'       : u'stemmmeißel',
        u'stengeln'         : u'stängeln',
        u'stengels'         : u'stängels',
        u'stengel'          : u'stängel',
        u'steptanz'         : u'stepptanz',
        u'steuermeßbeträgen': u'steuermessbeträgen',
        u'steuermeßbetrages': u'steuermessbetrages',
        u'steuermeßbetrage' : u'steuermessbetrage',
        u'steuermeßbeträge' : u'steuermessbeträge',
        u'steuermeßbetrags' : u'steuermessbetrags',
        u'steuermeßbetrag'  : u'steuermessbetrag',
        u'stewardeß'        : u'stewardess',
        u'stillebens'       : u'stilllebens',
        u'stilleben'        : u'stillleben',
        u'stillegend'       : u'stilllegend',
        u'stillegen'        : u'stilllegen',
        u'stillegest'       : u'stilllegest',
        u'stilleget'        : u'stillleget',
        u'stillege'         : u'stilllege',
        u'stillegst'        : u'stilllegst',
        u'stillegten'       : u'stilllegten',
        u'stillegtest'      : u'stilllegtest',
        u'stillegtet'       : u'stilllegtet',
        u'stillegte'        : u'stilllegte',
        u'stillegt'         : u'stilllegt',
        u'stillegungen'     : u'stilllegungen',
        u'stillegung'       : u'stilllegung',
        u'stoffaden'        : u'stofffaden',
        u'stoffarbe'        : u'stofffarbe',
        u'stoffaser'        : u'stofffaser',
        u'stoffetzens'      : u'stofffetzens',
        u'stoffetzen'       : u'stofffetzen',
        u'stok'             : u'stokes',
        u'stops'            : u'stopps',
        u'stop'             : u'stopp',
        u'stop'          : u'stopp',
        u'storchenbiß'      : u'storchenbiss',
        u'straferlaß'       : u'straferlass',
        u'strafprozeßordnung': u'strafprozessordnung',
        u'strafprozeßrecht' : u'strafprozessrecht',
        u'strafprozeß'      : u'strafprozess',
        u'straß'            : u'strass',
        u'streifschuß'      : u'streifschuss',
        u'streßfreiem'      : u'stressfreiem',
        u'streßfreien'      : u'stressfreien',
        u'streßfreier'      : u'stressfreier',
        u'streßfreies'      : u'stressfreies',
        u'streßfreie'       : u'stressfreie',
        u'streßfrei'        : u'stressfrei',
        u'streßhormonen'    : u'stresshormonen',
        u'streßhormone'     : u'stresshormone',
        u'streßhormons'     : u'stresshormons',
        u'streßhormon'      : u'stresshormon',
        u'streßresistentem' : u'stressresistentem',
        u'streßresistenten' : u'stressresistenten',
        u'streßresistenterem': u'stressresistenterem',
        u'streßresistenteren': u'stressresistenteren',
        u'streßresistenterer': u'stressresistenterer',
        u'streßresistenteres': u'stressresistenteres',
        u'streßresistentere': u'stressresistentere',
        u'streßresistenter' : u'stressresistenter',
        u'streßresistentestem': u'stressresistentestem',
        u'streßresistentesten': u'stressresistentesten',
        u'streßresistentester': u'stressresistentester',
        u'streßresistentestes': u'stressresistentestes',
        u'streßresistenteste': u'stressresistenteste',
        u'streßresistentes' : u'stressresistentes',
        u'streßresistente'  : u'stressresistente',
        u'streßresistent'   : u'stressresistent',
        u'streßsituation'   : u'stresssituation',
        u'streßten'         : u'stressten',
        u'streßtests'       : u'stresstests',
        u'streßtest'        : u'stresstest',
        u'streßtet'         : u'stresstet',
        u'streßte'          : u'stresste',
        u'streßt'           : u'stresst',
        u'streß'            : u'stress',
        u'stromanschluß'    : u'stromanschluss',
        u'studirend'        : u'studierend',
        u'studiren'         : u'studieren',
        u'studirest'        : u'studierest',
        u'studiret'         : u'studieret',
        u'studire'          : u'studiere',
        u'studirst'         : u'studierst',
        u'studirten'        : u'studierten',
        u'studirtest'       : u'studiertest',
        u'studirtet'        : u'studiertet',
        u'studirte'         : u'studierte',
        u'studirt'          : u'studiert',
        u'studir'           : u'studier',
        u'stukkateuren'     : u'stuckateuren',
        u'stukkateure'      : u'stuckateure',
        u'stukkateurs'      : u'stuckateurs',
        u'stukkateur'       : u'stuckateur',
        u'stuß'             : u'stuss',
        u'stusz'            : u'stuss',
        u'subcutanem'       : u'subkutanem',
        u'subcutanen'       : u'subkutanen',
        u'subcutaner'       : u'subkutaner',
        u'subcutanes'       : u'subkutanes',
        u'subcutane'        : u'subkutane',
        u'subcutan'         : u'subkutan',
        u'submiß'           : u'submiss',
        u'südrußlands'      : u'südrusslands',
        u'südrußland'       : u'südrussland',
        u'sukzeß'           : u'sukzess',
        u'sutanen'          : u'soutanen',
        u'sutane'           : u'soutane',
        u'swimming-pools'   : u'swimmingpools',
        u'swimming-pool'    : u'swimmingpool',
        u'sympathieen'      : u'sympathien',
        u'tablettenmißbrauches': u'tablettenmissbrauches',
        u'tablettenmißbrauche': u'tablettenmissbrauche',
        u'tablettenmißbrauchs': u'tablettenmissbrauchs',
        u'tablettenmißbrauch': u'tablettenmissbrauch',
        u'taferlklaßlern'   : u'taferlklasslern',
        u'taferlklaßlers'   : u'taferlklasslers',
        u'taferlklaßler'    : u'taferlklassler',
        u'talke'            : u'talk',
        u'talpaß'           : u'talpass',
        u'tankschloß'       : u'tankschloss',
        u'tankverschluß'    : u'tankverschluss',
        u'tarifabschluß'    : u'tarifabschluss',
        u'täßchens'         : u'tässchens',
        u'täßchen'          : u'tässchen',
        u'tatortphotos'     : u'tatortfotos',
        u'tatortphoto'      : u'tatortfoto',
        u'tauernexpreß'     : u'tauernexpress',
        u'taunaß'           : u'taunass',
        u'teerfaß'          : u'teerfass',
        u'telefonanschluß'  : u'telefonanschluss',
        u'telephonanrufen'  : u'telefonanrufen',
        u'telephonanrufes'  : u'telefonanrufes',
        u'telephonanrufe'   : u'telefonanrufe',
        u'telephonanrufs'   : u'telefonanrufs',
        u'telephonanruf'    : u'telefonanruf',
        u'telephonaten'     : u'telefonaten',
        u'telephonates'     : u'telefonates',
        u'telephonate'      : u'telefonate',
        u'telephonats'      : u'telefonats',
        u'telephonat'       : u'telefonat',
        u'telephonauskunft' : u'telefonauskunft',
        u'telephonbüchern'  : u'telefonbüchern',
        u'telephonbücher'   : u'telefonbücher',
        u'telephonbuches'   : u'telefonbuches',
        u'telephonbuche'    : u'telefonbuche',
        u'telephonbuchs'    : u'telefonbuchs',
        u'telephonbuch'     : u'telefonbuch',
        u'telephonen'       : u'telefonen',
        u'telephone'        : u'telefone',
        u'telephongesprächen': u'telefongesprächen',
        u'telephongespräches': u'telefongespräches',
        u'telephongespräche': u'telefongespräche',
        u'telephongesprächs': u'telefongesprächs',
        u'telephongespräch' : u'telefongespräch',
        u'telephonhäuschens': u'telefonhäuschens',
        u'telephonhäuschen' : u'telefonhäuschen',
        u'telephonhörern'   : u'telefonhörern',
        u'telephonhörers'   : u'telefonhörers',
        u'telephonhörer'    : u'telefonhörer',
        u'telephonierendem' : u'telefonierendem',
        u'telephonierenden' : u'telefonierenden',
        u'telephonierender' : u'telefonierender',
        u'telephonierendes' : u'telefonierendes',
        u'telephonierende'  : u'telefonierende',
        u'telephonierend'   : u'telefonierend',
        u'telephonieren'    : u'telefonieren',
        u'telephonierest'   : u'telefonierest',
        u'telephonieret'    : u'telefonieret',
        u'telephoniere'     : u'telefoniere',
        u'telephonierst'    : u'telefonierst',
        u'telephonierten'   : u'telefonierten',
        u'telephoniertest'  : u'telefoniertest',
        u'telephoniertet'   : u'telefoniertet',
        u'telephonierte'    : u'telefonierte',
        u'telephoniert'     : u'telefoniert',
        u'telephonier'      : u'telefonier',
        u'telephonie'       : u'telefonie',
        u'telephonischem'   : u'telefonischem',
        u'telephonischen'   : u'telefonischen',
        u'telephonischer'   : u'telefonischer',
        u'telephonisches'   : u'telefonisches',
        u'telephonische'    : u'telefonische',
        u'telephonisch'     : u'telefonisch',
        u'telephonisten'    : u'telefonisten',
        u'telephonistinnen' : u'telefonistinnen',
        u'telephonistin'    : u'telefonistin',
        u'telephonist'      : u'telefonist',
        u'telephonjokern'   : u'telefonjokern',
        u'telephonjokers'   : u'telefonjokers',
        u'telephonjoker'    : u'telefonjoker',
        u'telephonkonferenzen': u'telefonkonferenzen',
        u'telephonkonferenz': u'telefonkonferenz',
        u'telephonkontakten': u'telefonkontakten',
        u'telephonkontaktes': u'telefonkontaktes',
        u'telephonkontakte' : u'telefonkontakte',
        u'telephonkontakts' : u'telefonkontakts',
        u'telephonkontakt'  : u'telefonkontakt',
        u'telephonleitungen': u'telefonleitungen',
        u'telephonleitung'  : u'telefonleitung',
        u'telephonmasten'   : u'telefonmasten',
        u'telephonmastes'   : u'telefonmastes',
        u'telephonmaste'    : u'telefonmaste',
        u'telephonmasts'    : u'telefonmasts',
        u'telephonmast'     : u'telefonmast',
        u'telephonnetzen'   : u'telefonnetzen',
        u'telephonnetzes'   : u'telefonnetzes',
        u'telephonnetze'    : u'telefonnetze',
        u'telephonnetz'     : u'telefonnetz',
        u'telephonnummern'  : u'telefonnummern',
        u'telephonnummer'   : u'telefonnummer',
        u'telephonrechnungen': u'telefonrechnungen',
        u'telephonrechnung' : u'telefonrechnung',
        u'telephonseelsorge': u'telefonseelsorge',
        u'telephonsexes'    : u'telefonsexes',
        u'telephonsex'      : u'telefonsex',
        u'telephons'        : u'telefons',
        u'telephonterrors'  : u'telefonterrors',
        u'telephonterror'   : u'telefonterror',
        u'telephontischchens': u'telefontischchens',
        u'telephontischchen': u'telefontischchen',
        u'telephontischen'  : u'telefontischen',
        u'telephontisches'  : u'telefontisches',
        u'telephontische'   : u'telefontische',
        u'telephontischs'   : u'telefontischs',
        u'telephontisch'    : u'telefontisch',
        u'telephon'         : u'telefon',
        u'telephon'      : u'telefon',
        u'telephonvorwahlen': u'telefonvorwahlen',
        u'telephonvorwahl'  : u'telefonvorwahl',
        u'telephonzellen'   : u'telefonzellen',
        u'telephonzelle'    : u'telefonzelle',
        u'telephonzentralen': u'telefonzentralen',
        u'telephonzentrale' : u'telefonzentrale',
        u'terminstreß'      : u'terminstress',
        u'terrorprozeß'     : u'terrorprozess',
        u'teufelsabbiß'     : u'teufelsabbiss',
        u'thälern'          : u'tälern',
        u'thäler'           : u'täler',
        u'thales'           : u'tales',
        u'thale'            : u'tale',
        u'thals'            : u'tals',
        u'thal'             : u'tal',
        u'thaten'           : u'taten',
        u'thäten'           : u'täten',
        u'thatest'          : u'tatest',
        u'thätest'          : u'tätest',
        u'thatet'           : u'tatet',
        u'thätet'           : u'tätet',
        u'thäte'            : u'täte',
        u'thatst'           : u'tatst',
        u'that'             : u'tat',
        u'thauen'           : u'tauen',
        u'thaues'           : u'taues',
        u'thaue'            : u'taue',
        u'thaus'            : u'taus',
        u'thau'             : u'tau',
        u'thees'            : u'tees',
        u'thee'             : u'tee',
        u'theilen'          : u'teilen',
        u'theiles'          : u'teiles',
        u'theile'           : u'teile',
        u'theilnehmerinnen' : u'teilnehmerinnen',
        u'theilnehmerin'    : u'teilnehmerin',
        u'theilnehmern'     : u'teilnehmern',
        u'theilnehmers'     : u'teilnehmers',
        u'theilnehmer'      : u'teilnehmer',
        u'theils'           : u'teils',
        u'theil'            : u'teil',
        u'theorieen'        : u'theorien',
        u'thieren'          : u'tieren',
        u'thieres'          : u'tieres',
        u'thiere'           : u'tiere',
        u'thierischem'      : u'tierischem',
        u'thierischen'      : u'tierischen',
        u'thierischerem'    : u'tierischerem',
        u'thierischeren'    : u'tierischeren',
        u'thierischerer'    : u'tierischerer',
        u'thierischeres'    : u'tierischeres',
        u'thierischere'     : u'tierischere',
        u'thierischer'      : u'tierischer',
        u'thierisches'      : u'tierisches',
        u'thierische'       : u'tierische',
        u'thierischstem'    : u'tierischstem',
        u'thierischsten'    : u'tierischsten',
        u'thierischster'    : u'tierischster',
        u'thierischstes'    : u'tierischstes',
        u'thierischste'     : u'tierischste',
        u'thierisch'        : u'tierisch',
        u'thierkreislicht'  : u'tierkreislicht',
        u'thiers'           : u'tiers',
        u'thier'            : u'tier',
        u'thoren'           : u'toren',
        u'thores'           : u'tores',
        u'thore'            : u'tore',
        u'thors'            : u'tors',
        u'thor'             : u'tor',
        u'thränen'          : u'tränen',
        u'thräne'           : u'träne',
        u'threuem'          : u'treuem',
        u'threuen'          : u'treuen',
        u'threuerem'        : u'treuerem',
        u'threueren'        : u'treueren',
        u'threuerer'        : u'treuerer',
        u'threueres'        : u'treueres',
        u'threuere'         : u'treuere',
        u'threuer'          : u'treuer',
        u'threuestem'       : u'treuestem',
        u'threuesten'       : u'treuesten',
        u'threuester'       : u'treuester',
        u'threuestes'       : u'treuestes',
        u'threueste'        : u'treueste',
        u'threues'          : u'treues',
        u'threue'           : u'treue',
        u'threustem'        : u'treustem',
        u'threusten'        : u'treusten',
        u'threuster'        : u'treuster',
        u'threustes'        : u'treustes',
        u'threuste'         : u'treuste',
        u'threu'            : u'treu',
        u'thuend'           : u'tuend',
        u'thuen'            : u'tuen',
        u'thuest'           : u'tuest',
        u'thuet'            : u'tuet',
        u'thue'             : u'tue',
        u'thuns'            : u'tuns',
        u'thun'             : u'tun',
        u'thun'          : u'tun',
        u'thüren'           : u'türen',
        u'thüre'            : u'türe',
        u'thürmend'         : u'türmend',
        u'thürmen'          : u'türmen',
        u'thürmest'         : u'türmest',
        u'thurmes'          : u'turmes',
        u'thürmet'          : u'türmet',
        u'thurme'           : u'turme',
        u'thürme'           : u'türme',
        u'thürmst'          : u'türmst',
        u'thurms'           : u'turms',
        u'thürmten'         : u'türmten',
        u'thürmtest'        : u'türmtest',
        u'thürmtet'         : u'türmtet',
        u'thürmte'          : u'türmte',
        u'thürmt'           : u'türmt',
        u'thurm'            : u'turm',
        u'thürm'            : u'türm',
        u'thür'             : u'tür',
        u'thür'          : u'tür',
        u'thust'            : u'tust',
        u'thut'             : u'tut',
        u'thu'              : u'tu',
        u'tiefgeschoß'      : u'tiefgeschoss',
        u'tintenfaß'        : u'tintenfass',
        u'tintenfaß'     : u'tintenfass',
        u'tips'             : u'tipps',
        u'tip'              : u'tipp',
        u'todblaß'          : u'todblass',
        u'todesschuß'       : u'todesschuss',
        u'todtengräber'     : u'totengräber',
        u'todte'            : u'tote',
        u'tolpatschen'      : u'tollpatschen',
        u'tolpatsches'      : u'tollpatsches',
        u'tolpatsche'       : u'tollpatsche',
        u'tolpatschigem'    : u'tollpatschigem',
        u'tolpatschigen'    : u'tollpatschigen',
        u'tolpatschigerem'  : u'tollpatschigerem',
        u'tolpatschigeren'  : u'tollpatschigeren',
        u'tolpatschigerer'  : u'tollpatschigerer',
        u'tolpatschigeres'  : u'tollpatschigeres',
        u'tolpatschigere'   : u'tollpatschigere',
        u'tolpatschiger'    : u'tollpatschiger',
        u'tolpatschiges'    : u'tollpatschiges',
        u'tolpatschige'     : u'tollpatschige',
        u'tolpatschigstem'  : u'tollpatschigstem',
        u'tolpatschigsten'  : u'tollpatschigsten',
        u'tolpatschigster'  : u'tollpatschigster',
        u'tolpatschigstes'  : u'tollpatschigstes',
        u'tolpatschigste'   : u'tollpatschigste',
        u'tolpatschig'      : u'tollpatschig',
        u'tolpatschs'       : u'tollpatschs',
        u'tolpatsch'        : u'tollpatsch',
        u'toresschluß'      : u'toresschluss',
        u'torschlußpaniken' : u'torschlusspaniken',
        u'torschlußpanik'   : u'torschlusspanik',
        u'torschluß'        : u'torschluss',
        u'torschuß'         : u'torschuss',
        u'tortenguß'        : u'tortenguss',
        u'totbißt'          : u'totbisst',
        u'totbiß'           : u'totbiss',
        u'totenblaß'        : u'totenblass',
        u'totenblaß'     : u'totenblass',
        u'traditionsbewußtem': u'traditionsbewusstem',
        u'traditionsbewußten': u'traditionsbewussten',
        u'traditionsbewußterem': u'traditionsbewussterem',
        u'traditionsbewußteren': u'traditionsbewussteren',
        u'traditionsbewußterer': u'traditionsbewussterer',
        u'traditionsbewußteres': u'traditionsbewussteres',
        u'traditionsbewußtere': u'traditionsbewusstere',
        u'traditionsbewußter': u'traditionsbewusster',
        u'traditionsbewußtestem': u'traditionsbewusstestem',
        u'traditionsbewußtesten': u'traditionsbewusstesten',
        u'traditionsbewußtester': u'traditionsbewusstester',
        u'traditionsbewußtestes': u'traditionsbewusstestes',
        u'traditionsbewußteste': u'traditionsbewussteste',
        u'traditionsbewußtes': u'traditionsbewusstes',
        u'traditionsbewußte': u'traditionsbewusste',
        u'traditionsbewußtsein': u'traditionsbewusstsein',
        u'traditionsbewußt' : u'traditionsbewusst',
        u'trampschiffahrt'  : u'trampschifffahrt',
        u'tränenfluß'       : u'tränenfluss',
        u'tränennaß'        : u'tränennass',
        u'traß'             : u'trass',
        u'traumschloß'      : u'traumschloss',
        u'treibprozeß'      : u'treibprozess',
        u'trendbewußt'      : u'trendbewusst',
        u'trennetz'         : u'trennnetz',
        u'triefnaß'         : u'triefnass',
        u'tropfnaß'         : u'tropfnass',
        u'troßschiffen'     : u'trossschiffen',
        u'troßschiffes'     : u'trossschiffes',
        u'troßschiffe'      : u'trossschiffe',
        u'troßschiffs'      : u'trossschiffs',
        u'troßschiff'       : u'trossschiff',
        u'troß'             : u'tross',
        u'troßweibern'      : u'trossweibern',
        u'troßweiber'       : u'trossweiber',
        u'troßweibes'       : u'trossweibes',
        u'troßweibs'        : u'trossweibs',
        u'troßweib'         : u'trossweib',
        u'truchseß'         : u'truchsess',
        u'trugschluß'       : u'trugschluss',
        u'tschüß'           : u'tschüss',
        u'tuffelsen'        : u'tufffelsen',
        u'tuffels'          : u'tufffels',
        u'türschloß'        : u'türschloss',
        u'u-ausschuß'       : u'u-ausschuss',
        u'überbiß'          : u'überbiss',
        u'überdruß'         : u'überdruss',
        u'überflußgesellschaft': u'überflussgesellschaft',
        u'überfluß'         : u'überfluss',
        u'übergoßt'         : u'übergosst',
        u'übergoß'          : u'übergoss',
        u'überguß'          : u'überguss',
        u'überlaßt'         : u'überlasst',
        u'überläßt'         : u'überlässt',
        u'überlaß'          : u'überlass',
        u'überrißt'         : u'überrisst',
        u'überriß'          : u'überriss',
        u'überschußproduktion': u'überschussproduktion',
        u'überschuß'        : u'überschuss',
        u'überschwenglichem': u'überschwänglichem',
        u'überschwenglichen': u'überschwänglichen',
        u'überschwenglicherem': u'überschwänglicherem',
        u'überschwenglicheren': u'überschwänglicheren',
        u'überschwenglicherer': u'überschwänglicherer',
        u'überschwenglicheres': u'überschwänglicheres',
        u'überschwenglichere': u'überschwänglichere',
        u'überschwenglicher': u'überschwänglicher',
        u'überschwengliches': u'überschwängliches',
        u'überschwengliche' : u'überschwängliche',
        u'überschwenglichkeiten': u'überschwänglichkeiten',
        u'überschwenglichkeit': u'überschwänglichkeit',
        u'überschwenglichstem': u'überschwänglichstem',
        u'überschwenglichsten': u'überschwänglichsten',
        u'überschwenglichster': u'überschwänglichster',
        u'überschwenglichstes': u'überschwänglichstes',
        u'überschwenglichste': u'überschwänglichste',
        u'überschwenglich'  : u'überschwänglich',
        u'ueberbleibsel'    : u'überbleibsel',
        u'umdenkprozeß'     : u'umdenkprozess',
        u'umdenkungsprozeß' : u'umdenkungsprozess',
        u'umfaßten'         : u'umfassten',
        u'umfaßtest'        : u'umfasstest',
        u'umfaßtet'         : u'umfasstet',
        u'umfaßte'          : u'umfasste',
        u'umfaßte'       : u'umfasste',
        u'umfaßt'           : u'umfasst',
        u'umfaß'            : u'umfass',
        u'umgefaßt'         : u'umgefasst',
        u'umkehrschluß'     : u'umkehrschluss',
        u'umrißt'           : u'umrisst',
        u'umriß'            : u'umriss',
        u'umrißzeichnung'   : u'umrisszeichnung',
        u'umschichtungsprozeß': u'umschichtungsprozess',
        u'umschloßt'        : u'umschlosst',
        u'umschloß'         : u'umschloss',
        u'umschluß'         : u'umschluss',
        u'umstellungsprozeß': u'umstellungsprozess',
        u'umwandlungsprozeß': u'umwandlungsprozess',
        u'umweltbewußtem'   : u'umweltbewusstem',
        u'umweltbewußten'   : u'umweltbewussten',
        u'umweltbewußterem' : u'umweltbewussterem',
        u'umweltbewußteren' : u'umweltbewussteren',
        u'umweltbewußterer' : u'umweltbewussterer',
        u'umweltbewußteres' : u'umweltbewussteres',
        u'umweltbewußtere'  : u'umweltbewusstere',
        u'umweltbewußter'   : u'umweltbewusster',
        u'umweltbewußtestem': u'umweltbewusstestem',
        u'umweltbewußtesten': u'umweltbewusstesten',
        u'umweltbewußtester': u'umweltbewusstester',
        u'umweltbewußtestes': u'umweltbewusstestes',
        u'umweltbewußteste' : u'umweltbewussteste',
        u'umweltbewußtes'   : u'umweltbewusstes',
        u'umweltbewußte'    : u'umweltbewusste',
        u'umweltbewußtsein' : u'umweltbewusstsein',
        u'umweltbewußt'     : u'umweltbewusst',
        u'umwelteinfluß'    : u'umwelteinfluss',
        u'unangepaßtem'     : u'unangepasstem',
        u'unangepaßten'     : u'unangepassten',
        u'unangepaßterem'   : u'unangepassterem',
        u'unangepaßteren'   : u'unangepassteren',
        u'unangepaßterer'   : u'unangepassterer',
        u'unangepaßteres'   : u'unangepassteres',
        u'unangepaßtere'    : u'unangepasstere',
        u'unangepaßter'     : u'unangepasster',
        u'unangepaßtestem'  : u'unangepasstestem',
        u'unangepaßtesten'  : u'unangepasstesten',
        u'unangepaßtester'  : u'unangepasstester',
        u'unangepaßtestes'  : u'unangepasstestes',
        u'unangepaßteste'   : u'unangepassteste',
        u'unangepaßtes'     : u'unangepasstes',
        u'unangepaßte'      : u'unangepasste',
        u'unangepaßtheit'   : u'unangepasstheit',
        u'unangepaßt'       : u'unangepasst',
        u'unbeeinflußbarem' : u'unbeeinflussbarem',
        u'unbeeinflußbaren' : u'unbeeinflussbaren',
        u'unbeeinflußbarer' : u'unbeeinflussbarer',
        u'unbeeinflußbares' : u'unbeeinflussbares',
        u'unbeeinflußbare'  : u'unbeeinflussbare',
        u'unbeeinflußbarkeit': u'unbeeinflussbarkeit',
        u'unbeeinflußbar'   : u'unbeeinflussbar',
        u'unbeeinflußtem'   : u'unbeeinflusstem',
        u'unbeeinflußten'   : u'unbeeinflussten',
        u'unbeeinflußter'   : u'unbeeinflusster',
        u'unbeeinflußtes'   : u'unbeeinflusstes',
        u'unbeeinflußte'    : u'unbeeinflusste',
        u'unbeeinflußt'     : u'unbeeinflusst',
        u'unbewußtem'       : u'unbewusstem',
        u'unbewußten'       : u'unbewussten',
        u'unbewußterem'     : u'unbewussterem',
        u'unbewußteren'     : u'unbewussteren',
        u'unbewußterer'     : u'unbewussterer',
        u'unbewußteres'     : u'unbewussteres',
        u'unbewußtere'      : u'unbewusstere',
        u'unbewußter'       : u'unbewusster',
        u'unbewußtestem'    : u'unbewusstestem',
        u'unbewußtesten'    : u'unbewusstesten',
        u'unbewußtester'    : u'unbewusstester',
        u'unbewußtestes'    : u'unbewusstestes',
        u'unbewußteste'     : u'unbewussteste',
        u'unbewußtes'       : u'unbewusstes',
        u'unbewußte'        : u'unbewusste',
        u'unbewußtheit'     : u'unbewusstheit',
        u'unbewußt'         : u'unbewusst',
        u'unbewußt'      : u'unbewusst',
        u'unerläßlichem'    : u'unerlässlichem',
        u'unerläßlichen'    : u'unerlässlichen',
        u'unerläßlicherem'  : u'unerlässlicherem',
        u'unerläßlicheren'  : u'unerlässlicheren',
        u'unerläßlicherer'  : u'unerlässlicherer',
        u'unerläßlicheres'  : u'unerlässlicheres',
        u'unerläßlichere'   : u'unerlässlichere',
        u'unerläßlicher'    : u'unerlässlicher',
        u'unerläßliches'    : u'unerlässliches',
        u'unerläßliche'     : u'unerlässliche',
        u'unerläßlichstem'  : u'unerlässlichstem',
        u'unerläßlichsten'  : u'unerlässlichsten',
        u'unerläßlichster'  : u'unerlässlichster',
        u'unerläßlichstes'  : u'unerlässlichstes',
        u'unerläßlichste'   : u'unerlässlichste',
        u'unerläßlich'      : u'unerlässlich',
        u'unermeßlichem'    : u'unermesslichem',
        u'unermeßlichen'    : u'unermesslichen',
        u'unermeßlicherem'  : u'unermesslicherem',
        u'unermeßlicheren'  : u'unermesslicheren',
        u'unermeßlicherer'  : u'unermesslicherer',
        u'unermeßlicheres'  : u'unermesslicheres',
        u'unermeßlichere'   : u'unermesslichere',
        u'unermeßlicher'    : u'unermesslicher',
        u'unermeßliches'    : u'unermessliches',
        u'unermeßliche'     : u'unermessliche',
        u'unermeßlichkeit'  : u'unermesslichkeit',
        u'unermeßlichstem'  : u'unermesslichstem',
        u'unermeßlichsten'  : u'unermesslichsten',
        u'unermeßlichster'  : u'unermesslichster',
        u'unermeßlichstes'  : u'unermesslichstes',
        u'unermeßlichste'   : u'unermesslichste',
        u'unermeßlich'      : u'unermesslich',
        u'unfaßbarem'       : u'unfassbarem',
        u'unfaßbaren'       : u'unfassbaren',
        u'unfaßbarerem'     : u'unfassbarerem',
        u'unfaßbareren'     : u'unfassbareren',
        u'unfaßbarerer'     : u'unfassbarerer',
        u'unfaßbareres'     : u'unfassbareres',
        u'unfaßbarere'      : u'unfassbarere',
        u'unfaßbarer'       : u'unfassbarer',
        u'unfaßbares'       : u'unfassbares',
        u'unfaßbare'        : u'unfassbare',
        u'unfaßbarstem'     : u'unfassbarstem',
        u'unfaßbarsten'     : u'unfassbarsten',
        u'unfaßbarster'     : u'unfassbarster',
        u'unfaßbarstes'     : u'unfassbarstes',
        u'unfaßbarste'      : u'unfassbarste',
        u'unfaßbar'         : u'unfassbar',
        u'unfaßlichem'      : u'unfasslichem',
        u'unfaßlichen'      : u'unfasslichen',
        u'unfaßlicherem'    : u'unfasslicherem',
        u'unfaßlicheren'    : u'unfasslicheren',
        u'unfaßlicherer'    : u'unfasslicherer',
        u'unfaßlicheres'    : u'unfasslicheres',
        u'unfaßlichere'     : u'unfasslichere',
        u'unfaßlicher'      : u'unfasslicher',
        u'unfaßliches'      : u'unfassliches',
        u'unfaßliche'       : u'unfassliche',
        u'unfaßlichstem'    : u'unfasslichstem',
        u'unfaßlichsten'    : u'unfasslichsten',
        u'unfaßlichster'    : u'unfasslichster',
        u'unfaßlichstes'    : u'unfasslichstes',
        u'unfaßlichste'     : u'unfasslichste',
        u'unfaßlich'        : u'unfasslich',
        u'ungewißheit'      : u'ungewissheit',
        u'ungewiß'          : u'ungewiss',
        u'universitätsabschluß': u'universitätsabschluss',
        u'unmißverständlichem': u'unmissverständlichem',
        u'unmißverständlichen': u'unmissverständlichen',
        u'unmißverständlicherem': u'unmissverständlicherem',
        u'unmißverständlicheren': u'unmissverständlicheren',
        u'unmißverständlicherer': u'unmissverständlicherer',
        u'unmißverständlicheres': u'unmissverständlicheres',
        u'unmißverständlichere': u'unmissverständlichere',
        u'unmißverständlicher': u'unmissverständlicher',
        u'unmißverständliches': u'unmissverständliches',
        u'unmißverständliche': u'unmissverständliche',
        u'unmißverständlichstem': u'unmissverständlichstem',
        u'unmißverständlichsten': u'unmissverständlichsten',
        u'unmißverständlichster': u'unmissverständlichster',
        u'unmißverständlichstes': u'unmissverständlichstes',
        u'unmißverständlichste': u'unmissverständlichste',
        u'unmißverständlich': u'unmissverständlich',
        u'unpäßlichem'      : u'unpässlichem',
        u'unpäßlichen'      : u'unpässlichen',
        u'unpäßlicherem'    : u'unpässlicherem',
        u'unpäßlicheren'    : u'unpässlicheren',
        u'unpäßlicherer'    : u'unpässlicherer',
        u'unpäßlicheres'    : u'unpässlicheres',
        u'unpäßlichere'     : u'unpässlichere',
        u'unpäßlicher'      : u'unpässlicher',
        u'unpäßliches'      : u'unpässliches',
        u'unpäßliche'       : u'unpässliche',
        u'unpäßlichkeiten'  : u'unpässlichkeiten',
        u'unpäßlichkeit'    : u'unpässlichkeit',
        u'unpäßlichstem'    : u'unpässlichstem',
        u'unpäßlichsten'    : u'unpässlichsten',
        u'unpäßlichster'    : u'unpässlichster',
        u'unpäßlichstes'    : u'unpässlichstes',
        u'unpäßlichste'     : u'unpässlichste',
        u'unpäßlich'        : u'unpässlich',
        u'unpaß'            : u'unpass',
        u'unrechtsbewußtsein': u'unrechtsbewusstsein',
        u'unselbständig'    : u'unselbstständig',
        u'unterausschuß'    : u'unterausschuss',
        u'unterbewußtem'    : u'unterbewusstem',
        u'unterbewußten'    : u'unterbewussten',
        u'unterbewußter'    : u'unterbewusster',
        u'unterbewußtes'    : u'unterbewusstes',
        u'unterbewußte'     : u'unterbewusste',
        u'unterbewußtseins' : u'unterbewusstseins',
        u'unterbewußtsein'  : u'unterbewusstsein',
        u'unterbewußt'      : u'unterbewusst',
        u'unterbiß'         : u'unterbiss',
        u'untergränzen'     : u'untergrenzen',
        u'untergränze'      : u'untergrenze',
        u'unterlaßt'        : u'unterlasst',
        u'unterläßt'        : u'unterlässt',
        u'unterlaß'         : u'unterlass',
        u'unterschuß'       : u'unterschuss',
        u'untersuchungsausschuß': u'untersuchungsausschuss',
        u'unvergeßlichem'   : u'unvergesslichem',
        u'unvergeßlichen'   : u'unvergesslichen',
        u'unvergeßlicherem' : u'unvergesslicherem',
        u'unvergeßlicheren' : u'unvergesslicheren',
        u'unvergeßlicherer' : u'unvergesslicherer',
        u'unvergeßlicheres' : u'unvergesslicheres',
        u'unvergeßlichere'  : u'unvergesslichere',
        u'unvergeßlicher'   : u'unvergesslicher',
        u'unvergeßliches'   : u'unvergessliches',
        u'unvergeßliche'    : u'unvergessliche',
        u'unvergeßlichstem' : u'unvergesslichstem',
        u'unvergeßlichsten' : u'unvergesslichsten',
        u'unvergeßlichster' : u'unvergesslichster',
        u'unvergeßlichstes' : u'unvergesslichstes',
        u'unvergeßlichste'  : u'unvergesslichste',
        u'unvergeßlich'     : u'unvergesslich',
        u'unverläßlich'     : u'unverlässlich',
        u'vakuummeßröhren'  : u'vakuummessröhren',
        u'vakuummeßröhre'   : u'vakuummessröhre',
        u'varietees'        : u'varietés',
        u'varietee'         : u'varieté',
        u'vaterschaftsprozeß': u'vaterschaftsprozess',
        u'veränderungsprozeß': u'veränderungsprozess',
        u'veranlaßten'      : u'veranlassten',
        u'veranlaßtest'     : u'veranlasstest',
        u'veranlaßtet'      : u'veranlasstet',
        u'veranlaßte'       : u'veranlasste',
        u'veranlaßte'    : u'veranlasste',
        u'veranlaßt'        : u'veranlasst',
        u'veranlaß'         : u'veranlass',
        u'verantwortungsbewußtem': u'verantwortungsbewusstem',
        u'verantwortungsbewußten': u'verantwortungsbewussten',
        u'verantwortungsbewußterem': u'verantwortungsbewussterem',
        u'verantwortungsbewußteren': u'verantwortungsbewussteren',
        u'verantwortungsbewußterer': u'verantwortungsbewussterer',
        u'verantwortungsbewußteres': u'verantwortungsbewussteres',
        u'verantwortungsbewußtere': u'verantwortungsbewusstere',
        u'verantwortungsbewußter': u'verantwortungsbewusster',
        u'verantwortungsbewußtestem': u'verantwortungsbewusstestem',
        u'verantwortungsbewußtesten': u'verantwortungsbewusstesten',
        u'verantwortungsbewußtester': u'verantwortungsbewusstester',
        u'verantwortungsbewußtestes': u'verantwortungsbewusstestes',
        u'verantwortungsbewußteste': u'verantwortungsbewussteste',
        u'verantwortungsbewußtes': u'verantwortungsbewusstes',
        u'verantwortungsbewußte': u'verantwortungsbewusste',
        u'verantwortungsbewußtseins': u'verantwortungsbewusstseins',
        u'verantwortungsbewußtsein': u'verantwortungsbewusstsein',
        u'verantwortungsbewußt': u'verantwortungsbewusst',
        u'verbeßre'         : u'verbessre',
        u'verbißt'          : u'verbisst',
        u'verbiß'           : u'verbiss',
        u'verblaßtem'       : u'verblasstem',
        u'verblaßten'       : u'verblassten',
        u'verblaßterem'     : u'verblassterem',
        u'verblaßteren'     : u'verblassteren',
        u'verblaßterer'     : u'verblassterer',
        u'verblaßteres'     : u'verblassteres',
        u'verblaßtere'      : u'verblasstere',
        u'verblaßter'       : u'verblasster',
        u'verblaßtestem'    : u'verblasstestem',
        u'verblaßtesten'    : u'verblasstesten',
        u'verblaßtester'    : u'verblasstester',
        u'verblaßtestes'    : u'verblasstestes',
        u'verblaßteste'     : u'verblassteste',
        u'verblaßtes'       : u'verblasstes',
        u'verblaßte'        : u'verblasste',
        u'verblaßt'         : u'verblasst',
        u'verbleuend'       : u'verbläuend',
        u'verbleuen'        : u'verbläuen',
        u'verbleuest'       : u'verbläuest',
        u'verbleuet'        : u'verbläuet',
        u'verbleue'         : u'verbläue',
        u'verbleust'        : u'verbläust',
        u'verbleuten'       : u'verbläuten',
        u'verbleutest'      : u'verbläutest',
        u'verbleutet'       : u'verbläutet',
        u'verbleute'        : u'verbläute',
        u'verbleut'         : u'verbläut',
        u'verbleu'          : u'verbläu',
        u'verbrennungsprozeß': u'verbrennungsprozess',
        u'verbundschipaß'   : u'verbundschipass',
        u'verbundskipaß'    : u'verbundskipass',
        u'verdauungsprozeß' : u'verdauungsprozess',
        u'verdrängungsprozeß': u'verdrängungsprozess',
        u'verdroßt'         : u'verdrosst',
        u'verdroß'          : u'verdross',
        u'verdruß'          : u'verdruss',
        u'verdruß'       : u'verdruss',
        u'verfaßten'        : u'verfassten',
        u'verfaßtest'       : u'verfasstest',
        u'verfaßtet'        : u'verfasstet',
        u'verfaßte'         : u'verfasste',
        u'verfaßt'          : u'verfasst',
        u'verfaß'           : u'verfass',
        u'verfloß'          : u'verfloss',
        u'verfreßt'         : u'verfresst',
        u'verfrißt'         : u'verfrisst',
        u'verfriß'          : u'verfriss',
        u'vergeßlichem'     : u'vergesslichem',
        u'vergeßlichen'     : u'vergesslichen',
        u'vergeßlicherem'   : u'vergesslicherem',
        u'vergeßlicheren'   : u'vergesslicheren',
        u'vergeßlicherer'   : u'vergesslicherer',
        u'vergeßlicheres'   : u'vergesslicheres',
        u'vergeßlichere'    : u'vergesslichere',
        u'vergeßlicher'     : u'vergesslicher',
        u'vergeßliches'     : u'vergessliches',
        u'vergeßliche'      : u'vergessliche',
        u'vergeßlichkeit'   : u'vergesslichkeit',
        u'vergeßlichstem'   : u'vergesslichstem',
        u'vergeßlichsten'   : u'vergesslichsten',
        u'vergeßlichster'   : u'vergesslichster',
        u'vergeßlichstes'   : u'vergesslichstes',
        u'vergeßlichste'    : u'vergesslichste',
        u'vergeßlich'       : u'vergesslich',
        u'vergeßt'          : u'vergesst',
        u'vergißmeinnichten': u'vergissmeinnichten',
        u'vergißmeinnichtes': u'vergissmeinnichtes',
        u'vergißmeinnichte' : u'vergissmeinnichte',
        u'vergißmeinnichts' : u'vergissmeinnichts',
        u'vergißmeinnicht'  : u'vergissmeinnicht',
        u'vergißt'          : u'vergisst',
        u'vergißt'       : u'vergisst',
        u'vergiß'           : u'vergiss',
        u'vergiß'        : u'vergiss',
        u'vergoßt'          : u'vergosst',
        u'vergoß'           : u'vergoss',
        u'verhältniß'       : u'verhältnis',
        u'verhaßtem'        : u'verhasstem',
        u'verhaßten'        : u'verhassten',
        u'verhaßten'     : u'verhassten',
        u'verhaßterem'      : u'verhassterem',
        u'verhaßteren'      : u'verhassteren',
        u'verhaßterer'      : u'verhassterer',
        u'verhaßteres'      : u'verhassteres',
        u'verhaßtere'       : u'verhasstere',
        u'verhaßter'        : u'verhasster',
        u'verhaßtestem'     : u'verhasstestem',
        u'verhaßtesten'     : u'verhasstesten',
        u'verhaßtester'     : u'verhasstester',
        u'verhaßtestes'     : u'verhasstestes',
        u'verhaßteste'      : u'verhassteste',
        u'verhaßtes'        : u'verhasstes',
        u'verhaßte'         : u'verhasste',
        u'verhaßt'          : u'verhasst',
        u'verkehrsfluß'     : u'verkehrsfluss',
        u'verläßlichem'     : u'verlässlichem',
        u'verläßlichen'     : u'verlässlichen',
        u'verläßlicherem'   : u'verlässlicherem',
        u'verläßlicheren'   : u'verlässlicheren',
        u'verläßlicherer'   : u'verlässlicherer',
        u'verläßlicheres'   : u'verlässlicheres',
        u'verläßlichere'    : u'verlässlichere',
        u'verläßlicher'     : u'verlässlicher',
        u'verläßliches'     : u'verlässliches',
        u'verläßliche'      : u'verlässliche',
        u'verläßlichkeit'   : u'verlässlichkeit',
        u'verläßlichstem'   : u'verlässlichstem',
        u'verläßlichsten'   : u'verlässlichsten',
        u'verläßlichster'   : u'verlässlichster',
        u'verläßlichstes'   : u'verlässlichstes',
        u'verläßlichste'    : u'verlässlichste',
        u'verläßlich'       : u'verlässlich',
        u'verlaßt'          : u'verlasst',
        u'verläßt'          : u'verlässt',
        u'verläßt'       : u'verlässt',
        u'verlaß'           : u'verlass',
        u'verleumdungsprozeß': u'verleumdungsprozess',
        u'vermaßlest'       : u'vermasslest',
        u'vermaßlet'        : u'vermasslet',
        u'vermaßle'         : u'vermassle',
        u'vermeßt'          : u'vermesst',
        u'vermißtem'        : u'vermisstem',
        u'vermißtenanzeigen': u'vermisstenanzeigen',
        u'vermißtenanzeige' : u'vermisstenanzeige',
        u'vermißtenfällen'  : u'vermisstenfällen',
        u'vermißtenfalles'  : u'vermisstenfalles',
        u'vermißtenfalle'   : u'vermisstenfalle',
        u'vermißtenfälle'   : u'vermisstenfälle',
        u'vermißtenfalls'   : u'vermisstenfalls',
        u'vermißtenfall'    : u'vermisstenfall',
        u'vermißten'        : u'vermissten',
        u'vermißter'        : u'vermisster',
        u'vermißtest'       : u'vermisstest',
        u'vermißtes'        : u'vermisstes',
        u'vermißtet'        : u'vermisstet',
        u'vermißte'         : u'vermisste',
        u'vermißte'      : u'vermisste',
        u'vermißt'          : u'vermisst',
        u'vermißt'       : u'vermisst',
        u'vermiß'           : u'vermiss',
        u'vermittlungsausschuß': u'vermittlungsausschuss',
        u'vermuthend'       : u'vermutend',
        u'vermuthen'        : u'vermuten',
        u'vermuthest'       : u'vermutest',
        u'vermutheten'      : u'vermuteten',
        u'vermuthetest'     : u'vermutetest',
        u'vermuthetet'      : u'vermutetet',
        u'vermuthete'       : u'vermutete',
        u'vermuthet'        : u'vermutet',
        u'vermuthe'         : u'vermute',
        u'vermuth'          : u'vermut',
        u'verpaßten'        : u'verpassten',
        u'verpaßtest'       : u'verpasstest',
        u'verpaßtet'        : u'verpasstet',
        u'verpaßte'         : u'verpasste',
        u'verpaßt'          : u'verpasst',
        u'verpaß'           : u'verpass',
        u'verpißten'        : u'verpissten',
        u'verpißtest'       : u'verpisstest',
        u'verpißtet'        : u'verpisstet',
        u'verpißte'         : u'verpisste',
        u'verpißt'          : u'verpisst',
        u'verpiß'           : u'verpiss',
        u'verpraßt'         : u'verprasst',
        u'verrißt'          : u'verrisst',
        u'verriß'           : u'verriss',
        u'verschißt'        : u'verschisst',
        u'verschiß'         : u'verschiss',
        u'verschleißprozeß' : u'verschleißprozess',
        u'verschlimmbeßre'  : u'verschlimmbessre',
        u'verschlißt'       : u'verschlisst',
        u'verschliß'        : u'verschliss',
        u'verschloßt'       : u'verschlosst',
        u'verschloß'        : u'verschloss',
        u'verschlußdeckel'  : u'verschlussdeckel',
        u'verschlußkappe'   : u'verschlusskappe',
        u'verschlußlauten'  : u'verschlusslauten',
        u'verschlußlautes'  : u'verschlusslautes',
        u'verschlußlaute'   : u'verschlusslaute',
        u'verschlußlauts'   : u'verschlusslauts',
        u'verschlußlaut'    : u'verschlusslaut',
        u'verschlüßlest'    : u'verschlüsslest',
        u'verschlüßlet'     : u'verschlüsslet',
        u'verschlüßle'      : u'verschlüssle',
        u'verschlußsachen'  : u'verschlusssachen',
        u'verschlußsache'   : u'verschlusssache',
        u'verschlußschraube': u'verschlussschraube',
        u'verschlußstreifen': u'verschlussstreifen',
        u'verschluß'        : u'verschluss',
        u'verschlußzeit'    : u'verschlusszeit',
        u'verschoßt'        : u'verschosst',
        u'verschoß'         : u'verschoss',
        u'versicherungsmißbrauch': u'versicherungsmissbrauch',
        u'versorgungsengpaß': u'versorgungsengpass',
        u'versorgungsgenuß' : u'versorgungsgenuss',
        u'versplißt'        : u'versplisst',
        u'verspliß'         : u'verspliss',
        u'vertelephonierendem': u'vertelefonierendem',
        u'vertelephonierenden': u'vertelefonierenden',
        u'vertelephonierender': u'vertelefonierender',
        u'vertelephonierendes': u'vertelefonierendes',
        u'vertelephonierende': u'vertelefonierende',
        u'vertelephonierend': u'vertelefonierend',
        u'vertelephonieren' : u'vertelefonieren',
        u'vertelephonierest': u'vertelefonierest',
        u'vertelephonieret' : u'vertelefonieret',
        u'vertelephoniere'  : u'vertelefoniere',
        u'vertelephonierst' : u'vertelefonierst',
        u'vertelephoniertem': u'vertelefoniertem',
        u'vertelephonierten': u'vertelefonierten',
        u'vertelephonierter': u'vertelefonierter',
        u'vertelephoniertest': u'vertelefoniertest',
        u'vertelephoniertes': u'vertelefoniertes',
        u'vertelephoniertet': u'vertelefoniertet',
        u'vertelephonierte' : u'vertelefonierte',
        u'vertelephoniert'  : u'vertelefoniert',
        u'vertelephonier'   : u'vertelefonier',
        u'vertragsabschluß' : u'vertragsabschluss',
        u'vertragsschluß'   : u'vertragsschluss',
        u'vertrauensvorschuß': u'vertrauensvorschuss',
        u'verwäßre'         : u'verwässre',
        u'vierpaß'          : u'vierpass',
        u'viertkläßlern'    : u'viertklässlern',
        u'viertkläßlers'    : u'viertklässlers',
        u'viertkläßler'     : u'viertklässler',
        u'violettönen'      : u'violetttönen',
        u'violettones'      : u'violetttones',
        u'violettone'       : u'violetttone',
        u'violettöne'       : u'violetttöne',
        u'violettons'       : u'violetttons',
        u'violetton'        : u'violettton',
        u'vocalen'          : u'vokalen',
        u'vocale'           : u'vokale',
        u'vocals'           : u'vokals',
        u'vocal'            : u'vokal',
        u'vocativen'        : u'vokativen',
        u'vocative'         : u'vokative',
        u'vocativs'         : u'vokativs',
        u'vocativ'          : u'vokativ',
        u'vogelschiß'       : u'vogelschiss',
        u'volkskongreß'     : u'volkskongress',
        u'volksmässig'      : u'volksmäßig',
        u'volladen'         : u'vollladen',
        u'vollasten'        : u'volllasten',
        u'vollast'          : u'volllast',
        u'vollaufen'        : u'volllaufen',
        u'vollauten'        : u'volllauten',
        u'vollautes'        : u'volllautes',
        u'vollaute'         : u'volllaute',
        u'vollauts'         : u'volllauts',
        u'vollaut'          : u'volllaut',
        u'volleibig'        : u'vollleibig',
        u'vollgeschoß'      : u'vollgeschoss',
        u'vollkomne'        : u'vollkommne',
        u'vollschißt'       : u'vollschisst',
        u'vollschiß'        : u'vollschiss',
        u'vonnöthen'        : u'vonnöten',
        u'vorgefaßtem'      : u'vorgefasstem',
        u'vorgefaßten'      : u'vorgefassten',
        u'vorgefaßterem'    : u'vorgefassterem',
        u'vorgefaßteren'    : u'vorgefassteren',
        u'vorgefaßterer'    : u'vorgefassterer',
        u'vorgefaßteres'    : u'vorgefassteres',
        u'vorgefaßtere'     : u'vorgefasstere',
        u'vorgefaßter'      : u'vorgefasster',
        u'vorgefaßtestem'   : u'vorgefasstestem',
        u'vorgefaßtesten'   : u'vorgefasstesten',
        u'vorgefaßtester'   : u'vorgefasstester',
        u'vorgefaßtestes'   : u'vorgefasstestes',
        u'vorgefaßteste'    : u'vorgefassteste',
        u'vorgefaßtes'      : u'vorgefasstes',
        u'vorgefaßte'       : u'vorgefasste',
        u'vorgefaßt'        : u'vorgefasst',
        u'vorhängeschloß'   : u'vorhängeschloss',
        u'vorhangschloß'    : u'vorhangschloss',
        u'vorlagenmißbrauch': u'vorlagenmissbrauch',
        u'vorlaßt'          : u'vorlasst',
        u'vorläßt'          : u'vorlässt',
        u'vorlegeschloß'    : u'vorlegeschloss',
        u'vorschlußrunden'  : u'vorschlussrunden',
        u'vorschlußrunde'   : u'vorschlussrunde',
        u'vorschoßt'        : u'vorschosst',
        u'vorschoß'         : u'vorschoss',
        u'vorschußlorbeeren': u'vorschusslorbeeren',
        u'vorschuß'         : u'vorschuss',
        u'vorschußweise'    : u'vorschussweise',
        u'vorschußzahlung'  : u'vorschusszahlung',
        u'vorschußzinsen'   : u'vorschusszinsen',
        u'vorschußzinses'   : u'vorschusszinses',
        u'vorschußzinse'    : u'vorschusszinse',
        u'vorschußzins'     : u'vorschusszins',
        u'wachgeküßt'       : u'wachgeküsst',
        u'wachküßten'       : u'wachküssten',
        u'wachküßtest'      : u'wachküsstest',
        u'wachküßtet'       : u'wachküsstet',
        u'wachküßte'        : u'wachküsste',
        u'wachküßt'         : u'wachküsst',
        u'wachsabguß'       : u'wachsabguss',
        u'wachsthums'       : u'wachstums',
        u'wachsthum'        : u'wachstum',
        u'wachstumsprozeß'  : u'wachstumsprozess',
        u'wächten'          : u'wechten',
        u'wächte'           : u'wechte',
        u'waffenpaß'        : u'waffenpass',
        u'wagen'            : u'waagen',
        u'wage'             : u'waage',
        u'wahlausschuß'     : u'wahlausschuss',
        u'wählscheibentelephonen': u'wählscheibentelefonen',
        u'wählscheibentelephone': u'wählscheibentelefone',
        u'wählscheibentelephons': u'wählscheibentelefons',
        u'wählscheibentelephon': u'wählscheibentelefon',
        u'waldschlußzeiten' : u'waldschlusszeiten',
        u'waldschlußzeit'   : u'waldschlusszeit',
        u'walke'            : u'walk',
        u'walkfaß'          : u'walkfass',
        u'wallfisch'        : u'walfisch',
        u'walnußbäumen'     : u'walnussbäumen',
        u'walnußbaumes'     : u'walnussbaumes',
        u'walnußbaume'      : u'walnussbaume',
        u'walnußbäume'      : u'walnussbäume',
        u'walnußbaums'      : u'walnussbaums',
        u'walnußbaum'       : u'walnussbaum',
        u'walnußschalen'    : u'walnussschalen',
        u'walnußschale'     : u'walnussschale',
        u'walnuß'           : u'walnuss',
        u'walroß'           : u'walross',
        u'walther'       : u'walter',
        u'wandalen'         : u'vandalen',
        u'wandale'          : u'vandale',
        u'wandalierend'     : u'vandalierend',
        u'wandalieren'      : u'vandalieren',
        u'wandalierest'     : u'vandalierest',
        u'wandalieret'      : u'vandalieret',
        u'wandaliere'       : u'vandaliere',
        u'wandalierst'      : u'vandalierst',
        u'wandalierten'     : u'vandalierten',
        u'wandaliertest'    : u'vandaliertest',
        u'wandaliertet'     : u'vandaliertet',
        u'wandalierte'      : u'vandalierte',
        u'wandaliert'       : u'vandaliert',
        u'wandalier'        : u'vandalier',
        u'wandalismussicherungen': u'vandalismussicherungen',
        u'wandalismussicherung': u'vandalismussicherung',
        u'wandalismus'      : u'vandalismus',
        u'wandlungsprozeß'  : u'wandlungsprozess',
        u'warnschuß'        : u'warnschuss',
        u'wasseranschluß'   : u'wasseranschluss',
        u'wasserfaß'        : u'wasserfass',
        u'wasserschloß'     : u'wasserschloss',
        u'waßrest'          : u'wassrest',
        u'waßret'           : u'wassret',
        u'waßre'            : u'wassre',
        u'wäßre'            : u'wässre',
        u'wäßrigem'         : u'wässrigem',
        u'wäßrigen'         : u'wässrigen',
        u'wäßrigerem'       : u'wässrigerem',
        u'wäßrigeren'       : u'wässrigeren',
        u'wäßrigerer'       : u'wässrigerer',
        u'wäßrigeres'       : u'wässrigeres',
        u'wäßrigere'        : u'wässrigere',
        u'wäßriger'         : u'wässriger',
        u'wäßriges'         : u'wässriges',
        u'wäßrige'          : u'wässrige',
        u'wäßrigkeit'       : u'wässrigkeit',
        u'wäßrigstem'       : u'wässrigstem',
        u'wäßrigsten'       : u'wässrigsten',
        u'wäßrigster'       : u'wässrigster',
        u'wäßrigstes'       : u'wässrigstes',
        u'wäßrigste'        : u'wässrigste',
        u'wäßrig'           : u'wässrig',
        u'wechselprozeß'    : u'wechselprozess',
        u'wechselregreß'    : u'wechselregress',
        u'weggemußt'        : u'weggemusst',
        u'weglaßproben'     : u'weglassproben',
        u'weglaßprobe'      : u'weglassprobe',
        u'weglaßt'          : u'weglasst',
        u'wegläßt'          : u'weglässt',
        u'wegschmißt'       : u'wegschmisst',
        u'wegschmiß'        : u'wegschmiss',
        u'wehrpaß'          : u'wehrpass',
        u'weidenruthe'      : u'weidenrute',
        u'weinfaß'          : u'weinfass',
        u'weißfluß'         : u'weißfluss',
        u'weißrußlands'     : u'weißrusslands',
        u'weißrußland'      : u'weißrussland',
        u'weisst'           : u'weißt',
        u'weitereßt'        : u'weiteresst',
        u'weitergemußt'     : u'weitergemusst',
        u'weitergewußt'     : u'weitergewusst',
        u'weiterißt'        : u'weiterisst',
        u'weitermußten'     : u'weitermussten',
        u'weitermüßten'     : u'weitermüssten',
        u'weitermußtest'    : u'weitermusstest',
        u'weitermüßtest'    : u'weitermüsstest',
        u'weitermußtet'     : u'weitermusstet',
        u'weitermüßtet'     : u'weitermüsstet',
        u'weitermußte'      : u'weitermusste',
        u'weitermüßte'      : u'weitermüsste',
        u'weitermußt'       : u'weitermusst',
        u'weitermüßt'       : u'weitermüsst',
        u'weitermuß'        : u'weitermuss',
        u'weiterwißt'       : u'weiterwisst',
        u'weiterwußten'     : u'weiterwussten',
        u'weiterwüßten'     : u'weiterwüssten',
        u'weiterwußtest'    : u'weiterwusstest',
        u'weiterwüßtest'    : u'weiterwüsstest',
        u'weiterwußtet'     : u'weiterwusstet',
        u'weiterwüßtet'     : u'weiterwüsstet',
        u'weiterwußte'      : u'weiterwusste',
        u'weiterwüßte'      : u'weiterwüsste',
        u'weitschuß'        : u'weitschuss',
        u'weltprozeß'       : u'weltprozess',
        u'werkstatterminen' : u'werkstattterminen',
        u'werkstattermines' : u'werkstatttermines',
        u'werkstattermine'  : u'werkstatttermine',
        u'werkstattermins'  : u'werkstatttermins',
        u'werkstattermin'   : u'werkstatttermin',
        u'werkstofforschung': u'werkstoffforschung',
        u'werthhaltig'      : u'werthaltig',
        u'werth'            : u'wert',
        u'weßhalb'       : u'weshalb',
        u'westgothen'       : u'westgoten',
        u'westgothe'        : u'westgote',
        u'wettauchen'       : u'wetttauchen',
        u'wetteufel'        : u'wettteufel',
        u'wetturnen'        : u'wettturnen',
        u'wiktionary:teestube/archiv/2016/10': u'teestube/archiv/2016/10',
        u'willensbildungsprozeß': u'willensbildungsprozess',
        u'winterschlußverkäufen': u'winterschlussverkäufen',
        u'winterschlußverkaufes': u'winterschlussverkaufes',
        u'winterschlußverkaufe': u'winterschlussverkaufe',
        u'winterschlußverkäufe': u'winterschlussverkäufe',
        u'winterschlußverkaufs': u'winterschlussverkaufs',
        u'winterschlußverkauf': u'winterschlussverkauf',
        u'wirthen'          : u'wirten',
        u'wirthes'          : u'wirtes',
        u'wirthe'           : u'wirte',
        u'wirths'           : u'wirts',
        u'wirth'            : u'wirt',
        u'wirtschaftsausschuß': u'wirtschaftsausschuss',
        u'wischmops'        : u'wischmopps',
        u'wischmop'         : u'wischmopp',
        u'wißbegierde'      : u'wissbegierde',
        u'wißbegierigem'    : u'wissbegierigem',
        u'wißbegierigen'    : u'wissbegierigen',
        u'wißbegierigerem'  : u'wissbegierigerem',
        u'wißbegierigeren'  : u'wissbegierigeren',
        u'wißbegierigerer'  : u'wissbegierigerer',
        u'wißbegierigeres'  : u'wissbegierigeres',
        u'wißbegierigere'   : u'wissbegierigere',
        u'wißbegieriger'    : u'wissbegieriger',
        u'wißbegieriges'    : u'wissbegieriges',
        u'wißbegierige'     : u'wissbegierige',
        u'wißbegierigstem'  : u'wissbegierigstem',
        u'wißbegierigsten'  : u'wissbegierigsten',
        u'wißbegierigster'  : u'wissbegierigster',
        u'wißbegierigstes'  : u'wissbegierigstes',
        u'wißbegierigste'   : u'wissbegierigste',
        u'wißbegierig'      : u'wissbegierig',
        u'wißbegier'        : u'wissbegier',
        u'wißt'             : u'wisst',
        u'wißt'          : u'wisst',
        u'witterungseinfluß': u'witterungseinfluss',
        u'wochenfluß'       : u'wochenfluss',
        u'wohlfahrtsausschuß': u'wohlfahrtsausschuss',
        u'wollappen'        : u'wolllappen',
        u'wolläusen'        : u'wollläusen',
        u'wolläuse'         : u'wollläuse',
        u'wollaus'          : u'wolllaus',
        u'wünschelruthen'   : u'wünschelruten',
        u'wünschelruthe'    : u'wünschelrute',
        u'wußten'           : u'wussten',
        u'wußten'        : u'wussten',
        u'wüßten'           : u'wüssten',
        u'wüßten'        : u'wüssten',
        u'wußtest'          : u'wusstest',
        u'wüßtest'          : u'wüsstest',
        u'wußtet'           : u'wusstet',
        u'wüßtet'           : u'wüsstet',
        u'wußte'            : u'wusste',
        u'wußte'         : u'wusste',
        u'wüßte'            : u'wüsste',
        u'wüßte'         : u'wüsste',
        u'yaleschloß'       : u'yaleschloss',
        u'yoghurtbechern'   : u'joghurtbechern',
        u'yoghurtbechers'   : u'joghurtbechers',
        u'yoghurtbecher'    : u'joghurtbecher',
        u'yoghurts'         : u'joghurts',
        u'yoghurt'          : u'joghurt',
        u'zäheit'           : u'zähheit',
        u'zahlenschloß'     : u'zahlenschloss',
        u'zahlungsbilanzüberschuß': u'zahlungsbilanzüberschuss',
        u'zahlungsfluß'     : u'zahlungsfluss',
        u'zärter'           : u'zarter',
        u'zärtesten'        : u'zartesten',
        u'zaubernuß'        : u'zaubernuss',
        u'zechenstillegung' : u'zechenstilllegung',
        u'zeckenbiß'        : u'zeckenbiss',
        u'zeilengußmaschine': u'zeilengussmaschine',
        u'zellehre'         : u'zelllehre',
        u'zellstoffabrik'   : u'zellstofffabrik',
        u'zentralausschuß'  : u'zentralausschuss',
        u'zentralrußlands'  : u'zentralrusslands',
        u'zentralrußland'   : u'zentralrussland',
        u'zerbißt'          : u'zerbisst',
        u'zerbiß'           : u'zerbiss',
        u'zerfallsprozeß'   : u'zerfallsprozess',
        u'zerfloßt'         : u'zerflosst',
        u'zerfloß'          : u'zerfloss',
        u'zerfreßt'         : u'zerfresst',
        u'zerfrißt'         : u'zerfrisst',
        u'zerfriß'          : u'zerfriss',
        u'zerlaßt'          : u'zerlasst',
        u'zerläßt'          : u'zerlässt',
        u'zerlaß'           : u'zerlass',
        u'zerrißt'          : u'zerrisst',
        u'zerriß'           : u'zerriss',
        u'zerriß'        : u'zerriss',
        u'zerschlißt'       : u'zerschlisst',
        u'zerschliß'        : u'zerschliss',
        u'zerschmißt'       : u'zerschmisst',
        u'zerschmiß'        : u'zerschmiss',
        u'zerschoßt'        : u'zerschosst',
        u'zerschoß'         : u'zerschoss',
        u'zersetzungsprozeß': u'zersetzungsprozess',
        u'zielbewußtem'     : u'zielbewusstem',
        u'zielbewußten'     : u'zielbewussten',
        u'zielbewußterem'   : u'zielbewussterem',
        u'zielbewußteren'   : u'zielbewussteren',
        u'zielbewußterer'   : u'zielbewussterer',
        u'zielbewußteres'   : u'zielbewussteres',
        u'zielbewußtere'    : u'zielbewusstere',
        u'zielbewußter'     : u'zielbewusster',
        u'zielbewußtestem'  : u'zielbewusstestem',
        u'zielbewußtesten'  : u'zielbewusstesten',
        u'zielbewußtester'  : u'zielbewusstester',
        u'zielbewußtestes'  : u'zielbewusstestes',
        u'zielbewußteste'   : u'zielbewussteste',
        u'zielbewußtes'     : u'zielbewusstes',
        u'zielbewußte'      : u'zielbewusste',
        u'zielbewußte'   : u'zielbewusste',
        u'zielbewußtheit'   : u'zielbewusstheit',
        u'zielbewußt'       : u'zielbewusst',
        u'zielphotos'       : u'zielfotos',
        u'zielphoto'        : u'zielfoto',
        u'zierat'           : u'zierrat',
        u'zippverschluß'    : u'zippverschluss',
        u'zirbelnuß'        : u'zirbelnuss',
        u'zirkelschluß'     : u'zirkelschluss',
        u'zivilprozeßordnung': u'zivilprozessordnung',
        u'zivilprozeßrecht' : u'zivilprozessrecht',
        u'zivilprozeß'      : u'zivilprozess',
        u'zollang'          : u'zolllang',
        u'zollinie'         : u'zolllinie',
        u'zubißt'           : u'zubisst',
        u'zubiß'            : u'zubiss',
        u'zuckerguß'        : u'zuckerguss',
        u'zuckerpaß'        : u'zuckerpass',
        u'zufloßt'          : u'zuflosst',
        u'zufloß'           : u'zufloss',
        u'zufluß'           : u'zufluss',
        u'zugepaßt'         : u'zugepasst',
        u'zugepreßt'        : u'zugepresst',
        u'zugschlußsignalen': u'zugschlusssignalen',
        u'zugschlußsignale' : u'zugschlusssignale',
        u'zugschlußsignals' : u'zugschlusssignals',
        u'zugschlußsignal'  : u'zugschlusssignal',
        u'zulaßt'           : u'zulasst',
        u'zuläßt'           : u'zulässt',
        u'zündschloß'       : u'zündschloss',
        u'zungenkuß'        : u'zungenkuss',
        u'zupaßgekommen'    : u'zupassgekommen',
        u'zupaßkamen'       : u'zupasskamen',
        u'zupaßkämen'       : u'zupasskämen',
        u'zupaßkämest'      : u'zupasskämest',
        u'zupaßkämet'       : u'zupasskämet',
        u'zupaßkäme'        : u'zupasskäme',
        u'zupaßkamst'       : u'zupasskamst',
        u'zupaßkämst'       : u'zupasskämst',
        u'zupaßkamt'        : u'zupasskamt',
        u'zupaßkämt'        : u'zupasskämt',
        u'zupaßkam'         : u'zupasskam',
        u'zupaßkommend'     : u'zupasskommend',
        u'zupaßkommest'     : u'zupasskommest',
        u'zupaßkommet'      : u'zupasskommet',
        u'zupaßkomme'       : u'zupasskomme',
        u'zupaßkommst'      : u'zupasskommst',
        u'zupaßkommt'       : u'zupasskommt',
        u'zupaßzukommen'    : u'zupasszukommen',
        u'zurückgemußt'     : u'zurückgemusst',
        u'zusammenfaßten'   : u'zusammenfassten',
        u'zusammenfaßtest'  : u'zusammenfasstest',
        u'zusammenfaßtet'   : u'zusammenfasstet',
        u'zusammenfaßte'    : u'zusammenfasste',
        u'zusammenfaßt'     : u'zusammenfasst',
        u'zusammenfloßt'    : u'zusammenflosst',
        u'zusammenfloß'     : u'zusammenfloss',
        u'zusammenfluß'     : u'zusammenfluss',
        u'zusammengefaßtem' : u'zusammengefasstem',
        u'zusammengefaßten' : u'zusammengefassten',
        u'zusammengefaßter' : u'zusammengefasster',
        u'zusammengefaßtes' : u'zusammengefasstes',
        u'zusammengefaßte'  : u'zusammengefasste',
        u'zusammengefaßt'   : u'zusammengefasst',
        u'zusammengepaßt'   : u'zusammengepasst',
        u'zusammengepreßt'  : u'zusammengepresst',
        u'zusammenpreßten'  : u'zusammenpressten',
        u'zusammenpreßtest' : u'zusammenpresstest',
        u'zusammenpreßtet'  : u'zusammenpresstet',
        u'zusammenpreßte'   : u'zusammenpresste',
        u'zusammenpreßt'    : u'zusammenpresst',
        u'zusammenrißt'     : u'zusammenrisst',
        u'zusammenriß'      : u'zusammenriss',
        u'zusammenschloßt'  : u'zusammenschlosst',
        u'zusammenschloß'   : u'zusammenschloss',
        u'zusammenschluß'   : u'zusammenschluss',
        u'zuschloßt'        : u'zuschlosst',
        u'zuschloß'         : u'zuschloss',
        u'zuschoßt'         : u'zuschosst',
        u'zuschoß'          : u'zuschoss',
        u'zuschußanträgen'  : u'zuschussanträgen',
        u'zuschußantrages'  : u'zuschussantrages',
        u'zuschußantrage'   : u'zuschussantrage',
        u'zuschußanträge'   : u'zuschussanträge',
        u'zuschußantrags'   : u'zuschussantrags',
        u'zuschußantrag'    : u'zuschussantrag',
        u'zuschußbetrieb'   : u'zuschussbetrieb',
        u'zuschußbogen'     : u'zuschussbogen',
        u'zuschuß'          : u'zuschuss',
        u'zuschußwirtschaft': u'zuschusswirtschaft',
        u'zuthuns'          : u'zutuns',
        u'zuthun'           : u'zutun',
        u'zweitkläßlerinnen': u'zweitklässlerinnen',
        u'zweitkläßlerin'   : u'zweitklässlerin',
        u'zweitkläßlern'    : u'zweitklässlern',
        u'zweitkläßlers'    : u'zweitklässlers',
        u'zweitkläßler'     : u'zweitklässler',
        u'zweitplaciert'    : u'zweitplatziert',
        u'zweitplaziertem'  : u'zweitplatziertem',
        u'zweitplazierten'  : u'zweitplatzierten',
        u'zweitplazierter'  : u'zweitplatzierter',
        u'zweitplazierte'   : u'zweitplatzierte',
        u'zweitplaziert'    : u'zweitplatziert',
        u'zweyen'           : u'zweien',
        u'zweyer'           : u'zweier',
        u'zweye'            : u'zweie',
        u'zwey'             : u'zwei',
        u'zwillingsfluß'    : u'zwillingsfluss',
        u'zwischengeschoß'  : u'zwischengeschoss',
        u'zylinderschloß'   : u'zylinderschloss',

        # umlauts...

        u'aendern'             : u'ändern',
        u'aerztin'             : u'ärztin',
        u'aufraeumt'           : u'aufräumt',
        u'aufzaehlen'          : u'aufzählen',
        u'beschaeftigt'        : u'beschäftigt',
        u'daemlich'            : u'dämlich',
        u'daemliche'           : u'dämliche',
        u'erklaeren'           : u'erklären',
        u'erklaerung'          : u'erklärung',
        u'erzaehl'             : u'erzähl',
        u'erzaehle'            : u'erzähle',
        u'erzaehlen'           : u'erzählen',
        u'erzaehlt'            : u'erzählt',
        u'faellt'              : u'fällt',
        u'faengst'             : u'fängst',
        u'gefaellt'            : u'gefällt',
        u'gespraech'           : u'gespräch',
        u'gespraechig'         : u'gesprächig',
        u'haeltst'             : u'hältst',
        u'haende'              : u'hände',
        u'haesslich'           : u'hässlich',
        u'haesslicher'         : u'hässlicher',
        u'haette'              : u'hätte',
        u'haettest'            : u'hättest',
        u'laecherlich'         : u'lächerlich',
        u'laender'             : u'länder',
        u'laeufst'             : u'läufst',
        u'laeuft'              : u'läuft',
        u'lernfaehig'          : u'lernfähig',
        u'liebesfaehig'        : u'liebesfähig',
        u'maedchen'            : u'mädchen',
        u'maenner'             : u'männer',
        u'maennlich'           : u'männlich',
        u'maerchen'            : u'märchen',
        u'naechste'            : u'nächste',
        u'naechsten'           : u'nächsten',
        u'naechstes'           : u'nächstes',
        u'relativitaetstheorie': u'relativitätstheorie',
        u'saetze'              : u'sätze',
        u'schaetze'            : u'schätze',
        u'schlaefst'           : u'schläfst',
        u'spaet'               : u'spät',
        u'taeglich'            : u'täglich',
        u'traegst'             : u'trägst',
        u'traeume'             : u'träume',
        u'traeumen'            : u'träumen',
        u'ungefaehr'           : u'ungefähr',
        u'waehl'               : u'wähl',
        u'waehle'              : u'wähle',
        u'weitererzaehlen'     : u'weitererzählen',

        u'bloed'             : u'blöd',
        u'bloede'            : u'blöde',
        u'bloedes'           : u'blödes',
        u'bloedsinn'         : u'blödsinn',
        u'boese'             : u'böse',
        u'doener'            : u'döner',
        u'franzoesisch'      : u'französisch',
        u'froehlich'         : u'fröhlich',
        u'gehoert'           : u'gehört',
        u'hoechste'          : u'höchste',
        u'hoeflich'          : u'höflich',
        u'hoeflicher'        : u'höflicher',
        u'hoelle'            : u'hölle',
        u'hoer'              : u'hör',
        u'hoere'             : u'höre',
        u'hoeren'            : u'hören',
        u'hoerst'            : u'hörst',
        u'koennen'           : u'können',
        u'koennte'           : u'könnte',
        u'koenntest'         : u'könntest',
        u'koerperlich'       : u'körperlich',
        u'koerper'           : u'körper',
        u'loewe'             : u'löwe',
        u'moechte'           : u'möchte',
        u'moechtest'         : u'möchtest',
        u'moeglich'          : u'möglich',
        u'moeglichkeit'      : u'möglichkeit',
        u'monroe'            : u'monrö',
        u'noetig'            : u'nötig',
        u'oefter'            : u'öfter',
        u'oefters'           : u'öfters',
        u'schluesselwoerter' : u'schluesselwörter',
        u'schoenen'          : u'schönen',
        u'schoene'           : u'schöne',
        u'schoen'            : u'schön',
        u'schoepfer'         : u'schöpfer',
        u'schroeder'         : u'schröder',
        u'stoert'            : u'stört',
        u'unmoeglich'        : u'unmöglich',
        u'verhoer'           : u'verhör',
        u'voellig'           : u'völlig',
        u'woerter'           : u'wörter',
        u'zuhoeren'          : u'zuhören',

        u'betruege'         : u'betrüge',
        u'buecher'          : u'bücher',
        u'bueck'            : u'bück',
        u'darueber'         : u'darüber',
        u'duesseldorf'      : u'düsseldorf',
        u'fuehle'           : u'fühle',
        u'fuehlen'          : u'fühlen',
        u'fuehlst'          : u'fühlst',
        u'fuehlt'           : u'fühlt',
        u'fuenf'            : u'fünf',
        u'fuer'             : u'für',
        u'fuessen'          : u'füssen',
        u'gefuehl'          : u'gefühl',
        u'gefuehle'         : u'gefühle',
        u'gegenueber'       : u'gegenüber',
        u'geruecht'         : u'gerücht',
        u'gluecklich'       : u'glücklich',
        u'gruen'            : u'grün',
        u'gruenen'          : u'grünen',
        u'gruener'          : u'grüner',
        u'huebsch'          : u'hübsch',
        u'kluegste'         : u'klügste',
        u'kuenstlich'       : u'künstlich',
        u'kuenstliche'      : u'künstliche',
        u'luegen'           : u'lügen',
        u'luegner'          : u'lügner',
        u'luegst'           : u'lügst',
        u'muede'            : u'müde',
        u'muelheim'         : u'mülheim',
        u'muelltonne'       : u'mülltonne',
        u'muesstest'        : u'müsstest',
        u'natuerlich'       : u'natürlich',
        u'saarbruecken'     : u'saarbrücken',
        u'schluesselwoerter': u'schlüsselwörter',
        u'schuechtern'      : u'schüchtern',
        u'schueler'         : u'schüler',
        u'schuetze'         : u'schütze',
        u'sebstbezueglich'  : u'sebstbezüglich',
        u'spruenge'         : u'sprünge',
        u'suess'            : u'süß',
        u'tschuess'         : u'tschüss',
        u'tuerkisch'        : u'türkisch',
        u'ueber'            : u'über',
        u'ueberall'         : u'überall',
        u'ueberhaupt'       : u'überhaupt',
        u'uebersetzer'      : u'übersetzer',
        u'uebersetzt'       : u'übersetzt',
        u'verrueckt'        : u'verrückt',
        u'wofuer'           : u'wofür',
        u'worueber'         : u'worüber',
        u'wuerde'           : u'würde',
        u'wuerdest'         : u'würdest',
        u'wuesste'          : u'wüsste',
        u'wuetend'          : u'wütend',
        u'zuerich'          : u'zürich',
        u'zurueck'          : u'zurück',
        u'zusammengepreßten': u'zusammengepressten',

        u'swr3'             : u'swr drei',
        u'zx81'             : u'zx einundachtzig',


        u'§'                : u'paragraph'}


symb_abbrev_norm = [
        (u'Abk.'    , u'abkürzung '),
        (u'Abk '    , u'abkürzung '),
        (u'Prof.'   , u'professor '),
        (u'Dipl.'   , u'diplom '),
        (u'Ing.'    , u'ingenieur '),
        (u'Inf.'    , u'informatiker '),
        (u'Inform.' , u'informatiker '),
        (u'Tel.'    , u'telefon '),
        (u'bzw.'    , u'beziehungsweise '),
        (u'bzw '    , u'beziehungsweise '),
        (u'bspw.'   , u'beispielsweise '),
        (u'bspw '   , u'beispielsweise '),
        (u'bzgl.'   , u'bezüglich '),
        (u'ca.'     , u'circa '),
        (u'd.h.'    , u'das heißt '),
        (u'd. h.'   , u'das heißt '),
        (u'Dr. '    , u'doktor '),
        (u'evtl.'   , u'eventuell '),
        (u'evtl '   , u'eventuell '),
        (u'geb.'    , u'geborene '),
        (u'ggf.'    , u'gegebenenfalls '),
        (u'ggf '    , u'gegebenenfalls '),
        (u'kath.'   , u'katholische '),
        (u'Hrsg.'   , u'herausgeber '),
        (u'Mr.'     , u'mister '),
        (u'Mrd.'    , u'milliarden '),
        (u'Mrs.'    , u'misses '),
        (u'Nr.'     , u'nummer '),
        (u'Nrn.'    , u'nummern '),
        (u'o.k.'    , u'okay '),
        (u'o. k.'   , u'okay '),
        (u's.a.'    , u'siehe auch '),
        (u's. a.'   , u'siehe auch '),
        (u's.o.'    , u'siehe oben '),
        (u's. o.'   , u'siehe oben '),
        (u's.u.'    , u'siehe unten '),
        (u's. u.'   , u'siehe unten '),
        (u'jr.'     , u'junior '),
        (u'Str.'    , u'strasse '),
        (u'u.a.'    , u'unter anderem '),
        (u'u. a.'   , u'unter anderem '),
        (u'u.U.'    , u'unter umständen '),
        (u'u. U.'   , u'unter umständen '),
        (u'usw.'    , u'und so weiter '),
        (u'u.s.w.'  , u'und so weiter '),
        (u'u. s. w.', u'und so weiter '),
        (u'v.a.'    , u'vor allem '),
        (u'vgl.'    , u'vergleiche '),
        (u'vgl '    , u'vergleiche '),
        (u'Wdh.'    , u'wiederholung '),
        (u'Ziff.'   , u'ziffer '),
        (u'z.B.'    , u'zum beispiel '),
        (u'z. B.'   , u'zum beispiel '),
        (u'z.T.'    , u'zum teil '),
        (u'z. T.'   , u'zum teil '),
        (u'z.Zt.'   , u'zur zeit '),
        (u'z. Zt.'  , u'zur zeit '),
        (u'GHz'     , u'gigahertz '),
        (u'\ufeff'  , u' '),
        (u'\u2019'  , u' '),
        (u'\xa0'    , u' '),
        (u'\u203a'  , u' '),
        (u'\u2039'  , u' '),
        (u'&'       , u'und'),
        (u'\xa020'  , u' '),
        (u'„'       , u' '),
        (u'“'       , u' '),
        (u'$'       , u'dollar ')
    ]


# based on code from: http://www.python-forum.de/viewtopic.php?f=11&t=22543

w1 = u"null ein zwei drei vier fünf sechs sieben acht neun zehn elf zwölf dreizehn vierzehn fünfzehn sechzehn siebzehn achtzehn neunzehn".split()
w2 = u"zwanzig dreißig vierzig fünfzig sechzig siebzig achtzig neunzig".split()
 
def zahl_in_worten(n, s=True, z=False, e=False):
    if n < 0: raise ValueError
    if n == 0 and z: return ""
    if n == 1 and s: return "eins"
    if n == 1 and e: return "eine"
    if n < 20: return w1[n]
    if n < 100:
        w = w2[(n - 20) // 10]
        if n % 10:
            w = w1[n % 10] + "und" + w
        return w
    if n < 1000:
        if n // 100 == 1:
            if z: return "einhundert" + zahl_in_worten(n % 100, z=True)
            return "hundert" + zahl_in_worten(n % 100, z=True)
        return w1[n // 100] + "hundert" + zahl_in_worten(n % 100, z=True)
    if n < 2000:
        if n < 1100:
            return  "tausend" + zahl_in_worten(n % 1000, z=True)
        return w1[n // 100] + "hundert" + zahl_in_worten(n % 100, z=True)
    if n < 1000000:
        return zahl_in_worten(n // 1000, s=False) + "tausend" + zahl_in_worten(n % 1000, z=True)
    if n < 1000000000:
        m = n // 1000000
        suff = 'millionen' if m>1 else 'million'
        return zahl_in_worten(m, s=False, e=True) + suff + zahl_in_worten(n % 1000000, z=True)
    # raise ValueError
    logging.warn('zahl_in_worten: cannot handle %s' % n)
    return str(n)

def spellout_number (m):

    numstr = m.group(0)

    # print "spellout number:", numstr

    if numstr[0].isspace():
        numstr = numstr[1:]
        res = ' '
    else:
        res = ''

    if numstr[0] == '-':
        res += 'minus '
        numstr = numstr[1:].strip()

    if not '.' in numstr:
        numstr = numstr.replace(',','.')

    parts = numstr.split ('.')

    # print repr(parts)

    res += zahl_in_worten(int(parts[0]))

    if len(parts)>1 and len(parts[1])>0:

        # spell out fractional part in digits

        res += ' komma'

        for c in parts[1]:
            res += ' ' + zahl_in_worten(int(c))
    
    return res

def tokenize (s, lang='de', keep_punctuation=False, keep_macros=False, keep_underscores=True):

    global wrt

    if lang == 'en':
        return tokenize_en(s, keep_punctuation, keep_macros, keep_underscores)

    if lang != 'de':
        # FIXME
        raise Exception ("FIXME: implement tokenizer support for language: " + lang)

    # print '#1', s

    for san in symb_abbrev_norm:
        srch = san[0]
        repl = san[1]

        s = s.replace (srch, repl)

    # print '#2', s

    # deal with numbers
    s = NUMBER_PATTERN_START.sub(spellout_number, s)
    s = NUMBER_PATTERN_SPACE.sub(spellout_number, s)

    # deal with punctuation
    if keep_punctuation:
        for p in PUNCTUATION:
            s = s.replace (p, u' ' + p + u' ')
    else:
        for p in PUNCTUATION:
            s = s.replace(p,' ')
        if not keep_macros:
            for p in MACRO_PUNCTUATION:
                s = s.replace(p,' ')
        if not keep_underscores:
            s = s.replace('_',' ')

    # print '#3', s

    res = []

    words = re.split ('\s+', s)

    # print repr(words)

    for word in words:

        w = word.rstrip().replace(u'–',u'').lower()
        if len(w) > 0:

            if w in wrt:
                w = wrt[w]
        
                words2 = re.split('\s+', w)
                for w2 in words2:
                    res.append(w2)

            else:
                res.append (w)

    return res

def kill_umlauts(s):
    return s.replace(u'ß',u'ss') \
            .replace(u'Ä',u'Ae') \
            .replace(u'Ö',u'Oe') \
            .replace(u'Ü',u'Ue') \
            .replace(u'ä',u'ae') \
            .replace(u'ö',u'oe') \
            .replace(u'ü',u'ue') 

